-- MySQL dump 10.13  Distrib 5.6.12, for Linux (x86_64)
--
-- Host: localhost    Database: sdecarnyx1
-- ------------------------------------------------------
-- Server version	5.6.12

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `invGroups`
--

DROP TABLE IF EXISTS `invGroups`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `invGroups` (
  `groupID` int(11) NOT NULL,
  `categoryID` int(11) DEFAULT NULL,
  `groupName` varchar(100) DEFAULT NULL,
  `description` varchar(3000) DEFAULT NULL,
  `iconID` int(11) DEFAULT NULL,
  `useBasePrice` tinyint(1) DEFAULT NULL,
  `allowManufacture` tinyint(1) DEFAULT NULL,
  `allowRecycler` tinyint(1) DEFAULT NULL,
  `anchored` tinyint(1) DEFAULT NULL,
  `anchorable` tinyint(1) DEFAULT NULL,
  `fittableNonSingleton` tinyint(1) DEFAULT NULL,
  `published` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`groupID`),
  KEY `invGroups_IX_category` (`categoryID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `invGroups`
--

LOCK TABLES `invGroups` WRITE;
/*!40000 ALTER TABLE `invGroups` DISABLE KEYS */;
INSERT INTO `invGroups` VALUES (0,0,'#System',NULL,NULL,0,NULL,NULL,0,0,0,0),(1,1,'Character',NULL,NULL,0,NULL,NULL,0,0,0,0),(2,1,'Corporation',NULL,NULL,0,NULL,NULL,0,0,0,0),(3,2,'Region',NULL,NULL,0,NULL,NULL,0,0,0,0),(4,2,'Constellation',NULL,NULL,0,NULL,NULL,0,0,0,0),(5,2,'Solar System',NULL,NULL,0,NULL,NULL,0,0,0,0),(6,2,'Sun',NULL,NULL,0,NULL,NULL,0,0,0,0),(7,2,'Planet',NULL,NULL,0,NULL,NULL,0,0,0,0),(8,2,'Moon',NULL,NULL,0,NULL,NULL,0,0,0,0),(9,2,'Asteroid Belt',NULL,15,0,NULL,NULL,0,0,0,0),(10,2,'Stargate',NULL,NULL,0,NULL,NULL,0,0,0,0),(11,2,'Asteroid OLD',NULL,15,0,NULL,NULL,1,0,0,0),(12,2,'Cargo Container',NULL,16,1,NULL,NULL,0,0,0,1),(13,2,'Ring',NULL,0,0,NULL,NULL,0,0,0,0),(14,2,'Biomass',NULL,0,0,NULL,NULL,0,0,0,1),(15,3,'Station',NULL,NULL,0,NULL,NULL,1,0,0,0),(16,3,'Station Services',NULL,NULL,0,NULL,NULL,0,0,0,0),(17,4,'Money',NULL,21,0,NULL,NULL,0,0,0,0),(18,4,'Mineral',NULL,22,1,NULL,NULL,0,0,0,1),(19,1,'Faction',NULL,NULL,0,NULL,NULL,0,0,0,0),(20,4,'Drug',NULL,31,0,NULL,NULL,0,0,0,0),(23,5,'Clone',NULL,34,1,NULL,NULL,0,0,0,0),(24,5,'Voucher',NULL,NULL,0,NULL,NULL,0,0,0,0),(25,6,'Frigate',NULL,NULL,0,NULL,NULL,0,0,0,1),(26,6,'Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(27,6,'Battleship',NULL,NULL,0,NULL,NULL,0,0,0,1),(28,6,'Industrial',NULL,NULL,0,NULL,NULL,0,0,0,1),(29,6,'Capsule',NULL,73,0,NULL,NULL,0,0,0,0),(30,6,'Titan',NULL,NULL,0,NULL,NULL,0,0,0,1),(31,6,'Shuttle',NULL,0,0,NULL,NULL,0,0,0,1),(32,1,'Alliance',NULL,NULL,0,NULL,NULL,0,0,0,0),(38,7,'Shield Extender',NULL,82,0,NULL,NULL,0,0,0,1),(39,7,'Shield Recharger',NULL,83,0,NULL,NULL,0,0,0,1),(40,7,'Shield Booster',NULL,84,0,NULL,NULL,0,0,0,1),(41,7,'Remote Shield Booster',NULL,86,0,NULL,NULL,0,0,0,1),(43,7,'Capacitor Recharger',NULL,90,0,NULL,NULL,0,0,0,1),(46,7,'Propulsion Module',NULL,96,0,NULL,NULL,0,0,0,1),(47,7,'Cargo Scanner',NULL,106,0,NULL,NULL,0,0,0,1),(48,7,'Ship Scanner',NULL,107,0,NULL,NULL,0,0,0,1),(49,7,'Survey Scanner',NULL,107,0,NULL,NULL,0,0,0,1),(52,7,'Warp Scrambler',NULL,111,0,NULL,NULL,0,0,0,1),(53,7,'Energy Weapon',NULL,355,0,NULL,NULL,0,0,0,1),(54,7,'Mining Laser',NULL,138,0,NULL,NULL,0,0,0,1),(55,7,'Projectile Weapon',NULL,384,0,NULL,NULL,0,0,0,1),(56,7,'Missile Launcher',NULL,168,0,NULL,NULL,0,0,0,0),(57,7,'Shield Power Relay',NULL,0,0,NULL,NULL,0,0,0,1),(59,7,'Gyrostabilizer',NULL,0,0,NULL,NULL,0,0,0,1),(60,7,'Damage Control',NULL,0,0,NULL,NULL,0,0,0,1),(61,7,'Capacitor Battery',NULL,0,0,NULL,NULL,0,0,0,1),(62,7,'Armor Repair Unit',NULL,0,0,NULL,NULL,0,0,0,1),(63,7,'Hull Repair Unit',NULL,0,0,NULL,NULL,0,0,0,1),(65,7,'Stasis Web',NULL,0,0,NULL,NULL,0,0,0,1),(67,7,'Remote Capacitor Transmitter',NULL,0,0,NULL,NULL,0,0,0,1),(68,7,'Energy Vampire',NULL,0,0,NULL,NULL,0,0,0,1),(71,7,'Energy Destabilizer',NULL,0,0,NULL,NULL,0,0,0,1),(72,7,'Smart Bomb',NULL,0,0,NULL,NULL,0,0,0,1),(74,7,'Hybrid Weapon',NULL,370,0,NULL,NULL,0,0,0,1),(76,7,'Capacitor Booster',NULL,1031,0,NULL,NULL,0,0,0,1),(77,7,'Shield Hardener',NULL,0,0,NULL,NULL,0,0,0,1),(78,7,'Reinforced Bulkhead',NULL,0,0,NULL,NULL,0,0,0,1),(80,7,'ECM Burst',NULL,0,0,NULL,NULL,0,0,0,1),(82,7,'Passive Targeting System',NULL,0,0,NULL,NULL,0,0,0,1),(83,8,'Projectile Ammo',NULL,1296,0,NULL,NULL,0,0,1,1),(85,8,'Hybrid Charge',NULL,1325,0,NULL,NULL,0,0,1,1),(86,8,'Frequency Crystal',NULL,1142,0,NULL,NULL,0,0,1,1),(87,8,'Capacitor Booster Charge',NULL,1033,0,NULL,NULL,0,0,1,1),(88,8,'Light Defender Missile',NULL,192,0,NULL,NULL,0,0,1,1),(89,8,'Torpedo',NULL,1349,0,NULL,NULL,0,0,1,1),(90,8,'Bomb',NULL,3278,0,NULL,NULL,0,0,1,1),(92,8,'Mine',NULL,0,0,NULL,NULL,0,0,0,0),(94,10,'Trading',NULL,NULL,0,NULL,NULL,0,0,0,0),(95,10,'Trade Session',NULL,NULL,0,NULL,NULL,0,0,0,0),(96,7,'Automated Targeting System',NULL,0,0,NULL,NULL,0,0,0,1),(97,18,'Proximity Drone',NULL,0,0,NULL,NULL,0,0,0,0),(98,7,'Armor Coating',NULL,0,0,NULL,NULL,0,0,0,1),(99,11,'Sentry Gun',NULL,0,0,NULL,NULL,1,0,0,0),(100,18,'Combat Drone',NULL,0,0,NULL,NULL,0,0,0,1),(101,18,'Mining Drone',NULL,0,0,NULL,NULL,0,0,0,1),(104,9,'Clone Blueprint',NULL,34,1,NULL,NULL,0,0,0,1),(105,9,'Frigate Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(106,9,'Cruiser Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(107,9,'Battleship Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(108,9,'Industrial Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(109,9,'Capsule Blueprint',NULL,73,1,NULL,NULL,0,0,0,1),(110,9,'Titan Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(111,9,'Shuttle Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(118,9,'Shield Extender Blueprint',NULL,82,1,NULL,NULL,0,0,0,1),(119,9,'Shield Recharger Blueprint',NULL,83,1,NULL,NULL,0,0,0,1),(120,9,'Shield Booster Blueprint',NULL,84,1,NULL,NULL,0,0,0,1),(121,9,'Remote Shield Booster Blueprint',NULL,86,1,NULL,NULL,0,0,0,1),(123,9,'Capacitor Recharger Blueprint',NULL,90,1,NULL,NULL,0,0,0,1),(126,9,'Propulsion Module Blueprint',NULL,96,1,NULL,NULL,0,0,0,1),(127,9,'Cargo Scanner Blueprint',NULL,106,1,NULL,NULL,0,0,0,1),(128,9,'Ship Scanner Blueprint',NULL,107,1,NULL,NULL,0,0,0,1),(129,9,'Survey Scanner Blueprint',NULL,107,1,NULL,NULL,0,0,0,1),(130,9,'ECM Blueprint',NULL,109,1,NULL,NULL,0,0,0,1),(131,9,'ECCM Blueprint',NULL,110,1,NULL,NULL,0,0,0,1),(132,9,'Warp Scrambler Blueprint',NULL,111,1,NULL,NULL,0,0,0,1),(133,9,'Energy Weapon Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(134,9,'Mining Laser Blueprint',NULL,138,1,NULL,NULL,0,0,0,1),(135,9,'Projectile Weapon Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(136,9,'Missile Launcher Blueprint',NULL,168,1,NULL,NULL,0,0,0,1),(137,9,'Power Manager Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(139,9,'Fast Loader Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(140,9,'Damage Control Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(141,9,'Capacitor Battery Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(142,9,'Armor Repair Unit Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(143,9,'Hull Repair Unit Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(145,9,'Stasis Web Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(147,9,'Remote Capacitor Transmitter Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(148,9,'Energy Vampire Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(151,9,'Energy Destabilizer Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(152,9,'Smart Bomb Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(154,9,'Hybrid Weapon Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(156,9,'Capacitor Booster Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(157,9,'Shield Hardener Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(158,9,'Hull Mods Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(160,9,'ECM Burst Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(161,9,'Passive Targeting System Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(162,9,'Automated Targeting System Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(163,9,'Armor Coating Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(165,9,'Projectile Ammo Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(166,9,'Missile Blueprint',NULL,182,1,NULL,NULL,0,0,0,1),(167,9,'Hybrid Charge Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(168,9,'Frequency Crystal Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(169,9,'Capacitor Booster Charge Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(170,9,'Defender Missile Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(172,9,'Bomb Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(174,9,'Mine Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(175,9,'Proximity Drone Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(176,9,'Combat Drone Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(177,9,'Mining Drone Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(178,9,'Drug Blueprint',NULL,21,1,NULL,NULL,0,0,0,1),(180,11,'Protective Sentry Gun',NULL,NULL,0,NULL,NULL,0,0,0,0),(182,11,'Police Drone',NULL,NULL,0,NULL,NULL,0,0,0,0),(185,11,'Pirate Drone',NULL,0,0,NULL,NULL,0,0,0,0),(186,2,'Wreck',NULL,0,0,NULL,NULL,0,0,0,0),(190,14,'Bloodline Bonus',NULL,0,0,NULL,NULL,0,0,0,0),(191,14,'Physical Benefit',NULL,0,0,NULL,NULL,0,0,0,0),(192,14,'Physical Handicap',NULL,0,0,NULL,NULL,0,0,0,0),(193,14,'Phobia Handicap',NULL,0,0,NULL,NULL,0,0,0,0),(194,14,'Social Handicap',NULL,0,0,NULL,NULL,0,0,0,0),(195,14,'Amarr Education',NULL,0,0,NULL,NULL,0,0,0,0),(196,14,'Caldari Education',NULL,0,0,NULL,NULL,0,0,0,0),(197,14,'Gallente Education',NULL,0,0,NULL,NULL,0,0,0,0),(198,14,'Minmatar Education',NULL,0,0,NULL,NULL,0,0,0,0),(199,14,'Career Bonus',NULL,0,0,NULL,NULL,0,0,0,0),(201,7,'ECM',NULL,0,0,NULL,NULL,0,0,0,1),(202,7,'ECCM',NULL,0,0,NULL,NULL,0,0,0,1),(203,7,'Sensor Backup Array',NULL,0,0,NULL,NULL,0,0,0,1),(205,7,'Heat Sink',NULL,0,0,NULL,NULL,0,0,0,1),(208,7,'Remote Sensor Damper',NULL,105,0,NULL,NULL,0,0,0,1),(209,7,'Remote Tracking Computer',NULL,3346,0,NULL,NULL,0,0,0,1),(210,7,'Signal Amplifier',NULL,0,0,NULL,NULL,0,0,0,1),(211,7,'Tracking Enhancer',NULL,0,0,NULL,NULL,0,0,0,1),(212,7,'Sensor Booster',NULL,74,0,NULL,NULL,0,0,0,1),(213,7,'Tracking Computer',NULL,3346,0,NULL,NULL,0,0,0,1),(218,9,'Heat Sink Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(223,9,'Sensor Booster Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(224,9,'Tracking Computer Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(225,7,'Cheat Module Group',NULL,0,0,NULL,NULL,0,0,0,0),(226,2,'Large Collidable Object',NULL,NULL,0,NULL,NULL,1,0,0,0),(227,2,'Cloud',NULL,0,0,NULL,NULL,0,0,0,0),(237,6,'Rookie ship',NULL,0,0,NULL,NULL,0,0,0,1),(255,16,'Gunnery',NULL,NULL,1,NULL,NULL,0,0,0,1),(256,16,'Missiles',NULL,NULL,1,NULL,NULL,0,0,0,1),(257,16,'Spaceship Command',NULL,NULL,1,NULL,NULL,0,0,0,1),(258,16,'Leadership',NULL,NULL,1,NULL,NULL,0,0,0,1),(266,16,'Corporation Management',NULL,NULL,1,NULL,NULL,0,0,0,1),(267,17,'Obsolete Books',NULL,NULL,1,NULL,NULL,0,0,0,0),(268,16,'Production',NULL,NULL,1,NULL,NULL,0,0,0,1),(269,16,'Rigging',NULL,NULL,1,NULL,NULL,0,0,0,1),(270,16,'Science',NULL,NULL,1,NULL,NULL,0,0,0,1),(272,16,'Electronic Systems',NULL,NULL,1,NULL,NULL,0,0,0,1),(273,16,'Drones',NULL,NULL,1,NULL,NULL,0,0,0,1),(274,16,'Trade',NULL,NULL,1,NULL,NULL,0,0,0,1),(275,16,'Navigation',NULL,NULL,1,NULL,NULL,0,0,0,1),(278,16,'Social',NULL,NULL,1,NULL,NULL,0,0,0,1),(279,11,'LCO Drone',NULL,0,0,NULL,NULL,0,0,0,0),(280,17,'General',NULL,0,1,NULL,NULL,0,0,0,1),(281,17,'Frozen',NULL,0,1,NULL,NULL,0,0,0,1),(282,17,'Radioactive',NULL,0,1,NULL,NULL,0,0,0,1),(283,17,'Livestock',NULL,0,1,NULL,NULL,0,0,0,1),(284,17,'Biohazard',NULL,0,1,NULL,NULL,0,0,0,1),(285,7,'CPU Enhancer',NULL,0,0,NULL,NULL,0,0,0,1),(286,11,'Minor Threat',NULL,0,0,NULL,NULL,0,0,0,0),(287,11,'Rogue Drone',NULL,NULL,0,NULL,NULL,0,0,0,0),(288,11,'Faction Drone',NULL,0,0,NULL,NULL,0,0,0,0),(289,7,'Projected ECCM',NULL,NULL,0,NULL,NULL,0,0,0,1),(290,7,'Remote Sensor Booster',NULL,74,0,NULL,NULL,0,0,0,1),(291,7,'Tracking Disruptor',NULL,1639,0,NULL,NULL,0,0,0,1),(295,7,'Shield Amplifier',NULL,82,0,NULL,NULL,0,0,0,1),(296,9,'Shield Amplifier Blueprint',NULL,82,1,NULL,NULL,0,0,0,1),(297,11,'Convoy',NULL,0,0,NULL,NULL,0,0,0,0),(298,11,'Convoy Drone',NULL,0,0,NULL,NULL,0,0,0,0),(299,18,'Repair Drone',NULL,0,0,NULL,NULL,0,0,0,0),(300,20,'Cyberimplant',NULL,0,1,NULL,NULL,0,0,0,1),(301,11,'Concord Drone',NULL,0,0,NULL,NULL,0,0,0,0),(302,7,'Magnetic Field Stabilizer',NULL,0,0,NULL,NULL,0,0,0,1),(303,20,'Booster',NULL,0,0,NULL,NULL,0,0,0,1),(304,20,'DNA Mutator',NULL,0,0,NULL,NULL,0,0,0,0),(305,2,'Comet',NULL,0,0,NULL,NULL,0,0,0,0),(306,11,'Spawn Container',NULL,0,0,NULL,NULL,1,0,0,0),(307,2,'Construction Platform',NULL,0,0,NULL,NULL,0,1,0,1),(308,7,'Countermeasure Launcher',NULL,0,0,NULL,NULL,0,0,0,0),(309,7,'Autopilot',NULL,0,0,NULL,NULL,0,0,0,0),(310,2,'Beacon',NULL,0,0,NULL,NULL,1,0,0,0),(311,23,'Reprocessing Array',NULL,0,1,NULL,NULL,0,1,0,1),(312,2,'Planetary Cloud',NULL,0,0,NULL,NULL,0,0,0,0),(313,17,'Drugs',NULL,0,1,NULL,NULL,0,0,0,1),(314,17,'Miscellaneous',NULL,0,1,NULL,NULL,0,0,0,1),(315,7,'Warp Core Stabilizer',NULL,0,0,NULL,NULL,0,0,0,1),(316,7,'Gang Coordinator',NULL,0,0,NULL,NULL,0,0,0,1),(317,7,'Computer Interface Node',NULL,0,0,NULL,NULL,0,0,0,0),(318,2,'Landmark',NULL,0,0,NULL,NULL,0,0,0,0),(319,11,'Large Collidable Structure',NULL,0,0,NULL,NULL,1,0,0,0),(321,7,'Shield Disruptor',NULL,0,0,NULL,NULL,0,0,0,1),(323,11,'Billboard',NULL,0,0,NULL,NULL,1,0,0,0),(324,6,'Assault Frigate',NULL,0,0,NULL,NULL,0,0,0,1),(325,7,'Remote Armor Repairer',NULL,0,0,NULL,NULL,0,0,0,1),(326,7,'Armor Plating Energized',NULL,0,0,NULL,NULL,0,0,0,1),(328,7,'Armor Hardener',NULL,0,0,NULL,NULL,0,0,0,1),(329,7,'Armor Reinforcer',NULL,0,0,NULL,NULL,0,0,0,1),(330,7,'Cloaking Device',NULL,0,0,NULL,NULL,0,0,0,1),(332,17,'Tool',NULL,0,0,NULL,NULL,0,0,0,1),(333,17,'Datacores',NULL,0,0,NULL,NULL,0,0,0,1),(334,17,'Construction Components',NULL,0,0,NULL,NULL,0,0,0,1),(335,11,'Temporary Cloud',NULL,0,0,NULL,NULL,1,0,0,0),(336,2,'Mobile Sentry Gun',NULL,0,0,NULL,NULL,0,1,0,0),(337,11,'Mission Drone',NULL,0,0,NULL,NULL,0,0,0,0),(338,7,'Shield Boost Amplifier',NULL,0,0,NULL,NULL,0,0,0,1),(339,7,'Auxiliary Power Core',NULL,0,0,NULL,NULL,0,0,0,1),(340,2,'Secure Cargo Container',NULL,0,1,NULL,NULL,0,1,0,1),(341,7,'Signature Scrambling',NULL,0,0,NULL,NULL,0,0,0,0),(342,9,'Anti Warp Scrambler Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(343,9,'Tracking Disruptor Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(344,9,'Tracking Enhancer Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(345,9,'Remote Tracking Computer Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(346,9,'Co-Processor Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(347,9,'Signal Amplifier Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(348,9,'Armor Hardener Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(349,9,'Armor Reinforcer Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(350,9,'Remote Armor Repairer Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(352,9,'Auxiliary Power Core Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(353,7,'QA Module',NULL,0,0,NULL,NULL,0,0,0,0),(355,17,'Refinables',NULL,0,0,NULL,NULL,0,0,0,1),(356,9,'Tool Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(357,7,'DroneBayExpander',NULL,0,0,NULL,NULL,0,0,0,0),(358,6,'Heavy Assault Cruiser',NULL,0,0,NULL,NULL,0,0,0,1),(360,9,'Shield Boost Amplifier Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(361,22,'Mobile Warp Disruptor',NULL,0,0,NULL,NULL,0,1,0,1),(363,23,'Ship Maintenance Array',NULL,0,1,NULL,NULL,0,1,0,1),(364,23,'Mobile Storage',NULL,0,0,NULL,NULL,0,1,0,0),(365,23,'Control Tower',NULL,0,1,NULL,NULL,0,1,0,1),(366,2,'Warp Gate',NULL,0,0,NULL,NULL,1,0,0,0),(367,7,'Ballistic Control system',NULL,0,0,NULL,NULL,0,0,0,1),(368,2,'Global Warp Disruptor',NULL,0,0,NULL,NULL,1,0,0,0),(369,17,'Ship Logs',NULL,0,1,NULL,NULL,0,0,0,1),(370,17,'Criminal Tags',NULL,0,1,NULL,NULL,0,0,0,1),(371,9,'Mobile Warp Disruptor Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(372,8,'Advanced Autocannon Ammo',NULL,1296,0,NULL,NULL,0,0,1,1),(373,8,'Advanced Railgun Charge',NULL,1321,0,NULL,NULL,0,0,1,1),(374,8,'Advanced Beam Laser Crystal',NULL,1145,0,NULL,NULL,0,0,1,1),(375,8,'Advanced Pulse Laser Crystal',NULL,1140,0,NULL,NULL,0,0,1,1),(376,8,'Advanced Artillery Ammo',NULL,1292,0,NULL,NULL,0,0,1,1),(377,8,'Advanced Blaster Charge',NULL,1317,0,NULL,NULL,0,0,1,1),(378,7,'Cruise Control',NULL,0,0,NULL,NULL,0,0,0,0),(379,7,'Target Painter',NULL,0,0,NULL,NULL,0,0,0,1),(380,6,'Deep Space Transport',NULL,0,0,NULL,NULL,0,0,0,1),(381,6,'Elite Battleship',NULL,0,1,NULL,NULL,0,0,0,0),(382,2,'Shipping Crates',NULL,0,0,NULL,NULL,0,0,0,0),(383,11,'Destructible Sentry Gun',NULL,0,0,NULL,NULL,1,0,0,0),(384,8,'Light Missile',NULL,192,0,NULL,NULL,0,0,1,1),(385,8,'Heavy Missile',NULL,188,0,NULL,NULL,0,0,1,1),(386,8,'Cruise Missile',NULL,182,0,NULL,NULL,0,0,1,1),(387,8,'Rocket',NULL,1352,0,NULL,NULL,0,0,1,1),(394,8,'FoF Light Missile',NULL,1336,0,NULL,NULL,0,0,1,1),(395,8,'FoF Heavy Missile',NULL,1339,0,NULL,NULL,0,0,1,1),(396,8,'FoF Cruise Missile',NULL,1344,0,NULL,NULL,0,0,1,1),(397,23,'Assembly Array',NULL,0,1,NULL,NULL,0,1,0,1),(400,9,'Ballistic Control System Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(401,9,'Cloaking Device Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(404,23,'Silo',NULL,0,1,NULL,NULL,0,1,0,1),(405,7,'Anti Cloaking Pulse',NULL,0,0,NULL,NULL,0,0,0,0),(406,7,'Smartbomb Supercharger',NULL,0,0,NULL,NULL,0,0,0,0),(407,7,'Drone Control Unit',NULL,0,0,NULL,NULL,0,0,0,1),(408,9,'Drone Control Unit Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(409,17,'Empire Insignia Drops',NULL,0,1,NULL,NULL,0,0,0,1),(410,9,'Anti Cloaking Pulse Blueprint',NULL,0,1,NULL,NULL,0,0,0,0),(411,2,'Force Field',NULL,0,0,NULL,NULL,1,0,0,0),(413,23,'Laboratory',NULL,0,1,NULL,NULL,0,1,0,1),(414,23,'Mobile Power Core',NULL,0,0,NULL,NULL,0,1,0,0),(416,23,'Moon Mining',NULL,0,1,NULL,NULL,0,1,0,1),(417,23,'Mobile Missile Sentry',NULL,0,1,NULL,NULL,0,1,0,1),(418,23,'Mobile Shield Generator',NULL,0,0,NULL,NULL,0,1,0,0),(419,6,'Combat Battlecruiser',NULL,0,0,NULL,NULL,0,0,0,1),(420,6,'Destroyer',NULL,0,0,NULL,NULL,0,0,0,1),(422,4,'Gas Isotopes',NULL,0,0,NULL,NULL,0,0,0,0),(423,4,'Ice Product',NULL,0,1,NULL,NULL,0,0,0,1),(425,8,'Orbital Assault Unit',NULL,0,0,NULL,NULL,0,0,1,0),(426,23,'Mobile Projectile Sentry',NULL,0,1,NULL,NULL,0,1,0,1),(427,4,'Moon Materials',NULL,0,1,NULL,NULL,0,0,0,1),(428,4,'Intermediate Materials',NULL,0,1,NULL,NULL,0,0,0,1),(429,4,'Composite',NULL,0,1,NULL,NULL,0,0,0,1),(430,23,'Mobile Laser Sentry',NULL,0,1,NULL,NULL,0,1,0,1),(435,11,'Deadspace Overseer',NULL,0,0,NULL,NULL,0,0,0,0),(436,24,'Simple Reaction',NULL,2665,1,NULL,NULL,0,0,0,1),(438,23,'Mobile Reactor',NULL,0,1,NULL,NULL,0,1,0,1),(439,23,'Electronic Warfare Battery',NULL,0,1,NULL,NULL,0,1,0,1),(440,23,'Sensor Dampening Battery',NULL,0,1,NULL,NULL,0,1,0,1),(441,23,'Stasis Webification Battery',NULL,0,1,NULL,NULL,0,1,0,1),(443,23,'Warp Scrambling Battery',NULL,0,1,NULL,NULL,0,1,0,1),(444,23,'Shield Hardening Array',NULL,0,1,NULL,NULL,0,1,0,1),(445,23,'Force Field Array',NULL,0,1,NULL,NULL,0,1,0,0),(446,11,'Customs Official',NULL,0,0,NULL,NULL,0,0,0,0),(447,9,'Construction Component Blueprints',NULL,NULL,1,NULL,NULL,0,0,0,1),(448,2,'Audit Log Secure Container',NULL,NULL,1,NULL,NULL,0,1,0,1),(449,23,'Mobile Hybrid Sentry',NULL,0,1,NULL,NULL,0,1,0,1),(450,25,'Arkonor',NULL,15,0,NULL,NULL,1,0,0,1),(451,25,'Bistot',NULL,15,0,NULL,NULL,1,0,0,1),(452,25,'Crokite',NULL,15,0,NULL,NULL,1,0,0,1),(453,25,'Dark Ochre',NULL,15,0,NULL,NULL,1,0,0,1),(454,25,'Hedbergite',NULL,15,0,NULL,NULL,1,0,0,1),(455,25,'Hemorphite',NULL,15,0,NULL,NULL,1,0,0,1),(456,25,'Jaspet',NULL,15,0,NULL,NULL,1,0,0,1),(457,25,'Kernite',NULL,15,0,NULL,NULL,1,0,0,1),(458,25,'Plagioclase',NULL,15,0,NULL,NULL,1,0,0,1),(459,25,'Pyroxeres',NULL,15,0,NULL,NULL,1,0,0,1),(460,25,'Scordite',NULL,15,0,NULL,NULL,1,0,0,1),(461,25,'Spodumain',NULL,15,0,NULL,NULL,1,0,0,1),(462,25,'Veldspar',NULL,15,0,NULL,NULL,1,0,0,1),(463,6,'Mining Barge',NULL,0,0,NULL,NULL,0,0,0,1),(464,7,'Strip Miner',NULL,0,0,NULL,NULL,0,0,0,1),(465,25,'Ice',NULL,15,0,NULL,NULL,1,0,0,1),(467,25,'Gneiss',NULL,15,0,NULL,NULL,1,0,0,1),(468,25,'Mercoxit',NULL,15,0,NULL,NULL,1,0,0,1),(469,25,'Omber',NULL,15,0,NULL,NULL,1,0,0,1),(470,18,'Unanchoring Drone',NULL,0,0,NULL,NULL,0,0,0,0),(471,23,'Corporate Hangar Array',NULL,0,1,NULL,NULL,0,1,0,1),(472,7,'System Scanner',NULL,0,0,NULL,NULL,0,0,0,1),(473,23,'Tracking Array',NULL,0,1,NULL,NULL,0,1,0,1),(474,17,'Acceleration Gate Keys',NULL,0,0,NULL,NULL,0,0,0,1),(475,7,'Microwarpdrive',NULL,96,0,NULL,NULL,0,0,0,0),(476,8,'Citadel Torpedo',NULL,1349,0,NULL,NULL,0,0,1,1),(477,9,'Mining Barge Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(478,9,'System Scanner Blueprint',NULL,0,0,NULL,NULL,0,0,0,1),(479,8,'Scanner Probe',NULL,2222,0,NULL,NULL,0,0,1,1),(480,23,'Stealth Emitter Array',NULL,0,0,NULL,NULL,0,1,0,0),(481,7,'Scan Probe Launcher',NULL,2677,0,NULL,NULL,0,0,0,1),(482,8,'Mining Crystal',NULL,2660,0,NULL,NULL,0,0,1,1),(483,7,'Frequency Mining Laser',NULL,138,0,NULL,NULL,0,0,0,1),(484,24,'Complex Reactions',NULL,2666,1,NULL,NULL,0,0,0,1),(485,6,'Dreadnought',NULL,0,0,NULL,NULL,0,0,0,1),(486,9,'Scan Probe Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(487,9,'Destroyer Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(489,9,'Battlecruiser Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(490,9,'Strip Miner Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(492,8,'Survey Probe',NULL,2663,1,NULL,NULL,0,0,1,1),(493,17,'Overseer Personal Effects',NULL,0,1,NULL,NULL,0,0,0,1),(494,11,'Deadspace Overseer\'s Structure',NULL,0,0,NULL,NULL,1,0,0,0),(495,11,'Deadspace Overseer\'s Sentry',NULL,0,0,NULL,NULL,1,0,0,0),(496,11,'Deadspace Overseer\'s Belongings',NULL,0,0,NULL,NULL,1,0,0,0),(497,8,'Fuel',NULL,0,0,NULL,NULL,0,0,1,0),(498,8,'Modifications',NULL,0,0,NULL,NULL,0,0,1,0),(499,7,'New EW Testing',NULL,0,0,NULL,NULL,0,0,0,0),(500,8,'Festival Charges',NULL,0,0,NULL,NULL,0,0,1,1),(501,7,'Festival Launcher',NULL,0,0,NULL,NULL,0,0,0,1),(502,2,'Cosmic Signature',NULL,0,0,NULL,NULL,1,0,0,0),(503,9,'Elite Industrial Blueprint',NULL,0,0,NULL,NULL,0,0,0,1),(504,9,'Target Painter Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(505,16,'Fake Skills',NULL,0,0,NULL,NULL,0,0,0,0),(506,7,'Missile Launcher Cruise',NULL,2530,0,NULL,NULL,0,0,0,1),(507,7,'Missile Launcher Rocket',NULL,1345,0,NULL,NULL,0,0,0,1),(508,7,'Missile Launcher Torpedo',NULL,170,0,NULL,NULL,0,0,0,1),(509,7,'Missile Launcher Light',NULL,168,0,NULL,NULL,0,0,0,1),(510,7,'Missile Launcher Heavy',NULL,169,0,NULL,NULL,0,0,0,1),(511,7,'Missile Launcher Rapid Light',NULL,1345,0,NULL,NULL,0,0,0,1),(512,7,'Missile Launcher Defender',NULL,0,0,NULL,NULL,0,0,0,1),(513,6,'Freighter',NULL,0,0,NULL,NULL,0,0,0,1),(514,7,'ECM Stabilizer',NULL,0,0,NULL,NULL,0,0,0,1),(515,7,'Siege Module',NULL,0,0,NULL,NULL,0,0,0,1),(516,9,'Siege Module Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(517,2,'Agents in Space',NULL,0,0,NULL,NULL,1,0,0,0),(518,7,'Anti Ballistic Defense System',NULL,0,0,NULL,NULL,0,0,0,0),(519,25,'Terran Artifacts',NULL,0,1,NULL,NULL,0,0,0,0),(520,11,'Storyline Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(521,17,'Identification',NULL,0,0,NULL,NULL,0,0,0,1),(522,11,'Storyline Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(523,11,'Storyline Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(524,7,'Missile Launcher Citadel',NULL,2839,0,NULL,NULL,0,0,0,1),(525,9,'Freighter Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(526,17,'Commodities',NULL,0,0,NULL,NULL,0,0,0,1),(527,11,'Storyline Mission Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(528,17,'Artifacts and Prototypes',NULL,0,0,NULL,NULL,0,0,0,1),(530,17,'Materials and Compounds',NULL,0,0,NULL,NULL,0,0,0,1),(532,9,'Gang Coordinator Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(533,11,'Storyline Mission Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(534,11,'Storyline Mission Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(535,9,'Construction Platform Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(536,17,'Station Components',NULL,0,1,NULL,NULL,0,0,0,1),(537,9,'Dreadnought Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(538,7,'Data Miners',NULL,0,0,NULL,NULL,0,0,0,1),(540,6,'Command Ship',NULL,0,0,NULL,NULL,0,0,0,1),(541,6,'Interdictor',NULL,0,0,NULL,NULL,0,0,0,1),(543,6,'Exhumer',NULL,0,0,NULL,NULL,0,0,0,1),(544,18,'Cap Drain Drone',NULL,0,0,NULL,NULL,0,0,0,1),(545,18,'Warp Scrambling Drone',NULL,0,0,NULL,NULL,0,0,0,0),(546,7,'Mining Upgrade',NULL,0,0,NULL,NULL,0,0,0,1),(547,6,'Carrier',NULL,0,0,NULL,NULL,0,0,0,1),(548,8,'Interdiction Probe',NULL,1721,0,NULL,NULL,0,0,1,1),(549,18,'Fighter Drone',NULL,0,0,NULL,NULL,0,0,0,1),(550,11,'Asteroid Angel Cartel Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(551,11,'Asteroid Angel Cartel Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(552,11,'Asteroid Angel Cartel Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(553,11,'Asteroid Angel Cartel Officer',NULL,0,0,NULL,NULL,0,0,0,0),(554,11,'Asteroid Angel Cartel Hauler',NULL,0,0,NULL,NULL,0,0,0,0),(555,11,'Asteroid Blood Raiders Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(556,11,'Asteroid Blood Raiders Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(557,11,'Asteroid Blood Raiders Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(558,11,'Asteroid Blood Raiders Hauler',NULL,0,0,NULL,NULL,0,0,0,0),(559,11,'Asteroid Blood Raiders Officer',NULL,0,0,NULL,NULL,0,0,0,0),(560,11,'Asteroid Guristas Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(561,11,'Asteroid Guristas Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(562,11,'Asteroid Guristas Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(563,11,'Asteroid Guristas Hauler',NULL,0,0,NULL,NULL,0,0,0,0),(564,11,'Asteroid Guristas Officer',NULL,0,0,NULL,NULL,0,0,0,0),(565,11,'Asteroid Sansha\'s Nation Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(566,11,'Asteroid Sansha\'s Nation Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(567,11,'Asteroid Sansha\'s Nation Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(568,11,'Asteroid Sansha\'s Nation Hauler',NULL,0,0,NULL,NULL,0,0,0,0),(569,11,'Asteroid Sansha\'s Nation Officer',NULL,0,0,NULL,NULL,0,0,0,0),(570,11,'Asteroid Serpentis Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(571,11,'Asteroid Serpentis Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(572,11,'Asteroid Serpentis Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(573,11,'Asteroid Serpentis Hauler',NULL,0,0,NULL,NULL,0,0,0,0),(574,11,'Asteroid Serpentis Officer',NULL,0,0,NULL,NULL,0,0,0,0),(575,11,'Asteroid Angel Cartel Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(576,11,'Asteroid Angel Cartel BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(577,11,'Asteroid Blood Raiders Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(578,11,'Asteroid Blood Raiders BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(579,11,'Asteroid Guristas Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(580,11,'Asteroid Guristas BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(581,11,'Asteroid Sansha\'s Nation Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(582,11,'Asteroid Sansha\'s Nation BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(583,11,'Asteroid Serpentis Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(584,11,'Asteroid Serpentis BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(585,7,'Remote Hull Repairer',NULL,0,0,NULL,NULL,0,0,0,1),(586,7,'Drone Modules',NULL,0,0,NULL,NULL,0,0,0,0),(588,7,'Super Weapon',NULL,0,0,NULL,NULL,0,0,0,1),(589,7,'Interdiction Sphere Launcher',NULL,2990,0,NULL,NULL,0,0,0,1),(590,7,'Jump Portal Generator',NULL,0,0,NULL,NULL,0,0,0,1),(593,11,'Deadspace Angel Cartel BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(594,11,'Deadspace Angel Cartel Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(595,11,'Deadspace Angel Cartel Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(596,11,'Deadspace Angel Cartel Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(597,11,'Deadspace Angel Cartel Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(602,11,'Deadspace Blood Raiders BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(603,11,'Deadspace Blood Raiders Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(604,11,'Deadspace Blood Raiders Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(605,11,'Deadspace Blood Raiders Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(606,11,'Deadspace Blood Raiders Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(611,11,'Deadspace Guristas BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(612,11,'Deadspace Guristas Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(613,11,'Deadspace Guristas Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(614,11,'Deadspace Guristas Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(615,11,'Deadspace Guristas Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(620,11,'Deadspace Sansha\'s Nation BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(621,11,'Deadspace Sansha\'s Nation Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(622,11,'Deadspace Sansha\'s Nation Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(623,11,'Deadspace Sansha\'s Nation Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(624,11,'Deadspace Sansha\'s Nation Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(629,11,'Deadspace Serpentis BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(630,11,'Deadspace Serpentis Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(631,11,'Deadspace Serpentis Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(632,11,'Deadspace Serpentis Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(633,11,'Deadspace Serpentis Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(638,7,'Navigation Computer',NULL,0,0,NULL,NULL,0,0,0,0),(639,18,'Electronic Warfare Drone',NULL,0,0,NULL,NULL,0,0,0,1),(640,18,'Logistic Drone',NULL,0,0,NULL,NULL,0,0,0,1),(641,18,'Stasis Webifying Drone',NULL,0,0,NULL,NULL,0,0,0,1),(642,7,'Super Gang Enhancer',NULL,0,0,NULL,NULL,0,0,0,0),(643,9,'Carrier Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(644,7,'Drone Navigation Computer',NULL,0,0,NULL,NULL,0,0,0,1),(645,7,'Drone Damage Modules',NULL,0,0,NULL,NULL,0,0,0,1),(646,7,'Drone Tracking Modules',NULL,0,0,NULL,NULL,0,0,0,1),(647,7,'Drone Control Range Module',NULL,0,0,NULL,NULL,0,0,0,1),(648,8,'Advanced Rocket',NULL,1351,0,NULL,NULL,0,0,1,1),(649,2,'Freight Container',NULL,1174,1,NULL,NULL,0,0,0,1),(650,7,'Tractor Beam',NULL,0,0,NULL,NULL,0,0,0,1),(651,9,'Super Weapon Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(652,17,'Lease',NULL,0,1,NULL,NULL,0,0,0,1),(653,8,'Advanced Light Missile',NULL,191,0,NULL,NULL,0,0,1,1),(654,8,'Advanced Heavy Assault Missile',NULL,3235,0,NULL,NULL,0,0,1,1),(655,8,'Advanced Heavy Missile',NULL,188,0,NULL,NULL,0,0,1,1),(656,8,'Advanced Cruise Missile',NULL,184,0,NULL,NULL,0,0,1,1),(657,8,'Advanced Torpedo',NULL,1347,0,NULL,NULL,0,0,1,1),(658,7,'Cynosural Field',NULL,0,0,NULL,NULL,0,0,0,1),(659,6,'Supercarrier',NULL,0,0,NULL,NULL,0,0,0,1),(660,7,'Energy Vampire Slayer',NULL,0,0,NULL,NULL,0,0,0,0),(661,24,'Simple Biochemical Reactions',NULL,2665,0,NULL,NULL,0,0,0,1),(662,24,'Complex Biochemical Reactions',NULL,2665,0,NULL,NULL,0,0,0,1),(663,8,'Mercoxit Mining Crystal',NULL,2654,0,NULL,NULL,0,0,1,1),(665,11,'Mission Amarr Empire Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(666,11,'Mission Amarr Empire Battlecruiser',NULL,0,0,NULL,NULL,0,0,0,0),(667,11,'Mission Amarr Empire Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(668,11,'Mission Amarr Empire Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(669,11,'Mission Amarr Empire Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(670,11,'Mission Amarr Empire Other',NULL,0,0,NULL,NULL,0,0,0,0),(671,11,'Mission Caldari State Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(672,11,'Mission Caldari State Battlecruiser',NULL,0,0,NULL,NULL,0,0,0,0),(673,11,'Mission Caldari State Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(674,11,'Mission Caldari State Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(675,11,'Mission Caldari State Other',NULL,0,0,NULL,NULL,0,0,0,0),(676,11,'Mission Caldari State Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(677,11,'Mission Gallente Federation Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(678,11,'Mission Gallente Federation Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(679,11,'Mission Gallente Federation Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(680,11,'Mission Gallente Federation Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(681,11,'Mission Gallente Federation Battlecruiser',NULL,0,0,NULL,NULL,0,0,0,0),(682,11,'Mission Gallente Federation Other',NULL,0,0,NULL,NULL,0,0,0,0),(683,11,'Mission Minmatar Republic Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(684,11,'Mission Minmatar Republic Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(685,11,'Mission Minmatar Republic Battlecruiser',NULL,0,0,NULL,NULL,0,0,0,0),(686,11,'Mission Minmatar Republic Other',NULL,0,0,NULL,NULL,0,0,0,0),(687,11,'Mission Khanid Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(688,11,'Mission Khanid Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(689,11,'Mission Khanid Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(690,11,'Mission Khanid Battlecruiser',NULL,0,0,NULL,NULL,0,0,0,0),(691,11,'Mission Khanid Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(692,11,'Mission Khanid Other',NULL,0,0,NULL,NULL,0,0,0,0),(693,11,'Mission CONCORD Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(694,11,'Mission CONCORD Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(695,11,'Mission CONCORD Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(696,11,'Mission CONCORD Battlecruiser',NULL,0,0,NULL,NULL,0,0,0,0),(697,11,'Mission CONCORD Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(698,11,'Mission CONCORD Other',NULL,0,0,NULL,NULL,0,0,0,0),(699,11,'Mission Mordu Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(700,11,'Mission Mordu Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(701,11,'Mission Mordu Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(702,11,'Mission Mordu Battlecruiser',NULL,0,0,NULL,NULL,0,0,0,0),(703,11,'Mission Mordu Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(704,11,'Mission Mordu Other',NULL,0,0,NULL,NULL,0,0,0,0),(705,11,'Mission Minmatar Republic Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(706,11,'Mission Minmatar Republic Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(707,23,'Jump Portal Array',NULL,0,1,NULL,NULL,0,1,0,1),(709,23,'Scanner Array',NULL,0,1,NULL,NULL,0,1,0,1),(710,23,'Logistics Array',NULL,0,1,NULL,NULL,0,1,0,0),(711,2,'Harvestable Cloud',NULL,0,0,NULL,NULL,0,0,0,1),(712,4,'Biochemical Material',NULL,0,0,NULL,NULL,0,0,0,1),(715,11,'Destructible Agents In Space',NULL,0,0,NULL,NULL,1,0,0,0),(716,17,'Data Interfaces',NULL,0,0,NULL,NULL,0,0,0,1),(718,9,'Booster Blueprints',NULL,0,0,NULL,NULL,0,0,0,1),(721,20,'Temp',NULL,0,0,NULL,NULL,0,0,0,0),(722,9,'Advanced Hybrid Charge Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(723,9,'Tractor Beam Blueprint',NULL,349,1,NULL,NULL,0,0,0,1),(724,9,'Implant Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(725,9,'Advanced Projectile Ammo Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(726,9,'Advanced Frequency Crystal Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(727,9,'Mining Crystal Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(728,35,'Decryptors - Amarr',NULL,0,0,NULL,NULL,0,0,0,1),(729,35,'Decryptors - Minmatar',NULL,0,0,NULL,NULL,0,0,0,1),(730,35,'Decryptors - Gallente',NULL,0,0,NULL,NULL,0,0,0,1),(731,35,'Decryptors - Caldari',NULL,0,0,NULL,NULL,0,0,0,1),(732,17,'Decryptors - Sleepers',NULL,0,0,NULL,NULL,0,0,0,1),(733,17,'Decryptors - Yan Jung',NULL,0,0,NULL,NULL,0,0,0,1),(734,17,'Decryptors - Takmahl',NULL,0,0,NULL,NULL,0,0,0,1),(735,17,'Decryptors - Talocan',NULL,0,0,NULL,NULL,0,0,0,1),(737,7,'Gas Cloud Harvester',NULL,0,0,NULL,NULL,0,0,0,1),(738,20,'Cyber Armor',NULL,0,1,NULL,NULL,0,0,0,1),(739,20,'Cyber Drones',NULL,0,1,NULL,NULL,0,0,0,1),(740,20,'Cyber Electronic Systems',NULL,0,1,NULL,NULL,0,0,0,1),(741,20,'Cyber Engineering',NULL,0,1,NULL,NULL,0,0,0,1),(742,20,'Cyber Gunnery',NULL,0,1,NULL,NULL,0,0,0,1),(743,20,'Cyber Production',NULL,0,1,NULL,NULL,0,0,0,1),(744,20,'Cyber Leadership',NULL,0,1,NULL,NULL,0,0,0,1),(745,20,'Cyber Learning',NULL,0,1,NULL,NULL,0,0,0,1),(746,20,'Cyber Missile',NULL,0,1,NULL,NULL,0,0,0,1),(747,20,'Cyber Navigation',NULL,0,1,NULL,NULL,0,0,0,1),(748,20,'Cyber Science',NULL,0,1,NULL,NULL,0,0,0,1),(749,20,'Cyber Shields',NULL,0,1,NULL,NULL,0,0,0,1),(750,20,'Cyber Social',NULL,0,1,NULL,NULL,0,0,0,1),(751,20,'Cyber Trade',NULL,0,1,NULL,NULL,0,0,0,1),(753,7,'ECM Enhancer',NULL,0,0,NULL,NULL,0,0,0,0),(754,4,'Salvaged Materials',NULL,0,0,NULL,NULL,0,0,0,1),(755,11,'Asteroid Rogue Drone BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(756,11,'Asteroid Rogue Drone Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(757,11,'Asteroid Rogue Drone Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(758,11,'Asteroid Rogue Drone Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(759,11,'Asteroid Rogue Drone Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(760,11,'Asteroid Rogue Drone Hauler',NULL,0,0,NULL,NULL,0,0,0,0),(761,11,'Asteroid Rogue Drone Swarm',NULL,0,0,NULL,NULL,0,0,0,0),(762,7,'Inertial Stabilizer',NULL,0,0,NULL,NULL,0,0,0,1),(763,7,'Nanofiber Internal Structure',NULL,0,0,NULL,NULL,0,0,0,1),(764,7,'Overdrive Injector System',NULL,0,0,NULL,NULL,0,0,0,1),(765,7,'Expanded Cargohold',NULL,0,0,NULL,NULL,0,0,0,1),(766,7,'Power Diagnostic System',NULL,0,0,NULL,NULL,0,0,0,1),(767,7,'Capacitor Power Relay',NULL,0,0,NULL,NULL,0,0,0,1),(768,7,'Capacitor Flux Coil',NULL,0,0,NULL,NULL,0,0,0,1),(769,7,'Reactor Control Unit',NULL,0,0,NULL,NULL,0,0,0,1),(770,7,'Shield Flux Coil',NULL,0,0,NULL,NULL,0,0,0,1),(771,7,'Missile Launcher Heavy Assault',NULL,3241,0,NULL,NULL,0,0,0,1),(772,8,'Heavy Assault Missile',NULL,3237,0,NULL,NULL,0,0,1,1),(773,7,'Rig Armor',NULL,0,0,NULL,NULL,0,0,0,1),(774,7,'Rig Shield',NULL,0,0,NULL,NULL,0,0,0,1),(775,7,'Rig Energy Weapon',NULL,0,0,NULL,NULL,0,0,0,1),(776,7,'Rig Hybrid Weapon',NULL,0,0,NULL,NULL,0,0,0,1),(777,7,'Rig Projectile Weapon',NULL,0,0,NULL,NULL,0,0,0,1),(778,7,'Rig Drones',NULL,0,0,NULL,NULL,0,0,0,1),(779,7,'Rig Launcher',NULL,0,0,NULL,NULL,0,0,0,1),(781,7,'Rig Core',NULL,0,0,NULL,NULL,0,0,0,1),(782,7,'Rig Navigation',NULL,0,0,NULL,NULL,0,0,0,1),(783,20,'Cyber X Specials',NULL,0,1,NULL,NULL,0,0,0,0),(784,11,'Large Collidable Ship',NULL,0,0,NULL,NULL,1,0,0,0),(786,7,'Rig Electronic Systems',NULL,0,0,NULL,NULL,0,0,0,1),(787,9,'Rig Blueprint',NULL,76,1,NULL,NULL,0,0,0,1),(789,11,'Asteroid Angel Cartel Commander Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(790,11,'Asteroid Angel Cartel Commander Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(791,11,'Asteroid Blood Raiders Commander Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(792,11,'Asteroid Blood Raiders Commander Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(793,11,'Asteroid Angel Cartel Commander BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(794,11,'Asteroid Angel Cartel Commander Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(795,11,'Asteroid Blood Raiders Commander BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(796,11,'Asteroid Blood Raiders Commander Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(797,11,'Asteroid Guristas Commander BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(798,11,'Asteroid Guristas Commander Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(799,11,'Asteroid Guristas Commander Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(800,11,'Asteroid Guristas Commander Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(801,11,'Deadspace Rogue Drone BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(802,11,'Deadspace Rogue Drone Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(803,11,'Deadspace Rogue Drone Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(804,11,'Deadspace Rogue Drone Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(805,11,'Deadspace Rogue Drone Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(806,11,'Deadspace Rogue Drone Swarm',NULL,0,0,NULL,NULL,0,0,0,0),(807,11,'Asteroid Sansha\'s Nation Commander BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(808,11,'Asteroid Sansha\'s Nation Commander Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(809,11,'Asteroid Sansha\'s Nation Commander Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(810,11,'Asteroid Sansha\'s Nation Commander Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(811,11,'Asteroid Serpentis Commander BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(812,11,'Asteroid Serpentis Commander Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(813,11,'Asteroid Serpentis Commander Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(814,11,'Asteroid Serpentis Commander Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(815,7,'Clone Vat Bay',NULL,0,0,NULL,NULL,0,0,0,1),(816,11,'Mission Generic Battleships',NULL,0,0,NULL,NULL,0,0,0,0),(817,11,'Mission Generic Cruisers',NULL,0,0,NULL,NULL,0,0,0,0),(818,11,'Mission Generic Frigates',NULL,0,0,NULL,NULL,0,0,0,0),(819,11,'Deadspace Overseer Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(820,11,'Deadspace Overseer Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(821,11,'Deadspace Overseer Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(822,11,'Mission Thukker Battlecruiser',NULL,0,0,NULL,NULL,0,0,0,0),(823,11,'Mission Thukker Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(824,11,'Mission Thukker Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(825,11,'Mission Thukker Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(826,11,'Mission Thukker Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(827,11,'Mission Thukker Other',NULL,0,0,NULL,NULL,0,0,0,0),(828,11,'Mission Generic Battle Cruisers',NULL,0,0,NULL,NULL,0,0,0,0),(829,11,'Mission Generic Destroyers',NULL,0,0,NULL,NULL,0,0,0,0),(830,6,'Covert Ops',NULL,0,0,NULL,NULL,0,0,0,1),(831,6,'Interceptor',NULL,0,0,NULL,NULL,0,0,0,1),(832,6,'Logistics',NULL,0,0,NULL,NULL,0,0,0,1),(833,6,'Force Recon Ship',NULL,0,0,NULL,NULL,0,0,0,1),(834,6,'Stealth Bomber',NULL,0,0,NULL,NULL,0,0,0,1),(835,2,'Station Upgrade Platform',NULL,0,1,NULL,NULL,0,1,0,1),(836,2,'Station Improvement Platform',NULL,0,1,NULL,NULL,0,1,0,1),(837,23,'Energy Neutralizing Battery',NULL,0,1,NULL,NULL,0,1,0,1),(838,23,'Cynosural Generator Array',NULL,0,1,NULL,NULL,0,1,0,1),(839,23,'Cynosural System Jammer',NULL,0,1,NULL,NULL,0,1,0,1),(840,23,'Structure Repair Array',NULL,0,0,NULL,NULL,0,0,0,0),(841,9,'Structures - Control Tower Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(842,7,'Remote ECM Burst',NULL,0,0,NULL,NULL,0,0,0,1),(843,11,'Asteroid Rogue Drone Commander BattleCruiser',NULL,0,0,NULL,NULL,0,0,0,0),(844,11,'Asteroid Rogue Drone Commander Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(845,11,'Asteroid Rogue Drone Commander Cruiser',NULL,0,0,NULL,NULL,0,0,0,0),(846,11,'Asteroid Rogue Drone Commander Destroyer',NULL,0,0,NULL,NULL,0,0,0,0),(847,11,'Asteroid Rogue Drone Commander Frigate',NULL,0,0,NULL,NULL,0,0,0,0),(848,11,'Asteroid Angel Cartel Commander Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(849,11,'Asteroid Blood Raiders Commander Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(850,11,'Asteroid Guristas Commander Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(851,11,'Asteroid Sansha\'s Nation Commander Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(852,11,'Asteroid Serpentis Commander Battleship',NULL,0,0,NULL,NULL,0,0,0,0),(853,9,'Structures - Laser Battery Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(854,9,'Structures - Projectile Battery Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(855,9,'Structures - Hybrid Battery Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(856,9,'Structures - ECM Jamming Array Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(857,9,'Structures - Warp Scrambling Battery Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(858,9,'Structures - Stasis Webification Battery Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(859,9,'Structures - Sensor Dampening Array Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(860,9,'Structures - Energy Neutralizing Battery Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(861,11,'Mission Fighter Drone',NULL,0,0,NULL,NULL,0,0,0,0),(862,7,'Missile Launcher Bomb',NULL,2677,0,NULL,NULL,0,0,0,1),(863,8,'Bomb ECM',NULL,3283,0,NULL,NULL,0,0,1,1),(864,8,'Bomb Energy',NULL,3282,0,NULL,NULL,0,0,1,1),(865,11,'Mission Amarr Empire Carrier',NULL,0,0,NULL,NULL,1,0,0,0),(866,11,'Mission Caldari State Carrier',NULL,0,0,NULL,NULL,1,0,0,0),(867,11,'Mission Gallente Federation Carrier',NULL,0,0,NULL,NULL,1,0,0,0),(868,11,'Mission Minmatar Republic Carrier',NULL,0,0,NULL,NULL,1,0,0,0),(870,9,'Remote Hull Repairer Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(871,9,'Structures - Missile Battery Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(872,5,'Outpost Improvements',NULL,0,1,NULL,NULL,0,0,0,1),(873,17,'Capital Construction Components',NULL,0,0,NULL,NULL,0,0,0,1),(874,2,'Disruptable Station Services',NULL,0,0,NULL,NULL,0,0,0,0),(875,11,'Mission Faction Transports',NULL,0,0,NULL,NULL,0,0,0,0),(876,5,'Outpost Upgrades',NULL,0,0,NULL,NULL,0,0,0,1),(877,23,'Target Painting Battery',NULL,0,0,NULL,NULL,0,0,0,0),(878,7,'Cloak Enhancements',NULL,0,0,NULL,NULL,0,0,0,0),(879,17,'Slave Reception',NULL,0,0,NULL,NULL,0,0,0,1),(880,17,'Sleeper Components',NULL,0,1,NULL,NULL,0,0,0,1),(881,24,'Freedom Programs',NULL,0,0,NULL,NULL,0,0,0,0),(882,24,'Enslavement Programs',NULL,0,0,NULL,NULL,0,0,0,0),(883,6,'Capital Industrial Ship',NULL,0,0,NULL,NULL,0,0,0,1),(884,17,'Test Compressed Ore',NULL,0,0,NULL,NULL,0,0,0,0),(885,2,'Cosmic Anomaly',NULL,0,0,NULL,NULL,1,0,0,0),(886,4,'Rogue Drone Components',NULL,0,0,NULL,NULL,0,0,0,1),(888,9,'Ore Compression Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(889,9,'Ore Enhancement Blueprints',NULL,0,0,NULL,NULL,0,0,0,0),(890,9,'Ice Compression Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(891,9,'Structures - Mobile Laboratory Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(892,8,'Planet Satellites',NULL,0,0,NULL,NULL,0,0,0,0),(893,6,'Electronic Attack Ship',NULL,NULL,0,NULL,NULL,0,0,0,1),(894,6,'Heavy Interdiction Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(896,7,'Rig Security Transponder',NULL,0,0,NULL,NULL,0,0,0,0),(897,2,'Covert Beacon',NULL,0,0,NULL,NULL,0,0,0,0),(898,6,'Black Ops',NULL,NULL,0,NULL,NULL,0,0,0,1),(899,7,'Warp Disrupt Field Generator',NULL,0,0,NULL,NULL,0,0,0,1),(900,6,'Marauder',NULL,NULL,0,NULL,NULL,0,0,0,1),(901,7,'Mining Enhancer',NULL,0,0,NULL,NULL,0,0,0,0),(902,6,'Jump Freighter',NULL,0,0,NULL,NULL,0,0,0,1),(903,25,'Ancient Compressed Ice',NULL,0,0,NULL,NULL,0,0,0,0),(904,7,'Rig Mining',NULL,0,0,NULL,NULL,0,0,0,0),(905,7,'Covert Cynosural Field Generator',NULL,0,0,NULL,NULL,0,0,0,0),(906,6,'Combat Recon Ship',NULL,0,0,NULL,NULL,0,0,0,1),(907,8,'Tracking Script',NULL,3346,0,NULL,NULL,0,0,1,1),(908,8,'Warp Disruption Script',NULL,111,0,NULL,NULL,0,0,1,1),(909,8,'Tracking Disruption Script',NULL,1639,0,NULL,NULL,0,0,1,1),(910,8,'Sensor Booster Script',NULL,74,0,NULL,NULL,0,0,1,1),(911,8,'Sensor Dampener Script',NULL,105,0,NULL,NULL,0,0,1,1),(912,9,'Script Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(913,17,'Advanced Capital Construction Components',NULL,0,0,NULL,NULL,0,0,0,1),(914,9,'Advanced Capital Construction Component Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(915,9,'Capital Construction Blueprints',NULL,0,1,NULL,NULL,0,0,0,1),(916,8,'Nanite Repair Paste',NULL,0,1,NULL,NULL,0,0,1,1),(917,9,'Data Miner Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(918,9,'Scan Probe Launcher Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(920,2,'Effect Beacon',NULL,NULL,0,NULL,NULL,0,0,0,0),(922,11,'Capture Point',NULL,NULL,0,NULL,NULL,1,0,0,0),(924,11,'Mission Faction Battleship',NULL,NULL,0,NULL,NULL,0,0,0,0),(925,11,'FW Infrastructure Hub',NULL,NULL,0,NULL,NULL,0,0,0,0),(927,11,'Mission Faction Industrials',NULL,NULL,0,NULL,NULL,0,0,0,0),(934,11,'Zombie Entities',NULL,NULL,0,NULL,NULL,0,0,0,0),(935,26,'WorldSpace',NULL,NULL,0,NULL,NULL,0,0,0,0),(937,29,'Decorations',NULL,NULL,0,NULL,NULL,0,0,0,0),(940,49,'Furniture',NULL,NULL,0,NULL,NULL,0,0,0,1),(941,6,'Industrial Command Ship',NULL,NULL,0,NULL,NULL,0,0,0,1),(943,5,'Game Time',NULL,3001,0,NULL,NULL,0,0,0,1),(944,9,'Capital Industrial Ship Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(945,9,'Industrial Command Ship Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(952,11,'Mission Container',NULL,0,0,NULL,NULL,1,0,0,0),(954,32,'Defensive Systems',NULL,NULL,0,NULL,NULL,0,0,0,1),(955,32,'Electronic Systems',NULL,NULL,0,NULL,NULL,0,0,0,1),(956,32,'Offensive Systems',NULL,NULL,0,NULL,NULL,0,0,0,1),(957,32,'Propulsion Systems',NULL,NULL,0,NULL,NULL,0,0,0,1),(958,32,'Engineering Systems',NULL,NULL,0,NULL,NULL,0,0,0,1),(959,11,'Deadspace Sleeper Sleepless Sentinel',NULL,0,0,NULL,NULL,0,0,0,0),(960,11,'Deadspace Sleeper Awakened Sentinel',NULL,0,0,NULL,NULL,0,0,0,0),(961,11,'Deadspace Sleeper Emergent Sentinel',NULL,0,0,NULL,NULL,0,0,0,0),(963,6,'Strategic Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(964,17,'Hybrid Tech Components',NULL,NULL,1,NULL,NULL,0,0,0,1),(965,9,'Hybrid Component Blueprints',NULL,NULL,1,NULL,NULL,0,0,0,1),(966,4,'Ancient Salvage',NULL,NULL,0,NULL,NULL,0,0,0,1),(967,4,'Wormhole Minerals',NULL,NULL,0,NULL,NULL,0,0,0,0),(971,34,'Sleeper Propulsion Relics',NULL,NULL,0,NULL,NULL,0,0,0,1),(972,8,'Obsolete Probes',NULL,NULL,0,NULL,NULL,0,0,1,0),(973,9,'Subsystem Blueprints',NULL,NULL,0,NULL,NULL,0,0,0,1),(974,4,'Hybrid Polymers',NULL,NULL,0,NULL,NULL,0,0,0,1),(976,63,'Festival Charges Expired',NULL,NULL,0,NULL,NULL,0,0,0,1),(977,24,'Hybrid Reactions',NULL,NULL,1,NULL,NULL,0,0,0,1),(979,35,'Decryptors - Hybrid',NULL,NULL,0,NULL,NULL,0,0,0,1),(982,11,'Deadspace Sleeper Sleepless Defender',NULL,0,0,NULL,NULL,0,0,0,0),(983,11,'Deadspace Sleeper Sleepless Patroller',NULL,0,0,NULL,NULL,0,0,0,0),(984,11,'Deadspace Sleeper Awakened Defender',NULL,0,0,NULL,NULL,0,0,0,0),(985,11,'Deadspace Sleeper Awakened Patroller',NULL,0,0,NULL,NULL,0,0,0,0),(986,11,'Deadspace Sleeper Emergent Defender',NULL,0,0,NULL,NULL,0,0,0,0),(987,11,'Deadspace Sleeper Emergent Patroller',NULL,0,0,NULL,NULL,0,0,0,0),(988,2,'Wormhole',NULL,NULL,0,NULL,NULL,0,0,0,0),(990,34,'Sleeper Electronics Relics',NULL,NULL,0,NULL,NULL,0,0,0,1),(991,34,'Sleeper Offensive Relics',NULL,NULL,0,NULL,NULL,0,0,0,1),(992,34,'Sleeper Engineering Relics',NULL,NULL,0,NULL,NULL,0,0,0,1),(993,34,'Sleeper Defensive Relics',NULL,NULL,0,NULL,NULL,0,0,0,1),(995,2,'Secondary Sun',NULL,NULL,0,NULL,NULL,0,0,0,0),(996,9,'Strategic Cruiser Blueprints',NULL,NULL,0,NULL,NULL,0,0,0,1),(997,34,'Sleeper Hull Relics',NULL,NULL,0,NULL,NULL,0,0,0,1),(1003,40,'Territorial Claim Unit',NULL,NULL,1,NULL,NULL,0,1,0,1),(1004,40,'Defense Bunkers',NULL,NULL,0,NULL,NULL,0,1,0,0),(1005,40,'Sovereignty Blockade Unit',NULL,NULL,1,NULL,NULL,0,1,0,1),(1006,11,'Mission Faction Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,0),(1007,11,'Mission Faction Frigate',NULL,NULL,0,NULL,NULL,0,0,0,0),(1010,8,'Compact Citadel Torpedo',NULL,NULL,0,NULL,NULL,0,0,1,0),(1012,40,'Infrastructure Hub',NULL,NULL,1,NULL,NULL,0,1,0,1),(1013,9,'Supercarrier Blueprints',NULL,NULL,1,NULL,NULL,0,0,0,1),(1016,39,'Strategic Upgrades',NULL,NULL,1,NULL,NULL,0,0,0,1),(1019,8,'Citadel Cruise',NULL,182,0,NULL,NULL,0,0,1,1),(1020,39,'Industrial Upgrades',NULL,NULL,1,NULL,NULL,0,0,0,1),(1021,39,'Military Upgrades',NULL,NULL,1,NULL,NULL,0,0,0,1),(1022,6,'Prototype Exploration Ship',NULL,NULL,0,NULL,NULL,0,0,0,1),(1023,18,'Fighter Bomber',NULL,NULL,0,NULL,NULL,0,0,0,1),(1025,46,'Orbital Infrastructure',NULL,NULL,0,NULL,NULL,0,1,0,0),(1026,41,'Extractors',NULL,NULL,1,NULL,NULL,0,0,0,1),(1027,41,'Command Centers',NULL,NULL,1,NULL,NULL,0,0,0,1),(1028,41,'Processors',NULL,NULL,1,NULL,NULL,0,0,0,1),(1029,41,'Storage Facilities',NULL,NULL,1,NULL,NULL,0,0,0,1),(1030,41,'Spaceports',NULL,NULL,1,NULL,NULL,0,0,0,1),(1031,17,'Planetary Resources',NULL,NULL,0,NULL,NULL,0,0,0,1),(1032,42,'Planet Solid',NULL,NULL,0,NULL,NULL,0,0,0,1),(1033,42,'Planet Liquid-Gas',NULL,NULL,0,NULL,NULL,0,0,0,1),(1034,43,'Refined Commodities',NULL,NULL,1,NULL,NULL,0,0,0,1),(1035,42,'Planet Organic',NULL,NULL,0,NULL,NULL,0,0,0,1),(1036,41,'Planetary Links',NULL,NULL,1,NULL,NULL,0,0,0,1),(1040,43,'Specialized Commodities',NULL,NULL,1,NULL,NULL,0,0,0,1),(1041,43,'Advanced Commodities',NULL,NULL,0,NULL,NULL,0,0,0,1),(1042,43,'Basic Commodities',NULL,NULL,1,NULL,NULL,0,0,0,1),(1045,9,'Sovereignty Structure Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1046,9,'Nanite Repair Paste Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1048,9,'Structure Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1051,11,'Incursion Sansha\'s Nation Industrial',NULL,NULL,0,NULL,NULL,0,0,0,0),(1052,11,'Incursion Sansha\'s Nation Capital',NULL,NULL,0,NULL,NULL,0,0,0,0),(1053,11,'Incursion Sansha\'s Nation Frigate',NULL,NULL,0,NULL,NULL,0,0,0,0),(1054,11,'Incursion Sansha\'s Nation Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,0),(1056,11,'Incursion Sansha\'s Nation Battleship',NULL,NULL,0,NULL,NULL,0,0,0,0),(1063,41,'Extractor Control Units',NULL,NULL,1,NULL,NULL,0,0,0,1),(1067,26,'MaterialZone',NULL,NULL,0,NULL,NULL,0,0,0,0),(1068,26,'DetailMesh',NULL,NULL,0,NULL,NULL,0,0,0,0),(1071,2,'Flashpoint',NULL,NULL,0,NULL,NULL,1,0,0,1),(1073,46,'Test Orbitals',NULL,NULL,1,NULL,NULL,0,1,0,0),(1079,49,'Generic',NULL,NULL,0,NULL,NULL,0,0,0,1),(1081,41,'Mercenary Bases',NULL,NULL,0,NULL,NULL,0,0,0,1),(1082,41,'Capsuleer Bases',NULL,NULL,0,NULL,NULL,0,0,0,1),(1083,30,'Eyewear',NULL,NULL,0,NULL,NULL,0,0,0,1),(1084,30,'Tattoos',NULL,NULL,0,NULL,NULL,0,0,0,1),(1085,30,'Piercings',NULL,NULL,0,NULL,NULL,0,0,0,0),(1086,30,'Scars',NULL,NULL,0,NULL,NULL,0,0,0,0),(1087,30,'Mid Layer',NULL,NULL,0,NULL,NULL,0,0,0,0),(1088,30,'Outer',NULL,NULL,0,NULL,NULL,0,0,0,1),(1089,30,'Tops',NULL,NULL,0,NULL,NULL,0,0,0,1),(1090,30,'Bottoms',NULL,NULL,0,NULL,NULL,0,0,0,1),(1091,30,'Footwear',NULL,NULL,0,NULL,NULL,0,0,0,1),(1092,30,'Hair Styles',NULL,NULL,0,NULL,NULL,0,0,0,1),(1093,30,'Makeup',NULL,NULL,0,NULL,NULL,0,0,0,0),(1105,53,'Lens Flares',NULL,NULL,0,NULL,NULL,0,0,0,0),(1106,46,'Orbital Construction Platform',NULL,NULL,1,NULL,NULL,0,1,0,1),(1107,53,'Particle Systems',NULL,NULL,0,NULL,NULL,0,0,0,0),(1108,53,'Animated Lights',NULL,NULL,0,NULL,NULL,0,0,0,0),(1109,29,'Audio',NULL,NULL,0,NULL,NULL,0,0,0,0),(1110,54,'Point Lights',NULL,NULL,0,NULL,NULL,0,0,0,1),(1111,54,'Box Lights',NULL,NULL,0,NULL,NULL,0,0,0,1),(1112,54,'Spot Lights',NULL,NULL,0,NULL,NULL,0,0,0,1),(1118,17,'Surface Infrastructure Prefab Units',NULL,NULL,0,NULL,NULL,0,0,0,0),(1121,29,'Perception Points',NULL,NULL,0,NULL,NULL,0,0,0,1),(1122,7,'Salvager',NULL,NULL,0,NULL,NULL,0,0,0,1),(1123,9,'Salvager Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1126,59,'PhysicalPortals',NULL,NULL,0,NULL,NULL,0,0,0,0),(1136,4,'Fuel Block',NULL,NULL,1,NULL,NULL,0,0,0,1),(1137,9,'Fuel Block Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1139,9,'Mining Laser Upgrade Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1141,17,'Research Data',NULL,0,0,NULL,NULL,0,0,0,1),(1142,9,'Cap Drain Drone Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1143,9,'Electronic Warfare Drone Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1144,9,'Logistic Drone Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1145,9,'Fighter Bomber Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1146,9,'Fighter Drone Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1147,9,'Stasis Webifying Drone Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1149,22,'Mobile Jump Disruptor',NULL,0,0,NULL,NULL,0,1,0,0),(1150,7,'Armor Resistance Shift Hardener',NULL,NULL,0,NULL,NULL,0,0,0,1),(1151,9,'Armor Resistance Shift Hardener Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1152,9,'Drone Damage Module Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1153,8,'Shield Booster Script',NULL,NULL,0,NULL,NULL,0,0,1,0),(1154,7,'Target Breaker',NULL,NULL,0,NULL,NULL,0,0,0,1),(1155,9,'Target Breaker Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1156,7,'Fueled Shield Booster',NULL,10935,0,NULL,NULL,0,0,0,1),(1157,9,'Fueled Shield Booster Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1158,8,'Heavy Defender Missile',NULL,192,0,NULL,NULL,0,0,1,1),(1159,18,'Salvage Drone',NULL,NULL,0,NULL,NULL,0,0,0,1),(1160,9,'Survey Probe Blueprints',NULL,NULL,1,NULL,NULL,0,0,0,1),(1162,9,'Container Blueprints',NULL,NULL,1,NULL,NULL,0,0,0,1),(1165,2,'Satellite',NULL,NULL,0,NULL,NULL,0,0,0,1),(1166,11,'FW Minmatar Republic Frigate',NULL,NULL,0,NULL,NULL,0,0,0,1),(1167,11,'FW Caldari State Frigate',NULL,NULL,0,NULL,NULL,0,0,0,1),(1168,11,'FW Gallente Federation Frigate',NULL,NULL,0,NULL,NULL,0,0,0,1),(1169,11,'FW Amarr Empire Frigate',NULL,NULL,0,NULL,NULL,0,0,0,1),(1174,11,'Asteroid Rogue Drone Officer',NULL,NULL,0,NULL,NULL,0,0,0,0),(1175,11,'FW Amarr Empire Destroyer',NULL,NULL,0,NULL,NULL,0,0,0,1),(1176,11,'FW Caldari State Destroyer',NULL,NULL,0,NULL,NULL,0,0,0,1),(1177,11,'FW Gallente Federation Destroyer',NULL,NULL,0,NULL,NULL,0,0,0,1),(1178,11,'FW Minmatar Republic Destroyer',NULL,NULL,0,NULL,NULL,0,0,0,1),(1179,11,'FW Amarr Empire Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1180,11,'FW Caldari State Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1181,11,'FW Gallente Federation Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1182,11,'FW Minmatar Republic Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1183,11,'FW Amarr Empire Battlecruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1184,11,'FW Caldari State Battlecruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1185,11,'FW Gallente Federation Battlecruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1186,11,'FW Minmatar Republic Battlecruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1189,7,'Micro Jump Drive',NULL,0,1,NULL,NULL,0,0,0,1),(1190,9,'Salvage Drone Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1191,9,'Micro Jump Drive Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1194,63,'Special Edition Commodities',NULL,NULL,0,NULL,NULL,0,0,0,1),(1195,63,'Tournament Cards: New Eden Open YC 114',NULL,NULL,0,NULL,NULL,0,0,0,1),(1197,9,'Special Edition Commodity Blueprints',NULL,NULL,0,NULL,NULL,0,0,0,1),(1198,2,'Orbital Target',NULL,NULL,0,NULL,NULL,0,0,0,1),(1199,7,'Fueled Armor Repairer',NULL,NULL,0,NULL,NULL,0,0,0,1),(1200,9,'Fueled Armor Repairer Blueprint',NULL,NULL,0,NULL,NULL,0,0,0,1),(1201,6,'Attack Battlecruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1202,6,'Blockade Runner',NULL,NULL,0,NULL,NULL,0,0,0,1),(1206,17,'Security Tags',NULL,NULL,1,NULL,NULL,0,0,0,1),(1207,11,'Scatter Container',NULL,NULL,0,NULL,NULL,0,0,0,1),(1209,16,'Shields',NULL,NULL,1,NULL,NULL,0,0,0,1),(1210,16,'Armor',NULL,NULL,1,NULL,NULL,0,0,0,1),(1212,23,'Personal Hangar',NULL,0,0,NULL,NULL,0,1,0,1),(1213,16,'Targeting',NULL,NULL,1,NULL,NULL,0,0,0,1),(1216,16,'Engineering',NULL,NULL,1,NULL,NULL,0,0,0,1),(1217,16,'Scanning',NULL,NULL,1,NULL,NULL,0,0,0,1),(1218,16,'Resource Processing',NULL,NULL,1,NULL,NULL,0,0,0,1),(1220,16,'Neural Enhancement',NULL,NULL,1,NULL,NULL,0,0,0,1),(1222,9,'ECM Stabilizer Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1223,7,'Scanning Upgrade',NULL,0,0,NULL,NULL,0,0,0,1),(1224,9,'Scanning Upgrade Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1225,63,'Tournament Cards: Alliance Tournament All Stars',NULL,NULL,0,NULL,NULL,0,0,0,1),(1226,7,'Survey Probe Launcher',NULL,2677,0,NULL,NULL,0,0,0,1),(1227,9,'Survey Probe Launcher Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1228,20,'Cyber Targeting',NULL,NULL,0,NULL,NULL,0,0,0,1),(1229,20,'Cyber Resource Processing',NULL,NULL,0,NULL,NULL,0,0,0,1),(1230,20,'Cyber Scanning',NULL,NULL,0,NULL,NULL,0,0,0,1),(1231,20,'Cyber Biology',NULL,NULL,0,NULL,NULL,0,0,0,1),(1232,7,'Rig Resource Processing',NULL,NULL,0,NULL,NULL,0,0,0,1),(1233,7,'Rig Scanning',NULL,NULL,0,NULL,NULL,0,0,0,1),(1234,7,'Rig Targeting',NULL,NULL,0,NULL,NULL,0,0,0,1),(1238,7,'Scanning Upgrade Time',NULL,NULL,0,NULL,NULL,0,0,0,1),(1239,9,'Scanning Upgrade Time Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1240,16,'Subsystems',NULL,NULL,1,NULL,NULL,0,0,0,1),(1241,16,'Planet Management',NULL,NULL,1,NULL,NULL,0,0,0,1),(1245,7,'Missile Launcher Rapid Heavy',NULL,NULL,0,NULL,NULL,0,0,0,1),(1246,22,'Mobile Depot',NULL,NULL,0,NULL,NULL,0,0,0,1),(1247,22,'Mobile Siphon Unit',NULL,NULL,0,NULL,NULL,0,0,0,1),(1248,17,'Empire Bounty Reimbursement Tags',NULL,NULL,1,NULL,NULL,0,0,0,1),(1249,22,'Mobile Cyno Inhibitor',NULL,NULL,0,NULL,NULL,0,0,0,1),(1250,22,'Mobile Tractor Unit',NULL,NULL,0,NULL,NULL,0,0,0,1),(1252,11,'Ghost Sites Angel Cartel Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1255,11,'Ghost Sites Blood Raiders Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1259,11,'Ghost Sites Guristas Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1262,11,'Ghost Sites Serpentis Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1265,11,'Ghost Sites Sanshas Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1267,9,'Mobile Siphon Unit Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(1268,9,'Mobile Cynosural Inhibitor Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1269,9,'Mobile Depot Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1270,9,'Mobile Tractor Unit Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1271,30,'Prosthetics',NULL,NULL,0,NULL,NULL,0,0,0,1),(1273,22,'Encounter Surveillance System',NULL,NULL,1,NULL,NULL,0,0,0,1),(1274,22,'Mobile Decoy Unit',NULL,NULL,0,NULL,NULL,0,0,0,0),(1275,22,'Mobile Scan Inhibitor',NULL,NULL,0,NULL,NULL,0,0,0,1),(1276,22,'Mobile Micro Jump Unit',NULL,NULL,0,NULL,NULL,0,0,0,1),(1277,9,'Encounter Surveillance System Blueprint',NULL,0,1,NULL,NULL,0,0,0,1),(1282,23,'Compression Array',NULL,NULL,1,NULL,NULL,0,1,0,1),(1283,6,'Expedition Frigate',NULL,NULL,0,NULL,NULL,0,0,0,1),(1285,11,'Asteroid Mordus Legion Commander Frigate',NULL,NULL,0,NULL,NULL,0,0,0,0),(1286,11,'Asteroid Mordus Legion Commander Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,0),(1287,11,'Asteroid Mordus Legion Commander Battleship',NULL,NULL,0,NULL,NULL,0,0,0,0),(1288,11,'Ghost Sites Mordu\'s Legion',NULL,NULL,0,NULL,NULL,0,0,0,1),(1289,7,'Warp Accelerator',NULL,NULL,0,NULL,NULL,0,0,0,1),(1292,7,'Drone Tracking Enhancer',NULL,NULL,0,NULL,NULL,0,0,0,1),(1293,9,'Mobile Scan Inhibitor Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1294,9,'Mobile Micro Jump Unit Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1295,9,'Mobile Decoy Unit Blueprint',NULL,NULL,0,NULL,NULL,0,0,0,1),(1297,22,'Mobile Vault',NULL,NULL,0,NULL,NULL,0,0,0,1),(1299,7,'Jump Drive Economizer',NULL,NULL,0,NULL,NULL,0,0,0,1),(1301,5,'Services',NULL,NULL,0,NULL,NULL,0,0,0,1),(1304,35,'Generic Decryptor',NULL,NULL,0,NULL,NULL,0,0,0,1),(1305,6,'Tactical Destroyer',NULL,NULL,0,NULL,NULL,0,0,0,1),(1306,7,'Ship Modifiers',NULL,NULL,0,NULL,NULL,0,0,0,1),(1307,11,'Roaming Sleepers Cruiser',NULL,NULL,0,NULL,NULL,0,0,0,1),(1308,7,'Rig Anchor',NULL,NULL,0,NULL,NULL,0,0,0,1),(1309,9,'Tactical Destroyer Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1310,11,'Drifters Battleship',NULL,NULL,0,NULL,NULL,0,0,0,1),(1311,5,'Super Kerr-Induced Nanocoatings',NULL,NULL,0,NULL,NULL,0,0,0,1),(1312,22,'Observatory Structures',NULL,NULL,0,NULL,NULL,0,0,0,1),(1313,7,'Entosis Link',NULL,NULL,0,NULL,NULL,0,0,0,1),(1314,17,'Unknown Components',NULL,0,1,NULL,NULL,0,0,0,1),(1316,11,'Entosis Command Node',NULL,NULL,0,NULL,NULL,0,0,0,0),(1317,9,'Infrastructure Upgrade Blueprint',NULL,NULL,1,NULL,NULL,0,0,0,1),(1318,9,'Entosis Link Blueprint',NULL,107,1,NULL,NULL,0,0,0,1),(1319,29,'Miscellaneous',NULL,NULL,0,NULL,NULL,0,0,0,0),(1320,65,'Citadel',NULL,NULL,0,NULL,NULL,0,0,0,1),(1395,7,'EVE/Evetypes/Groups/Names:505982',NULL,0,0,NULL,NULL,0,0,0,1),(1396,7,'EVE/Evetypes/Groups/Names:505983',NULL,NULL,0,NULL,NULL,0,0,0,1),(1397,9,'EVE/Evetypes/Groups/Names:505988',NULL,0,1,NULL,NULL,0,0,0,1),(350858,350001,'Infantry Weapons',NULL,NULL,1,NULL,NULL,0,0,0,0),(351064,350001,'Infantry Dropsuits',NULL,NULL,1,NULL,NULL,0,0,0,0),(351121,350001,'Infantry Modules',NULL,NULL,1,NULL,NULL,0,0,0,0),(351210,350001,'Infantry Vehicles',NULL,NULL,1,NULL,NULL,0,0,0,0),(351648,350001,'Infantry Skills',NULL,NULL,1,NULL,NULL,0,0,0,0),(351844,350001,'Infantry Equipment',NULL,NULL,1,NULL,NULL,0,0,0,0),(354641,350001,'Infantry Skill Enhancers',NULL,NULL,1,NULL,NULL,0,0,0,0),(354753,350001,'Infantry Installations',NULL,NULL,1,NULL,NULL,0,0,0,0),(364204,350001,'Surface Infrastructure',NULL,NULL,1,NULL,NULL,0,0,0,0),(367487,350001,'Services ',NULL,NULL,0,NULL,NULL,0,0,0,0),(367580,350001,'Agents',NULL,NULL,0,NULL,NULL,0,0,0,0),(367594,350001,'Visual Customization',NULL,NULL,1,NULL,NULL,0,0,0,0),(367774,350001,'Salvage Containers',NULL,NULL,0,NULL,NULL,0,0,0,0),(367776,350001,'Salvage Decryptors',NULL,NULL,0,NULL,NULL,0,0,0,0),(368656,350001,'Battle Salvage',NULL,NULL,1,NULL,NULL,0,0,0,0),(368666,350001,'Warbarge',NULL,NULL,1,NULL,NULL,0,0,0,0),(368726,350001,'Infantry Color Skin',NULL,NULL,1,NULL,NULL,0,0,0,0);
/*!40000 ALTER TABLE `invGroups` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2015-06-02 21:29:14
