-- MySQL dump 10.13  Distrib 5.6.12, for Linux (x86_64)
--
-- Host: localhost    Database: sdecarnyx1
-- ------------------------------------------------------
-- Server version	5.6.12

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `invTypes`
--

DROP TABLE IF EXISTS `invTypes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `invTypes` (
  `typeID` int(11) NOT NULL,
  `groupID` int(11) DEFAULT NULL,
  `typeName` varchar(100) DEFAULT NULL,
  `description` varchar(3000) DEFAULT NULL,
  `mass` double DEFAULT NULL,
  `volume` double DEFAULT NULL,
  `capacity` double DEFAULT NULL,
  `portionSize` int(11) DEFAULT NULL,
  `raceID` tinyint(3) unsigned DEFAULT NULL,
  `basePrice` decimal(19,4) DEFAULT NULL,
  `published` tinyint(1) DEFAULT NULL,
  `marketGroupID` int(11) DEFAULT NULL,
  `chanceOfDuplicating` double DEFAULT NULL,
  PRIMARY KEY (`typeID`),
  KEY `invTypes_IX_Group` (`groupID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `invTypes`
--

LOCK TABLES `invTypes` WRITE;
/*!40000 ALTER TABLE `invTypes` DISABLE KEYS */;
INSERT INTO `invTypes` VALUES (0,0,'#System',' ',1,0,0,1,NULL,0.0000,0,NULL,0),(2,2,'Corporation',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3,3,'Region',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(4,4,'Constellation',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(5,5,'Solar System',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(6,6,'Sun G5 (Yellow)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(7,6,'Sun K7 (Orange)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(8,6,'Sun K5 (Red Giant)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(9,6,'Sun B0 (Blue)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(10,6,'Sun F0 (White)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(11,7,'Planet (Temperate)','Life-bearing worlds are often referred to as \"temperate\", as their mild temperatures are one of their defining features. Planets with existing, stable ecosystems are prime targets for colonization efforts as they are generally easier to make fully habitable; as a result, the majority of highly populated worlds are of this type. Indeed, it is not altogether uncommon for detailed surveys to reveal signs of previous settlements from various stages of New Eden\'s history.',1e35,1,0,1,NULL,0.0000,0,NULL,0),(12,7,'Planet (Ice)','The majority of icy planets went through a period of being barren terrestrials, before being surfaced with ice over the course of many millennia. The exact process for this varies from case to case, but the end result is both common and visually uniform - a bright, reflective planet scored by countless fractures and crevasses. A few icy planets are hypothesized to have been warmer, liquid-bearing planets in the past that have subsequently frozen, as a result of either stellar cooling or failed terraforming projects.',1e35,1,0,1,NULL,0.0000,0,NULL,0),(13,7,'Planet (Gas)','Gas planets are characterized by a deep, opaque upper atmosphere, usually composed primarily of light elements such as hydrogen or helium. Simple chemicals can add a range of hues and shades in the visual spectrum, and the interaction between upwellings and rapidly circulating pressure bands result in a huge variety of visible surface structures. A similar level of diversity can be found beneath the cloud-tops: the inner composition of a given gas planet might belong to any one of a dozen broad groups, with no two planets entirely alike in this regard.',1e35,1,0,1,NULL,0.0000,0,NULL,0),(14,8,'Moon',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(15,9,'Asteroid Belt',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(16,10,'Stargate (Caldari System)',' ',100000000000,10000000,0,1,1,0.0000,0,NULL,0),(17,10,'Stargate (Amarr Constellation)',' ',100000000000,100000000,0,1,4,0.0000,0,NULL,0),(18,458,'Plagioclase','Plagioclase is not amongst the most valuable ore types around, but it contains a large amount of pyerite and is thus always in constant demand. It also yields some tritanium and mexallon.\r\r\n\r\r\nAvailable in <color=\'0xFF4DFFCC\'>0.9</color> security status solar systems or lower.',1e35,0.35,0,100,NULL,5342.0000,1,516,0),(19,461,'Spodumain','Spodumain is amongst the most desirable ore types around, as it contains high volumes of the four most heavily demanded minerals. Huge volumes of tritanium and pyerite, as well as moderate amounts of mexallon and isogen can be obtained by refining these rocks.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,333200.0000,1,517,0),(20,457,'Kernite','Kernite is a fairly common ore type that yields a large amount of mexallon. Besides mexallon the kernite also has a bit of tritanium and isogen.\r\r\n\r\r\nAvailable in <color=\'0xFF00FF00\'>0.7</color> security status solar systems or lower.',1e35,1.2,0,100,NULL,25964.0000,1,523,0),(21,454,'Hedbergite','Hedbergite is sought after for its high concentration of nocxium and isogen. However hedbergite also yields some  pyerite and zydrine.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF4D00\'>0.2</color> security status solar systems or lower.',1e35,3,0,100,4,123712.0000,1,527,0),(22,450,'Arkonor','The rarest and most sought-after ore in the known universe. A sizable nugget of this can sweep anyone from rags to riches in no time. Arkonor has the largest amount of megacyte of any ore, and also contains some mexallon and tritanium.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,2745440.0000,1,512,0),(23,12,'Cargo Container','This cargo container is flimsily constructed and may not survive the rigors of space for more than an hour or so.',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(24,13,'Ring',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(25,14,'Corpse',' ',80,2,0,1,NULL,0.0000,1,NULL,0),(26,16,'Office Folder',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(27,16,'Office',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(28,16,'Factory Folder',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(29,17,'Credits',' ',0,0,0,57344,NULL,57344.0000,0,NULL,0),(30,19,'Faction',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(34,18,'Tritanium','The main building block in space structures. A very hard, yet bendable metal. Cannot be used in human habitats due to its instability at atmospheric temperatures. Very common throughout the universe.\r\r\n\r\r\nMay be obtained by reprocessing the following ores:\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:22>Arkonor</a>, <a href=showinfo:17425>Crimson Arkonor</a>, <a href=showinfo:17426>Prime Arkonor</a>\r\r\n<a href=showinfo:1225>Crokite</a>, <a href=showinfo:17432>Sharp Crokite</a>, <a href=showinfo:17433>Crystalline Crokite</a>\r\r\n<a href=showinfo:1232>Dark Ochre</a>, <a href=showinfo:17436>Onyx Ochre</a>, <a href=showinfo:17437>Obsidian Ochre</a>\r\r\n<a href=showinfo:19>Spodumain</a>, <a href=showinfo:17466>Bright Spodumain</a>, <a href=showinfo:17467>Gleaming Spodumain</a>\r\r\n\r\r\n<color=\'0xFFFF4D00\'>0.2</color> security status solar system or lower:\r\r\n<a href=showinfo:1231>Hemorphite</a>, <a href=showinfo:17444>Vivid Hemorphite</a>, <a href=showinfo:17445>Radiant Hemorphite</a>\r\r\n\r\r\n<color=\'0xFF00FF00\'>0.7</color> security status solar system or lower:\r\r\n<a href=showinfo:20>Kernite</a>, <a href=showinfo:17452>Luminous Kernite</a>, <a href=showinfo:17453>Fiery Kernite</a>\r\r\n<a href=showinfo:1227>Omber</a>, <a href=showinfo:17867>Silvery Omber</a>, <a href=showinfo:17868>Golden Omber</a>\r\r\n\r\r\n<color=\'0xFF4DFFCC\'>0.9</color> security status solar system or lower:\r\r\n<a href=showinfo:18>Plagioclase</a>, <a href=showinfo:17455>Azure Plagioclase</a>, <a href=showinfo:17456>Rich Plagioclase</a>\r\r\n<a href=showinfo:1224>Pyroxeres</a>, <a href=showinfo:17459>Solid Pyroxeres</a>, <a href=showinfo:17460>Viscous Pyroxeres</a>\r\r\n\r\r\n<color=\'0xFF33FFFF\'>1.0</color> security status solar system or lower:\r\r\n<a href=showinfo:1228>Scordite</a>, <a href=showinfo:17463>Condensed Scordite</a>, <a href=showinfo:17464>Massive Scordite</a>\r\r\n<a href=showinfo:1230>Veldspar</a>, <a href=showinfo:17470>Concentrated Veldspar</a>, <a href=showinfo:17471>Dense Veldspar</a>',0,0.01,0,1,NULL,2.0000,1,1857,0),(35,18,'Pyerite','A soft crystal-like mineral with a very distinguishing orange glow as if on fire. Used as conduit and in the bio-chemical industry. Commonly found in many asteroid-ore types.\r\r\n\r\r\nMay be obtained by reprocessing the following ores:\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:1223>Bistot</a>, <a href=showinfo:17429>Monoclinic Bistot</a>, <a href=showinfo:17428>Triclinic Bistot</a>\r\r\n<a href=showinfo:1229>Gneiss</a>, <a href=showinfo:17865>Iridescent Gneiss</a>, <a href=showinfo:17866>Prismatic Gneiss</a>\r\r\n<a href=showinfo:19>Spodumain</a>, <a href=showinfo:17466>Bright Spodumain</a>, <a href=showinfo:17467>Gleaming Spodumain</a>\r\r\n\r\r\n<color=\'0xFFFF4D00\'>0.2</color> security status solar system or lower:\r\r\n<a href=showinfo:21>Hedbergite</a>, <a href=showinfo:17440>Vitric Hedbergite</a>, <a href=showinfo:17441>Glazed Hedbergite</a>\r\r\n\r\r\n<color=\'0xFF00FF00\'>0.7</color> security status solar system or lower:\r\r\n<a href=showinfo:1227>Omber</a>, <a href=showinfo:17867>Silvery Omber</a>, <a href=showinfo:17868>Golden Omber</a>\r\r\n\r\r\n<color=\'0xFF4DFFCC\'>0.9</color> security status solar system or lower:\r\r\n<a href=showinfo:18>Plagioclase</a>, <a href=showinfo:17455>Azure Plagioclase</a>, <a href=showinfo:17456>Rich Plagioclase</a>\r\r\n<a href=showinfo:1224>Pyroxeres</a>, <a href=showinfo:17459>Solid Pyroxeres</a>, <a href=showinfo:17460>Viscous Pyroxeres</a>\r\r\n\r\r\n<color=\'0xFF33FFFF\'>1.0</color> security status solar system or lower:\r\r\n<a href=showinfo:1228>Scordite</a>, <a href=showinfo:17463>Condensed Scordite</a>, <a href=showinfo:17464>Massive Scordite</a>',0,0.01,0,1,NULL,8.0000,1,1857,0),(36,18,'Mexallon','Very flexible metallic mineral, dull to bright silvery green in color. Can be mixed with tritanium to make extremely hard alloys or it can be used by itself for various purposes. Fairly common in most regions.\r\r\n\r\r\nMay be obtained by reprocessing the following ores:\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:1229>Gneiss</a>, <a href=showinfo:17865>Iridescent Gneiss</a>, <a href=showinfo:17866>Prismatic Gneiss</a>\r\r\n<a href=showinfo:19>Spodumain</a>, <a href=showinfo:17466>Bright Spodumain</a>, <a href=showinfo:17467>Gleaming Spodumain</a>\r\r\n\r\r\n<color=\'0xFFE58000\'>0.4</color> security status solar system or lower:\r\r\n<a href=showinfo:1226>Jaspet</a>, <a href=showinfo:17448>Pure Jaspet</a>, <a href=showinfo:17449>Pristine Jaspet</a>\r\r\n\r\r\n<color=\'0xFF00FF00\'>0.7</color> security status solar system or lower:\r\r\n<a href=showinfo:20>Kernite</a>, <a href=showinfo:17452>Luminous Kernite</a>, <a href=showinfo:17453>Fiery Kernite</a>\r\r\n\r\r\n<color=\'0xFF4DFFCC\'>0.9</color> security status solar system or lower:\r\r\n<a href=showinfo:18>Plagioclase</a>, <a href=showinfo:17455>Azure Plagioclase</a>, <a href=showinfo:17456>Rich Plagioclase</a>\r\r\n<a href=showinfo:1224>Pyroxeres</a>, <a href=showinfo:17459>Solid Pyroxeres</a>, <a href=showinfo:17460>Viscous Pyroxeres</a>',0,0.01,0,1,NULL,32.0000,1,1857,0),(37,18,'Isogen','Light-bluish crystal, formed by intense pressure deep within large asteroids and moons. Used in electronic and weapon manufacturing. Only found in abundance in a few areas.\r\r\n\r\r\nMay be obtained by reprocessing the following ores:\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:1232>Dark Ochre</a>, <a href=showinfo:17436>Onyx Ochre</a>, <a href=showinfo:17437>Obsidian Ochre</a>\r\r\n<a href=showinfo:1229>Gneiss</a>, <a href=showinfo:17865>Iridescent Gneiss</a>, <a href=showinfo:17866>Prismatic Gneiss</a>\r\r\n<a href=showinfo:19>Spodumain</a>, <a href=showinfo:17466>Bright Spodumain</a>, <a href=showinfo:17467>Gleaming Spodumain</a>\r\r\n\r\r\n<color=\'0xFFFF4D00\'>0.2</color> security status solar system or lower:\r\r\n<a href=showinfo:21>Hedbergite</a>, <a href=showinfo:17440>Vitric Hedbergite</a>, <a href=showinfo:17441>Glazed Hedbergite</a>\r\r\n<a href=showinfo:1231>Hemorphite</a>, <a href=showinfo:17444>Vivid Hemorphite</a>, <a href=showinfo:17445>Radiant Hemorphite</a>\r\r\n\r\r\n<color=\'0xFF00FF00\'>0.7</color> security status solar system or lower:\r\r\n<a href=showinfo:20>Kernite</a>, <a href=showinfo:17452>Luminous Kernite</a>, <a href=showinfo:17453>Fiery Kernite</a>\r\r\n<a href=showinfo:1227>Omber</a>, <a href=showinfo:17867>Silvery Omber</a>, <a href=showinfo:17868>Golden Omber</a>',0,0.01,0,1,NULL,128.0000,1,1857,0),(38,18,'Nocxium','A highly volatile mineral only formed during supernovas, thus severely limiting the extent of its distribution. Vital ingredient in capsule production, making it very coveted.\r\r\n\r\r\nMay be obtained by reprocessing the following ores:\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:1225>Crokite</a>, <a href=showinfo:17432>Sharp Crokite</a>, <a href=showinfo:17433>Crystalline Crokite</a>\r\r\n<a href=showinfo:1232>Dark Ochre</a>, <a href=showinfo:17436>Onyx Ochre</a>, <a href=showinfo:17437>Obsidian Ochre</a>\r\r\n\r\r\n<color=\'0xFFFF4D00\'>0.2</color> security status solar system or lower:\r\r\n<a href=showinfo:21>Hedbergite</a>, <a href=showinfo:17440>Vitric Hedbergite</a>, <a href=showinfo:17441>Glazed Hedbergite</a>\r\r\n<a href=showinfo:1231>Hemorphite</a>, <a href=showinfo:17444>Vivid Hemorphite</a>, <a href=showinfo:17445>Radiant Hemorphite</a>\r\r\n\r\r\n<color=\'0xFFE58000\'>0.4</color> security status solar system or lower:\r\r\n<a href=showinfo:1226>Jaspet</a>, <a href=showinfo:17448>Pure Jaspet</a>, <a href=showinfo:17449>Pristine Jaspet</a>\r\r\n\r\r\n<color=\'0xFF4DFFCC\'>0.9</color> security status solar system or lower:\r\r\n<a href=showinfo:1224>Pyroxeres</a>, <a href=showinfo:17459>Solid Pyroxeres</a>, <a href=showinfo:17460>Viscous Pyroxeres</a>',0,0.01,0,1,NULL,512.0000,1,1857,0),(39,18,'Zydrine','Only found in huge geodes; rocks on the outside with crystal-like quartz on the inside. The rarest and most precious of these geodes are those that contain the dark green zydrine within. Very rare and very expensive.\r\r\n\r\r\nMay be obtained by reprocessing the following ores:\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:1223>Bistot</a>, <a href=showinfo:17429>Monoclinic Bistot</a>, <a href=showinfo:17428>Triclinic Bistot</a>\r\r\n<a href=showinfo:1225>Crokite</a>, <a href=showinfo:17432>Sharp Crokite</a>, <a href=showinfo:17433>Crystalline Crokite</a>\r\r\n\r\r\n<color=\'0xFFFF4D00\'>0.2</color> security status solar system or lower:\r\r\n<a href=showinfo:21>Hedbergite</a>, <a href=showinfo:17440>Vitric Hedbergite</a>, <a href=showinfo:17441>Glazed Hedbergite</a>\r\r\n<a href=showinfo:1231>Hemorphite</a>, <a href=showinfo:17444>Vivid Hemorphite</a>, <a href=showinfo:17445>Radiant Hemorphite</a>\r\r\n\r\r\n<color=\'0xFFE58000\'>0.4</color> security status solar system or lower:\r\r\n<a href=showinfo:1226>Jaspet</a>, <a href=showinfo:17448>Pure Jaspet</a>, <a href=showinfo:17449>Pristine Jaspet</a>',0,0.01,0,1,NULL,2048.0000,1,1857,0),(40,18,'Megacyte','An extremely rare mineral found in comets and very occasionally in asteroids that have traveled through gas clouds. Has unique explosive traits that make it very valuable in the armaments industry.\r\r\n\r\r\nMay be obtained by reprocessing the following ores:\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:22>Arkonor</a>, <a href=showinfo:17425>Crimson Arkonor</a>, <a href=showinfo:17426>Prime Arkonor</a>\r\r\n<a href=showinfo:1223>Bistot</a>, <a href=showinfo:17429>Monoclinic Bistot</a>, <a href=showinfo:17428>Triclinic Bistot</a>',0,0.01,0,1,NULL,8192.0000,1,1857,0),(41,280,'Garbage','Production waste can mean garbage to some but valuable resource material to others.',2500,0.25,0,1,NULL,20.0000,1,20,0),(42,280,'Spiced Wine','Luxury goods are always solid commodities for inter-stellar trading. Spiced wine is not the rarest of luxury goods, but it can still be sold at small outposts and bases that don\'t manufacture any themselves.',500,0.5,0,1,NULL,1500.0000,1,492,0),(43,280,'Antibiotics','Antibiotics are in constant demand everywhere and new, more potent versions, are always made available to counter the increased immunity of bacteria against antibiotics.',5,0.2,0,1,NULL,325.0000,1,492,0),(44,1034,'Enriched Uranium','Enriched Uranium is used in many kinds of manufacturing and as a fuel, making it a steady trade commodity. Enriched Uranium is generally manufactured by combining standard semiconductor PVD methods with ionic separation by means of mass spectrometry.',0,1.5,0,1,NULL,5000.0000,1,1335,0),(45,281,'Frozen Plant Seeds','Frozen plant seeds are in high demand in many regions, especially on stations orbiting a non-habitable planet.',400,0.5,0,1,NULL,75.0000,1,492,0),(49,24,'Player Kill','Kill confirmation',0,0,0,1,NULL,0.0000,0,NULL,0),(50,24,'Company Shares','Shares of a corporation.',0,0,0,1,NULL,0.0000,0,NULL,0),(51,24,'Bookmark',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(52,94,'Trading',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(53,95,'Trade Session',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(54,15,'Caldari Logistics Station',' ',0,1,0,1,1,0.0000,0,NULL,0),(56,15,'Gallente Military Station',' ',0,1,0,1,8,0.0000,0,NULL,0),(57,15,'Gallente Station Hub ',' ',0,1,0,1,8,0.0000,0,NULL,0),(58,15,'C-O-1','Caldari Outpost 1',0,1,0,1,1,0.0000,0,NULL,0),(59,15,'C-O-2','Caldari Outpost 2',0,1,0,1,1,0.0000,0,NULL,0),(164,23,'Clone Grade Alpha',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(165,23,'Clone Grade Beta',' ',0,1,0,1,NULL,28000.0000,0,NULL,0),(166,23,'Clone Grade Gamma',' ',0,1,0,1,NULL,45500.0000,0,NULL,0),(178,83,'Carbonized Lead S','Small Projectile Ammo. This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem. \r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,222.0000,1,113,0),(179,83,'Nuclear S','Small Projectile Ammo. Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,332.0000,1,113,0),(180,83,'Proton S','Small Projectile Ammo. Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,428.0000,1,113,0),(181,83,'Depleted Uranium S','Small projectile Ammo. Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead. \r\r\n\r\r\n20% tracking speed bonus.',0.01,0.0025,0,100,NULL,524.0000,1,113,0),(182,83,'Titanium Sabot S','Small Projectile Ammo. This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',0.01,0.0025,0,100,NULL,660.0000,1,113,0),(183,83,'Fusion S','Small Projectile Ammo. The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,732.0000,1,113,0),(184,83,'Phased Plasma S','Small Projectile Ammo. This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,848.0000,1,113,0),(185,83,'EMP S','Small projectile Ammo. A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,1056.0000,1,113,0),(186,83,'Carbonized Lead M','Medium Projectile Ammo. This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.05,0.0125,0,100,NULL,848.0000,1,112,0),(187,83,'Nuclear M','Medium Projectile Ammo. Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.05,0.0125,0,100,NULL,1328.0000,1,112,0),(188,83,'Proton M','Medium Projectile Ammo. Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.0125,0,100,NULL,1830.0000,1,112,0),(189,83,'Depleted Uranium M','Medium Projectile Ammo. Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.0125,0,100,NULL,2236.0000,1,112,0),(190,83,'Titanium Sabot M','Medium Projectile Ammo. This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.0125,0,100,NULL,2608.0000,1,112,0),(191,83,'Fusion M','Medium Projectile Ammo. The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,3054.0000,1,112,0),(192,83,'Phased Plasma M','Medium Projectile Ammo. This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,3544.0000,1,112,0),(193,83,'EMP M','Medium Projectile Ammo. A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,4458.0000,1,112,0),(194,83,'Carbonized Lead L','Large Projectile Ammo. This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.025,0,100,NULL,2210.0000,1,109,0),(195,83,'Nuclear L','Large Projectile Ammo. Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.025,0,100,NULL,3184.0000,1,109,0),(196,83,'Proton L','Large Projectile Ammo. Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.025,0,100,NULL,4446.0000,1,109,0),(197,83,'Depleted Uranium L','Large Projectile Ammo. Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.025,0,100,NULL,5556.0000,1,109,0),(198,83,'Titanium Sabot L','Large Projectile Ammo. This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.025,0,100,NULL,6656.0000,1,109,0),(199,83,'Fusion L','Large Projectile Ammo. The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,7776.0000,1,109,0),(200,83,'Phased Plasma L','Large Projectile Ammo. This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,8850.0000,1,109,0),(201,83,'EMP L','Large Projectile Ammo. A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,11132.0000,1,109,0),(202,386,'Mjolnir Cruise Missile','The mother of all missiles, the Mjolnir cruise missile delivers a tremendous payload, guaranteed to get its victims acquainted with their personal god in a quick, but painful manner.',1250,0.05,0,100,NULL,20312.0000,1,921,0),(203,386,'Scourge Cruise Missile','The first Minmatar-made large missile. Constructed of reactionary alloys, the Scourge cruise missile is built to get to the target. Guidance and propulsion systems are of Gallente origin and were initially used in drones, making this a nimble projectile despite its heavy payload.',1250,0.05,0,100,NULL,14646.0000,1,921,0),(204,386,'Inferno Cruise Missile','An Amarr creation with powerful capabilities, the Inferno cruise missile was for a long time confined solely to the Amarr armed forces, but exports began some years ago and the missile is now found throughout the universe.',1250,0.05,0,100,NULL,17532.0000,1,921,0),(205,386,'Nova Cruise Missile','A very basic missile for large launchers with reasonable payload. Utilizes the now substandard technology of bulls-eye guidance systems.',1250,0.05,0,100,NULL,10094.0000,1,921,0),(206,385,'Nova Heavy Missile','The be-all and end-all of medium-sized missiles, the Nova heavy missile is a must for those who want a guaranteed kill no matter the cost.',1000,0.03,0,100,NULL,2166.0000,1,924,0),(207,385,'Mjolnir Heavy Missile','First introduced by the armaments lab of the Wiyrkomi Corporation, the Mjolnir heavy missile is a solid investment with a large payload and steady performance.',1000,0.03,0,100,NULL,3776.0000,1,924,0),(208,385,'Inferno Heavy Missile','Originally designed as a \'finisher\' - the killing blow to a crippled ship - the Inferno heavy missile has since gone through various technological upgrades. The latest version has a lighter payload than the original, but much improved guidance systems.',1000,0.03,0,100,NULL,3176.0000,1,924,0),(209,385,'Scourge Heavy Missile','The Scourge heavy missile is an old relic from the Caldari-Gallente War that is still in widespread use because of its low price and versatility.',1000,0.03,0,100,NULL,2664.0000,1,924,0),(210,384,'Scourge Light Missile','From its humble beginnings in tiny Minmatar design labs, the Scourge light missile has quickly established itself throughout the star cluster as a premier missile for light launchers.',700,0.015,0,100,NULL,546.0000,1,920,0),(211,384,'Inferno Light Missile','The explosion the Inferno light missile creates upon impact is stunning enough for any display of fireworks - just ten times more deadly.',700,0.015,0,100,NULL,692.0000,1,920,0),(212,384,'Mjolnir Light Missile','An advanced missile with a volatile payload of magnetized plasma, the Mjolnir light missile is specifically engineered to take down shield systems.',700,0.015,0,100,NULL,828.0000,1,920,0),(213,384,'Nova Light Missile','The Nova light missile is a tiny nuclear projectile based on a classic Minmatar design that has been in use since the early days of the Minmatar Resistance.',700,0.015,0,100,NULL,428.0000,1,920,0),(215,85,'Iron Charge S','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.01,0.0025,0,100,NULL,222.0000,1,107,0),(216,85,'Tungsten Charge S','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.01,0.0025,0,100,NULL,332.0000,1,107,0),(217,85,'Iridium Charge S','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.01,0.0025,0,100,NULL,428.0000,1,107,0),(218,85,'Lead Charge S','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.01,0.0025,0,100,NULL,524.0000,1,107,0),(219,85,'Thorium Charge S','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.01,0.0025,0,100,NULL,660.0000,1,107,0),(220,85,'Uranium Charge S','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.01,0.0025,0,100,NULL,778.0000,1,107,0),(221,85,'Plutonium Charge S','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.01,0.0025,0,100,NULL,848.0000,1,107,0),(222,85,'Antimatter Charge S','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,1056.0000,1,107,0),(223,85,'Iron Charge M','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.05,0.0125,0,100,NULL,848.0000,1,108,0),(224,85,'Tungsten Charge M','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.05,0.0125,0,100,NULL,1208.0000,1,108,0),(225,85,'Iridium Charge M','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.05,0.0125,0,100,NULL,1664.0000,1,108,0),(226,85,'Lead Charge M','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.05,0.0125,0,100,NULL,1832.0000,1,108,0),(227,85,'Thorium Charge M','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.05,0.0125,0,100,NULL,2436.0000,1,108,0),(228,85,'Uranium Charge M','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.05,0.0125,0,100,NULL,3042.0000,1,108,0),(229,85,'Plutonium Charge M','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.05,0.0125,0,100,NULL,3588.0000,1,108,0),(230,85,'Antimatter Charge M','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.05,0.0125,0,100,NULL,4458.0000,1,108,0),(231,85,'Iron Charge L','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.1,0.025,0,100,NULL,2210.0000,1,106,0),(232,85,'Tungsten Charge L','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.1,0.025,0,100,NULL,3184.0000,1,106,0),(233,85,'Iridium Charge L','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.1,0.025,0,100,NULL,4446.0000,1,106,0),(234,85,'Lead Charge L','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.1,0.025,0,100,NULL,5556.0000,1,106,0),(235,85,'Thorium Charge L','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.1,0.025,0,100,NULL,6656.0000,1,106,0),(236,85,'Uranium Charge L','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.1,0.025,0,100,NULL,7776.0000,1,106,0),(237,85,'Plutonium Charge L','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.1,0.025,0,100,NULL,8850.0000,1,106,0),(238,85,'Antimatter Charge L','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.1,0.025,0,100,NULL,11132.0000,1,106,0),(239,86,'Radio S','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3008.0000,1,102,0),(240,86,'Microwave S','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2000.0000,1,102,0),(241,86,'Infrared S','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1128.0000,1,102,0),(242,86,'Standard S','Modulates the beam of a laser weapon into the visible light spectrum. \r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1358.0000,1,102,0),(243,86,'Ultraviolet S','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1628.0000,1,102,0),(244,86,'Xray S','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2532.0000,1,102,0),(245,86,'Gamma S','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3508.0000,1,102,0),(246,86,'Multifrequency S','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4000.0000,1,102,0),(247,86,'Radio M','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,31062.0000,1,103,0),(248,86,'Microwave M','Modulates the beam of a laser weapon into the microwave frequencies. Improved range.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,20192.0000,1,103,0),(249,86,'Infrared M','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,10192.0000,1,103,0),(250,86,'Standard M','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,12736.0000,1,103,0),(251,86,'Ultraviolet M','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased damage.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,15648.0000,1,103,0),(252,86,'Xray M','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased damage.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,26064.0000,1,103,0),(253,86,'Gamma M','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased damage.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,35160.0000,1,103,0),(254,86,'Multifrequency M','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,40072.0000,1,103,0),(255,86,'Radio L','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,336522.0000,1,105,0),(256,86,'Microwave L','Modulates the beam of a laser weapon into the microwave frequencies. Improved range.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,218720.0000,1,105,0),(257,86,'Infrared L','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,108552.0000,1,105,0),(258,86,'Standard L','Modulates the beam of a laser weapon into the visible light spectrum. \r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,141320.0000,1,105,0),(259,86,'Ultraviolet L','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased damage.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,166464.0000,1,105,0),(260,86,'Xray L','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased damage.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,279152.0000,1,105,0),(261,86,'Gamma L','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased damage.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,385880.0000,1,105,0),(262,86,'Multifrequency L','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,443296.0000,1,105,0),(263,87,'Cap Booster 25','Provides a quick injection of power into your capacitor. Good for tight situations!',2.5,1,100,10,NULL,1098.0000,1,139,0),(264,87,'Cap Booster 50','Provides a quick injection of power into your capacitor. Good for tight situations!',5,2,100,10,NULL,2824.0000,1,139,0),(265,1158,'Heavy Defender Missile I','Defensive missile used to destroy incoming missiles.\r\r\n\r\r\nNote: This missile fits into heavy missile launchers.',1000,0.03,0,100,NULL,2168.0000,1,116,0),(266,387,'Scourge Rocket','A small rocket with a piercing warhead.',100,0.005,0,100,NULL,270.0000,1,922,0),(267,89,'Scourge Torpedo','An ultra-heavy piercing missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,61096.0000,1,923,0),(269,394,'Mjolnir Auto-Targeting Light Missile I','An Amarr light missile with an EMP warhead and automatic guidance system.',700,0.015,0,100,4,828.0000,1,914,0),(270,92,'Python Mine','Standard mine with nuclear payload.',1,0.15,0,10,NULL,1494.0000,0,NULL,0),(377,38,'Small Shield Extender I','Increases the maximum strength of the shield.',0,5,0,1,NULL,5320.0000,1,605,0),(380,38,'Small Shield Extender II','Increases the maximum strength of the shield.',0,5,0,1,NULL,57288.0000,1,605,0),(393,39,'Shield Recharger I','Improves the recharge rate of the shield.',0,5,1,1,NULL,9476.0000,1,126,0),(394,39,'Shield Recharger II','Improves the recharge rate of the shield.',0,5,1,1,NULL,45294.0000,1,126,0),(399,40,'Small Shield Booster I','Expends energy to provide a quick boost in shield strength.',0,5,0,1,NULL,10118.0000,1,609,0),(400,40,'Small Shield Booster II','Expends energy to provide a quick boost in shield strength.',0,5,0,1,NULL,61436.0000,1,609,0),(405,41,'Micro Remote Shield Booster I','Transfers shield power over to the target ship, aiding in its defense.',0,2.5,0,1,NULL,1998.0000,1,604,0),(406,41,'Micro Remote Shield Booster II','Transfers shield power over to the target ship, aiding in its defense.',0,2.5,0,1,NULL,35736.0000,1,604,0),(421,43,'\'Basic\' Capacitor Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,9500.0000,1,665,0),(434,46,'5MN Microwarpdrive I','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,34966.0000,1,131,0),(438,46,'1MN Afterburner II','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,366332.0000,1,542,0),(439,46,'1MN Afterburner I','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,7104.0000,1,542,0),(440,46,'5MN Microwarpdrive II','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,1074512.0000,1,131,0),(442,47,'Cargo Scanner I','Scans the cargo hold of another ship.',0,5,0,1,NULL,1650.0000,1,711,0),(443,48,'Ship Scanner I','Scans the target ship and provides a tactical analysis of its capabilities. The further it goes beyond scan range, the more inaccurate its results will be.',0,5,0,1,NULL,2190.0000,1,713,0),(444,49,'Survey Scanner I','Scans the composition of asteroids, ice and gas clouds.',0,5,0,1,NULL,2222.0000,1,714,0),(447,52,'Warp Scrambler I','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,47476.0000,1,1936,0),(448,52,'Warp Scrambler II','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,445774.0000,1,1936,0),(450,53,'Gatling Pulse Laser I','Rapid fire multi-barreled energy weapon that delivers a steady stream of damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,NULL,2222.0000,1,570,0),(451,53,'Dual Light Pulse Laser I','This light pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. Good skirmish weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,NULL,8356.0000,1,570,0),(452,53,'Dual Light Beam Laser I','This light beam laser uses two separate laser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,NULL,11788.0000,1,567,0),(453,53,'Small Focused Pulse Laser I','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,NULL,13368.0000,1,570,0),(454,53,'Small Focused Beam Laser I','A high-powered beam laser. Good for medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,NULL,20248.0000,1,567,0),(455,53,'Quad Light Beam Laser I','Uses four light laser focusing systems. Low powered, but makes up for it with a fast firing rate. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,NULL,20578.0000,1,568,0),(456,53,'Focused Medium Pulse Laser I','A high-energy, concentrated laser designed for short to medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,NULL,73954.0000,1,572,0),(457,53,'Focused Medium Beam Laser I','A high-energy, concentrated laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,NULL,99930.0000,1,568,0),(458,53,'Heavy Pulse Laser I','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,25,1,1,NULL,133234.0000,1,572,0),(459,53,'Heavy Beam Laser I','A high-energy heavy laser designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,25,1,1,NULL,166754.0000,1,568,0),(460,53,'Dual Heavy Pulse Laser I','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,253168.0000,1,573,0),(461,53,'Dual Heavy Beam Laser I','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,50,1,1,NULL,683790.0000,1,569,0),(462,53,'Mega Pulse Laser I','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,50,1,1,NULL,1116734.0000,1,573,0),(463,53,'Mega Beam Laser I','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,50,1,1,NULL,1568334.0000,1,569,0),(464,53,'Tachyon Beam Laser I','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,50,1,1,NULL,2015232.0000,1,569,0),(482,54,'Miner II','Has an improved technology beam, making the extraction process more efficient. Useful for extracting all but the rarest ore.',0,5,0,1,NULL,124922.0000,1,1039,0),(483,54,'Miner I','Basic mining laser. Extracts common ore quickly, but has difficulty with the more rare types.',0,5,0,1,NULL,10304.0000,1,1039,0),(484,55,'125mm Gatling AutoCannon I','This multi-barrel autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.5,1,NULL,2222.0000,1,574,0),(485,55,'150mm Light AutoCannon I','A simple but effective close combat autocannon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.4,1,NULL,8488.0000,1,574,0),(486,55,'200mm AutoCannon I','A powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.3,1,NULL,9958.0000,1,574,0),(487,55,'250mm Light Artillery Cannon I','This artillery is one of the most powerful weapons that can be mounted on a frigate. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.1,1,NULL,13320.0000,1,577,0),(488,55,'280mm Howitzer Artillery I','Rocket-assisted artillery projectiles designed for long-range combat. It is the most powerful projectile weapon able to be fitted onto frigates. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.05,1,NULL,20306.0000,1,577,0),(489,55,'Dual 180mm AutoCannon I','This dual 180mm autocannon is a simple but effective close combat weapon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',12.5,10,2.5,1,NULL,22214.0000,1,575,0),(490,55,'220mm Vulcan AutoCannon I','The 220mm multi-barrel autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,2,1,NULL,73954.0000,1,575,0),(491,55,'425mm AutoCannon I','The 425mm is a behemoth that will inflict severe damage on most cruisers and frigates in short-range battles. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,1.5,1,NULL,99930.0000,1,575,0),(492,55,'650mm Artillery Cannon I','A powerful long-range cannon. One of the most damaging weapons mountable on a cruiser. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',125,25,0.5,1,NULL,133234.0000,1,578,0),(493,55,'720mm Howitzer Artillery I','This 720mm rocket-assisted howitzer is designed for long-range bombardment. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',50,25,0.25,1,NULL,166754.0000,1,578,0),(494,55,'Dual 425mm AutoCannon I','Combines the damage output of two 425mm intermediate-range autocannons. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',200,20,5,1,NULL,253168.0000,1,576,0),(495,55,'Dual 650mm Repeating Cannon I','Powerful, intermediate-range repeating autocannon with a decent rate of fire. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,50,4,1,NULL,683790.0000,1,576,0),(496,55,'800mm Repeating Cannon I','A two-barreled, intermediate-range, powerful cannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,25,3,1,NULL,1116734.0000,1,576,0),(497,55,'1200mm Artillery Cannon I','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,50,1,1,NULL,1568334.0000,1,579,0),(498,55,'1400mm Howitzer Artillery I','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,50,0.5,1,NULL,2015232.0000,1,579,0),(499,509,'Light Missile Launcher I','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.6,1,NULL,6670.0000,1,640,0),(501,510,'Heavy Missile Launcher I','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,0.9,1,NULL,33348.0000,1,642,0),(503,508,'Torpedo Launcher I','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,1.5,1,NULL,204004.0000,1,644,0),(506,767,'\'Basic\' Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,4864.0000,1,667,0),(508,770,'Basic Shield Flux Coil','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,NULL,1664.0000,1,687,0),(509,768,'\'Basic\' Capacitor Flux Coil','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,NULL,1664.0000,1,666,0),(518,59,'Basic Gyrostabilizer','Gives a bonus to the speed and damage of projectile turrets.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,9728.0000,1,646,0),(519,59,'Gyrostabilizer II','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,396130.0000,1,646,0),(520,59,'Gyrostabilizer I','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,30626.0000,1,646,0),(521,60,'Basic Damage Control','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,NULL,2000.0000,1,615,0),(522,61,'Micro Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,2.5,0,1,NULL,4000.0000,1,702,0),(523,62,'Small Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,36788.0000,1,1049,0),(524,63,'Small Hull Repairer I','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,12.5,0,1,NULL,55556.0000,1,1053,0),(526,65,'Stasis Webifier I','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,24988.0000,1,683,0),(527,65,'Stasis Webifier II','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,330598.0000,1,683,0),(529,67,'Small Remote Capacitor Transmitter I','Transfers capacitor energy to another ship.',1000,25,0,1,NULL,40448.0000,1,695,0),(530,68,'Small Nosferatu I','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,51194.0000,1,692,0),(533,71,'Small Energy Neutralizer I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,40456.0000,1,689,0),(561,74,'75mm Gatling Rail I','A small multi-barreled railgun for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,NULL,2222.0000,1,564,0),(562,74,'Light Electron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,NULL,8488.0000,1,561,0),(563,74,'Light Ion Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.3,1,NULL,9958.0000,1,561,0),(564,74,'Light Neutron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,NULL,13320.0000,1,561,0),(565,74,'150mm Railgun I','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,NULL,20306.0000,1,564,0),(566,74,'Heavy Electron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,10,2.5,1,NULL,73954.0000,1,562,0),(567,74,'Dual 150mm Railgun I','This cruiser-sized weapon is a double-barreled version of the frigate class 150mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2,1,NULL,22214.0000,1,565,0),(568,74,'Heavy Neutron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,25,1,1,NULL,133234.0000,1,562,0),(569,74,'Heavy Ion Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1.5,1,NULL,99930.0000,1,562,0),(570,74,'250mm Railgun I','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,25,0.5,1,NULL,166754.0000,1,565,0),(571,74,'Electron Blaster Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,50,5,1,NULL,683790.0000,1,563,0),(572,74,'Dual 250mm Railgun I','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,NULL,253166.0000,1,566,0),(573,74,'Neutron Blaster Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,50,2,1,NULL,1568334.0000,1,563,0),(574,74,'425mm Railgun I','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,50,1,1,NULL,2015232.0000,1,566,0),(575,74,'Ion Blaster Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,50,3,1,NULL,1116734.0000,1,563,0),(577,76,'Medium Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,10,32,1,NULL,40356.0000,1,700,0),(578,77,'Adaptive Invulnerability Field I','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,20,0,1,NULL,83310.0000,1,1696,0),(580,80,'ECM Burst I','Emits random electronic bursts which have a chance of momentarily disrupting target locks on ships within range.\r\r\n\r\r\nGiven the unstable nature of the bursts and the amount of internal shielding needed to ensure they do not affect their own point of origin, only battleship-class vessels can use this module to its fullest extent. \r\r\n\r\r\nNote: Only one module of this type can be activated at the same time.',5000,5,0,1,NULL,71572.0000,1,678,0),(581,82,'Passive Targeter I','Uses advanced gravitational and visual targeting to identify threats. Allows target lock without alerting the ship to a possible threat.',2000,25,0,1,NULL,27778.0000,1,672,0),(582,25,'Bantam','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. In the Caldari State, this led to the redesign and redeployment of the Bantam.\r\r\n\r\r\nThe Bantam, a strong and sturdy craft, was originally an extremely effective mining frigate. After its redesign, the Bantam\'s large structure had to give way for logistics systems that ate up some of its interior room but allowed it to focus extensively on shield support for fellow vessels.',1480000,20000,270,1,1,259868.0000,1,61,0),(583,25,'Condor','The Condor is fast and agile. It has limited cargo space so it\'s not very suitable for trading or mining. It is best used as an assault vessel in a hit-and-run type of operations.',1100000,18000,130,1,1,224000.0000,1,61,0),(584,25,'Griffin','The Griffin is much used by the Caldari Navy as a support vessel in combat squadrons, using its impressive array of electronic gadgetry to disrupt the operation of target ships, making them easy prey for traditional combat vessels.',1056000,19400,260,1,1,333530.0000,1,61,0),(585,25,'Slasher','The Slasher is cheap, but versatile. It\'s been manufactured en masse, making it one of the most common vessels in Minmatar space. The Slasher is extremely fast, with decent armaments, and is popular amongst budding pirates and smugglers.',1075000,17400,120,1,2,250126.0000,1,64,0),(586,25,'Probe','The Probe is large compared to most Minmatar frigates and is considered a good scout and cargo-runner.  Uncharacteristically for a Minmatar ship, its hard outer coating makes it difficult to destroy, while the limited weapon hardpoints force it to rely on drone assistance if engaged in combat.',1123000,19500,400,1,2,374712.0000,1,64,0),(587,25,'Rifter','The Rifter is a very powerful combat frigate and can easily tackle the best frigates out there. It has gone through many radical design phases since its inauguration during the Minmatar Rebellion. The Rifter has a wide variety of offensive capabilities, making it an unpredictable and deadly adversary.',1067000,27289,140,1,2,366116.0000,1,64,0),(588,237,'Reaper','The Reaper-class is one of the smallest of the Minmatar vessels, just barely reaching rookie ship status instead of a manned fighter. The Reaper is very cheap and is used en masse in daring hit-and-run operations by Minmatars either side of the law.',1157000,15800,120,1,2,0.0000,1,1819,0),(589,25,'Executioner','The Executioner is another newly commissioned ship of the Amarr Imperial Navy. The Executioner was designed specially to counter the small, fast raider frigates of the Minmatar Republic; thus it is different from most Amarr ships in favoring speed over defenses. With the Executioner, the Amarrians have expanded their tactical capabilities on the battlefield.',1090000,28100,115,1,4,234844.0000,1,72,0),(590,25,'Inquisitor','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. In the Amarr Empire, this led to the redesign and redeployment of the Inquisitor.\r\r\n\r\r\nThe Inquisitor was originally an example of how the Amarr Imperial Navy modeled their design to counter specific tactics employed by the other empires. After its redesign, it was exclusively devoted to the role of a support frigate, and its formerly renowned missile capabilities gave way to a focus on remote armor repair.\r\r\n',1630000,28700,250,1,4,244966.0000,1,72,0),(591,25,'Tormentor','The Tormentor has been in service for many decades. For most of that time it saw service as a mining ship, its size barring it from making any kind of impact on the battlefield. As with most Amarr ships, however, its strong defenses always made it a tough opponent to crack, and with recent advances in turret capacitor use and damage output, its lasers have now stopped digging into dead ore and are instead focused on boring through the hulls of hapless vessels in combat.',1080000,24398,130,1,4,302204.0000,1,72,0),(592,25,'Navitas','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. In the Gallente Federation, this led to the redesign and redeployment of the Navitas.\r\r\n\r\r\nThe Navitas had been a solid mining vessel that had seen wide use by independent excavators, along with being one of the best ships available for budding traders and even for much-maligned scavengers. After its redesign, its long-range scanners and sturdy outer shell gave way entirely for remote repairing capabilities, moving the Navitas away from the calming buzz of mining lasers and into the roar of battle.',1450000,10000,280,1,8,265962.0000,1,77,0),(593,25,'Tristan','Often nicknamed The Fat Man this nimble little frigate is mainly used by the Federation in escort duties or on short-range patrols. The Tristan has been very popular throughout Gallente space for years because of its versatility. It is rather expensive, but buyers will definitely get their money\'s worth, as the Tristan is one of the more powerful frigates available on the market.',956000,26500,140,1,8,337330.0000,1,77,0),(594,25,'Incursus','The Incursus may be found both spearheading and bulwarking Gallente military operations. Its speed makes it excellent for skirmishing duties, while its resilience helps it outlast its opponents on the battlefield. Incursus-class ships move together in groups and can quickly and effectively gang up on ships many times their size and overwhelm them. In recent years the Incursus has increasingly found its way into the hands of pirates, who love its aggressive appearance. ',1028000,29500,165,1,8,281058.0000,1,77,0),(595,25,'Gallente Police Ship','The standard police vessel of the Gallente Federation. Renowned for its high quality equipment and loadout.',2040000,20400,200,1,8,0.0000,0,NULL,0),(596,237,'Impairor','The Impairor-class rookie ship has been mass-produced by the Amarr Empire for decades. It is the most common spacevessel sighted within the Amarrian boundaries, and is used both as a basic trade vessel and as a small-scale slave transport. ',1148000,28100,115,1,4,0.0000,1,1816,0),(597,25,'Punisher','The Punisher is considered by many to be one of the best Amarr frigates in existence. As evidenced by its heavy armaments, the Punisher is mainly intended for large-scale military operations, acting in coordination with larger military vessels. With its damage output, however, it is also perfectly capable of punching its way right through unwary opponents.',1190000,28600,135,1,4,353292.0000,1,72,0),(598,25,'Breacher','The Breacher\'s structure is little more than a fragile scrapheap, but the ship\'s missile launcher hardpoints and superior sensors have placed it among the most valued Minmatar frigates when it comes to long range combat.',1087000,20000,175,1,2,284260.0000,1,64,0),(599,25,'Burst','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. In the Minmatar Republic, this led to the redesign and redeployment of the Burst.\r\r\n\r\r\nThe Burst had been a small and fast cargo vessel. This all changed after the redesign, when the Burst found its small-time mining capabilities curtailed in lieu of logistics systems that moved its focus to shield support for friendly vessels.',1420000,17100,260,1,2,265740.0000,1,64,0),(600,25,'Minmatar Peacekeeper Ship','Minmatar Police 1',1200000,12000,80,1,2,0.0000,0,NULL,0),(601,237,'Ibis','The Caldari Ibis rookie ship is a small but stout vessel that fits admirably well as a cargo hauler or small-scale miner. Its reliability makes it a good choice for novice ship captains.',1163000,15000,125,1,1,0.0000,1,1817,0),(602,25,'Kestrel','The Kestrel is a heavy missile boat with one of the most sophisticated sensor arrays around. Interestingly enough, it has been used by both the Caldari Navy and several wealthy trade corporations as a cargo-hauling vessel. It is one of few trading vessels with good punching power, making it ideal for solo trade-runs in dangerous areas. The Kestrel was designed so that it could take up to four missile launchers but as a result it can not be equipped with turret weapons nor with mining lasers.',1113000,19700,160,1,1,388388.0000,1,61,0),(603,25,'Merlin','The Merlin is the most powerful combat frigate of the Caldari. Its role has evolved through the years, and while its defenses have always remained exceptionally strong for a Caldari vessel, its offensive capabilities have evolved from versatile, jack-of-all-trades attack patterns into focused and deadly gunfire tactics. The Merlin\'s primary aim is to have its turrets punch holes in opponents\' hulls.',997000,16500,150,1,1,330262.0000,1,61,0),(605,25,'Heron','The Heron has good computer and electronic systems, giving it the option of participating in electronic warfare. But it has relatively poor defenses and limited weaponry, so it\'s more commonly used for scouting and exploration.',1150000,18900,400,1,1,391906.0000,1,61,0),(606,237,'Velator','The Velator class rookie ship is one of the older vessel types in the Gallente fleet. It was first deployed on the market as a fast passenger craft but the extra passenger quarters were later modified into weapon hardpoints as the newer models came to be used for small-scale security and military duties. The Velator is still a very solid mining and trading vessel.',1148000,24500,135,1,8,0.0000,1,1818,0),(607,25,'Imicus','The Imicus is a slow but hard-shelled frigate, ideal for any type of scouting activity. Used by merchant, miner and combat groups, the Imicus is usually relied upon as the operation\'s eyes and ears when traversing low security sectors.',997000,21500,400,1,8,383638.0000,1,77,0),(608,25,'Atron','The Atron is a hard nugget with an advanced power conduit system, but little space for cargo. Although it is a good harvester when it comes to mining, its main ability is as a combat vessel.',1050000,22500,145,1,8,232160.0000,1,77,0),(609,25,'Maulus','The Maulus is a high-tech vessel, specialized for electronic warfare. It is particularly valued in fleet warfare due to its optimization for sensor dampening technology.',1063000,23000,275,1,8,225264.0000,1,77,0),(613,25,'Devourer','Pirate Frigate 2',1200000,19100,110,1,2,0.0000,0,NULL,0),(614,25,'Fury','Pirate Frigate 3',1200000,26000,180,1,2,0.0000,0,NULL,0),(615,237,'Immolator','The Immolator is a small ship, designed by the upper (read: unslaved) echelon of Sansha\'s Nation to serve as a good entry for those pilots new to the glory of Nation. It excels in picking off smaller targets and hitting them hard with energy beams.',1148000,17400,115,1,4,0.0000,1,1619,0),(616,25,'Medusa','Pirate Frigate 5',1200000,17500,30,1,2,0.0000,0,NULL,0),(617,237,'Echo','The Echo is a small vessel, designed by the Angel Cartel to be easily missed in the heat of battle, while posing a viable threat in combat. As such, it is intended to rush in with guns blazing and subsequently escape without being eaten up by larger ships.',1157000,17660,120,1,2,0.0000,1,1619,0),(618,25,'Lynx','Pirate Frigate 7',1200000,22500,200,1,2,0.0000,0,NULL,0),(619,25,'Swordspine','Pirate Frigate 8',1047000,21120,220,1,2,0.0000,0,NULL,0),(620,26,'Osprey','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. Both Frigate and Cruiser-class ships were put under the microscope, and in the Caldari State the outcome of the re-evaluation process led, among other developments, to a redesign and redeployment of the Osprey.\r\r\n\r\r\nThe Osprey originally offered excellent versatility and power for what was considered a comparably low price. After its redesign, its inbuilt mining technology - now a little creaky and long in the tooth - was gutted from the Osprey and replaced in its entirety with tech of a different type, capable of high energy and shield transfers.',11100000,107000,485,1,1,8321496.0000,1,75,0),(621,26,'Caracal','The Caracal is a powerful vessel that specializes in missile deployment. It has excellent shield defenses, but poor armor plating. Its missile arsenal, when fully stocked, is capable of making mincemeat of almost anyone.',11910000,92000,450,1,1,13705288.0000,1,75,0),(622,26,'Stabber','The Stabber is the mainstay of the Minmatar fleet. It is light and extremely fast, yet surprisingly powerful, with a wide variety of weapons. It is one of few Minmatar vessels that have reached popularity outside Minmatar space.',11400000,80000,420,1,2,11104854.0000,1,73,0),(623,26,'Moa','The Moa was designed as an all-out combat ship, and its heavy armament allows the Moa to tackle almost anything that floats in space. In contrast to its nemesis the Thorax, the Moa is most effective at long range where its railguns can rain death upon foes.',12000000,101000,450,1,1,12149230.0000,1,75,0),(624,26,'Maller','Quite possibly the toughest cruiser in the galaxy, the Maller is a common sight in Amarrian Imperial Navy operations. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches.',13150000,118000,480,1,4,11502474.0000,1,74,0),(625,26,'Augoror','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. Both Frigate and Cruiser-class ships were put under the microscope, and in the Amarr Empire the outcome of the re-evaluation process led, among other developments, to a redesign and redeployment of the Augoror.\r\r\n\r\r\nThe Augoror-class cruiser is one of the old warhorses of the Amarr Empire, having seen action in both the Jovian War and the Minmatar Rebellion. Like most Amarr vessels, the Augoror depended first and foremost on its resilience and heavy armor to escape unscathed from unfriendly encounters. After its overhaul, it had some of the armor stripped off to make room for equipment allowing it to focus on the armor of other vessels, along with energy transfers.',12870000,115000,465,1,4,7686436.0000,1,74,0),(626,26,'Vexor','The Vexor is a strong combat ship that is also geared to operate in a variety of other roles. The Vexor is especially useful for surveying in potentially hostile sectors as it can stay on duty for a very long time before having to return to base. Furthermore, it is well capable of defending itself against even concentrated attacks.',11100000,115000,480,1,8,12003364.0000,1,76,0),(627,26,'Thorax','The Thorax-class cruiser is the latest combat ship commissioned by the Federation. While the Thorax is a very effective ship at any range, typical of modern Gallente design philosophy it is most effective when working at extreme close range where its blasters and hordes of combat drones tear through even the toughest of enemies.',11280000,112000,465,1,8,11124452.0000,1,76,0),(628,26,'Arbitrator','The Arbitrator is unusual for Amarr ships in that it\'s primarily a drone carrier. While it is not the best carrier around, it has superior armor that gives it greater durability than most ships in its class.',11200000,120000,345,1,4,9375896.0000,1,74,0),(629,26,'Rupture','The Rupture is slow for a Minmatar ship, but it more than makes up for it in power. The Rupture has superior firepower and is used by the Minmatar Republic both to defend space stations and other stationary objects and as part of massive attack formations.',12200000,96000,450,1,2,12012230.0000,1,73,0),(630,26,'Bellicose','Being a highly versatile class of Minmatar ships, the Bellicose has been used as a combat juggernaut as well as a support ship for wings of frigates. While not quite in the league of newer navy cruisers, the Bellicose is still a very solid ship for most purposes, especially in terms of long range combat.',11550000,85000,315,1,2,8858050.0000,1,73,0),(631,26,'Scythe','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. Both Frigate and Cruiser-class ships were put under the microscope, and in the Minmatar Republic  the outcome of the re-evaluation process led, among other developments, to a redesign and redeployment of the Scythe.\r\r\n\r\r\nThe Scythe-class cruiser remains the oldest Minmatar ship still in use. It has seen many battles and is an integrated part in Minmatar tales and heritage. With its redesign, past firmware upgrades for mining output were tossed out entirely in favor of two new separate systems that focused on shield transporting and logistics drones respectively.',11110000,89000,475,1,2,7971114.0000,1,73,0),(632,26,'Blackbird','The Blackbird is a small high-tech cruiser newly employed by the Caldari Navy. Commonly seen in fleet battles or acting as wingman, it is not intended for head-on slugfests, but rather delicate tactical situations. ',13190000,96000,305,1,1,10565614.0000,1,75,0),(633,26,'Celestis','The Celestis cruiser is a versatile ship which can be employed in a myriad of roles, making it handy for small corporations with a limited number of ships. True to Gallente style the Celestis is especially deadly in close quarters combat due to its advanced targeting systems.',12070000,116000,320,1,8,9231892.0000,1,76,0),(634,26,'Exequror','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. Both Frigate and Cruiser-class ships were put under the microscope, and in the Gallente Federation the outcome of the re-evaluation process led, among other developments, to a redesign and redeployment of the Exequoror.\r\r\n\r\r\nThe Exequror was a heavy cargo cruiser originally strong enough to defend itself against raiding frigates, though it lacked prowess in heavier combat situations. After its redesign, it had some of that bulk - and, necessarily, some of that strength - yanked out and replaced with the capability to help others in heavy combat situations, in particular those who needed armor repairs.',11020000,113000,495,1,8,8223414.0000,1,76,0),(635,26,'Opux Luxury Yacht','The Opux Luxury Yachts are normally used by the entertainment industry for pleasure tours for wealthy Gallente citizens. These Opux Luxury Yacht cruisers are rarely seen outside of Gallente controlled space, but are extremely popular within the Federation.',13075000,115000,1750,1,8,0.0000,1,1699,0),(638,27,'Raven','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.',99300000,486000,665,1,1,198117134.0000,1,80,0),(639,27,'Tempest','The Tempest is one of the Republic Fleet\'s key vessels; a versatile gunship proficient at long-range bombardment and capable of dishing out specialized types of damage with great effectiveness. A well-rounded squadron of Tempests has been proven time and time again to be an invaluable wild card in a fleet battle, one which opponents should ignore at their own peril.',99500000,450000,600,1,2,187005890.0000,1,78,0),(640,27,'Scorpion','The first Scorpion-class battleship was launched only a couple of years ago, and those that have been built are considered to be prototypes. Little is known of its capabilities, but what has been garnered suggests that the Scorpion is crammed to the brink with sophisticated hi-tech equipment that few can match.',103600000,468000,550,1,1,186230718.0000,1,80,0),(641,27,'Megathron','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.',98400000,486000,675,1,8,190932898.0000,1,81,0),(642,27,'Apocalypse','In days past, only those in high favor with the Emperor could hope to earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. In latter years, even though now in full market circulation, these golden, metallic monstrosities are still feared and respected as enduring symbols of Amarrian might.',97100000,495000,675,1,4,199648910.0000,1,79,0),(643,27,'Armageddon','The mighty Armageddon class is one of the enduring warhorses of the Amarr Empire. Once a juggernaut that steamrolled its way into battle, it has now taken on a more stately and calculated approach, sending out a web of drones in its place while it drains the enemy from a distance.',105200000,486000,600,1,4,251111582.0000,1,79,0),(644,27,'Typhoon','Much praised by its proponents and much maligned by its detractors, the Typhoon-class battleship has always been one of the most hotly debated spacefaring vessels around. Its distinguishing aspect - and the source of most of the controversy - is its sheer versatility, variously seen as either a lack of design focus or a deliberate freedom for pilot modification. ',100600000,414000,625,1,2,178394358.0000,1,78,0),(645,27,'Dominix','The Dominix is one of the old warhorses dating back to the Gallente-Caldari War. While no longer regarded as the king of the hill, it is by no means obsolete. Its formidable hulk and powerful drone arsenal means that anyone not in the largest and latest battleships will regret ever locking horns with it.',100250000,454500,600,1,8,220059424.0000,1,81,0),(648,28,'Badger','The Badger-class industrial is the main cargo-carrier for the Caldari State, particularly in long, arduous trade-runs.  It s huge size and comfortable armament makes it perfectly equipped for those tasks, although the Caldari seldom let it roam alone.\r\r\n',10650000,250000,3900,1,1,860870.0000,1,84,0),(649,28,'Tayra','The Tayra, an evolution of the now-defunct Badger Mark II, focuses entirely on reaching the highest potential capacity that Caldari engineers can manage.',13000000,270000,7300,1,1,1043248.0000,1,84,0),(650,28,'Nereus','Originally set to sail under the guise of \"Iteron\", this new iteration of an old stalwart is fast and reliable. It is equally popular among civilians and militaries due to its low price and ability to be fitted in myriad different ways. Despite its speed and resilience, however, it may need to be guarded while in particularly unfriendly territories, which is why it has also been outfitted with a drone bay for extra protection.',11250000,240000,2700,1,8,843178.0000,1,83,0),(651,28,'Hoarder','Aside from being endowed with the usual hauling capabilities of Industrials, the Hoarder possesses an extra cargo bay. That bay is a static-free, blast-proof chamber, and as such is meant to be dedicated solely to ferrying consumable charges of all kinds, including ammunition, missiles, capacitor charges, nanite paste and bombs. ',10625000,400000,500,1,2,855008.0000,1,82,0),(652,28,'Mammoth','The Mammoth is the largest industrial ship of the Minmatar Republic. It was designed with aid from the Gallente Federation, making the Mammoth both large and powerful yet also nimble and technologically advanced. A very good buy.',11500000,255000,5500,1,2,1243218.0000,1,82,0),(653,28,'Wreathe','The Wreathe is an old ship of the Minmatar Republic and one of the oldest ships still in usage. The design of the Wreathe is very plain, which is the main reason for its longevity, but it also makes the ship incapable of handling anything but the most mundane tasks.',10000000,225000,2900,1,2,795556.0000,1,82,0),(654,28,'Kryos','Aside from being endowed with the usual hauling capabilities of Industrials, the Kryos possesses an extra cargo bay. That bay is equipped with precise temperature and pressure controls, and is dedicated solely to ferrying minerals. The Kryos was originally designed as a variant of the Iteron, but eventually evolved to perform an entirely separate role.',12625000,245000,550,1,8,930102.0000,1,83,0),(655,28,'Epithal','Aside from being endowed with the usual hauling capabilities of Industrials, the Epithal possesses an extra cargo bay. That bay is equipped with sealed sub-chambers capable of maintaining hospitable environments for practically any kind of organism or entity, from biocells to viral agents, and is meant solely for ferrying planetary commodities. The Epithal was originally designed as a variant of the Iteron, but eventually evolved to perform an entirely separate role.',12800000,250000,550,1,8,765984.0000,1,83,0),(656,28,'Miasmos','Aside from being endowed with the usual hauling capabilities of Industrials, the Miasmos possesses an extra cargo bay. That bay is equipped with sealed, temperature-controlled vats, and is meant solely for ferrying all types of interstellar ore: ice, gasses and asteroids. The Miasmos was originally designed as a variant of the Iteron, but eventually evolved to perform an entirely separate role.',12975000,265000,550,1,8,847316.0000,1,83,0),(657,28,'Iteron Mark V','This lumbering giant is the latest and last iteration in a chain of haulers. It is the only one to retain the original \"Iteron\"-class callsign, but while all the others eventually evolved into specialized versions, the Iteron Mk. V still does what haulers do best: Transporting enormous amounts of goods and commodities between the stars.',13500000,275000,5800,1,8,1241352.0000,1,83,0),(670,29,'Capsule','Standard capsule.',32000,1000,0,1,16,0.0000,0,NULL,0),(671,30,'Erebus','From the formless void\'s gaping maw, there springs an entity.  Not an entity such as any you can conceive of, nor I; an entity more primordial than the elements themselves, yet constantly coming into existence even as it is destroyed.  It is the Child of Chaos, the Pathway to the Next.\r\r\n\r\r\nThe darkness shall swallow the land, and in its wake there will follow a storm, as the appetite of nothing expands over the world.\r\r\n\r\r\nFrom the formless void\'s gaping maw, there springs an entity.\r\r\n\r\r\n<i>-Dr. Damella Macaper,\r\r\nThe Seven Events of the Apocalypse</i>\r\r\n\r\r\n',2379370000,145500000,16250,1,8,82648782748.0000,1,815,0),(672,31,'Caldari Shuttle','Caldari Shuttle',1600000,5000,10,1,1,5556.0000,1,396,0),(681,104,'Clone Grade Beta Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(682,104,'Clone Grade Gamma Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(683,105,'Bantam Blueprint',' ',0,0.01,0,1,NULL,2550000.0000,1,261,0),(684,105,'Condor Blueprint',' ',0,0.01,0,1,NULL,2150000.0000,1,261,0),(685,105,'Griffin Blueprint',' ',0,0.01,0,1,NULL,2350000.0000,1,261,0),(686,106,'Osprey Blueprint',' ',0,0.01,0,1,NULL,80500000.0000,1,275,0),(687,106,'Caracal Blueprint',' ',0,0.01,0,1,NULL,82500000.0000,1,275,0),(688,107,'Raven Blueprint',' ',0,0.01,0,1,NULL,1135000000.0000,1,280,0),(689,105,'Slasher Blueprint',' ',0,0.01,0,1,NULL,2100000.0000,1,264,0),(690,105,'Probe Blueprint',' ',0,0.01,0,1,NULL,2700000.0000,1,264,0),(691,105,'Rifter Blueprint',' ',0,0.01,0,1,NULL,2800000.0000,1,264,0),(692,106,'Stabber Blueprint',' ',0,0.01,0,1,NULL,82000000.0000,1,273,0),(693,107,'Tempest Blueprint',' ',0,0.01,0,1,NULL,1055000000.0000,1,278,0),(784,134,'Miner II Blueprint',' ',0,0.01,0,1,NULL,463600.0000,1,NULL,0),(785,134,'Miner I Blueprint',' ',0,0.01,0,1,NULL,92720.0000,1,338,0),(786,136,'Light Missile Launcher I Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,340,0),(788,136,'Heavy Missile Launcher I Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,340,0),(790,136,'Torpedo Launcher I Blueprint',' ',0,0.01,0,1,NULL,999960.0000,1,340,0),(803,166,'Mjolnir Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,5000000.0000,1,1526,0),(804,166,'Scourge Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,3000000.0000,1,1526,0),(805,166,'Inferno Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,4000000.0000,1,1526,0),(806,166,'Nova Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,2500000.0000,1,1526,0),(807,166,'Nova Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,700000.0000,1,1527,0),(808,166,'Mjolnir Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,900000.0000,1,1527,0),(809,166,'Inferno Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,800000.0000,1,1527,0),(810,166,'Scourge Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,750000.0000,1,1527,0),(811,166,'Scourge Light Missile Blueprint',' ',1,0.01,0,1,NULL,150000.0000,1,1528,0),(812,166,'Inferno Light Missile Blueprint',' ',1,0.01,0,1,NULL,160000.0000,1,1528,0),(813,166,'Mjolnir Light Missile Blueprint',' ',1,0.01,0,1,NULL,180000.0000,1,1528,0),(814,166,'Nova Light Missile Blueprint',' ',1,0.01,0,1,NULL,140000.0000,1,1528,0),(819,135,'125mm Gatling AutoCannon I Blueprint',' ',0,0.01,0,1,NULL,20000.0000,1,296,0),(820,135,'150mm Light AutoCannon I Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,296,0),(821,135,'200mm AutoCannon I Blueprint',' ',0,0.01,0,1,NULL,90000.0000,1,296,0),(822,135,'250mm Light Artillery Cannon I Blueprint',' ',0,0.01,0,1,NULL,120000.0000,1,296,0),(823,135,'280mm Howitzer Artillery I Blueprint',' ',0,0.01,0,1,NULL,150000.0000,1,296,0),(824,135,'Dual 180mm AutoCannon I Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,297,0),(825,135,'220mm Vulcan AutoCannon I Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,297,0),(826,135,'425mm AutoCannon I Blueprint',' ',0,0.01,0,1,NULL,900000.0000,1,297,0),(827,135,'650mm Artillery Cannon I Blueprint',' ',0,0.01,0,1,NULL,1200000.0000,1,297,0),(828,135,'720mm Howitzer Artillery I Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,297,0),(829,135,'Dual 425mm AutoCannon I Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,298,0),(830,135,'Dual 650mm Repeating Cannon I Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,1,298,0),(831,135,'800mm Repeating Cannon I Blueprint',' ',0,0.01,0,1,NULL,9000000.0000,1,298,0),(832,135,'1200mm Artillery Cannon I Blueprint',' ',0,0.01,0,1,NULL,12000000.0000,1,298,0),(833,135,'1400mm Howitzer Artillery I Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,298,0),(834,133,'Gatling Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,20000.0000,1,292,0),(835,133,'Dual Light Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,292,0),(836,133,'Dual Light Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,90000.0000,1,292,0),(837,133,'Small Focused Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,120000.0000,1,292,0),(838,133,'Small Focused Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,150000.0000,1,292,0),(839,133,'Quad Light Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,185280.0000,1,293,0),(840,133,'Focused Medium Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,293,0),(841,133,'Focused Medium Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,900000.0000,1,293,0),(842,133,'Heavy Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,1200000.0000,1,293,0),(843,133,'Heavy Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,293,0),(844,133,'Dual Heavy Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,295,0),(845,133,'Dual Heavy Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,1,295,0),(846,133,'Mega Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,9000000.0000,1,295,0),(847,133,'Mega Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,12000000.0000,1,295,0),(848,133,'Tachyon Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,295,0),(879,165,'Carbonized Lead S Blueprint',' ',0,0.01,0,1,NULL,20000.0000,1,313,0),(880,165,'Nuclear S Blueprint',' ',0,0.01,0,1,NULL,30000.0000,1,313,0),(881,165,'Proton S Blueprint',' ',0,0.01,0,1,NULL,40000.0000,1,313,0),(882,165,'Depleted Uranium S Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,313,0),(883,165,'Titanium Sabot S Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,313,0),(884,165,'Fusion S Blueprint',' ',0,0.01,0,1,NULL,70000.0000,1,313,0),(885,165,'Phased Plasma S Blueprint',' ',0,0.01,0,1,NULL,80000.0000,1,313,0),(886,165,'EMP S Blueprint',' ',0,0.01,0,1,NULL,100000.0000,1,313,0),(887,165,'Carbonized Lead M Blueprint',' ',0,0.01,0,1,NULL,80000.0000,1,312,0),(888,165,'Nuclear M Blueprint',' ',0,0.01,0,1,NULL,120000.0000,1,312,0),(889,165,'Proton M Blueprint',' ',0,0.01,0,1,NULL,165000.0000,1,312,0),(890,165,'Depleted Uranium M Blueprint',' ',0,0.01,0,1,NULL,205000.0000,1,312,0),(891,165,'Titanium Sabot M Blueprint',' ',0,0.01,0,1,NULL,235000.0000,1,312,0),(892,165,'Fusion M Blueprint',' ',0,0.01,0,1,NULL,275000.0000,1,312,0),(893,165,'Phased Plasma M Blueprint',' ',0,0.01,0,1,NULL,325000.0000,1,312,0),(894,165,'EMP M Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,312,0),(895,165,'Carbonized Lead L Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,309,0),(896,165,'Nuclear L Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,309,0),(897,165,'Proton L Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,309,0),(898,165,'Depleted Uranium L Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,309,0),(899,165,'Titanium Sabot L Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,309,0),(900,165,'Fusion L Blueprint',' ',0,0.01,0,1,NULL,700000.0000,1,309,0),(901,165,'Phased Plasma L Blueprint',' ',0,0.01,0,1,NULL,800000.0000,1,309,0),(902,165,'EMP L Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,309,0),(935,105,'Reaper Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(936,105,'Executioner Blueprint',' ',0,0.01,0,1,NULL,2175000.0000,1,272,0),(937,105,'Inquisitor Blueprint',' ',0,0.01,0,1,NULL,2575000.0000,1,272,0),(938,105,'Tormentor Blueprint',' ',0,0.01,0,1,NULL,2875000.0000,1,272,0),(939,105,'Navitas Blueprint',' ',0,0.01,0,1,NULL,2525000.0000,1,277,0),(940,105,'Tristan Blueprint',' ',0,0.01,0,1,NULL,2825000.0000,1,277,0),(941,105,'Incursus Blueprint',' ',0,0.01,0,1,NULL,2825000.0000,1,277,0),(943,105,'Impairor Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(944,105,'Punisher Blueprint',' ',0,0.01,0,1,NULL,2875000.0000,1,272,0),(945,105,'Breacher Blueprint',' ',0,0.01,0,1,NULL,2800000.0000,1,264,0),(946,105,'Burst Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,264,0),(947,105,'Minmatar Peacekeeper Ship Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(948,105,'Ibis Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(949,105,'Kestrel Blueprint',' ',0,0.01,0,1,NULL,2850000.0000,1,261,0),(950,105,'Merlin Blueprint',' ',0,0.01,0,1,NULL,2850000.0000,1,261,0),(952,105,'Heron Blueprint',' ',0,0.01,0,1,NULL,2750000.0000,1,261,0),(953,105,'Velator Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(954,105,'Imicus Blueprint',' ',0,0.01,0,1,NULL,2725000.0000,1,277,0),(955,105,'Atron Blueprint',' ',0,0.01,0,1,NULL,2125000.0000,1,277,0),(956,105,'Maulus Blueprint',' ',0,0.01,0,1,NULL,2325000.0000,1,277,0),(960,105,'Devourer Blueprint',' ',0,0.01,0,1,2,9999999.0000,0,NULL,0),(961,105,'Fury Blueprint',' ',0,0.01,0,1,2,9999999.0000,0,NULL,0),(962,105,'Immolator Blueprint',' ',0,0.01,0,1,4,9999999.0000,0,NULL,0),(963,105,'Medusa Blueprint',' ',0,0.01,0,1,2,9999999.0000,0,NULL,0),(964,105,'Echo Blueprint',' ',0,0.01,0,1,2,9999999.0000,0,NULL,0),(965,105,'Lynx Blueprint',' ',0,0.01,0,1,2,9999999.0000,0,NULL,0),(966,105,'Swordspine Blueprint',' ',0,0.01,0,1,2,9999999.0000,0,NULL,0),(967,111,'Caldari Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,416,0),(968,106,'Moa Blueprint',' ',0,0.01,0,1,NULL,83500000.0000,1,275,0),(969,106,'Maller Blueprint',' ',0,0.01,0,1,NULL,83750000.0000,1,274,0),(970,106,'Augoror Blueprint',' ',0,0.01,0,1,NULL,80750000.0000,1,274,0),(971,106,'Vexor Blueprint',' ',0,0.01,0,1,NULL,83250000.0000,1,276,0),(972,106,'Thorax Blueprint',' ',0,0.01,0,1,NULL,82250000.0000,1,276,0),(973,106,'Arbitrator Blueprint',' ',0,0.01,0,1,NULL,81750000.0000,1,274,0),(974,106,'Rupture Blueprint',' ',0,0.01,0,1,NULL,83000000.0000,1,273,0),(975,106,'Bellicose Blueprint',' ',0,0.01,0,1,NULL,81000000.0000,1,273,0),(976,106,'Scythe Blueprint',' ',0,0.01,0,1,NULL,80000000.0000,1,273,0),(977,106,'Blackbird Blueprint',' ',0,0.01,0,1,NULL,81500000.0000,1,275,0),(978,106,'Celestis Blueprint',' ',0,0.01,0,1,NULL,81250000.0000,1,276,0),(979,106,'Exequror Blueprint',' ',0,0.01,0,1,NULL,80250000.0000,1,276,0),(983,108,'Badger Blueprint',' ',0,0.01,0,1,NULL,3487500.0000,1,284,0),(984,108,'Tayra Blueprint',' ',0,0.01,0,1,NULL,7425000.0000,1,284,0),(985,108,'Nereus Blueprint',' ',0,0.01,0,1,NULL,3100000.0000,1,283,0),(986,108,'Hoarder Blueprint',' ',0,0.01,0,1,NULL,4525000.0000,1,282,0),(987,108,'Mammoth Blueprint',' ',0,0.01,0,1,NULL,9375000.0000,1,282,0),(988,108,'Wreathe Blueprint',' ',0,0.01,0,1,NULL,3225000.0000,1,282,0),(989,108,'Kryos Blueprint',' ',0,0.01,0,1,NULL,3425000.0000,1,283,0),(990,108,'Epithal Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,1,283,0),(991,108,'Miasmos Blueprint',' ',0,0.01,0,1,NULL,4287500.0000,1,283,0),(992,108,'Iteron Mark V Blueprint',' ',0,0.01,0,1,NULL,11250000.0000,1,283,0),(994,107,'Scorpion Blueprint',' ',0,0.01,0,1,NULL,1075000000.0000,1,280,0),(995,107,'Megathron Blueprint',' ',0,0.01,0,1,NULL,1250000000.0000,1,281,0),(996,107,'Apocalypse Blueprint',' ',0,0.01,0,1,NULL,1265000000.0000,1,279,0),(997,107,'Armageddon Blueprint',' ',0,0.01,0,1,NULL,1565000000.0000,1,279,0),(998,107,'Typhoon Blueprint',' ',0,0.01,0,1,NULL,975000000.0000,1,278,0),(999,107,'Dominix Blueprint',' ',0,0.01,0,1,NULL,1660000000.0000,1,281,0),(1002,110,'Erebus Blueprint',' ',0,0.01,0,1,NULL,72500000000.0000,1,886,0),(1010,118,'Small Shield Extender I Blueprint',' ',0,0.01,0,1,NULL,49920.0000,1,1549,0),(1013,118,'Small Shield Extender II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1026,119,'Shield Recharger I Blueprint',' ',0,0.01,0,1,NULL,87360.0000,1,1551,0),(1027,119,'Shield Recharger II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1032,120,'Small Shield Booster I Blueprint',' ',0,0.01,0,1,NULL,91160.0000,1,1552,0),(1033,120,'Small Shield Booster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1067,126,'5MN Microwarpdrive I Blueprint',' ',0,0.01,0,1,4,316360.0000,1,331,0),(1071,126,'1MN Afterburner II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1072,126,'1MN Afterburner I Blueprint',' ',0,0.01,0,1,NULL,64500.0000,1,1525,0),(1073,126,'5MN Microwarpdrive II Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(1074,127,'Cargo Scanner I Blueprint',' ',0,0.01,0,1,NULL,15000.0000,1,325,0),(1075,128,'Ship Scanner I Blueprint',' ',0,0.01,0,1,NULL,19840.0000,1,325,0),(1076,129,'Survey Scanner I Blueprint',' ',0,0.01,0,1,NULL,20000.0000,1,325,0),(1079,132,'Warp Scrambler I Blueprint',' ',0,0.01,0,1,NULL,394240.0000,1,1939,0),(1080,132,'Warp Scrambler II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1095,139,'Gyrostabilizer II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1096,139,'Gyrostabilizer I Blueprint',' ',0,0.01,0,1,NULL,243200.0000,1,343,0),(1099,142,'Small Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,1536,0),(1100,143,'Small Hull Repairer I Blueprint',' ',0,0.01,0,1,NULL,499980.0000,1,1537,0),(1102,145,'Stasis Webifier I Blueprint',' ',0,0.01,0,1,NULL,224880.0000,1,1570,0),(1103,145,'Stasis Webifier II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1105,147,'Small Remote Capacitor Transmitter I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1562,0),(1106,148,'Small Nosferatu I Blueprint',' ',0,0.01,0,1,NULL,395040.0000,1,1564,0),(1109,151,'Small Energy Neutralizer I Blueprint',' ',0,0.01,0,1,NULL,199680.0000,1,1565,0),(1112,154,'75mm Gatling Rail I Blueprint',' ',0,0.01,0,1,NULL,20000.0000,1,291,0),(1113,154,'Light Electron Blaster I Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,291,0),(1114,154,'Light Ion Blaster I Blueprint',' ',0,0.01,0,1,NULL,90000.0000,1,291,0),(1115,154,'Light Neutron Blaster I Blueprint',' ',0,0.01,0,1,NULL,120000.0000,1,291,0),(1116,154,'150mm Railgun I Blueprint',' ',0,0.01,0,1,NULL,150000.0000,1,291,0),(1117,154,'Heavy Electron Blaster I Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,290,0),(1118,154,'Dual 150mm Railgun I Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,290,0),(1119,154,'Heavy Neutron Blaster I Blueprint',' ',0,0.01,0,1,NULL,1200000.0000,1,290,0),(1120,154,'Heavy Ion Blaster I Blueprint',' ',0,0.01,0,1,NULL,900000.0000,1,290,0),(1121,154,'250mm Railgun I Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,290,0),(1122,154,'Electron Blaster Cannon I Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,1,289,0),(1123,154,'Dual 250mm Railgun I Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,289,0),(1124,154,'Neutron Blaster Cannon I Blueprint',' ',0,0.01,0,1,NULL,12000000.0000,1,289,0),(1125,154,'425mm Railgun I Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,289,0),(1126,154,'Ion Blaster Cannon I Blueprint',' ',0,0.01,0,1,NULL,9000000.0000,1,289,0),(1128,156,'Medium Capacitor Booster I Blueprint',' ',0,0.01,0,1,NULL,281240.0000,1,1563,0),(1129,157,'Adaptive Invulnerability Field I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1548,0),(1130,167,'Iron Charge S Blueprint',' ',0,0.01,0,1,NULL,20000.0000,1,307,0),(1131,167,'Tungsten Charge S Blueprint',' ',0,0.01,0,1,NULL,30000.0000,1,307,0),(1132,167,'Iridium Charge S Blueprint',' ',0,0.01,0,1,NULL,40000.0000,1,307,0),(1133,167,'Lead Charge S Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,307,0),(1134,167,'Thorium Charge S Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,307,0),(1135,167,'Uranium Charge S Blueprint',' ',0,0.01,0,1,NULL,70000.0000,1,307,0),(1136,167,'Plutonium Charge S Blueprint',' ',0,0.01,0,1,NULL,80000.0000,1,307,0),(1137,167,'Antimatter Charge S Blueprint',' ',0,0.01,0,1,NULL,100000.0000,1,307,0),(1138,167,'Iron Charge M Blueprint',' ',0,0.01,0,1,NULL,80000.0000,1,308,0),(1139,167,'Tungsten Charge M Blueprint',' ',0,0.01,0,1,NULL,110000.0000,1,308,0),(1140,167,'Iridium Charge M Blueprint',' ',0,0.01,0,1,NULL,150000.0000,1,308,0),(1141,167,'Lead Charge M Blueprint',' ',0,0.01,0,1,NULL,175000.0000,1,308,0),(1142,167,'Thorium Charge M Blueprint',' ',0,0.01,0,1,NULL,225000.0000,1,308,0),(1143,167,'Uranium Charge M Blueprint',' ',0,0.01,0,1,NULL,275000.0000,1,308,0),(1144,167,'Plutonium Charge M Blueprint',' ',0,0.01,0,1,NULL,325000.0000,1,308,0),(1145,167,'Antimatter Charge M Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,308,0),(1146,167,'Iron Charge L Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,306,0),(1147,167,'Tungsten Charge L Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,306,0),(1148,167,'Iridium Charge L Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,306,0),(1149,167,'Lead Charge L Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,306,0),(1150,167,'Thorium Charge L Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,306,0),(1151,167,'Uranium Charge L Blueprint',' ',0,0.01,0,1,NULL,700000.0000,1,306,0),(1152,167,'Plutonium Charge L Blueprint',' ',0,0.01,0,1,NULL,800000.0000,1,306,0),(1153,167,'Antimatter Charge L Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,306,0),(1154,168,'Radio S Blueprint',' ',0,0.01,0,1,NULL,30000.0000,1,302,0),(1155,168,'Microwave S Blueprint',' ',0,0.01,0,1,NULL,20000.0000,1,302,0),(1156,168,'Infrared S Blueprint',' ',0,0.01,0,1,NULL,10000.0000,1,302,0),(1157,168,'Standard S Blueprint',' ',0,0.01,0,1,NULL,12500.0000,1,302,0),(1158,168,'Ultraviolet S Blueprint',' ',0,0.01,0,1,NULL,15000.0000,1,302,0),(1159,168,'Xray S Blueprint',' ',0,0.01,0,1,NULL,25000.0000,1,302,0),(1160,168,'Gamma S Blueprint',' ',0,0.01,0,1,NULL,35000.0000,1,302,0),(1161,168,'Multifrequency S Blueprint',' ',0,0.01,0,1,NULL,40000.0000,1,302,0),(1162,168,'Radio M Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,303,0),(1163,168,'Microwave M Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,303,0),(1164,168,'Infrared M Blueprint',' ',0,0.01,0,1,NULL,100000.0000,1,303,0),(1165,168,'Standard M Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,303,0),(1166,168,'Ultraviolet M Blueprint',' ',0,0.01,0,1,NULL,150000.0000,1,303,0),(1167,168,'Xray M Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,303,0),(1168,168,'Gamma M Blueprint',' ',0,0.01,0,1,NULL,350000.0000,1,303,0),(1169,168,'Multifrequency M Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,303,0),(1170,168,'Radio L Blueprint',' ',0,0.01,0,1,NULL,3000000.0000,1,305,0),(1171,168,'Microwave L Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,305,0),(1172,168,'Infrared L Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,305,0),(1173,168,'Standard L Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,305,0),(1174,168,'Ultraviolet L Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,305,0),(1175,168,'Xray L Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,305,0),(1176,168,'Gamma L Blueprint',' ',0,0.01,0,1,NULL,3500000.0000,1,305,0),(1177,168,'Multifrequency L Blueprint',' ',0,0.01,0,1,NULL,4000000.0000,1,305,0),(1178,169,'Cap Booster 25 Blueprint',' ',0,0.01,0,1,NULL,100000.0000,1,339,0),(1179,169,'Cap Booster 50 Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,339,0),(1182,96,'Auto Targeting System I','Targets any hostile ship within range on activation. Grants a +2 bonus to ship\'s max targets when online.',30,5,0,1,NULL,3208.0000,1,670,0),(1183,62,'Small Armor Repairer II','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,101226.0000,1,1049,0),(1184,142,'Small Armor Repairer II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1185,61,'Small Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,5,0,1,NULL,10960.0000,1,703,0),(1186,141,'Small Capacitor Battery I Blueprint',' ',0,0.01,0,1,NULL,100000.0000,1,1558,0),(1190,67,'Small Remote Capacitor Transmitter II','Transfers capacitor energy to another ship.',10000,5,0,1,NULL,361888.0000,1,695,0),(1191,147,'Small Remote Capacitor Transmitter II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1192,764,'\'Basic\' Overdrive Injector System','This unit increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,4,10000.0000,1,1087,0),(1193,98,'Basic EM Plating','An array of microscopic reactive prizms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,1984.0000,1,1668,0),(1194,99,'Amarr Sentry Gun','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,4,0.0000,0,NULL,0),(1195,43,'Cap Recharger I','Increases the capacitor recharge rate.',1,5,0,1,NULL,33662.0000,1,665,0),(1196,123,'Cap Recharger I Blueprint',' ',0,0.01,0,1,NULL,237500.0000,1,1555,0),(1197,98,'EM Plating I','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1668,0),(1198,98,'EM Plating II','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,41576.0000,1,1668,0),(1201,100,'Wasp I','Heavy Attack Drone',10000,25,0,1,1,74430.0000,1,839,0),(1202,101,'Civilian Mining Drone','Civilian Mining Drone',0,5,0,1,NULL,21360.0000,1,158,0),(1204,163,'EM Plating I Blueprint',' ',0,0.01,0,1,NULL,49740.0000,1,1544,0),(1205,163,'EM Plating II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1208,162,'Auto Targeting System I Blueprint',' ',0,0.01,0,1,NULL,29440.0000,1,1579,0),(1210,160,'ECM Burst I Blueprint',' ',0,0.01,0,1,NULL,416640.0000,1,1568,0),(1212,161,'Passive Targeter I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1582,0),(1214,176,'Wasp I Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,359,0),(1215,170,'Heavy Defender Missile I Blueprint',' ',0,0.01,0,1,NULL,150000.0000,1,316,0),(1216,166,'Mjolnir Auto-Targeting Light Missile I Blueprint',' ',1,0.01,0,1,NULL,180000.0000,1,315,0),(1217,174,'Python Mine Blueprint',' ',0,0.01,0,1,NULL,136400.0000,0,NULL,0),(1218,177,'Civilian Mining Drone Blueprint','Civilian Mining Drone Blueprint',0,0.01,0,1,NULL,1498600.0000,1,358,0),(1220,166,'Scourge Rocket Blueprint',' ',1,0.01,0,1,NULL,45000.0000,1,318,0),(1221,166,'Scourge Torpedo Blueprint',' ',1,0.01,0,1,NULL,9000000.0000,1,390,0),(1223,451,'Bistot','Bistot is a very valuable ore as it holds large portions of two of the rarest minerals in the universe, zydrine and megacyte. It also contains a decent amount of pyerite.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,1836800.0000,1,514,0),(1224,459,'Pyroxeres','Pyroxeres is an interesting ore type, as it is very plain in most respects except one - deep core reprocessing yields a little bit of nocxium, increasing its value considerably. It also has a large portion of tritanium and some pyerite and mexallon.\r\r\n\r\r\nAvailable in <color=\'0xFF4DFFCC\'>0.9</color> security status solar systems or lower.',1e35,0.3,0,100,NULL,5062.0000,1,515,0),(1225,452,'Crokite','Crokite is a very heavy ore that is always in high demand because it has the largest ratio of nocxium for any ore in the universe. Valuable deposits of zydrine and tritanium can also be found within this rare ore.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,707600.0000,1,521,0),(1226,456,'Jaspet','Jaspet has three valuable mineral types, making it easy to sell. It has a large portion of mexallon plus some nocxium and zydrine.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFE58000\'>0.4</color> security status solar systems or lower.',1e35,2,0,100,4,65984.0000,1,529,0),(1227,469,'Omber','Omber is a common ore that is still an excellent ore for novice miners as it has a sizeable portion of isogen, as well as some tritanium and pyerite. A few trips of mining this and a novice is quick to rise in status.\r\r\n\r\r\nAvailable in <color=\'0xFF00FF00\'>0.7</color> security status solar systems or lower.',1e35,0.6,0,100,NULL,11322.0000,1,526,0),(1228,460,'Scordite','Scordite is amongst the most common ore types in the known universe. It has a large portion of tritanium plus a fair bit of pyerite. Good choice for those starting their mining careers.\r\r\n\r\r\nAvailable in <color=\'0xFF33FFFF\'>1.0</color> security status solar systems or lower.',1e35,0.15,0,100,NULL,2076.0000,1,519,0),(1229,467,'Gneiss','Gneiss is a popular ore type because it holds significant volumes of three heavily used minerals, increasing its utility value. It has a quite a bit of mexallon as well as some pyerite and isogen.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,5,0,100,4,132800.0000,1,525,0),(1230,462,'Veldspar','The most common ore type in the known universe, veldspar can be found almost everywhere. It is still in constant demand as it holds a large portion of the much-used tritanium mineral.\r\r\n\r\r\nAvailable in <color=\'0xFF33FFFF\'>1.0</color> security status solar systems or lower.',4000,0.1,0,100,NULL,830.0000,1,518,0),(1231,455,'Hemorphite','With a large portion of nocxium, hemorphite is always a good find. It is common enough that even novice miners can expect to run into it. Hemorphite also has a bit of tritanium, isogen and zydrine.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF4D00\'>0.2</color> security status solar systems or lower.',1e35,3,0,100,4,109360.0000,1,528,0),(1232,453,'Dark Ochre','Considered a worthless ore for years, dark ochre was ignored by most miners until improved reprocessing techniques managed to extract the huge amount of isogen inside it. Dark ochre also contains useful amounts of tritanium and nocxium.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,8,0,100,4,286240.0000,1,522,0),(1233,237,'Polaris Enigma Frigate','The Polaris Enigma frigate is one of the most powerful Polaris ships built, superior in both combat and maneuverability.',1000000,20400,1000000,1,16,0.0000,0,NULL,0),(1236,764,'Overdrive Injector System II','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,NULL,99490.0000,1,1087,0),(1237,158,'Overdrive Injector System II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1240,78,'\'Basic\' Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,4,5000.0000,1,1195,0),(1242,763,'\'Basic\' Nanofiber Internal Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,4,1664.0000,1,1196,0),(1244,764,'Overdrive Injector System I','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,NULL,27772.0000,1,1087,0),(1245,158,'Overdrive Injector System I Blueprint',' ',0,0.01,0,1,NULL,249980.0000,1,332,0),(1246,768,'Capacitor Flux Coil I','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,NULL,4654.0000,1,666,0),(1247,137,'Capacitor Flux Coil I Blueprint',' ',0,0.01,0,1,NULL,41600.0000,1,1556,0),(1248,768,'Capacitor Flux Coil II','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,NULL,106342.0000,1,666,0),(1249,137,'Capacitor Flux Coil II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1254,770,'Shield Flux Coil I','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,NULL,4646.0000,1,687,0),(1255,137,'Shield Flux Coil I Blueprint',' ',0,0.01,0,1,NULL,41600.0000,1,1547,0),(1256,770,'Shield Flux Coil II','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,NULL,106334.0000,1,687,0),(1257,137,'Shield Flux Coil II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1262,98,'Basic Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,1984.0000,1,1667,0),(1264,98,'Explosive Plating I','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1667,0),(1265,163,'Explosive Plating I Blueprint',' ',0,0.01,0,1,NULL,49740.0000,1,1544,0),(1266,98,'Explosive Plating II','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,42236.0000,1,1667,0),(1267,163,'Explosive Plating II Blueprint',' ',0,0.01,0,1,NULL,179200.0000,1,NULL,0),(1272,98,'Basic Layered Plating','This plating is composed of several additional tritanium layers, effectively increasing its hit points.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,1984.0000,1,1669,0),(1274,98,'Layered Plating I','This plating is composed of several additional tritanium layers, effectively increasing its hit points.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1669,0),(1275,163,'Layered Plating I Blueprint',' ',0,0.01,0,1,NULL,49740.0000,1,1544,0),(1276,98,'Layered Plating II','This plating is composed of several additional tritanium layers, effectively increasing its hit points.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,42236.0000,1,1669,0),(1277,163,'Layered Plating II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1282,98,'Basic Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,1984.0000,1,1666,0),(1284,98,'Kinetic Plating I','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1666,0),(1285,163,'Kinetic Plating I Blueprint',' ',0,0.01,0,1,NULL,49740.0000,1,1544,0),(1286,98,'Kinetic Plating II','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,41576.0000,1,1666,0),(1287,163,'Kinetic Plating II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1292,98,'Basic Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,1984.0000,1,1665,0),(1294,98,'Thermic Plating I','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1665,0),(1295,163,'Thermic Plating I Blueprint',' ',0,0.01,0,1,NULL,49740.0000,1,1544,0),(1296,98,'Thermic Plating II','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,42236.0000,1,1665,0),(1297,163,'Thermic Plating II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1302,98,'Basic Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,1984.0000,1,1670,0),(1304,98,'Adaptive Nano Plating I','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,8304.0000,1,1670,0),(1305,163,'Adaptive Nano Plating I Blueprint',' ',0,0.01,0,1,NULL,74680.0000,1,1544,0),(1306,98,'Adaptive Nano Plating II','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,43712.0000,1,1670,0),(1307,163,'Adaptive Nano Plating II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1315,765,'\'Basic\' Expanded Cargohold','Increases cargo hold capacity.',50,5,0,1,4,800.0000,1,1197,0),(1317,765,'Expanded Cargohold I','Increases cargo hold capacity.',50,5,0,1,NULL,1792.0000,1,1197,0),(1318,158,'Expanded Cargohold I Blueprint',' ',0,0.01,0,1,NULL,16640.0000,1,335,0),(1319,765,'Expanded Cargohold II','Increases cargo hold capacity.',50,5,0,1,NULL,51390.0000,1,1197,0),(1320,158,'Expanded Cargohold II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1333,78,'Reinforced Bulkheads I','Increases structural hit points while reducing agility and cargo capacity.',200,25,0,1,NULL,13888.0000,1,1195,0),(1334,158,'Reinforced Bulkheads I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,335,0),(1335,78,'Reinforced Bulkheads II','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,NULL,50656.0000,1,1195,0),(1336,158,'Reinforced Bulkheads II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1351,769,'Basic Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,3968.0000,1,659,0),(1353,769,'Reactor Control Unit I','Boosts power core output.',20,5,0,1,NULL,10976.0000,1,659,0),(1354,137,'Reactor Control Unit I Blueprint',' ',0,0.01,0,1,NULL,99200.0000,1,1561,0),(1355,769,'Reactor Control Unit II','Boosts power core output.',20,5,0,1,NULL,138644.0000,1,659,0),(1356,137,'Reactor Control Unit II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1373,1,'CharacterAmarr','Character type for characters of the Amarrian Amarr bloodline.',0,1,0,1,4,0.0000,0,NULL,0),(1374,1,'CharacterNiKunni','Character type for characters of the Amarr Nikunni bloodline.',0,1,0,1,4,0.0000,0,NULL,0),(1375,1,'CharacterCivire','Character type for characters of the Caldari Civire bloodline.',0,1,0,1,1,0.0000,0,NULL,0),(1376,1,'CharacterDeteis','Character type for characters of the Caldari Deteis bloodline.',0,1,0,1,1,0.0000,0,NULL,0),(1377,1,'CharacterGallente','Character type for characters of the Gallente Gallente bloodline.',0,1,0,1,8,0.0000,0,NULL,0),(1378,1,'CharacterIntaki','Character type for characters of the Gallente Intaki bloodline.',0,1,0,1,8,0.0000,0,NULL,0),(1379,1,'CharacterSebiestor','Character type for characters of the Minmatar Sebiestor bloodline.',0,1,0,1,2,0.0000,0,NULL,0),(1380,1,'CharacterBrutor','Character type for characters of the Minmatar Brutor bloodline.',0,1,0,1,2,0.0000,0,NULL,0),(1381,1,'CharacterStatic','Character type for characters of the Jove Static bloodline.',0,1,0,1,16,0.0000,0,NULL,0),(1382,1,'CharacterModifier','Character type for characters of the Jove Modifier bloodline.',0,1,0,1,16,0.0000,0,NULL,0),(1383,1,'CharacterAchura','Character type for characters of the Caldari Achura bloodline.',0,1,0,1,1,0.0000,0,NULL,0),(1384,1,'CharacterJinMei','Character type for characters of the Gallente Jin-Mei bloodline.',0,1,0,1,8,0.0000,0,NULL,0),(1385,1,'CharacterKhanid','Character type for characters of the Amarr Khanid bloodline.',0,1,0,1,4,0.0000,0,NULL,0),(1386,1,'CharacterVherokior','Character type for characters of the Minmatar Vherokior bloodline.',0,1,0,1,2,0.0000,0,NULL,0),(1401,762,'\'Basic\' Inertial Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,4,2176.0000,1,1086,0),(1403,762,'Inertial Stabilizers I','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,4,6036.0000,1,1086,0),(1404,158,'Inertial Stabilizers I Blueprint',' ',0,0.01,0,1,4,54380.0000,1,332,0),(1405,762,'Inertial Stabilizers II','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,4,64094.0000,1,1086,0),(1406,158,'Inertial Stabilizers II Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(1419,57,'Basic Shield Power Relay','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,NULL,4864.0000,1,688,0),(1422,57,'Shield Power Relay II','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,NULL,72894.0000,1,688,0),(1423,137,'Shield Power Relay II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1436,96,'Auto Targeting System II','Targets any hostile ship within range on activation. Grants a +3 bonus to ship\'s max targets when online.',40,5,0,1,NULL,148267.0000,1,670,0),(1437,162,'Auto Targeting System II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1445,767,'Capacitor Power Relay I','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,10656.0000,1,667,0),(1446,137,'Capacitor Power Relay I Blueprint',' ',0,0.01,0,1,NULL,97440.0000,1,1557,0),(1447,767,'Capacitor Power Relay II','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,72894.0000,1,667,0),(1448,137,'Capacitor Power Relay II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1529,15,'Caldari Administrative Station',' ',0,1,0,1,1,0.0000,0,NULL,0),(1530,15,'Caldari Research Station',' ',0,1,0,1,1,0.0000,0,NULL,0),(1531,15,'Caldari Trading Station',' ',0,1,0,1,1,0.0000,0,NULL,0),(1537,766,'\'Basic\' Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,3968.0000,1,658,0),(1539,766,'Power Diagnostic System I','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,14544.0000,1,658,0),(1540,137,'Power Diagnostic System I Blueprint',' ',0,0.01,0,1,NULL,99200.0000,1,1560,0),(1541,766,'Power Diagnostic System II','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,156022.0000,1,658,0),(1542,137,'Power Diagnostic System II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1547,72,'Small Proton Smartbomb I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',10,12.5,0,1,NULL,60916.0000,1,382,0),(1548,152,'Small Proton Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,341,0),(1549,72,'Small Proton Smartbomb II','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',40,5,0,1,NULL,194140.0000,1,382,0),(1550,152,'Small Proton Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1551,72,'Small Graviton Smartbomb I','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',10,12.5,0,1,NULL,68346.0000,1,382,0),(1552,152,'Small Graviton Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,550000.0000,1,341,0),(1553,72,'Small Graviton Smartbomb II','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',40,5,0,1,NULL,201570.0000,1,382,0),(1554,152,'Small Graviton Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1557,72,'Small Plasma Smartbomb I','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',10,12.5,0,1,NULL,73890.0000,1,382,0),(1558,152,'Small Plasma Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,341,0),(1559,72,'Small Plasma Smartbomb II','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',40,5,0,1,NULL,207114.0000,1,382,0),(1560,152,'Small Plasma Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1563,72,'Small EMP Smartbomb I','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',10,12.5,0,1,NULL,83152.0000,1,382,0),(1564,152,'Small EMP Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,650000.0000,1,341,0),(1565,72,'Small EMP Smartbomb II','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',40,5,0,1,NULL,216376.0000,1,382,0),(1566,152,'Small EMP Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1601,190,'Amarr Bonus','-50% cost for using Amarrian stargates.',0,0,0,1,NULL,0.0000,0,NULL,0),(1602,190,'Ni-Kunni Bonus','+25% max ask/bid value on market.',0,0,0,1,NULL,0.0000,0,NULL,0),(1603,190,'Civire Bonus','+3% Accuracy bonus for Hybrid Weapons.',0,0,0,1,NULL,0.0000,0,NULL,0),(1604,190,'Deteis Bonus','-2% production time for all modules.',0,0,0,1,NULL,0.0000,0,NULL,0),(1605,190,'Gallente Bonus','-10% drill time when mining asteroids with mining lasers.',0,0,0,1,NULL,0.0000,0,NULL,0),(1606,190,'Intaki Bonus','+20% chance of getting a new agent.',0,0,0,1,NULL,0.0000,0,NULL,0),(1607,190,'Sebiestor Bonus','-20% ship repair cost.',0,0,0,1,NULL,0.0000,0,NULL,0),(1608,190,'Brutor Bonus','+10% speed bonus for Projectile Weapons.',0,0,0,1,NULL,0.0000,0,NULL,0),(1611,191,'Computer Empathy Bonus','Reduces CPU usage 20%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1612,191,'Ordered Mind Bonus','Lower skill loss severity by 25%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1613,191,'Standard DNA Pattern Bonus','+1 character clone usage advance level.',0,0,0,1,NULL,0.0000,0,NULL,0),(1614,191,'Killer Instinct Bonus','+5% Shield seeping.',0,0,0,1,NULL,0.0000,0,NULL,0),(1615,191,'Deft Hands Bonus','Upgrade time -10%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1616,191,'Structural Understanding Bonus','Manufacture time -5%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1617,191,'Creative Bonus','Research time -5%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1618,191,'Glib Tongue Bonus','NPC dir.trade price -5%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1619,191,'August Demeanor Bonus','Better agent missions.',0,0,0,1,NULL,0.0000,0,NULL,0),(1620,191,'Superior Motion Sense Bonus','Turret wp accuracy +2%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1621,191,'High-G Tolerance Bonus','Ship Agility +5%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1622,191,'Vector Reckoning Bonus','Half acc.penalty for high speed.',0,0,0,1,NULL,0.0000,0,NULL,0),(1623,191,'Stratum Form Feel Bonus','Mining efficiency +10%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1624,191,'Doctrine Ingrained Bonus','+5% damage while in formation.',0,0,0,1,NULL,0.0000,0,NULL,0),(1625,191,'Three Dimensional Thinking Bonus','Missile accuracy +3%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1626,191,'Swift Neural Grafting Bonus','C-Implant install time -50%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1627,191,'Booster Immunity Bonus','Booster resistance +25%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1628,193,'Algiophobia Bonus','PwC +5% when in combat (being shot at).',0,0,0,1,NULL,0.0000,0,NULL,0),(1629,193,'Barophobia Bonus','+50% warp cost if planet/moon in target bubble.',0,0,0,1,NULL,0.0000,0,NULL,0),(1630,193,'Cenophobia Bonus','+50% warp cost to bubbles with no station/stargate.',0,0,0,1,NULL,0.0000,0,NULL,0),(1631,193,'Claustrophobia Bonus','If floating in capsule in space for 5 mins, he dies.',0,0,0,1,NULL,0.0000,0,NULL,0),(1632,193,'Monophobia Bonus','Dies if he doesn\'t dock at a station every 60 mins.',0,0,0,1,NULL,0.0000,0,NULL,0),(1633,193,'Mysophobia Bonus','Worse agent missions.',0,0,0,1,NULL,0.0000,0,NULL,0),(1634,193,'Taphephobia Bonus','If Structure damage is >25% then he ejects capsule.',0,0,0,1,NULL,0.0000,0,NULL,0),(1635,193,'Xenophobia Bonus','Faction standing modifier -25% vs. factions of other race.',0,0,0,1,NULL,0.0000,0,NULL,0),(1636,192,'Mechanical Inaptitude Bonus','Engineering skills training time +25%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1639,192,'Weak Double-helix Bond Bonus','Clone cost +5%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1640,192,'Short Attention Span Bonus','Equipment duration -20%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1641,192,'Wasteful Bonus','Turret weapon power usage +5%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1642,192,'Trigger-happy Bonus','Turret weapon accuracy -2%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1643,192,'Epileptic Bonus','Prevents attribute change instigated skill training time adjustments.  Boosters and trained skills which change the primary or secondary attributes would therefore have no effect on an epileptic character.\r\r\n',0,0,0,1,NULL,0.0000,0,NULL,0),(1644,192,'Strong Immunity System Bonus','Cyber implant install time +50% AND booster resistance -25%.',0,0,0,1,NULL,0.0000,0,NULL,0),(1650,195,'Amarr Military Academy Pilot Bonus','-5% training time for all skills that rely on the perception attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1651,195,'Amarr Military Academy Gunner Bonus','-5% weapon power consumption.',0,0,0,1,NULL,0.0000,0,NULL,0),(1652,195,'Amarr Technical School Engineering Bonus','-5% training time for all skills that rely on the memory attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1653,195,'Amarr Technical School Electronics Bonus','-5% CPU usage.',0,0,0,1,NULL,0.0000,0,NULL,0),(1654,195,'Amarr Business School Commerce Bonus','-5% training time for all skills that rely on the charisma attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1655,195,'Amarr Business School Industry Bonus','-5% factory prod.time.',0,0,0,1,NULL,0.0000,0,NULL,0),(1657,196,'Caldari Military Academy Pilot Bonus','-5% training time for all skills that rely on the perception attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1658,196,'Caldari Military Academy Gunner Bonus','-5% weapon power consumption.',0,0,0,1,NULL,0.0000,0,NULL,0),(1659,196,'Caldari Technical School Engineering Bonus','-5% training time for all skills that rely on the memory attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1660,196,'Caldari Technical School Electronics Bonus','-5% CPU usage.',0,0,0,1,NULL,0.0000,0,NULL,0),(1661,196,'Caldari Business School Commerce Bonus','-5% training time for all skills that rely on the charisma attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1662,196,'Caldari Business School Industry Bonus','-5% factory prod.time.',0,0,0,1,NULL,0.0000,0,NULL,0),(1663,197,'Gallente Military Academy Pilot Bonus','-5% training time for all skills that rely on the perception attribute.\r\r\n',0,0,0,1,NULL,0.0000,0,NULL,0),(1664,197,'Gallente Military Academy Gunner Bonus','-5% weapon power consumption.',0,0,0,1,NULL,0.0000,0,NULL,0),(1665,197,'Gallente Technical School Engineering Bonus','-5% training time for all skills that rely on the memory attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1666,197,'Gallente Technical School Electronics Bonus','-5% CPU usage.',0,0,0,1,NULL,0.0000,0,NULL,0),(1667,197,'Gallente Business School Commerce Bonus','-5% training time for all skills that rely on the charisma attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1668,197,'Gallente Business School Industry Bonus','-5% factory prod.time.',0,0,0,1,NULL,0.0000,0,NULL,0),(1669,198,'Minmatar Military Academy Pilot Bonus','-5% training time for all skills that rely on the perception attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1670,198,'Minmatar Military Academy Gunner Bonus','-5% weapon power consumption.',0,0,0,1,NULL,0.0000,0,NULL,0),(1671,198,'Minmatar Technical School Engineering Bonus','-5% training time for all skills that rely on the memory attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1672,198,'Minmatar Technical School Electronic Bonus','-5% CPU usage.',0,0,0,1,NULL,0.0000,0,NULL,0),(1673,198,'Minmatar Business School Commerce Bonus','-5% training time for all skills that rely on the charisma attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1674,198,'Minmatar Business School Industry Bonus','-5% factory prod.time.',0,0,0,1,NULL,0.0000,0,NULL,0),(1675,199,'Bounty Hunter Bonus','+5% skill training time for skills with memory as the primary attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1676,199,'Scientist Bonus','+5% skill training time for skills with perception as the primary attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1677,199,'Industrialist Bonus','+5% skill training time for skills with perception as the primary attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1678,199,'Corporate Magnate Bonus','+5% skill training time for skills with willpower as the primary attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1679,199,'Covert-op Bonus','+5% skill training time for skills with intelligence as the primary attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1680,199,'Navy Captain Bonus','+5% skill training time for skills with charisma as the primary attribute.',0,0,0,1,NULL,0.0000,0,NULL,0),(1798,295,'Basic EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,7494.0000,1,1691,0),(1800,295,'Basic Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,7494.0000,1,1688,0),(1802,295,'Basic Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,7494.0000,1,1689,0),(1804,295,'Basic Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,7494.0000,1,1690,0),(1808,295,'EM Ward Amplifier I','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1691,0),(1809,296,'EM Ward Amplifier I Blueprint',' ',0,0.01,0,1,NULL,187420.0000,1,1554,0),(1810,394,'Scourge Auto-Targeting Light Missile I','A Caldarian light missile with a graviton warhead and automatic guidance system.',700,0.015,0,100,NULL,546.0000,1,914,0),(1811,166,'Scourge Auto-Targeting Light Missile I Blueprint',' ',1,0.01,0,1,NULL,150000.0000,1,315,0),(1814,394,'Nova Auto-Targeting Light Missile I','A Minmatar light missile with a nuclear warhead and automatic guidance system.',700,0.015,0,100,NULL,428.0000,1,914,0),(1815,166,'Nova Auto-Targeting Light Missile I Blueprint',' ',1,0.01,0,1,NULL,140000.0000,1,315,0),(1816,394,'Inferno Auto-Targeting Light Missile I','A Gallente light missile with a plasma warhead and automatic guidance system.',700,0.015,0,100,8,692.0000,1,914,0),(1817,166,'Inferno Auto-Targeting Light Missile I Blueprint',' ',1,0.01,0,1,NULL,160000.0000,1,315,0),(1818,395,'Scourge Auto-Targeting Heavy Missile I','A Caldarian heavy missile with a graviton warhead and automatic guidance system.',1000,0.03,0,100,NULL,2664.0000,1,914,0),(1819,166,'Scourge Auto-Targeting Heavy Missile I Blueprint',' ',1,0.01,0,1,NULL,750000.0000,1,315,0),(1820,395,'Mjolnir Auto-Targeting Heavy Missile I','An Amarr heavy missile with an EMP warhead and automatic guidance system.',1000,0.03,0,100,NULL,3776.0000,1,914,0),(1821,166,'Mjolnir Auto-Targeting Heavy Missile I Blueprint',' ',1,0.01,0,1,NULL,900000.0000,1,315,0),(1822,395,'Nova Auto-Targeting Heavy Missile I','A Minmatar heavy missile with a nuclear warhead and automatic guidance system.',1000,0.03,0,100,2,2166.0000,1,914,0),(1823,166,'Nova Auto-Targeting Heavy Missile I Blueprint',' ',1,0.01,0,1,NULL,700000.0000,1,315,0),(1824,395,'Inferno Auto-Targeting Heavy Missile I','A Gallente heavy missile with a plasma warhead and automatic guidance system.',1000,0.03,0,100,NULL,3176.0000,1,914,0),(1825,166,'Inferno Auto-Targeting Heavy Missile I Blueprint',' ',1,0.01,0,1,NULL,800000.0000,1,315,0),(1826,396,'Scourge Auto-Targeting Cruise Missile I','A Caldarian cruise missile with a graviton warhead and automatic guidance system.',1250,0.05,0,100,1,14646.0000,1,914,0),(1827,166,'Scourge Auto-Targeting Cruise Missile I Blueprint',' ',1,0.01,0,1,NULL,3000000.0000,1,315,0),(1828,396,'Mjolnir Auto-Targeting Cruise Missile I','An Amarr cruise missile with an EMP warhead and automatic guidance system.',1250,0.05,0,100,NULL,20312.0000,1,914,0),(1829,166,'Mjolnir Auto-Targeting Cruise Missile I Blueprint',' ',1,0.01,0,1,NULL,5000000.0000,1,315,0),(1830,396,'Nova Auto-Targeting Cruise Missile I','A Minmatar cruise missile with a nuclear warhead and automatic guidance system.',1250,0.05,0,100,NULL,10094.0000,1,914,0),(1831,166,'Nova Auto-Targeting Cruise Missile I Blueprint',' ',1,0.01,0,1,NULL,2500000.0000,1,315,0),(1832,396,'Inferno Auto-Targeting Cruise Missile I','A Gallente cruise missile with a plasma warhead and automatic guidance system ',1250,0.05,0,100,NULL,17532.0000,1,914,0),(1833,166,'Inferno Auto-Targeting Cruise Missile I Blueprint',' ',1,0.01,0,1,NULL,4000000.0000,1,315,0),(1855,48,'Ship Scanner II','Scans the target ship and provides a tactical analysis of its capabilities. The further it goes beyond scan range, the more inaccurate its results will be.',0,5,0,1,NULL,98747.0000,1,713,0),(1856,128,'Ship Scanner II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1875,511,'Rapid Light Missile Launcher I','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.285,1,NULL,9792.0000,1,641,0),(1876,136,'Rapid Light Missile Launcher I Blueprint',' ',0,0.01,0,1,NULL,90000.0000,1,340,0),(1877,511,'Rapid Light Missile Launcher II','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular and advanced light missiles.',0,10,0.3,1,NULL,188446.0000,1,641,0),(1878,136,'Rapid Light Missile Launcher II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(1893,205,'Basic Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,9984.0000,1,647,0),(1896,25,'Concord Police Frigate','A Concord Patrol Frigate. ',1200000,20400,300,1,NULL,0.0000,0,NULL,0),(1898,25,'Concord SWAT Frigate','A Concord SWAT vessel. .',1200000,20400,300,1,NULL,0.0000,0,NULL,0),(1900,25,'Concord Army Frigate','A Concord millitary vessel. ',1200000,20400,300,1,NULL,0.0000,0,NULL,0),(1902,25,'Concord Special Ops Frigate','A Concord Special Ops Frigate',1200000,20400,300,1,NULL,0.0000,0,NULL,0),(1904,26,'Concord Police Cruiser','Designed by co-operative efforts from all the empires, the Concord cruisers employ many of the finest traditions and technologies enjoyed by the empires, thus making them truly fearsome opponents.',12155000,101000,900,1,NULL,0.0000,0,NULL,0),(1912,27,'Concord Police Battleship','The Concord battleships were built by a joint effort of the empires, each empire investing it with their own special technologies. Although this makes them a bit mismatched, their performance leaves no doubt about their awesome power.',112903000,486000,14000,1,NULL,2959998.0000,0,NULL,0),(1914,27,'Concord Special Ops Battleship','The Concord battleships were built by a joint effort of the empires, each empire investing it with their own special technologies. Although this makes them a bit mismatched, their performance leaves no doubt about their awesome power.',112903000,486000,14000,1,NULL,2959998.0000,0,NULL,0),(1916,27,'Concord SWAT Battleship','The Concord battleships were built by a joint effort of the empires, each empire investing it with their own special technologies. Although this makes them a bit mismatched, their performance leaves no doubt about their awesome power.',112903000,486000,14000,1,NULL,2959998.0000,0,NULL,0),(1918,27,'Concord Army Battleship','The Concord battleships were built by a joint effort of the empires, each empire investing it with their own special technologies. Although this makes them a bit mismatched, their performance leaves no doubt about their awesome power.',112903000,486000,14000,1,NULL,2959998.0000,0,NULL,0),(1926,15,'Amarr Station Hub',' ',0,0,0,1,4,0.0000,0,NULL,0),(1927,15,'Amarr Station Military',' ',0,0,0,1,4,0.0000,0,NULL,0),(1928,15,'Amarr Industrial Station',' ',0,0,0,1,4,0.0000,0,NULL,0),(1929,15,'Amarr Standard Station',' ',0,0,0,1,4,0.0000,0,NULL,0),(1930,15,'Amarr Mining Station',' ',0,0,0,1,4,0.0000,0,NULL,0),(1931,15,'Amarr Research Station',' ',0,0,0,1,4,0.0000,0,NULL,0),(1932,15,'Amarr Trade Post',' ',0,0,0,1,4,0.0000,0,NULL,0),(1944,28,'Bestower','The Bestower has for decades been used by the Empire as a slave transport, shipping human labor between cultivated planets in Imperial space. As a proof to how reliable this class has been through the years, the Emperor has used an upgraded version of this very same class as transports for the Imperial Treasury. The Bestower has very thick armor and large cargo space.\r\r\n',13500000,260000,4800,1,4,996272.0000,1,85,0),(1945,108,'Bestower Blueprint',' ',0,0.01,0,1,NULL,4977500.0000,1,285,0),(1946,203,'Basic RADAR Backup Array','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,4912.0000,1,722,0),(1947,202,'ECCM - Radar I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,729,0),(1948,201,'ECM - Ion Field Projector I','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors. ',0,5,0,1,NULL,29504.0000,1,715,0),(1949,210,'Basic Signal Amplifier','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,4736.0000,1,669,0),(1951,211,'Basic Tracking Enhancer','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',10,5,0,1,NULL,5760.0000,1,707,0),(1952,212,'Sensor Booster II','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,212299.0000,1,671,0),(1955,201,'ECM - Spatial Destabilizer I','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',0,5,0,1,NULL,29504.0000,1,717,0),(1956,201,'ECM - White Noise Generator I','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',0,5,0,1,NULL,29504.0000,1,718,0),(1957,201,'ECM - Multispectral Jammer I','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,33024.0000,1,719,0),(1958,201,'ECM - Phase Inverter I','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',0,5,0,1,NULL,29504.0000,1,716,0),(1959,289,'ECCM Projector I','ECCM Projectors utilize a sophisticated system of electronics to fortify the sensor strengths of an allied ship allowing it to overcome jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,20,0,1,NULL,44396.0000,1,686,0),(1960,289,'ECCM Projector II','ECCM Projectors utilize a sophisticated system of electronics to fortify the sensor strengths of an allied ship allowing it to overcome jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,848081.0000,1,686,0),(1963,290,'Remote Sensor Booster I','Can only be activated on targets to increase their scan resolutions and boost their targeting range.  This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,25,1,1,NULL,44396.0000,1,673,0),(1964,290,'Remote Sensor Booster II','Can only be activated on targets to increase their scan resolutions and boost their targeting range.  This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,356278.0000,1,673,0),(1968,208,'Remote Sensor Dampener I','Reduces the range and speed of a targeted ship\'s sensors. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,55560.0000,1,679,0),(1969,208,'Remote Sensor Dampener II','Reduces the range and speed of a targeted ship\'s sensors. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,441018.0000,1,679,0),(1973,212,'Sensor Booster I','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n\r\r\n',0,5,1,1,NULL,10940.0000,1,671,0),(1977,213,'Tracking Computer I','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,18282.0000,1,706,0),(1978,213,'Tracking Computer II','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,528970.0000,1,706,0),(1982,203,'Basic Ladar Backup Array','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,4912.0000,1,721,0),(1983,203,'Basic Gravimetric Backup Array','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,4912.0000,1,720,0),(1984,203,'Basic Magnetometric Backup Array','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,4912.0000,1,723,0),(1985,203,'Basic Multi Sensor Backup Array','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,9986.0000,1,724,0),(1986,210,'Signal Amplifier I','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18610.0000,1,669,0),(1987,210,'Signal Amplifier II','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,164687.0000,1,669,0),(1998,211,'Tracking Enhancer I','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,15764.0000,1,707,0),(1999,211,'Tracking Enhancer II','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',30,5,0,1,NULL,282964.0000,1,707,0),(2001,1016,'Cynosural Suppression','This upgrade allows alliances to anchor Cynosural System Jammers at their starbases in a solar system.',1000,200000,0,1,NULL,200000000.0000,1,1282,0),(2002,202,'ECCM - Ladar I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,726,0),(2003,202,'ECCM - Magnetometric I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,727,0),(2004,202,'ECCM - Gravimetric I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,725,0),(2005,202,'ECCM - Omni I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,728,0),(2006,26,'Omen','The Omen is a stereotypical example of the Amarrian School of thinking when it comes to ship design: thick armor and hard hitting lasers. Advancements in heat dissipation allow the Omen to fire its lasers faster than other ships without this technology.',13000000,118000,400,1,4,12315518.0000,1,74,0),(2007,106,'Omen Blueprint',' ',0,0.01,0,1,NULL,82750000.0000,1,274,0),(2008,1016,'Cynosural Navigation','This upgrade allows alliances to anchor Cynosural Generator Arrays at their starbases in a solar system.',1000,200000,0,1,NULL,100000000.0000,1,1282,0),(2009,1016,'Supercapital Construction Facilities','This upgrade allows alliances to anchor Supercapital Ship Assembly Arrays at their starbases in a solar system.',1000,200000,0,1,NULL,50000000.0000,1,1282,0),(2010,286,'Rebel Leader','Terrorist Leader.',2112000,21120,100,1,2,0.0000,0,NULL,0),(2011,306,'Prison Facility','This rat-infested prison is being closely guarded.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(2012,597,'Terrorist Leader','This highly-wanted criminal has been sought after by DED officials for years since he began bombing innocent civilians on stations as part of an extortion racket. As a capsuleer, he has managed to evade capture this far. CONCORD officials have to be happy with quickly targeted assassination hits that send him back to his black-market cloning facility deep out on the frontiers of 0.0 space. Until they can raid those cloning labs, he will continue to rebuild and strike again.',1645000,16450,120,1,2,0.0000,0,NULL,0),(2013,283,'Hostages','These hostages have been waiting for someone to rescue them for quite some time.',80,1,0,1,NULL,0.0000,1,NULL,0),(2014,7,'Planet (Oceanic)','Oceanic worlds are a class of terrestrial world covered entirely by liquids, usually in the form of mundane water. While the liquid surface is exceptionally smooth, the ocean floor on most worlds of this type exhibits significant topographic variety. It is this subsurface irregularity which causes the formation of complex weather systems, which would otherwise revert to more uniform patterns.',1e35,1,0,1,NULL,0.0000,0,NULL,0),(2015,7,'Planet (Lava)','So-called \"lava planets\" (properly \"magmatic planets\") fall into one of three groups: solar magmatics, which orbit sufficiently close to their star that the surface never cools enough to solidify; gravitational magmatics, which experience gravitational shifts sufficiently strong to regularly and significantly fracture cooling crusts; and magmatoids, which are for largely-unexplained reasons simply incapable of cooling and forming a persistent crust. All three types generally exhibit the same external phenomena - huge red-orange lava fields being a defining feature - but the latter two types are sometimes capable of briefly solidifying for a period measured in years or perhaps decades.',1e35,1,0,1,NULL,0.0000,0,NULL,0),(2016,7,'Planet (Barren)','Barren planets are archetypical \"dead terrestrials\": dry, rocky worlds with a minimal atmosphere and an unremarkable composition. They are commonly etched with flood channels, which are often broad enough to be visible from orbit; most such worlds have accumulated significant quantities of ice over their lifetimes, but cannot retain it on their surface. Generally surface liquid evaporates rapidly, contributing to the thin atmosphere, but occasionally it will seep back into the ground and refreeze, ready for another breakout in future when the local temperature rises.',1e35,1,0,1,NULL,0.0000,0,NULL,0),(2017,7,'Planet (Storm)','Storm worlds are usually considered terrestrial planets, although to a casual eye they may appear more similar to gas planets, given their opaque, high-pressure atmospheres. Geomorphically, however, the distinctions are clear: compared to a gas world, the atmosphere of a storm world is usually considerably shallower, and generally composed primarily of more complex chemicals, while the majority of the planet\'s mass is a rocky terrestrial ball. Their name is derived from the continent-scale electrical storms that invariably flash through their upper atmospheres.',1e35,1,0,1,NULL,0.0000,0,NULL,0),(2018,61,'Medium Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,10,0,1,NULL,27684.0000,1,704,0),(2019,141,'Medium Capacitor Battery I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1558,0),(2020,61,'Large Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,15,0,1,NULL,73036.0000,1,705,0),(2021,141,'Large Capacitor Battery I Blueprint',' ',0,0.01,0,1,NULL,624500.0000,1,1558,0),(2022,61,'X-Large Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,20,0,1,NULL,192472.0000,0,NULL,0),(2023,141,'X-Large Capacitor Battery I Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(2024,76,'Medium Capacitor Booster II','Provides a quick injection of power into the capacitor.',0,10,40,1,NULL,272710.0000,1,700,0),(2025,156,'Medium Capacitor Booster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2026,1021,'Pirate Detection Array 1','This upgrade increases the number of active combat sites in the upgraded solar system.',1000,5000,0,1,NULL,50000000.0000,1,1284,0),(2027,1021,'Pirate Detection Array 2','This upgrade increases the number of active combat sites in the upgraded solar system.',1000,10000,0,1,NULL,100000000.0000,1,1284,0),(2028,1021,'Pirate Detection Array 3','This upgrade increases the number of active combat sites in the upgraded solar system.',1000,20000,0,1,NULL,150000000.0000,1,1284,0),(2029,1021,'Pirate Detection Array 4','This upgrade increases the number of active combat sites in the upgraded solar system.',1000,40000,0,1,NULL,200000000.0000,1,1284,0),(2030,1021,'Pirate Detection Array 5','This upgrade increases the number of active combat sites in the upgraded solar system.',1000,60000,0,1,NULL,250000000.0000,1,1284,0),(2031,1021,'Entrapment Array 1','This upgrade increases the chance of finding a complex in the system.',1000,5000,0,1,NULL,100000000.0000,1,1284,0),(2032,43,'Cap Recharger II','Increases the capacitor recharge rate.',1,5,0,1,NULL,158886.0000,1,665,0),(2033,123,'Cap Recharger II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2034,1021,'Entrapment Array 2','This upgrade increases the chance of finding a complex in the system.',1000,10000,0,1,NULL,200000000.0000,1,1284,0),(2035,1021,'Entrapment Array 3','This upgrade increases the chance of finding a complex in the system.',1000,20000,0,1,NULL,300000000.0000,1,1284,0),(2036,1021,'Entrapment Array 4','This upgrade increases the chance of finding a complex in the system.',1000,40000,0,1,NULL,400000000.0000,1,1284,0),(2037,1021,'Entrapment Array 5','This upgrade increases the chance of finding a complex in the system.',1000,60000,0,1,NULL,500000000.0000,1,1284,0),(2038,47,'Cargo Scanner II','Scans the cargo hold of another ship.',0,5,0,1,NULL,98207.0000,1,711,0),(2039,127,'Cargo Scanner II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2040,1020,'Ore Prospecting Array 1','This upgrade increases the ore resources available in a system.',1000,5000,0,1,NULL,50000000.0000,1,1283,0),(2041,1020,'Ore Prospecting Array 2','This upgrade increases the ore resources available in a system.',1000,10000,0,1,NULL,75000000.0000,1,1283,0),(2042,1020,'Ore Prospecting Array 3','This upgrade increases the ore resources available in a system.',1000,20000,0,1,NULL,100000000.0000,1,1283,0),(2043,1020,'Ore Prospecting Array 4','This upgrade increases the ore resources available in a system.',1000,40000,0,1,NULL,125000000.0000,1,1283,0),(2044,1020,'Ore Prospecting Array 5','This upgrade increases the ore resources available in a system.',1000,60000,0,1,NULL,250000000.0000,1,1283,0),(2045,693,'SARO Frigate','Special Affairs for Regulations & Order (SARO) is an elite branch of CONCORD\'s DED. They\'re called upon for high risk missions, including hostage situations, anti-terrorist ops, and the assault of heavily armed pirate havens.',1650000,16500,235,1,NULL,0.0000,0,NULL,0),(2046,60,'Damage Control I','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,NULL,3836.0000,1,615,0),(2047,140,'Damage Control I Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,1542,0),(2048,60,'Damage Control II','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,NULL,70254.0000,1,615,0),(2049,140,'Damage Control II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2050,77,'Gistum C-Type Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(2052,286,'Mercenary Trainee','This is a mercenary fighter.  Its faction alignment is unknown.  It may be aggressive, depending on its assignment.  Threat level: Moderate',1970000,19700,125,1,1,0.0000,0,NULL,0),(2053,1020,'Survey Networks 1','This upgrade increases the chance of a mini-profession site being present in the upgraded solar system.',1000,5000,0,1,NULL,50000000.0000,1,1283,0),(2054,1020,'Survey Networks 2','This upgrade increases the chance of a mini-profession site being present in the upgraded solar system.',1000,10000,0,1,NULL,100000000.0000,1,1283,0),(2055,1020,'Survey Networks 3','This upgrade increases the chance of a mini-profession site being present in the upgraded solar system.',1000,20000,0,1,NULL,150000000.0000,1,1283,0),(2056,1020,'Survey Networks 4','This upgrade increases the chance of a mini-profession site being present in the upgraded solar system.',1000,40000,0,1,NULL,200000000.0000,1,1283,0),(2057,1020,'Survey Networks 5','This upgrade increases the chance of a mini-profession site being present in the upgraded solar system.',1000,60000,0,1,NULL,250000000.0000,1,1283,0),(2058,1021,'Quantum Flux Generator 1','This upgrade increases the chance of a wormhole being present in the upgraded solar system.',1000,5000,0,1,NULL,50000000.0000,1,1284,0),(2059,1021,'Quantum Flux Generator 2','This upgrade increases the chance of a wormhole being present in the upgraded solar system.',1000,10000,0,1,NULL,100000000.0000,1,1284,0),(2060,1021,'Quantum Flux Generator 3','This upgrade increases the chance of a wormhole being present in the upgraded solar system.',1000,20000,0,1,NULL,150000000.0000,1,1284,0),(2061,1021,'Quantum Flux Generator 4','This upgrade increases the chance of a wormhole being present in the upgraded solar system.',1000,40000,0,1,NULL,200000000.0000,1,1284,0),(2062,1021,'Quantum Flux Generator 5','This upgrade increases the chance of a wormhole being present in the upgraded solar system.',1000,60000,0,1,NULL,250000000.0000,1,1284,0),(2063,7,'Planet (Plasma)','The aptly-named \"plasma planets\" have captured the imagination of countless artists and inspired innumerable works, yet the physics behind them are surprisingly mundane by cosmological standards. A rocky terrestrial with the right kind of atmosphere and magnetic field will, when bombarded with solar radiation, generate sprawling plasma storms as specific atmospheric elements are stripped of their electrons. Over time these storms will generally scorch the surface rock black, adding to the visual impact.',1e35,1,0,1,NULL,0.0000,0,NULL,0),(2064,995,'EVE Gate',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(2065,517,'Patrikia Noirild\'s Reaper','Patrikia Noirild is a Professor of Evolutionary Genetics at Republic University. Regarded as one of the foremost minds in her field, her early achievements include pioneering a revolutionary gene therapy for Toluuk\'s Syndrome - a genetic disorder that causes excess bone growth in Brutor descended from slaves bred to work on high-gravity worlds. For the last two years, however, she has worked in the field of anti-vitoxin research.',0,0,0,1,2,0.0000,0,NULL,0),(2066,517,'Karsten Lundham\'s Typhoon','Karsten Lundham is a microbiologist working for the Sebiestor Tribe. Currently in his fifties, he worked in the field of immunology for ten years before deciding to dedicate the rest of his life to the search for a cure to vitoxin.',0,0,0,1,2,0.0000,0,NULL,0),(2071,15,'Station (InterBus)',' ',0,1,0,1,8,0.0000,0,NULL,0),(2072,602,'Anire Scarlet','Anire is everything you could want in a pirate queen   bright green eyes, wild red hair and curves in all the right places. She dresses in a dark brown, form-fitting jumpsuit with gold accents here and there.<br><br>The most that people ever usually get to see, though, is her guns trained on them, as the Crimson Dawn comes bearing down to seal their fate.<br><br><br><i>\"I just liked it because it was red. What\'s a Carthum?\"</i>',11800000,118000,235,1,4,0.0000,0,NULL,0),(2073,1035,'Microorganisms','Any life form too small to be detected by the unaided human eye qualifies as a microorganism, yet as a whole, this classification of biology covers an enormous and diverse spectrum. From parasites and viruses to fungi and insects, the study or industrial application of these creatures is just as broad.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2074,314,'Zazzmatazz','Zazzmatazz\'s DNA',1,0.1,0,1,NULL,0.0000,1,NULL,0),(2075,314,'Consolidated Holdings Commander Access Key','This Commander key has the information needed to unlock the acceleration gate in the Checkpoint which it was found.',0.01,0.01,0,1,NULL,0.0000,1,NULL,0),(2076,474,'Gate Key','This transponder, set with a unique code built into the device\'s hardware, acts as a key to a specific acceleration gate.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(2077,952,'Amarr Frigate Container','Frigate luxury vessel.',0,0,500,1,4,0.0000,0,NULL,0),(2078,1022,'Zephyr','The Zephyr is a unique starship design, relying almost entirely on solar winds for sublight propulsion. Super-light sails allow it to ride the torrents of photons streaming through space, and its barebones construction gives it a tiny sensor footprint and almost negligible mass.\r\r\n\r\r\nOriginally conceived by the ascetic Intaki polymath Valsas en Dilat as a demonstration of minimalist starship design, it was never intended as a commercial venture. The recent discovery of the uncharted Sleeper Territories and their myriad wormholes has brought the Zephyr new attention - its mass makes it an ideal exploration vessel.\r\r\n\r\r\nValsas remains adamant that the Zephyr never sees mass production, but at the close of YC111 he authorized the Intaki Syndicate to distribute a single hull to every registered capsuleer.',5000,5000,10,1,8,5000.0000,1,1619,0),(2082,300,'Genolution Core Augmentation CA-1','<font color=\"yellow\"><b>Traits</b></font><br>Slot 1<br>Primary Effect: +3 bonus to Perception<br>Secondary Effect: +1.5% bonus to powergrid and capacitor amount<br>Implant Set Effect: 50% bonus to the strength of all Genolution implant secondary effects<br><br><font color=\"yellow\"><b>Development</b></font><br>The modestly titled  Core Augmentation  implant set was developed by Genolution with the assistance of implantation specialists and other leaders in the field of neural augmentation, some of whom have long been rumored to be SoCT alumni.<br><br>The CA-1 is a rarity in the often hyper-specialized industry of neural augmentations. It provides a dual function; tapping into both the occipital lobe for a perception boost, and also the neocortex, for improving the brain\'s handling of a ship\'s energy and capacitor needs. Like the infamous pirate implant sets found on capsuleer markets, each implant is also designed to work at higher levels when integrated into a neural implant network.<br><br>Though many in the augmentation industry initially questioned the agenda behind Genolution\'s entry into the implantation field, fears eventually subsided as the implant was shown to be one of the safest on record. Genolution went one step further to assuage fears however and vowed never to release the implant to open markets, providing only a single-run issue to capsuleers as a demonstration of the technology.',0,1,0,1,NULL,800000.0000,1,618,0),(2083,481,'Prototype Iris Probe Launcher','The Iris system is a prototype launcher designed to work exclusively with the Zephyr exploration platform.\r\r\n\r\r\nIts tight integration allows it to work effectively with the minimal power and CPU capacity the Zephyr can provide, but the non-standard interfaces needed for this optimization make it entirely unusable on other ship types.',5,5,0.8,1,NULL,2.0000,1,NULL,0),(2093,283,'Kidnapped Citizens','These poor people have been through enough already; all they want is to go home.',5,1,0,1,8,0.0000,1,NULL,0),(2096,226,'Caldari Supercarrier Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2097,226,'Amarr Supercarrier Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2098,632,'Phenod\'s Broke-Ass Destroyer','This officer of The Seven will engage anyone threatening the gang\'s operations.',2650000,26500,235,1,8,0.0000,0,NULL,0),(2100,314,'Phenod\'s DNA','Identification tags such as these may prove valuable if handed to the proper organization.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(2101,226,'Gallente Supercarrier Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2102,226,'Minmatar Supercarrier Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2103,209,'Remote Tracking Computer I','Establishes a fire control link with another ship, thereby boosting the turret range and tracking speed of that ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,25,1,1,NULL,33284.0000,1,708,0),(2104,209,'Remote Tracking Computer II','Establishes a fire control link with another ship, thereby boosting the turret range and tracking speed of that ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,312398.0000,1,708,0),(2105,226,'Amarr Carrier Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2106,226,'Caldari Carrier Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2107,226,'Gallente Carrier Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2108,291,'Tracking Disruptor I','Disrupts the turret range and tracking speed of the target ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,47656.0000,1,680,0),(2109,291,'Tracking Disruptor II','Disrupts the turret range and tracking speed of the target ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,414994.0000,1,680,0),(2110,226,'Minmatar Carrier Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2111,226,'Amarr Freighter Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2112,226,'Caldari Freighter Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2113,226,'Gallente Freighter Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2114,226,'Minmatar Freighter Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2115,226,'Amarr Dreadnought Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2116,226,'Caldari Dreadnought Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2117,80,'ECM Burst II','Emits random electronic bursts which have a chance of momentarily disrupting target locks on ships within range.\r\r\n\r\r\nGiven the unstable nature of the bursts and the amount of internal shielding needed to ensure they do not affect their own point of origin, only battleship-class vessels can use this module to its fullest extent. \r\r\n\r\r\nNote: Only one module of this type can be activated at the same time.',5000,5,0,1,NULL,407614.0000,1,678,0),(2118,160,'ECM Burst II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2119,226,'Gallente Dreadnought Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2120,226,'Minmatar Dreadnought Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2121,226,'Amarr Titan Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2122,226,'Caldari Titan Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2123,226,'Gallente Titan Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2124,226,'Minmatar Titan Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(2126,633,'Anakism','This officer of The Seven will engage anyone threatening the gang\'s operations.',2250000,22500,235,1,8,0.0000,0,NULL,0),(2127,306,'Amarr Diplomat Quarters',' ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(2128,632,'Locced\'s Destroyer','This officer of The Seven will engage anyone threatening the gang\'s operations.',2650000,26500,235,1,8,0.0000,0,NULL,0),(2129,1027,'Limited Barren Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,100,500,1,NULL,670000.0000,0,NULL,0),(2130,1027,'Standard Barren Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,200,500,1,NULL,1600000.0000,0,NULL,0),(2131,1027,'Improved Barren Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,400,500,1,NULL,2800000.0000,0,NULL,0),(2132,1027,'Advanced Barren Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,800,500,1,NULL,3700000.0000,0,NULL,0),(2133,1027,'Elite Barren Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,1600,500,1,NULL,6400000.0000,0,NULL,0),(2134,1027,'Limited Gas Command Center','Maintaining control over a section of  territory  above a gas giant requires a very specific type of command facility, one that is able to maintain its own orbit, house administrative personnel, and easily communicate and interact with other nodes. Suspended with equilibrium technology, these nodes are able to maintain altitude with minimal upkeep. If there is one major advantage to colonizing gas giant planets, it is that these facilities can literally be dropped directly from orbit with almost no concern for their descent or deployment.',5000,100,500,1,NULL,670000.0000,0,NULL,0),(2135,1027,'Standard Gas Command Center','Maintaining control over a section of  territory  above a gas giant requires a very specific type of command facility, one that is able to maintain its own orbit, house administrative personnel, and easily communicate and interact with other nodes. Suspended with equilibrium technology, these nodes are able to maintain altitude with minimal upkeep. If there is one major advantage to colonizing gas giant planets, it is that these facilities can literally be dropped directly from orbit with almost no concern for their descent or deployment.',5000,200,500,1,NULL,1600000.0000,0,NULL,0),(2136,1027,'Improved Gas Command Center','Maintaining control over a section of  territory  above a gas giant requires a very specific type of command facility, one that is able to maintain its own orbit, house administrative personnel, and easily communicate and interact with other nodes. Suspended with equilibrium technology, these nodes are able to maintain altitude with minimal upkeep. If there is one major advantage to colonizing gas giant planets, it is that these facilities can literally be dropped directly from orbit with almost no concern for their descent or deployment.',5000,400,500,1,NULL,2800000.0000,0,NULL,0),(2137,1027,'Advanced Gas Command Center','Maintaining control over a section of  territory  above a gas giant requires a very specific type of command facility, one that is able to maintain its own orbit, house administrative personnel, and easily communicate and interact with other nodes. Suspended with equilibrium technology, these nodes are able to maintain altitude with minimal upkeep. If there is one major advantage to colonizing gas giant planets, it is that these facilities can literally be dropped directly from orbit with almost no concern for their descent or deployment.',5000,800,500,1,NULL,3700000.0000,0,NULL,0),(2138,1027,'Elite Gas Command Center','Maintaining control over a section of  territory  above a gas giant requires a very specific type of command facility, one that is able to maintain its own orbit, house administrative personnel, and easily communicate and interact with other nodes. Suspended with equilibrium technology, these nodes are able to maintain altitude with minimal upkeep. If there is one major advantage to colonizing gas giant planets, it is that these facilities can literally be dropped directly from orbit with almost no concern for their descent or deployment.',5000,1600,500,1,NULL,6400000.0000,0,NULL,0),(2139,1027,'Limited Ice Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,100,500,1,NULL,670000.0000,0,NULL,0),(2140,1027,'Standard Ice Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,200,500,1,NULL,1600000.0000,0,NULL,0),(2141,1027,'Improved Ice Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,400,500,1,NULL,2800000.0000,0,NULL,0),(2142,1027,'Advanced Ice Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,800,500,1,NULL,3700000.0000,0,NULL,0),(2143,1027,'Elite Ice Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,1600,500,1,NULL,6400000.0000,0,NULL,0),(2144,1027,'Limited Lava Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,100,500,1,NULL,670000.0000,0,NULL,0),(2145,1027,'Standard Lava Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,200,500,1,NULL,1600000.0000,0,NULL,0),(2146,1027,'Improved Lava Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,400,500,1,NULL,2800000.0000,0,NULL,0),(2147,1027,'Advanced Lava Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,800,500,1,NULL,3700000.0000,0,NULL,0),(2148,1027,'Elite Lava Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,1600,500,1,NULL,6400000.0000,0,NULL,0),(2149,1027,'Limited Oceanic Command Center','Several interconnected underwater buildings comprise the oceanic command center, which serves as the nervous system for node structures built on water worlds. Built on the ocean floor, this facility includes a thick umbilical that connects it to a communications pod floating on the surface, through which all interplanetary transmissions are sent and received. It also houses a basic two-stage pressurized rocket tube for getting people and cargo to the surface and thence off world into orbit.',5000,100,500,1,NULL,670000.0000,0,NULL,0),(2150,1027,'Standard Oceanic Command Center','Several interconnected underwater buildings comprise the oceanic command center, which serves as the nervous system for node structures built on water worlds. Built on the ocean floor, this facility includes a thick umbilical that connects it to a communications pod floating on the surface, through which all interplanetary transmissions are sent and received. It also houses a basic two-stage pressurized rocket tube for getting people and cargo to the surface and thence off world into orbit.',5000,200,500,1,NULL,1600000.0000,0,NULL,0),(2151,1027,'Improved Oceanic Command Center','Several interconnected underwater buildings comprise the oceanic command center, which serves as the nervous system for node structures built on water worlds. Built on the ocean floor, this facility includes a thick umbilical that connects it to a communications pod floating on the surface, through which all interplanetary transmissions are sent and received. It also houses a basic two-stage pressurized rocket tube for getting people and cargo to the surface and thence off world into orbit.',5000,400,500,1,NULL,2800000.0000,0,NULL,0),(2152,1027,'Advanced Oceanic Command Center','Several interconnected underwater buildings comprise the oceanic command center, which serves as the nervous system for node structures built on water worlds. Built on the ocean floor, this facility includes a thick umbilical that connects it to a communications pod floating on the surface, through which all interplanetary transmissions are sent and received. It also houses a basic two-stage pressurized rocket tube for getting people and cargo to the surface and thence off world into orbit.',5000,800,500,1,NULL,3700000.0000,0,NULL,0),(2153,1027,'Elite Oceanic Command Center','Several interconnected underwater buildings comprise the oceanic command center, which serves as the nervous system for node structures built on water worlds. Built on the ocean floor, this facility includes a thick umbilical that connects it to a communications pod floating on the surface, through which all interplanetary transmissions are sent and received. It also houses a basic two-stage pressurized rocket tube for getting people and cargo to the surface and thence off world into orbit.',5000,1600,500,1,NULL,6400000.0000,0,NULL,0),(2154,1027,'Limited Plasma Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,100,500,1,NULL,670000.0000,0,NULL,0),(2155,1027,'Standard Plasma Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,200,500,1,NULL,1600000.0000,0,NULL,0),(2156,1027,'Improved Plasma Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,400,500,1,NULL,2800000.0000,0,NULL,0),(2157,1027,'Advanced Plasma Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,800,500,1,NULL,3700000.0000,0,NULL,0),(2158,1027,'Elite Plasma Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,1600,500,1,NULL,6400000.0000,0,NULL,0),(2159,1027,'Limited Storm Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,100,500,1,NULL,670000.0000,0,NULL,0),(2160,1027,'Standard Storm Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,200,500,1,NULL,1600000.0000,0,NULL,0),(2161,25,'Crucifier','The Crucifier was first designed as an explorer/scout, but the current version employs the electronic equipment originally intended for scientific studies for more offensive purposes. The Crucifier\'s electronic and computer systems take up a large portion of the internal space leaving limited room for cargo or traditional weaponry.  ',1064000,28100,265,1,4,388538.0000,1,72,0),(2162,105,'Crucifier Blueprint',' ',0,0.01,0,1,NULL,2375000.0000,1,272,0),(2163,952,'CONCORD Collection Vessel','A CONCORD ship.',0,0,100,1,NULL,0.0000,0,NULL,0),(2165,386,'Haunter Cruise Missile','Extra heavy assault missile. The first and only Minmatar-made large missile. Constructed of reactionary alloys, the Wrath is built to get to the target. Guidance and propulsion systems are of Gallentean origin and were initially used in drones, making Wrath fast and nimble despite its heavy payload. ',1250,0.05,0,100,NULL,14646.0000,0,NULL,0),(2173,100,'Infiltrator I','Medium Scout Drone',5000,10,0,1,4,20794.0000,1,838,0),(2174,176,'Infiltrator I Blueprint',' ',0,0.01,0,1,NULL,1700000.0000,1,1532,0),(2175,100,'Infiltrator II','Medium Scout Drone',5000,10,0,1,4,145138.0000,1,838,0),(2176,176,'Infiltrator II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2178,1019,'Guristas Nova Citadel Cruise Missile','Citadel Cruise Missiles are designed for long range bombardment of capital ships and installations. They are a specialized design usable only by capital ships.\r\r\n\r\r\nNocxium atoms captured in morphite matrices form this missile\'s devastating payload. A volley of these is able to completely obliterate almost everything that floats in space, be it vehicle or structure.',1500,0.3,0,100,NULL,278458.0000,1,1317,0),(2179,166,'Sansha Wrath Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,3000000.0000,1,NULL,0),(2180,1019,'Guristas Scourge Citadel Cruise Missile','Citadel Cruise Missiles are designed for long range bombardment of capital ships and installations. They are a specialized design usable only by capital ships.\r\r\n\r\r\nFitted with a graviton pulse generator, this weapon causes massive damage as it overwhelms ships\' internal structures, tearing bulkheads and armor plating apart with frightening ease.',1500,0.3,0,100,NULL,332424.0000,1,1317,0),(2181,306,'Minmatar Diplomat Quarters','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(2182,1019,'Guristas Inferno Citadel Cruise Missile','Citadel Cruise Missiles are designed for long range bombardment of capital ships and installations. They are a specialized design usable only by capital ships.\r\r\n\r\r\nPlasma suspended in an electromagnetic field gives this torpedo the ability to deliver a flaming inferno of destruction, wreaking almost unimaginable havoc.',1500,0.3,0,100,NULL,360746.0000,1,1317,0),(2183,100,'Hammerhead I','Medium Scout Drone',5000,10,0,1,8,23610.0000,1,838,0),(2184,176,'Hammerhead I Blueprint',' ',0,0.01,0,1,NULL,1800000.0000,1,1532,0),(2185,100,'Hammerhead II','Medium Scout Drone',5000,10,0,1,8,147954.0000,1,838,0),(2186,176,'Hammerhead II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2187,952,'Orca Container','The Orca was developed as a joint venture between Outer Ring Excavations and Deep Core Mining Inc as a vessel to help meet the demands of New Eden\'s industry and provide a flexible platform from which mining operations can be more easily managed. The Orca uses much of the technology developed by ORE for the Rorqual and integrated with the latest advancements from Deep Core Mining research division has developed a vessel which offers a diverse role to all sizes of operations and needs.',0,0,500,1,NULL,0.0000,0,NULL,0),(2188,1019,'Guristas Mjolnir Citadel Cruise Missile','Citadel Cruise Missiles are designed for long range bombardment of capital ships and installations. They are a specialized design usable only by capital ships.\r\r\n\r\r\nNothing more than a baby nuclear warhead, this guided missile wreaks havoc with the delicate electronic systems aboard a starship. Specifically designed to damage shield systems, it is able to ravage heavily shielded targets in no time.',1500,0.3,0,100,NULL,386168.0000,1,1317,0),(2189,952,'Drone Infested Dominix',' ',105000000,1010000,600,1,8,0.0000,0,NULL,0),(2190,1053,'Renyn Meten','<font color=yellow>Subject:</font>  Prototype Nation Vessel (ID: Renyn Meten)<br>\r\r\n<font color=yellow>Military Specifications:</font>  Frigate-class vessel. Primary anti-support damage dealer amongst frigate-class prototypes. Significant microwarp velocity. Short range laser systems.<br>\r\r\n<font color=yellow>Additional Intelligence:</font>  There were no reported civilian abductions from the Renyn VI invasion. The Renyn identifier suggests a small number of captives may have been initially unaccounted for, as with the Eystur Rhomben variant. The Meten identifier suggests an oversight role amongst the other frigate-class prototypes, or alternatively, that it was created during the first phase of development.<br>\r\r\n<i>Synopsis from ISHAEKA-0043. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>\r\r\n',2000000,20000,235,1,4,0.0000,0,NULL,0),(2191,1054,'Antem Neo','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID:Antem Neo)<br>\r\r\n<font color=yellow>Military Specifications:</font> Cruiser-class vessel. Primary role is long-range sniping support. Moderate microwarp velocity. Vessel will attempt to establish orbit ranges in excess of 100km.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 900,000 civilian abductions from Antem IV. The Neo identifier suggests this variant was designed recently, or alternatively, is an improvement upon other, pre-existing designs. Possible links to the Mara Paleo variant.<br>\r\r\n<i>Synopsis from ISHAEKA-0059. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>  \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2192,1052,'The Kundalini Manifest','True power lies within all of us. Coiled beneath our fears and insecurities like a resting serpent, it has waited with infinite patience for those last few layers of our imperfection to be stripped away. It waits, as we strive, for a freedom only this part of ourselves truly deserves.<br>\r\r\nFor as long as human history records, we have ignored what we truly are, and worse, we have ignored everything we could yet become. We must learn, now, to let go. Not everything we have taken with us so far on this journey should remain.<br>\r\r\nOur flaws and faults, these near-indelible errors pervading throughout human history, they can all be removed. Together, as one, we can overcome the enemy within.<br>\r\r\n<i>- Sansha Kuvakei</i>\r\r\n',1546875000,62000000,1337,1,4,0.0000,0,NULL,0),(2193,100,'Praetor I','Heavy Attack Drone',10000,25,0,1,4,88424.0000,1,839,0),(2194,176,'Praetor I Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,1,359,0),(2195,100,'Praetor II','Heavy Attack Drone',10000,25,0,1,4,342512.0000,1,839,0),(2196,176,'Praetor II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2197,314,'Environmentally-friendly Mining Equipment','The latest generation of environmentally-friendly mining drills reduces airborne pollutants by 75% when compared to the most popular drills on the market. This is accomplished through a revolutionary  dust recapture  system that essentially vacuums the air around the drill head. The collected dust is captured in large, on-site filtration systems which then compacts the dust into blocks. These blocks can either be refined along with the extracted ores, or simply placed back into the mine as backfill once drilling operations are complete. While more than five times as expensive as normal drills, the efficiency of these new models provides an entirely new level of environmental protection. ',70,32,0,1,NULL,0.0000,1,NULL,0),(2198,314,'Crate of Environmentally-friendly Mining Equipment','The latest generation of environmentally-friendly mining drills reduces airborne pollutants by 75% when compared to the most popular drills on the market. This is accomplished through a revolutionary  dust recapture  system that essentially vacuums the air around the drill head. The collected dust is captured in large, on-site filtration systems which then compacts the dust into blocks. These blocks can either be refined along with the extracted ores, or simply placed back into the mine as backfill once drilling operations are complete. While more than five times as expensive as normal drills, the efficiency of these new models provides an entirely new level of environmental protection. ',210,450,0,1,NULL,0.0000,1,NULL,0),(2199,314,'Prototype Body Armor Fabric ','This energy and force-absorbing fabric could represent a generational advancement in light body armor technology. What makes this remarkable fabric unique is that it contains microscopically thin layers of an advanced polymer containing nanites programmed for self-repair. In short, when a suit of body armor made form this material is impacted by any significant force, the nanites instantly begin to repair any damage done, which protects the wearer from further harm. Most importantly, during the manufacturing phase, if the fabric is properly pre-stressed, the nanites are forced to bond thus creating stronger and stronger material, without any increase in weight or decrease in flexibility. For these reasons, this prototype body armor fabric will undoubtedly become the most sought-after material for those groups able to afford its exorbitant price. ',50,20,0,1,NULL,0.0000,1,NULL,0),(2200,314,'Crate of Prototype Body Armor Fabric ','This energy and force-absorbing fabric could represent a generational advancement in light body armor technology. What makes this remarkable fabric unique is that it contains microscopically thin layers of an advanced polymer containing nanites programmed for self-repair. In short, when a suit of body armor made form this material is impacted by any significant force, the nanites instantly begin to repair any damage done, which protects the wearer from further harm. Most importantly, during the manufacturing phase, if the fabric is properly pre-stressed, the nanites are forced to bond thus creating stronger and stronger material, without any increase in weight or decrease in flexibility. For these reasons, this prototype body armor fabric will undoubtedly become the most sought-after material for those groups able to afford its exorbitant price. ',5000,2000,0,1,NULL,0.0000,1,NULL,0),(2201,314,'Riot Interdiction Team','Riot Interdiction Teams, or RITs, are the primary Amarrian response forces for incidents involving slave riots and uprisings. These forces are equipped with the latest generations of body armor, stun sticks, flash-bang grenades, and other less-lethal technologies. In those cases where less-lethal force is insufficient, the teams are fully trained and equipped to use lethal force to resolve any such threat. For example, the RITs are often called in to resolve hostage situations in which one or more of the captives has been killed, thus eliminating the need for a phased operation and then transitioning to lethal force contingency operations (i.e., shoot to kill). Therefore, it is of little surprise that they are among the most highly trained Amarr ground forces in hostage rescue operations, and are sometimes called on to act in situations unrelated to slave-based scenarios.',30,30,0,1,NULL,0.0000,1,NULL,0),(2202,314,'Riot Interdiction Teams','Riot Interdiction Teams, or RITs, are the primary Amarrian response forces for incidents involving slave riots and uprisings. These forces are equipped with the latest generations of body armor, stun sticks, flash-bang grenades, and other less-lethal technologies. In those cases where less-lethal force is insufficient, the teams are fully trained and equipped to use lethal force to resolve any such threat. For example, the RITs are often called in to resolve hostage situations in which one or more of the captives has been killed, thus eliminating the need for a phased operation and then transitioning to lethal force contingency operations (i.e., shoot to kill). Therefore, it is of little surprise that they are among the most highly trained Amarr ground forces in hostage rescue operations, and are sometimes called on to act in situations unrelated to slave-based scenarios.',500,300,0,1,NULL,0.0000,1,NULL,0),(2203,100,'Acolyte I','Light Scout Drone',3000,5,0,1,4,2094.0000,1,837,0),(2204,176,'Acolyte I Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,1531,0),(2205,100,'Acolyte II','Light Scout Drone',3000,5,0,1,4,47142.0000,1,837,0),(2206,176,'Acolyte II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2207,1054,'Vylade Dien','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Vylade Dien)<br>\r\r\n<font color=yellow>Military Specifications:</font> Cruiser-class vessel. Primary roles are damage dealing and squad enhancement. Low microwarp velocity.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 100,000 civilian abductions from Vylade II. The Dien identifier suggests an oversight role amongst other cruiser-class prototypes, or alternatively, that it was created during the first phase of development. The nature of Nation\'s squad boosting technology is still not fully understood, although current intelligence from recovered wrecks indicates that the designs deviates from standard warfare links in the same way as Tech III Warfare Processors.<br>\r\r\n<i>Synopsis from ISHAEKA-0047. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>  \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2208,1054,'Uitra Telen','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Uitra Telen)<br>\r\r\n<font color=yellow>Military Specifications:</font> Cruiser-class vessel. Moderate microwarp velocity. Limited weapons systems.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 210,000 civilian abductions from VII. The Telen identifier suggests an oversight role amongst other Cruiser-class variants, or that other, more advanced prototypes may have originated from this design.<br>\r\r\n<i>Synopsis from ISHAEKA-0055. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i> \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2209,1054,'Arnon Epithalamus','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Arnon Epithalmus)<br>\r\r\n<font color=yellow>Military Specifications:</font> Cruiser-class vessel. Primary role is extreme range ECM support. Low microwarp velocity. Long range missile support.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> There were no reported civilian abductions from the invasion of Arnon III, IX and XI. The Arnon identifier suggests a number of captives may have been initially unaccounted for, as with the Eystur Rhomben and Renyn Meten variants. This supports previous conjecture that Nation\'s synchronized attacks on multiple planets were at least partly designed to aid in covert abduction. The Epithalmus identifier suggests a unifying role between the cruiser-class prototypes and other hull classes, and perhaps an additional regulatory role in crew emotional response, similar to the suspected behavior of the Tama Cerebellum variant.<br>\r\r\n<i>Synopsis from ISHAEKA-0049. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>   \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2210,89,'Banshee Torpedo','An ultra-heavy piercing missile. Slow and dumb but its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,61096.0000,0,NULL,0),(2211,166,'Sansha Juggernaut Torpedo Blueprint',' ',1,0.01,0,1,NULL,9000000.0000,1,NULL,0),(2212,385,'Ghost Heavy Missile','The Scourge is an old relic from the Caldari-Gallente War that is still in widespread use because of its low price and versatility.',1000,0.03,0,100,4,2664.0000,0,NULL,0),(2213,166,'Ghost Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,750000.0000,1,NULL,0),(2214,952,'Guard Post','This inconspicuous guard post is awaiting security clearance before taking any action.',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(2215,314,'Amarr TIL-1A Nexus Chips ','The Amarr TIL-1A Nexus Chip was once used to store the key elements of a ship\'s artificial intelligence system, as well as for controlling some of the vessel\'s autonomous functions. In addition, the TIL-1A series chip had been modified by top Viziam scientists for the Imperial Navy, making it far more resilient to damage and harsh environmental conditions than standard chips of its kind. The TIL-1A chip, specifically, was designed for front-line Amarr battleship-class vessels where it saw widespread use for almost a decade before being replaced by newer technologies. As a result, very few examples of this remain outside Amarr military historical archives, where they are often highly valued for the data they contain on early naval operations. ',1,12,0,1,NULL,0.0000,1,NULL,0),(2216,314,'Crate of Amarr TIL-1A Nexus Chips','The Amarr TIL-1A Nexus Chip was once used to store the key elements of a ship\'s artificial intelligence system, as well as for controlling some of the vessel\'s autonomous functions. In addition, the TIL-1A series chip had been modified by top Viziam scientists for the Imperial Navy, making it far more resilient to damage and harsh environmental conditions than standard chips of its kind. The TIL-1A chip, specifically, was designed for front-line Amarr battleship-class vessels where it saw widespread use for almost a decade before being replaced by newer technologies. As a result, very few examples of this remain outside Amarr military historical archives, where they are often highly valued for the data they contain on early naval operations. ',10,120,0,1,NULL,0.0000,1,NULL,0),(2217,283,'Preacher','Tolmak\'s preachers serve as his proxies, and are the primary way he spreads his controversial message.',65,1,0,1,NULL,0.0000,1,NULL,0),(2218,306,'Locced\'s Bribe','This cargo container is filled with all the extra supplies the pirates brought along with them.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(2219,314,'Large Group of Civilian Workers and Dependents','Civilian workers and their dependents, including men, women, and children.',110,125,0,1,NULL,0.0000,1,NULL,0),(2220,314,'Civilian Workers and Dependents','Civilian workers and their dependents, including men, women, and children.',11,12,0,1,NULL,0.0000,1,NULL,0),(2221,314,'Manportable Electromagnetic Pulse Weapons ','These EM beam weapons have been custom fitted to detect and eradicate specific nanotechnologies. Normally, these EMP devices are used by special operations personnel during covert operations. They are placed in proximity to the enemy\'s defense grid and used to  short out  any nearby electronics, thus creating a hole in the defense grid such that conventional forces can then move through unimpeded by sentry grids, security bots, and other lethal defensive systems. The devices themselves are approximately the size of a large rucksack and can be both emplaced and operated by a single trained individual. ',25,25,0,1,NULL,0.0000,1,NULL,0),(2222,673,'Scions of the Superior Gene','The Scions of the Superior Gene are a minor extremist cult. They believe that the Jovians are gods, and their technology is sacred   too pure to be used by the lowly empires. They have a small fleet of well-armed ships used exclusively to \"purify\" those who they feel have offended the Jovians.\r\r\n\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(2223,306,'Preacher\'s Quarters','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,8850,1,NULL,0.0000,0,NULL,0),(2224,1006,'Tolmak\'s Zealots','Tolmak has managed to convert a number of people to his religious message. Some of them are so fanatical they\'re willing to fight for him. These zealots form a motley fleet of whatever small ships they have been able to buy with donations from their planetside brethren.',11500000,115000,465,1,4,0.0000,0,NULL,0),(2226,283,'Sisters of Eve Negotiator','An emissary sent by the Sisters of Eve to oversee peace talks.',85,1,0,1,NULL,0.0000,1,NULL,0),(2232,306,'Life pod','A life pod from a long since destroyed ship.',10000,1200,1400,1,NULL,0.0000,0,NULL,0),(2233,1025,'Customs Office','Orbital Customs Offices are the primary points of contact between planetary and interplanetary economies. These facilities, resembling massive hangars in space, provide high-volume, high-frequency cargo transport services between a planet\'s surface and orbit.\r\r\n\r\r\n<i>Excerpt from the Amarr Prime Customs Agency regulations, section 17, subsection 4, paragraph 8:\r\r\n\r\r\nThe following items may only be imported or exported with the express prior approval of the Imperial Underscrivener for Commercial Affairs:\r\r\n\r\r\nNarcotic substances; handheld firearms; slaver hounds (except as personal property); Mindflood; live insects; ungulates; Class 1 refrigerants and aerosols; forced laborers/personal slaves (or other sapient livestock); animal germ-plasm; biomass of human origin; xenobiotics; walnuts.</i>',5000000000,100000000,35000,1,NULL,0.0000,0,NULL,0),(2234,226,'Sansha\'s Battletower','This gigantic war station is one of the military installations of Sansha\'s slumbering nation.  It is known to be able to hold a massive number of Sansha vessels, but strange whispers hint at darker things than mere warfare going on underneath its jagged exterior.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(2239,283,'Oura Madusaari','A half-mad young female Caldari salvager, she was among the few survivors of <i>The Paryi</i>\'s salvaging crew.',85,1,0,1,NULL,0.0000,1,NULL,0),(2240,283,'Harroken Ikero','A half-mad young male Caldari salvager, he was among the few survivors of <i>The Paryi</i>\'s salvaging crew.',85,3,0,1,NULL,0.0000,1,NULL,0),(2244,283,'Fajah Ateshi','A serious middle-aged female Amarr scientist, Dr. Ateshi remained eerily calm while the crew all around her lost their minds. She attributes her survival to God being on her side.',85,1,0,1,NULL,0.0000,1,NULL,0),(2250,314,'Neurowave Pattern Scanner','This scanner will track the brainwaves of any living creatures within a ship.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(2252,226,'Roden Station','This facility bears the red color scheme particular to Roden Shipyards.',0,1,0,1,8,600000.0000,0,NULL,0),(2254,1027,'Temperate Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,1000,500,1,NULL,90000.0000,1,1322,0),(2256,1030,'Temperate Launchpad','The temperate launchpad is able to send and receive payloads from orbit. Because of the relatively calm atmospheric conditions of most temperate planets, the primary focus of this facility is on interfacing effectively with adjacent facilities, allowing for passengers and commodities to be easily organized, scanned, and transported to the appropriate areas. The obvious importance of a centralized spaceport often leads to its becoming a focal point of local culture, including trade, entertainment, and even illegal activities.',0,0,10000,1,NULL,900000.0000,1,NULL,0),(2257,1029,'Ice Storage Facility','\"At some point, it all comes down to more metal.\" The designers of this storage site believed this adage above all else. The outer walls of each container are comprised of almost a meter of titanium alloy around a flexible, lightweight tritanium frame, all sealed with a few layers of active nanite coating to prevent microfractures and thermal warping. This combination allows the building to withstand nearly any environmental challenge. To prevent the tritanium supports from decaying, the interior is kept in a constant vacuum, and workers must wear fully sealed atmosphere suits at all times.',0,0,12000,1,NULL,250000.0000,1,NULL,0),(2258,202,'ECCM - Omni II','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,282226.0000,1,728,0),(2259,202,'ECCM - Gravimetric II','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,292306.0000,1,725,0),(2260,202,'ECCM - Ladar II','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,292306.0000,1,726,0),(2261,202,'ECCM - Magnetometric II','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,292306.0000,1,727,0),(2262,202,'ECCM - Radar II','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,292306.0000,1,729,0),(2263,12,'Planetary Launch Container','This container has been launched from the planet surface into low orbit for collection by starships.  These containers will burn up within a few days if not collected.',10000,27500,1000,1,NULL,0.0000,0,NULL,0),(2267,1032,'Base Metals','Iron and nickel are two widespread, easily recognized examples of base metals, or those metals that oxidize relatively easily. Their tremendous usefulness in numerous applications ensures that base metals are always in high demand. Thankfully, so is their abundance on most planetary surfaces.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2268,1033,'Aqueous Liquids','The abundance of water on terrestrial planets is often a misconception: What many refer to offhandedly as \"water\" is often an amalgamation of many liquids, microscopic particles, and saturated compounds combined with water and other liquids. Aqueous liquids represent those liquids from which pure water can be separated easily from waste or hazardous particles, but only using the proper equipment.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2270,1032,'Noble Metals','Highly resistant to corrosion and oxidation, noble metals are somewhat rarer than base metals, yet they are just as sought after for their different electrical, material, and chemical attributes. When painstakingly refined and purified, some noble metal ores can produce \"precious metals.\"',0,0.01,0,1,NULL,0.0000,1,1333,0),(2272,1032,'Heavy Metals','In small quantities, heavy metals are vital to life, providing essential minerals for biological processes. In bulk, they are commonly found in most construction materials, forming the most basic components of computer electronics and reinforced structures.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2280,1036,'Link',' ',0,0,1000,1,NULL,0.0000,1,NULL,0),(2281,77,'Adaptive Invulnerability Field II','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,NULL,645308.0000,1,1696,0),(2282,157,'Adaptive Invulnerability Field II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2284,226,'Megathron (Roden)','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.',0,0,0,1,8,0.0000,0,NULL,0),(2285,226,'Dominix (Roden)','The Dominix is one of the old warhorses dating back to the Gallente-Caldari War. While no longer regarded as the king of the hill, it is by no means obsolete. Its formidable hulk and powerful drone arsenal means that anyone not in the largest and latest battleships will regret ever locking horns with it.',0,0,0,1,8,0.0000,0,NULL,0),(2286,1035,'Planktic Colonies','Harvested in mass quantities, planktic colonies are used for much more than just a bulk food source that flourishes in water-rich environments. Their cumulative biomass has advanced properties that contribute to some of the most advanced material and medical sciences in New Eden.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2287,1035,'Complex Organisms','Organic flora and fauna growing on worlds across the cluster technically qualify as  alien life,  though none of it has registered as sentient. However, their usefulness as comestibles or building materials in other areas of industry is invaluable.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2288,1035,'Carbon Compounds','Often referred to as the building blocks of life, carbon compounds form the basis of most organic material; hence, they are ideally suited for use in the early development of advanced, reactive molecules, such as those used in biofuel and supertensile structures.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2289,77,'Explosive Deflection Field I','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,20,0,1,NULL,83310.0000,1,1694,0),(2290,157,'Explosive Deflection Field I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1548,0),(2291,77,'Kinetic Deflection Field I','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,20,0,1,NULL,83310.0000,1,1693,0),(2292,157,'Kinetic Deflection Field I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1548,0),(2293,77,'EM Ward Field I','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,20,0,1,NULL,83310.0000,1,1695,0),(2294,157,'EM Ward Field I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1548,0),(2295,77,'Thermic Dissipation Field I','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,20,0,1,NULL,83310.0000,1,1692,0),(2296,157,'Thermic Dissipation Field I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1548,0),(2297,77,'Explosive Deflection Field II','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,NULL,494704.0000,1,1694,0),(2298,157,'Explosive Deflection Field II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2299,77,'Kinetic Deflection Field II','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,NULL,494704.0000,1,1693,0),(2300,157,'Kinetic Deflection Field II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2301,77,'EM Ward Field II','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,NULL,494704.0000,1,1695,0),(2302,157,'EM Ward Field II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2303,77,'Thermic Dissipation Field II','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,NULL,494704.0000,1,1692,0),(2304,157,'Thermic Dissipation Field II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2305,1035,'Autotrophs','At the very bottom of the food chain are autotrophs, those organisms that produce carbohydrates, proteins, and fats for higher life forms to consume. When properly gathered and ordered, they can be plied into industrial fibers, which then go on to contribute to advanced material technologies.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2306,1032,'Non-CS Crystals','The orderly, compact nature of crystals makes them well suited for a staggering array of manufacturing processes, in which they are just as often the product of the factory as they are incorporated into many of the tools and machinery used therein.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2307,1032,'Felsic Magma','The churning core of lava planets is rife with felsic magma, or silicate material that is infused with lighter elements, from which basic silicon and other atomic matter may be extracted. Silicon is abundant on many terrestrial planets, but the fastest and easiest way to obtain it, given advances in planetary mining processes, is from felsic magma.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2308,1033,'Suspended Plasma','When found in harvestable quantities beyond the unapproachable heat of an active star, plasma is said to be in a  suspended  state. Specialized electronic equipment is used to attract the ionized particles into collection tubes, after which it can be stored, transported, or applied to a variety of technologies.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2309,1033,'Ionic Solutions','An electrolyte found in a raw, natural form is called an ionic solution, especially in terms of planetary astronomy. Only after a lengthy process of extraction and refining can the resulting fluid go on to be used for medical, industrial, or nutritive applications. ',0,0.01,0,1,NULL,0.0000,1,1333,0),(2310,1033,'Noble Gas','This colorless, odorless, and usually nonflammable substance is one of seven known monoatomic gases, or those that do not easily combine with other atoms. They are thus well suited for a variety of manufacturing implementations.',0,0.01,0,1,NULL,0.0000,1,1333,0),(2311,1033,'Reactive Gas','Consisting of any number of volatile atomic structures, reactive gases are the most useful when applied to the fields of explosives, molecular restructuring, and electrical conduction. Great care must be taken when storing or transporting any sizeable quantity. ',0,0.01,0,1,NULL,0.0000,1,1333,0),(2312,1034,'Supertensile Plastics',' Hyperoxidation  was the term given to the process of rapidly fossilizing the carbon structures, readily available in the form of biomass, which forms the basic framework of supertensile plastics. The only amorphous solid known to retain the resilience of other such materials while also adopting conductive properties, supertensile plastic is highly sought after for a wide range of industrial applications.',0,1.5,0,1,NULL,1.0000,1,1335,0),(2317,1034,'Oxides','Technically, any chemical compound that contains at least one oxygen atom is an oxide, though some are far more valuable than others. Once broken down and separated from waste material, many oxides can be applied to various industrial processes.',0,1.5,0,1,NULL,1.0000,1,1335,0),(2319,1034,'Test Cultures','When bacteria are allowed to thrive in a water-based environment, they undergo generational transformations that can be monitored and documented, providing research data invaluable to numerous scientific fields.',0,1.5,0,1,NULL,1.0000,1,1335,0),(2321,1034,'Polyaramids','Polyaramid textiles are produced when industrial fibers are harvested from autotrophic life forms and subjected to intense pressure using reactive gas pistons. Able to absorb a startling amount of kinetic energy, sheets of this miraculous material can be form-fitted to just about any structure, protecting it from anything but weapons-grade impact forces.',0,1.5,0,1,NULL,1.0000,1,1335,0),(2327,1034,'Microfiber Shielding','Using advanced residual substrate isolation technology, silicon weave is threaded through layers of tough organic fibers. The resulting microfiber shielding is incredibly resilient and retains the microscopic profile required to shield miniaturized electronics.',0,1.5,0,1,NULL,1.0000,1,1335,0),(2328,1034,'Water-Cooled CPU','Despite how ancient the technology is, there is still no method more cost-effective for cooling computer processing units than ordinary water, which can be heated and cooled rapidly via any number of proven methods. Most often, thermally conductive tubing makes its way through all of the vital components and over heat sinks, helping to regulate operating temperatures.',0,1.5,0,1,NULL,1.0000,1,1335,0),(2329,1034,'Biocells','Similar to an ancient battery, a biocell instead uses biofuels distilled from organic material and precious metals to produce an electrical current in a self-contained, modular unit. However, modern biocells dwarf the capabilities of ancient batteries by several orders of magnitude.',0,1.5,0,1,NULL,1.0000,1,1335,0),(2331,57,'Shield Power Relay I','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,NULL,10656.0000,1,688,0),(2332,137,'Shield Power Relay I Blueprint',' ',0,0.01,0,1,NULL,97440.0000,1,1550,0),(2333,49,'Survey Scanner II','Scans the composition of asteroids, ice and gas clouds.',0,5,0,1,NULL,98779.0000,1,714,0),(2334,129,'Survey Scanner II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2335,226,'Mysterious Probe','Despite its familiar construction, this ancient probe is made from materials and electronics unlike anything you\'ve ever seen in New Eden. It floats silently through space, seemingly dormant.',0,0,0,1,NULL,0.0000,0,NULL,0),(2341,82,'Passive Targeter II','Uses advanced gravitational and visual targeting to identify threats. Allows target lock without alerting the ship to a possible threat.',2000,5,0,1,NULL,132340.0000,1,672,0),(2342,161,'Passive Targeter II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2344,1040,'Condensates','Oxidized coolant is required to produce the temperatures needed to force rare particles to condense out of ordinary matter, which is the most economic way to produce valuable base elements in bulk.',0,6,0,1,NULL,1.0000,1,1336,0),(2345,1040,'Camera Drones','Most visibly used in starship development, especially on capsuleer craft, other types of camera drones are also employed in the fields of nano-medicine, surveillance, and entertainment.',0,6,0,1,NULL,1.0000,1,1336,0),(2346,1040,'Synthetic Synapses','The wide range of uses for synthetic synapses is largely due to the fact that they are able to serve double duty as electrical conduits and as replacements or additions to biological nervous systems. This allows them to be used in computers, cybernetics, and artificial intelligence equipment.',0,6,0,1,NULL,1.0000,1,1336,0),(2348,1040,'Gel-Matrix Biopaste','Gel-matrix biopaste is a highly unstable substance that must be formed from elements that don\'t combine under normal circumstances. Forcing them to do so requires enormous amounts of energy, but the end product is invaluable to high-end electronics and cybernetic medicine.',0,6,0,1,NULL,1.0000,1,1336,0),(2349,1040,'Supercomputers','When an individual computer system incorporates a wide range of networked utilities, layered processors, and redundant memory cores, it is said to have evolved into a supercomputer. Such systems can be put to use managing spaceships, starbases, or even entire planetary administrations.',0,6,0,1,NULL,1.0000,1,1336,0),(2351,1040,'Smartfab Units','These tiny cubes form the building blocks of many simple structures, from basic walls and doors to entire homes and even industrial office spaces. Whenever a sufficient number of smartfab units are placed together and have been programmed with the same instructions, they will automatically combine to form some portion of that object and then become inert in their new form. With adequately detailed blueprints, there is theoretically no limit to the complexity of object or structure these clever devices can create. ',0,6,0,1,NULL,1.0000,1,1336,0),(2352,1040,'Nuclear Reactors','This power core is able to convert heavy elements into electricity by way of nuclear fission, splitting atoms to produce thermal energy on a massive scale. If they are properly shielded and cooled, there are few safer, cleaner ways to power buildings or large vehicles. ',0,6,0,1,NULL,1.0000,1,1336,0),(2354,1040,'Neocoms','As an essential component of the navigational and tactical interface of spaceships, Neocoms are a small but essential cornerstone of the interstellar economy.',0,6,0,1,NULL,1.0000,1,1336,0),(2355,63,'Small Hull Repairer II','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,5,0,1,NULL,119994.0000,1,1053,0),(2356,143,'Small Hull Repairer II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2358,1040,'Biotech Research Reports','As the core fundamentals of organic life constantly evolve and develop on micro and macro levels, the constant production and distribution of biotech research is a mandatory part of ongoing advances in countless scientific disciplines.',0,6,0,1,NULL,1.0000,1,1336,0),(2360,1040,'Industrial Explosives','The primary difference between military and industrial explosives is that the latter are effective only when used in bulk, and they are never sold or transported with  ready to use  detonators. As such, they must be carefully installed, primed, and triggered from remote locations before their full destructive force can be applied.',0,6,0,1,NULL,1.0000,1,1336,0),(2361,1040,'Hermetic Membranes','How do you make a sheet of material absolutely impermeable to specific particles? Simple: You make the material <i>want</i> to stop those particles. Such is the case with hermetic membranes, supertensile fabrics instilled with living genetic material that actively hunts down and absorbs or repels whatever they were bred to counteract.',0,6,0,1,NULL,1.0000,1,1336,0),(2363,205,'Heat Sink I','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,40456.0000,1,647,0),(2364,205,'Heat Sink II','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,405960.0000,1,647,0),(2366,1040,'Hazmat Detection Systems','A critical component of space stations, starships, or any other isolated environment, these tiny devices are set to trigger alarms when the genetically engineered viruses inside mutate   which means that they\'ve encountered a significant dose of radiation, natural contaminant, or airborne pathogen, signifying that the surrounding crew is in danger.',0,6,0,1,NULL,1.0000,1,1336,0),(2367,1040,'Cryoprotectant Solution','The base elements present in certain synthetic oils can, at extreme temperatures, produce habitable environments for genetically engineered extremophile. The byproduct of their rapid life-death cycle is a highly thermal resistant solution ideal for hybrid electronics.',0,6,0,1,NULL,1.0000,1,1336,0),(2368,314,'Broken Organic Mortar Applicators','While nanites are ideal for many forms of construction, sealing joints between large structural bulkheads is a job best left to organic mortar, a thick gel that actively permeates every microscopic gap between two parts. Due to the aggressive nature of the genetically engineered bacteria that intelligently guides into place the hardening condensate material, this paste is extremely hazardous to humans and must be applied by robots.',0,100,0,1,NULL,25000.0000,1,20,0),(2369,314,'Broken Sterile Conduits','Sustaining diverse populations of station inhabitants   many of whom come from different worlds with different ecologies   was a medical nightmare until the development of sterile conduits. Each length of flexible, self-repairing tube is powered by breaking down the chemical energy in the water they convey, which itself is laced with smart vaccines able to identify and destroy almost any known antigen.',0,100,0,1,NULL,25000.0000,1,20,0),(2370,572,'Serpentis Initiate','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2450000,24500,60,1,8,0.0000,0,NULL,0),(2371,314,'Broken Nano-Factory','Only the highly advanced Ukomi superconductor can be rendered small enough for use in nano-factories, microscopic devices programmed to absorb and recycle ambient material into useful matter. Each factory is built from reactive metals, ensuring that they interact properly   or not at all   with their environment, while a mote of industrial explosive automatically destroys them when they have completed their task.',0,100,0,1,NULL,25000.0000,1,20,0),(2372,550,'Angel Rogue','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2250000,22500,75,1,2,0.0000,0,NULL,0),(2373,314,'Broken Self-Harmonizing Power Core','With camera drones diligently monitoring the temperature, radioactivity, and electrical output of these advanced nuclear reactors, instant adjustments can be made to a dynamic, adaptive layer of hermetic membranes, which keeps the power core functioning safely at maximum capacity, with no human attention required whatsoever.',0,100,0,1,NULL,25000.0000,1,20,0),(2374,314,'Broken Recursive Computing Module','Not all automated functions are delicate or complicated enough to warrant advanced computer hardware; relatively mundane tasks are best when assigned to an RCM bank. These sturdy, reliable processing units are able to effectively handle most of the day-to-day operations of stations, starships, and stargates.',0,100,0,1,NULL,25000.0000,1,20,0),(2375,314,'Broken Broadcast Node','By integrating transcranial microcontrollers into a circuit made from synthetic synapses, the broadcast node is able to communicate directly with various station functions and with negligible signal loss and latency. The addition of computerized guidance systems, each running independent navigation system software routines, allows a single node to coordinate starship docking procedures, drone operations, and even station defenses.',0,100,0,1,NULL,25000.0000,1,20,0),(2376,314,'Broken Integrity Response Drones','Hull breaches are a constant, serious threat during space travel, as well as a dangerous reality to orbital stations, which are too massive to avoid incoming objects. Integrity response drones help mitigate that threat by providing the automated, immediate application of sealants to any detected impact or pressure fracture in the structure they patrol.',0,100,0,1,NULL,25000.0000,1,20,0),(2377,314,'Broken Wetware Mainframe','So advanced and energy-demanding are wetware mainframes that they require vehicle-scale power cores and the constant attention of maintenance personnel. When operating at peak performance levels, nothing in New Eden can match the raw computing power of these machines, from calculating warp coordinates to administrating the core functions of an entire space station.',0,100,0,1,NULL,25000.0000,1,20,0),(2378,675,'Mysterious Shuttle','The only thing sensors can make out about this ship is that it has some kind of receiver that interacts with the star\'s natural magnetic field. There is one faint life sign, similar to a human in cryogenic stasis.',1600000,5000,10,1,1,0.0000,0,NULL,0),(2379,572,'Serpentis Spy','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2500000,25000,60,1,8,0.0000,0,NULL,0),(2381,571,'Serpentis Chief Spy','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',11600000,116000,900,1,8,0.0000,0,NULL,0),(2382,562,'Guristas Arrogator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',1500100,15001,45,1,1,0.0000,0,NULL,0),(2383,562,'Guristas Invader','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2025000,20250,65,1,1,0.0000,0,NULL,0),(2384,562,'Guristas Imputor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',1612000,16120,80,1,1,0.0000,0,NULL,0),(2385,562,'Guristas Despoiler','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2040000,20400,100,1,1,0.0000,0,NULL,0),(2386,562,'Guristas Plunderer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(2387,561,'Guristas Silencer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',10700000,107000,850,1,1,0.0000,0,NULL,0),(2389,1042,'Plasmoids','In the early days of humanity\'s return to space flight, scientists Planto and Ginch co-discovered a self-sustaining natural structure made entirely from plasma suspended in a planetary magnetic field. Since then, the term has been applied to any such construct, whether occurring under normal conditions or produced artificially using electrical currents.',0,0.38,0,1,NULL,1.0000,1,1334,0),(2390,1042,'Electrolytes','This conductive liquid is able to carry an electrical current due to its unique ionic properties, making it ideal for use as a reactive coolant, a high-energy fuel, or a transference medium for power plants.',0,0.38,0,1,NULL,1.0000,1,1334,0),(2392,1042,'Oxidizing Compound','Converting various matter from its basic state to an oxidized form requires an oxidizing compound, the most effective of which is a powerful agent made from pressurized reactive gas. Special containers are required to keep the compound from causing significant damage to common metals and organic life.',0,0.38,0,1,NULL,1.0000,1,1334,0),(2393,1042,'Bacteria','The term  bacteria  covers a wide, diverse family of unicellular microorganisms, from those found in almost every climate in New Eden to those that thrive in the bodies of other living beings. Though some bacteria are known to convey diseases, others are more helpful than harmful to humans.',0,0.38,0,1,NULL,1.0000,1,1334,0),(2395,1042,'Proteins','One of the most basic components of biological life, proteins form the core DNA structure and are involved in almost every process that sustains a living being. Harvested at the microscopic level, proteins can be put to use in everything from medical genetics to nanite technology.',0,0.38,0,1,NULL,1.0000,1,1334,0),(2396,1042,'Biofuels','The most widely used, renewable solid fuel in the cluster, biofuel production is present in some fashion on almost every inhabited world. A steady fuel source can be maintained in a planetary economy by converting living material directly into energy instead of relying on fossil fuels. ',0,0.38,0,1,NULL,1.0000,1,1334,0),(2397,1042,'Industrial Fibers','The main difference between fibers used in industry and those created for civilian use is the trade-off of comfort for tensile strength and durability. This allows industrial fibers to be used in more severe environments, from electronic component shielding on hostile worlds to solar sails in the frigid void of space. ',0,0.38,0,1,NULL,1.0000,1,1334,0),(2398,1042,'Reactive Metals','Very dense metals are often called reactive metals, as their ability to conduct electrical currents and absorb heat is unparalleled. Rarely found in a natural solid state, they are instead usually assembled on an atomic level from particulate matter found in other forms.',0,0.38,0,1,NULL,1.0000,1,1334,0),(2399,1042,'Precious Metals','A cousin of noble metals, precious metals are named as such because of how infrequently they appear on terrestrial worlds where they were first encountered.',0,0.38,0,1,NULL,1.0000,1,1334,0),(2400,1042,'Toxic Metals','Derived from heavy metals, toxic metals are those that have no biological function and are in fact poisonous to most living creatures.',0,0.38,0,1,NULL,1.0000,1,1334,0),(2401,1042,'Chiral Structures','A chiral structure is a crystal that is unsymmetrical, which makes it volatile in some situations but ideal for conductivity, especially in micro-circuitry. Using semi-rare chiral structures in electronics has allowed for an unprecedented advancement in the field of miniaturization.',0,0.38,0,1,NULL,1.0000,1,1334,0),(2403,1241,'Advanced Planetology','The advanced understanding of planet evolution allowing you to interpret data from scans of planets for resources at much higher resolutions.\r\r\n\r\r\nBonus:\r\r\nThe skill further increases the resolution of resource data when scanning a planet to allow for very precise surveying.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,7500000.0000,1,1823,0),(2404,509,'Light Missile Launcher II','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.795,1,NULL,197494.0000,1,640,0),(2405,136,'Light Missile Launcher II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2406,1241,'Planetology','The understanding of planet evolution allowing you to better interpret data from scans of planets for resources.\r\r\n\r\r\nBonus:\r\r\nThe skill increases the resolution of resource data when scanning a planet to allow for more accurate surveying.',0,0.01,0,1,NULL,1000000.0000,1,1823,0),(2407,226,'The Terminus Stream','The material being ejected from this wormhole consists of hydrogen, oxygen, silicon, iron, and other materials usually only found in those states and frequency on terrestrial planets.',1,0,0,1,NULL,0.0000,0,NULL,0),(2409,1026,'Barren Aqueous Liquid Extractor','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2410,510,'Heavy Missile Launcher II','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,1.2,1,NULL,305466.0000,1,642,0),(2411,136,'Heavy Missile Launcher II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2412,1026,'Temperate Aqueous Liquid Extractor','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2413,1026,'Storm Aqueous Liquid Extractor','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2414,1026,'Oceanic Aqueous Liquid Extractor','This underwater platform and extendable extraction arms are capable of scouring the ocean floor for valuable materials and bringing them to the surface for transportation to processing facilities. A small habitation module serves as living and operation quarters for the human administration and maintenance crew, along with emergency surfacing capsules in the case of a seismic event or breach of the building\'s integrity.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2415,1026,'Ice Aqueous Liquid Extractor','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2416,1026,'Gas Aqueous Liquid Extractor','Extracting gas from a gas giant requires more effort than simply opening a door into a container. Each specific type of desirable gas requires an ionized filament to be calibrated to attract only the right particles from the atmosphere. Even a fraction of a percent error could spoil an entire batch of product by tainting it with unwanted material. Likewise, once the gas is extracted from the surrounding air, the platform\'s equilibrium tanks must be adjusted to compensate for the added weight or buoyancy. Beyond that, it\'s a simple matter of supercooling it and transferring the liquid form into a container for transport. As one pioneer of this technology accurately described it,  The extractor itself is much like a living organism, breathing in what it needs and expelling that which becomes cumbersome. ',0,0,0,1,NULL,45000.0000,1,NULL,0),(2417,1026,'Plasma Suspended Plasma Extractor','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2418,1026,'Lava Suspended Plasma Extractor','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2419,1026,'Storm Suspended Plasma Extractor','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2420,508,'Torpedo Launcher II','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2,1,NULL,1438516.0000,1,644,0),(2421,136,'Torpedo Launcher II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2422,1026,'Storm Ionic Solutions Extractor','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2423,1026,'Ice Noble Gas Extractor','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2424,1026,'Gas Ionic Solutions Extractor','Extracting gas from a gas giant requires more effort than simply opening a door into a container. Each specific type of desirable gas requires an ionized filament to be calibrated to attract only the right particles from the atmosphere. Even a fraction of a percent error could spoil an entire batch of product by tainting it with unwanted material. Likewise, once the gas is extracted from the surrounding air, the platform\'s equilibrium tanks must be adjusted to compensate for the added weight or buoyancy. Beyond that, it\'s a simple matter of supercooling it and transferring the liquid form into a container for transport. As one pioneer of this technology accurately described it,  The extractor itself is much like a living organism, breathing in what it needs and expelling that which becomes cumbersome. ',0,0,0,1,NULL,45000.0000,1,NULL,0),(2425,1026,'Storm Noble Gas Extractor','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2426,1026,'Gas Noble Gas Extractor','Custom-built gas extractors were first developed to take advantage of gas giant settlements and represented the most lucrative long-term development of such unique worlds. These enormous extraction units, when carefully lowered to the proper altitude on gas giant planets, provide a cost-effective way of acquiring rare and high-demand resources, such as noble and reactive gases and suspended plasma. The proliferation of gas giant settlement in recent years has drastically lowered the price of these base materials, which in turn has seen increased productivity in the numerous planetside and spacebound industries built around these valuable commodities.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2427,1026,'Gas Reactive Gas Extractor','Custom-built gas extractors were first developed to take advantage of gas giant settlements and represented the most lucrative long-term development of such unique worlds. These enormous extraction units, when carefully lowered to the proper altitude on gas giant planets, provide a cost-effective way of acquiring rare and high-demand resources, such as noble and reactive gases and suspended plasma. The proliferation of gas giant settlement in recent years has drastically lowered the price of these base materials, which in turn has seen increased productivity in the numerous planetside and spacebound industries built around these valuable commodities.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2428,1026,'Lava Base Metals Extractor','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2429,1026,'Plasma Base Metals Extractor','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2430,1026,'Barren Base Metals Extractor','Surface mining is a common and effective practice that dates back to early planetary settlement. The process involves stripping a planet\'s surface layer until the ore buried beneath is exposed. At this point, the ore can be more easily extracted. Surface mines are typically quite shallow and are built in areas where the surface material covering the valuable deposits is relatively thin. For this reason, surface mines are sometimes built on the ocean floor.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2431,1026,'Storm Base Metals Extractor','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2432,1026,'Ice Microorganisms Extractor','Modular biomass cultivators have been the mainstay of low-cost micro-agriculture for centuries. As a result, these facilities have proliferated across many planetary settlements. These adaptable micro-ponds allow communities to alter their cultivators to take advantage of local environments, benefiting optimally from the unique bacterial makeup of local water supplies.  Although traditional farming methods remain competitive on terrestrial planets, the production of microorganisms is most efficient when handled by a custom biomass cultivator.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2433,1026,'Gas Base Metals Extractor','Custom-built gas extractors were first developed to take advantage of gas giant settlements and represented the most lucrative long-term development of such unique worlds. These enormous extraction units, when carefully lowered to the proper altitude on gas giant planets, provide a cost-effective way of acquiring rare and high-demand resources, such as noble and reactive gases and suspended plasma. The proliferation of gas giant settlement in recent years has drastically lowered the price of these base materials, which in turn has seen increased productivity in the numerous planetside and spacebound industries built around these valuable commodities. ',0,0,0,1,NULL,45000.0000,1,NULL,0),(2434,1026,'Plasma Noble Metals Extractor','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2435,1026,'Barren Noble Metals Extractor','Surface mining is a common and effective practice that dates back to early planetary settlement. The process involves stripping a planet\'s surface layer until the ore buried beneath is exposed. At this point, the ore can be more easily extracted. Surface mines are typically quite shallow and are built in areas where the surface material covering the valuable deposits is relatively thin. For this reason, surface mines are sometimes built on the ocean floor.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2436,100,'Wasp II','Heavy Attack Drone',10000,25,0,1,1,328518.0000,1,839,0),(2437,176,'Wasp II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2438,1026,'Ice Planktic Colonies Extractor','Modular biomass cultivators have been the mainstay of low-cost micro-agriculture for centuries. As a result, these facilities have proliferated across many planetary settlements. These adaptable micro-ponds allow communities to alter their cultivators to take advantage of local environments, benefitting optimally from the unique bacterial makeup of local water supplies.  Although traditional farming methods remain competitive on terrestrial planets, the production of micro-organisms is most efficient when handled by a custom biomass cultivator.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2439,1026,'Lava Heavy Metals Extractor','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2440,1026,'Plasma Heavy Metals Extractor','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2441,1026,'Ice Heavy Metals Extractor','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2442,1026,'Lava Non-CS Crystals Extractor','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2443,1026,'Plasma Non-CS Crystals Extractor','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2444,100,'Ogre I','Heavy Attack Drone',12000,25,0,1,8,106788.0000,1,839,0),(2445,176,'Ogre I Blueprint',' ',0,0.01,0,1,NULL,7000000.0000,1,359,0),(2446,100,'Ogre II','Heavy Attack Drone',12000,25,0,1,8,360876.0000,1,839,0),(2447,176,'Ogre II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2448,1026,'Lava Felsic Magma Extractor','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2449,1026,'Barren Microorganisms Extractor','Modular biomass cultivators have been the mainstay of low-cost micro-agriculture for centuries. As a result, these facilities have proliferated across many planetary settlements. These adaptable micro-ponds allow communities to alter their cultivators to take advantage of local environments, benefiting optimally from the unique bacterial makeup of local water supplies.  Although traditional farming methods remain competitive on terrestrial planets, the production of microorganisms is most efficient when handled by a custom biomass cultivator.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2450,1026,'Temperate Microorganisms Extractor','Modular biomass cultivators have been the mainstay of low-cost micro-agriculture for centuries. As a result, these facilities have proliferated across many planetary settlements. These adaptable micro-ponds allow communities to alter their cultivators to take advantage of local environments, benefiting optimally from the unique bacterial makeup of local water supplies.  Although traditional farming methods remain competitive on terrestrial planets, the production of microorganisms is most efficient when handled by a custom biomass cultivator.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2451,1026,'Oceanic Microorganisms Extractor','Centuries of aquatic life and plant growth typically blanket ocean worlds\' floors with a thick layer of valuable biomass. When properly cultivated, harvested, and refined, the applications of such material range anywhere from food production and medical application to more esoteric functions, such as genetic enhancements and super-resilient textiles. The facility itself includes both a processing plant, which filters and compresses the material; and a roving collector, which is little more than a series of churning scoops and a powerful pumping mechanism connected to the facility via flexible conduit.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2452,1026,'Oceanic Planktic Colonies Extractor','Centuries of aquatic life and plant growth typically blanket ocean worlds\' floors with a thick layer of valuable biomass. When properly cultivated, harvested, and refined, the applications of such material range anywhere from food production and medical application to more esoteric functions, such as genetic enhancements and super-resilient textiles. The facility itself includes both a processing plant, which filters and compresses the material; and a roving collector, which is little more than a series of churning scoops and a powerful pumping mechanism connected to the facility via flexible conduit.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2453,1026,'Temperate Complex Organisms Extractor','Modular biomass cultivators have been the mainstay of low-cost micro-agriculture for centuries. As a result, these facilities have proliferated across many planetary settlements. These adaptable micro-ponds allow communities to alter their cultivators to take advantage of local environments, benefitting optimally from the unique bacterial makeup of local water supplies.  Although traditional farming methods remain competitive on terrestrial planets, the production of micro-organisms is most efficient when handled by a custom biomass cultivator.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2454,100,'Hobgoblin I','Light Scout Drone',3000,5,0,1,8,2610.0000,1,837,0),(2455,176,'Hobgoblin I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1531,0),(2456,100,'Hobgoblin II','Light Scout Drone',3000,5,0,1,8,47658.0000,1,837,0),(2457,176,'Hobgoblin II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2458,1026,'Oceanic Complex Organisms Extractor','Centuries of aquatic life and plant growth typically blanket ocean worlds\' floors with a thick layer of valuable biomass. When properly cultivated, harvested, and refined, the applications of such material range anywhere from food production and medical application to more esoteric functions, such as genetic enhancements and super-resilient textiles. The facility itself includes both a processing plant, which filters and compresses the material; and a roving collector, which is little more than a series of churning scoops and a powerful pumping mechanism connected to the facility via flexible conduit.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2459,1026,'Barren Carbon Compounds Extractor','Modular biomass cultivators have been the mainstay of low-cost micro-agriculture for centuries. As a result, these facilities have proliferated across many planetary settlements. These adaptable micro-ponds allow communities to alter their cultivators to take advantage of local environments, benefitting optimally from the unique bacterial makeup of local water supplies.  Although traditional farming methods remain competitive on terrestrial planets, the production of micro-organisms is most efficient when handled by a custom biomass cultivator.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2460,1026,'Temperate Carbon Compounds Extractor','Modular biomass cultivators have been the mainstay of low-cost micro-agriculture for centuries. As a result, these facilities have proliferated across many planetary settlements. These adaptable micro-ponds allow communities to alter their cultivators to take advantage of local environments, benefitting optimally from the unique bacterial makeup of local water supplies.  Although traditional farming methods remain competitive on terrestrial planets, the production of micro-organisms is most efficient when handled by a custom biomass cultivator.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2461,1026,'Oceanic Carbon Compounds Extractor','This underwater platform and extendable extraction arms are capable of scouring the ocean floor for valuable materials and bringing them to the surface for transportation to processing facilities. A small habitation module serves as living and operation quarters for the human administration and maintenance crew, along with emergency surfacing capsules in the case of a seismic event or breach of the building\'s integrity.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2462,1026,'Temperate Autotrophs Extractor','Modular biomass cultivators have been the mainstay of low-cost micro-agriculture for centuries. As a result, these facilities have proliferated across many planetary settlements. These adaptable micro-ponds allow communities to alter their cultivators to take advantage of local environments, benefitting optimally from the unique bacterial makeup of local water supplies.  Although traditional farming methods remain competitive on terrestrial planets, the production of micro-organisms is most efficient when handled by a custom biomass cultivator.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2463,1034,'Nanites','Though they are only simple machines and very small, nanites can be used to achieve miraculous medical results in small amounts or astounding feats of engineering in mass quantities.',0,1.5,0,1,NULL,1.0000,1,1335,0),(2464,100,'Hornet I','Light Scout Drone',3500,5,0,1,1,3164.0000,1,837,0),(2465,176,'Hornet I Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,1531,0),(2466,100,'Hornet II','Light Scout Drone',3500,5,0,1,1,48212.0000,1,837,0),(2467,176,'Hornet II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2468,226,'Fortified Drone Structure II','This gigantic superstructure was built by the effort of thousands of rogue drones. While the structure appears to be incomplete, its intended shape remains a mystery to clueless carbon-based lifeforms.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(2469,1028,'Lava Basic Industry Facility','Instead of laboring to shield the production lines of this industrial facility from the surrounding environment, designers opted instead to use the available heat, interference, and even crushing pressure to help power the structure itself. A plant on an ice planet might have highly advanced extended heat sinks, while a factory on a plasma world might draw most, if not all of its electricity from magnetized coils specially attuned to the planet\'s local ion winds. Taking advantage of the indigenous features of each world helps offset the cost of building mass production infrastructure there, which usually involves protective coatings, environmental clothing, and reinforced foundations.',0,0,0,1,NULL,75000.0000,1,NULL,0),(2470,1028,'Lava Advanced Industry Facility','Instead of laboring to shield the production lines of this industrial facility from the surrounding environment, designers opted instead to use the available heat, interference, and even crushing pressure to help power the structure itself. A plant on an ice planet might have highly advanced extended heat sinks, while a factory on a plasma world might draw most, if not all of its electricity from magnetized coils specially attuned to the planet\'s local ion winds. Taking advantage of the indigenous features of each world helps offset the cost of building mass production infrastructure there, which usually involves protective coatings, environmental clothing, and reinforced foundations.',0,0,0,1,NULL,250000.0000,1,NULL,0),(2471,1028,'Plasma Basic Industry Facility','Instead of laboring to shield the production lines of this industrial facility from the surrounding environment, designers opted instead to use the available heat, interference, and even crushing pressure to help power the structure itself. A plant on an ice planet might have highly advanced extended heat sinks, while a factory on a plasma world might draw most, if not all of its electricity from magnetized coils specially attuned to the planet\'s local ion winds. Taking advantage of the indigenous features of each world helps offset the cost of building mass production infrastructure there, which usually involves protective coatings, environmental clothing, and reinforced foundations.',0,0,0,1,NULL,75000.0000,1,NULL,0),(2472,1028,'Plasma Advanced Industry Facility','Instead of laboring to shield the production lines of this industrial facility from the surrounding environment, designers opted instead to use the available heat, interference, and even crushing pressure to help power the structure itself. A plant on an ice planet might have highly advanced extended heat sinks, while a factory on a plasma world might draw most, if not all of its electricity from magnetized coils specially attuned to the planet\'s local ion winds. Taking advantage of the indigenous features of each world helps offset the cost of building mass production infrastructure there, which usually involves protective coatings, environmental clothing, and reinforced foundations.',0,0,0,1,NULL,250000.0000,1,NULL,0),(2473,1028,'Barren Basic Industry Facility','Populated almost entirely by robotic laborers, mass production facilities excel at creating products in bulk with minimal supervision and maintenance. They can be so self-sufficient that rumors abound of Gallente factories operated entirely by androids and governed by a skeleton crew of drones. (Detractors of this method like to note that Sansha facilities work in much the same fashion.) Either way, the results are irrefutable: Raw materials and components go in one end, and polished commodities come out the other side.',0,0,0,1,NULL,75000.0000,1,NULL,0),(2474,1028,'Barren Advanced Industry Facility','Populated almost entirely by robotic laborers, mass production facilities excel at creating products in bulk with minimal supervision and maintenance. They can be so self-sufficient that rumors abound of Gallente factories operated entirely by androids and governed by a skeleton crew of drones. (Detractors of this method like to note that Sansha facilities work in much the same fashion.) Either way, the results are irrefutable: Raw materials and components go in one end, and polished commodities come out the other side.',0,0,0,1,NULL,250000.0000,1,NULL,0),(2475,1028,'Barren High-Tech Production Plant','Populated almost entirely by robotic laborers, mass production facilities excel at creating products in bulk with minimal supervision and maintenance. They can be so self-sufficient that rumors abound of Gallente factories operated entirely by androids and governed by a skeleton crew of drones. (Detractors of this method like to note that Sansha facilities work in much the same fashion.) Either way, the results are irrefutable: Raw materials and components go in one end, and polished commodities come out the other side.',0,0,0,1,NULL,525000.0000,1,NULL,0),(2476,100,'Berserker I','Heavy Attack Drone',10000,25,0,1,2,51744.0000,1,839,0),(2477,176,'Berserker I Blueprint',' ',0,0.01,0,1,NULL,4000000.0000,1,359,0),(2478,100,'Berserker II','Heavy Attack Drone',10000,25,0,1,2,305832.0000,1,839,0),(2479,176,'Berserker II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2480,1028,'Temperate Advanced Industry Facility','Populated almost entirely by robotic laborers, mass production facilities excel at creating products in bulk with minimal supervision and maintenance. They can be so self-sufficient that rumors abound of Gallente factories operated entirely by androids and governed by a skeleton crew of drones. (Detractors of this method like to note that Sansha facilities work in much the same fashion.) Either way, the results are irrefutable: Raw materials and components go in one end, and polished commodities come out the other side.',0,0,0,1,NULL,250000.0000,1,NULL,0),(2481,1028,'Temperate Basic Industry Facility','Populated almost entirely by robotic laborers, mass production facilities excel at creating products in bulk with minimal supervision and maintenance. They can be so self-sufficient that rumors abound of Gallente factories operated entirely by androids and governed by a skeleton crew of drones. (Detractors of this method like to note that Sansha facilities work in much the same fashion.) Either way, the results are irrefutable: Raw materials and components go in one end, and polished commodities come out the other side.',0,0,0,1,NULL,75000.0000,1,NULL,0),(2482,1028,'Temperate High-Tech Production Plant','Populated almost entirely by robotic laborers, mass production facilities excel at creating products in bulk with minimal supervision and maintenance. They can be so self-sufficient that rumors abound of Gallente factories operated entirely by androids and governed by a skeleton crew of drones. (Detractors of this method like to note that Sansha facilities work in much the same fashion.) Either way, the results are irrefutable: Raw materials and components go in one end, and polished commodities come out the other side.',0,0,0,1,NULL,525000.0000,1,NULL,0),(2483,1028,'Storm Basic Industry Facility','Instead of laboring to shield the production lines of this industrial facility from the surrounding environment, designers opted instead to use the available heat, interference, and even crushing pressure to help power the structure itself. A plant on an ice planet might have highly advanced extended heat sinks, while a factory on a plasma world might draw most, if not all of its electricity from magnetized coils specially attuned to the planet\'s local ion winds. Taking advantage of the indigenous features of each world helps offset the cost of building mass production infrastructure there, which usually involves protective coatings, environmental clothing, and reinforced foundations.',0,0,0,1,NULL,75000.0000,1,NULL,0),(2484,1028,'Storm Advanced Industry Facility','Instead of laboring to shield the production lines of this industrial facility from the surrounding environment, designers opted instead to use the available heat, interference, and even crushing pressure to help power the structure itself. A plant on an ice planet might have highly advanced extended heat sinks, while a factory on a plasma world might draw most, if not all of its electricity from magnetized coils specially attuned to the planet\'s local ion winds. Taking advantage of the indigenous features of each world helps offset the cost of building mass production infrastructure there, which usually involves protective coatings, environmental clothing, and reinforced foundations.',0,0,0,1,NULL,250000.0000,1,NULL,0),(2485,1028,'Oceanic Advanced Industry Facility','Because of the difficulties involved in maintaining a habitable environment for human workers, all requirements for such personnel have been eliminated on oceanic mass production facilities. Instead, the building\'s focus is centered on maintaining production quotas under extreme circumstances, with reinforced bulkheads occupying almost every space that would normally have been reserved for hallways, offices, and living quarters.',0,0,0,1,NULL,250000.0000,1,NULL,0),(2486,100,'Warrior I','Light Scout Drone',4000,5,0,1,2,4230.0000,1,837,0),(2487,176,'Warrior I Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,1531,0),(2488,100,'Warrior II','Light Scout Drone',4000,5,0,1,2,49278.0000,1,837,0),(2489,176,'Warrior II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2490,1028,'Oceanic Basic Industry Facility','Because of the difficulties involved in maintaining a habitable environment for human workers, all requirements for such personnel have been eliminated on oceanic mass production facilities. Instead, the building\'s focus is centered on maintaining production quotas under extreme circumstances, with reinforced bulkheads occupying almost every space that would normally have been reserved for hallways, offices, and living quarters.',0,0,0,1,NULL,75000.0000,1,NULL,0),(2491,1028,'Ice Advanced Industry Facility','Instead of laboring to shield the production lines of this industrial facility from the surrounding environment, designers opted instead to use the available heat, interference, and even crushing pressure to help power the structure itself. A plant on an ice planet might have highly advanced extended heat sinks, while a factory on a plasma world might draw most, if not all of its electricity from magnetized coils specially attuned to the planet\'s local ion winds. Taking advantage of the indigenous features of each world helps offset the cost of building mass production infrastructure there, which usually involves protective coatings, environmental clothing, and reinforced foundations.',0,0,0,1,NULL,250000.0000,1,NULL,0),(2492,1028,'Gas Basic Industry Facility','Hovering eerily among the clouds of a gas giant planet, this mass production industry platform can cast a long shadow, for it requires a massive static attunement system to remain afloat. Inside, the only real difference between it and one of its terrestrial counterparts is in the material composition used in its construction. Anything that would have been made from cheap, sturdy metal is replaced with high-strength, ultra-resistant alloys. Spare parts and raw materials are kept at absolutely minimal levels to maintain the proper weight and balance, while even items as innocuous as staff personal effects are carefully monitored and regulated.',0,0,0,1,NULL,75000.0000,1,NULL,0),(2493,1028,'Ice Basic Industry Facility','Instead of laboring to shield the production lines of this industrial facility from the surrounding environment, designers opted instead to use the available heat, interference, and even crushing pressure to help power the structure itself. A plant on an ice planet might have highly advanced extended heat sinks, while a factory on a plasma world might draw most, if not all of its electricity from magnetized coils specially attuned to the planet\'s local ion winds. Taking advantage of the indigenous features of each world helps offset the cost of building mass production infrastructure there, which usually involves protective coatings, environmental clothing, and reinforced foundations.',0,0,0,1,NULL,75000.0000,1,NULL,0),(2494,1028,'Gas Advanced Industry Facility','Hovering eerily among the clouds of a gas giant planet, this mass production industry platform can cast a long shadow, for it requires a massive static attunement system to remain afloat. Inside, the only real difference between it and one of its terrestrial counterparts is in the material composition used in its construction. Anything that would have been made from cheap, sturdy metal is replaced with high-strength, ultra-resistant alloys. Spare parts and raw materials are kept at absolutely minimal levels to maintain the proper weight and balance, while even items as innocuous as staff personal effects are carefully monitored and regulated',0,0,0,1,NULL,250000.0000,1,NULL,0),(2495,1241,'Interplanetary Consolidation','For each level in this skill, you may install a command center on one additional planet, to a maximum of 6 planets. You can have only one command center per planet.',0,0.01,0,1,NULL,500000.0000,1,1823,0),(2496,15,'Minmatar Hub',' ',0,1,0,1,2,0.0000,0,NULL,0),(2497,15,'Minmatar Industrial Station',' ',0,1,0,1,2,0.0000,0,NULL,0),(2498,15,'Minmatar Military Station',' ',0,1,0,1,2,0.0000,0,NULL,0),(2499,15,'Minmatar Mining Station',' ',0,1,0,1,2,0.0000,0,NULL,0),(2500,15,'Minmatar Research Station',' ',0,1,0,1,2,0.0000,0,NULL,0),(2501,15,'Minmatar Station',' ',0,1,0,1,2,0.0000,0,NULL,0),(2502,15,'Minmatar Trade Post',' ',0,1,0,1,2,0.0000,0,NULL,0),(2505,1241,'Command Center Upgrades','Each level in this skill improves the quality of command facility available to you, in turn allowing for a greater number of connected facilities on that planet.',0,0.01,0,1,NULL,500000.0000,1,1823,0),(2506,89,'Mjolnir Torpedo','An ultra-heavy EMP missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,60744.0000,1,923,0),(2507,166,'Mjolnir Torpedo Blueprint',' ',1,0.01,0,1,NULL,7000000.0000,1,390,0),(2508,89,'Nova Torpedo','An ultra-heavy nuclear missile. While it is a slow projectile, its sheer damage potential is simply staggering.   ',1500,0.1,0,100,NULL,42794.0000,1,923,0),(2509,166,'Nova Torpedo Blueprint',' ',1,0.01,0,1,NULL,10000000.0000,1,390,0),(2510,89,'Inferno Torpedo','An ultra-heavy plasma missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,37794.0000,1,923,0),(2511,166,'Inferno Torpedo Blueprint',' ',1,0.01,0,1,NULL,8000000.0000,1,390,0),(2512,387,'Mjolnir Rocket','A small rocket with an EMP warhead. ',100,0.005,0,100,NULL,392.0000,1,922,0),(2513,166,'Mjolnir Rocket Blueprint',' ',1,0.01,0,1,NULL,35000.0000,1,318,0),(2514,387,'Inferno Rocket','A small rocket with a plasma warhead.  ',100,0.005,0,100,NULL,290.0000,1,922,0),(2515,166,'Inferno Rocket Blueprint',' ',1,0.01,0,1,NULL,40000.0000,1,318,0),(2516,387,'Nova Rocket','A small rocket with a nuclear warhead.',100,0.005,0,100,NULL,200.0000,1,922,0),(2517,166,'Nova Rocket Blueprint',' ',1,0.01,0,1,NULL,50000.0000,1,318,0),(2524,1027,'Barren Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,1000,500,1,NULL,90000.0000,1,1322,0),(2525,1027,'Oceanic Command Center','Several interconnected underwater buildings comprise the oceanic command center, which serves as the nervous system for node structures built on water worlds. Built on the ocean floor, this facility includes a thick umbilical that connects it to a communications pod floating on the surface, through which all interplanetary transmissions are sent and received. It also houses a basic two-stage pressurized rocket tube for getting people and cargo to the surface and thence off world into orbit.',5000,1000,500,1,NULL,90000.0000,1,1322,0),(2528,353,'SpaceAnchor','This module does not exist.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(2529,295,'Explosive Deflection Amplifier I','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1690,0),(2530,296,'Explosive Deflection Amplifier I Blueprint',' ',0,0.01,0,1,NULL,187420.0000,1,1554,0),(2531,295,'Explosive Deflection Amplifier II','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,236968.0000,1,1690,0),(2532,296,'Explosive Deflection Amplifier II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2533,1027,'Ice Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,1000,500,1,NULL,90000.0000,1,1322,0),(2534,1027,'Gas Command Center','Maintaining control over a section of  territory  above a gas giant requires a very specific type of command facility, one that is able to maintain its own orbit, house administrative personnel, and easily communicate and interact with other nodes. Suspended with equilibrium technology, these nodes are able to maintain altitude with minimal upkeep. If there is one major advantage to colonizing gas giant planets, it is that these facilities can literally be dropped directly from orbit with almost no concern for their descent or deployment.',5000,1000,500,1,NULL,90000.0000,1,1322,0),(2535,1029,'Oceanic Storage Facility','Goods and commodities are stored on ocean planets in a similar fashion as on more habitable terrestrial planets. Even though most underwater industrial processes conventionally take place inside residential dome habitats, underwater silos, due to their sheer size, must be stored outside these domes and be able to withstand the immense pressures and environmental stresses at the ocean floor.',0,0,12000,1,NULL,250000.0000,1,NULL,0),(2536,1029,'Gas Storage Facility','The problem of how to safely store mass quantities of harvested materials and assembled commodities until they can be transported to higher orbital facilities was difficult to solve. The issue was alleviated by the invention of the equilibrium cargo silo system, an arrangement of empty canisters suspended in a hollow chamber, which is then carefully filled with a specific type of common material from different strata of the host planet. The result has an effective net mass of zero kilograms, causing the facility to hang eerily at the exact desired altitude.',0,0,12000,1,NULL,250000.0000,1,NULL,0),(2537,295,'Thermic Dissipation Amplifier I','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1688,0),(2538,296,'Thermic Dissipation Amplifier I Blueprint',' ',0,0.01,0,1,NULL,187420.0000,1,1554,0),(2539,295,'Thermic Dissipation Amplifier II','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,236968.0000,1,1688,0),(2540,296,'Thermic Dissipation Amplifier II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2541,1029,'Barren Storage Facility','Barren environment storage units require a great amount of technology to be reliable and effective. The super structure is made from adaptive materials designed to withstand a wide range of extreme weather conditions, as barren planets have little to no atmosphere and are therefore prone to extreme climates. Likewise, each module of the structure is designed to store different states of matter, further compounding preservation and containment concerns.',0,0,12000,1,NULL,250000.0000,1,NULL,0),(2542,1030,'Oceanic Launchpad','Despite being anchored to the ocean floor, the underwater launch pad is able to deliver and receive payloads from orbit via two separate mechanisms. First, a compressed gyrostabilized gas containment system provides the required pressure to propel a solid fuel rocket to the surface of the water, where it can achieve escape velocity under its own power. Secondly, the structure houses an automated drone bay capable of retrieving splash-down canisters deposited on the surface as well as recovering booster stages of export rockets for reuse.',0,0,10000,1,NULL,900000.0000,1,NULL,0),(2543,1030,'Gas Launchpad','In order to transport produced commodities from the lower orbit position of the node structure to the higher orbit of spaceports and trade hubs above gas giant planets, an old but reliable technology was revisited. The lack of a solid surface requires a very low recoil launch system, a situation that prohibits the use of solid fuel rockets, but the Hohmann Mass Driver uses a series of triggered electromagnets instead, producing minimal waste force. Essentially an enormous cargo railgun, the device propels a ferrous canister to a waiting deceleration receptacle aboard a high-orbit facility.',0,0,10000,1,NULL,900000.0000,1,NULL,0),(2544,1030,'Barren Launchpad','The barren launchpad is able to send and receive payloads from orbit. Because of the relatively calm atmospheric conditions of most barren planets, the primary focus of this facility is on interfacing effectively with adjacent facilities, allowing for passengers and commodities to be easily organized, scanned, and transported to the appropriate areas. The obvious importance of a centralized spaceport often leads to its becoming a focal point of local culture, including trade, entertainment, and even illegal activities.',0,0,10000,1,NULL,900000.0000,1,NULL,0),(2545,295,'Kinetic Deflection Amplifier I','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1689,0),(2546,296,'Kinetic Deflection Amplifier I Blueprint',' ',0,0.01,0,1,NULL,187420.0000,1,1554,0),(2547,295,'Kinetic Deflection Amplifier II','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,236968.0000,1,1689,0),(2548,296,'Kinetic Deflection Amplifier II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2549,1027,'Lava Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,1000,500,1,NULL,90000.0000,1,1322,0),(2550,1027,'Storm Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,1000,500,1,NULL,90000.0000,1,1322,0),(2551,1027,'Plasma Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,1000,500,1,NULL,90000.0000,1,1322,0),(2552,1030,'Ice Launchpad','After years of customer complaints about catastrophic failures resulting from punctured fuel pods and corroded launch towers, a new line of hazardous environment launch facility was introduced. In addition to improving the overall structural integrity of the entire facility, each section is heavily compartmentalized. Should any one section fail or collapse, the faulty section is immediately locked down. Redundant systems allow the entire facility to continue functioning for some time. The rockets used by this type of launch pad are also heavily modified, sacrificing some cargo capacity for additional protection.',0,0,10000,1,NULL,900000.0000,1,NULL,0),(2553,295,'EM Ward Amplifier II','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,236968.0000,1,1691,0),(2554,296,'EM Ward Amplifier II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2555,1030,'Lava Launchpad','After years of customer complaints about catastrophic failures resulting from punctured fuel pods and corroded launch towers, a new line of hazardous environment launch facility was introduced. In addition to improving the overall structural integrity of the entire facility, each section is heavily compartmentalized. Should any one section fail or collapse, the faulty section is immediately locked down. Redundant systems allow the entire facility to continue functioning for some time. The rockets used by this type of launch pad are also heavily modified, sacrificing some cargo capacity for additional protection.',0,0,10000,1,NULL,900000.0000,1,NULL,0),(2556,1030,'Plasma Launchpad','After years of customer complaints about catastrophic failures resulting from punctured fuel pods and corroded launch towers, a new line of hazardous environment launch facility was introduced. In addition to improving the overall structural integrity of the entire facility, each section is heavily compartmentalized. Should any one section fail or collapse, the faulty section is immediately locked down. Redundant systems allow the entire facility to continue functioning for some time. The rockets used by this type of launch pad are also heavily modified, sacrificing some cargo capacity for additional protection.',0,0,10000,1,NULL,900000.0000,1,NULL,0),(2557,1030,'Storm Launchpad','After years of customer complaints about catastrophic failures resulting from punctured fuel pods and corroded launch towers, a new line of hazardous environment launch facility was introduced. In addition to improving the overall structural integrity of the entire facility, each section is heavily compartmentalized. Should any one section fail or collapse, the faulty section is immediately locked down. Redundant systems allow the entire facility to continue functioning for some time. The rockets used by this type of launch pad are also heavily modified, sacrificing some cargo capacity for additional protection.',0,0,10000,1,NULL,900000.0000,1,NULL,0),(2558,1029,'Lava Storage Facility','\"At some point, it all comes down to more metal.\" The designers of this storage site believed this adage above all else. The outer walls of each container are comprised of almost a meter of titanium alloy around a flexible, lightweight tritanium frame, all sealed with a few layers of active nanite coating to prevent microfractures and thermal warping. This combination allows the building to withstand nearly any environmental challenge. To prevent the tritanium supports from decaying, the interior is kept in a constant vacuum, and workers must wear fully sealed atmosphere suits at all times.',0,0,12000,1,NULL,250000.0000,1,NULL,0),(2559,201,'ECM - Phase Inverter II','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',0,5,0,1,NULL,414214.0000,1,716,0),(2560,1029,'Plasma Storage Facility','\"At some point, it all comes down to more metal.\" The designers of this storage site believed this adage above all else. The outer walls of each container are comprised of almost a meter of titanium alloy around a flexible, lightweight tritanium frame, all sealed with a few layers of active nanite coating to prevent microfractures and thermal warping. This combination allows the building to withstand nearly any environmental challenge. To prevent the tritanium supports from decaying, the interior is kept in a constant vacuum, and workers must wear fully sealed atmosphere suits at all times.',0,0,12000,1,NULL,250000.0000,1,NULL,0),(2561,1029,'Storm Storage Facility','\"At some point, it all comes down to more metal.\" The designers of this storage site believed this adage above all else. The outer walls of each container are comprised of almost a meter of titanium alloy around a flexible, lightweight tritanium frame, all sealed with a few layers of active nanite coating to prevent microfractures and thermal warping. This combination allows the building to withstand nearly any environmental challenge. To prevent the tritanium supports from decaying, the interior is kept in a constant vacuum, and workers must wear fully sealed atmosphere suits at all times.',0,0,12000,1,NULL,250000.0000,1,NULL,0),(2562,1029,'Temperate Storage Facility','Terrestrial storage units require a great amount of technology to be reliable and effective. The super structure is made from adaptive materials designed to withstand a wide range of extreme weather conditions, as temperate planets tend to experience more pronounced seasonal changes. Likewise, each module of the structure is designed to store different states of matter, further compounding preservation and containment concerns.',0,0,12000,1,NULL,250000.0000,1,NULL,0),(2563,201,'ECM - Ion Field Projector II','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors. ',0,5,0,1,NULL,414214.0000,1,715,0),(2567,201,'ECM - Multispectral Jammer II','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,472222.0000,1,719,0),(2571,201,'ECM - Spatial Destabilizer II','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',0,5,0,1,NULL,414214.0000,1,717,0),(2573,226,'The Solitaire','A ghost ship of enormous proportions, this Ragnarok-class Titan should be at the core of a Minmatar strike force or planetary defense, yet here it floats in silence. Its hull is airtight, yet all useful technology has been meticulously stripped from it, including weapons systems, propulsion, and electronics. There is no trace of its crew, despite all of its escape pods being present.',0,0,0,1,NULL,0.0000,0,NULL,0),(2574,1027,'Improved Storm Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,400,500,1,NULL,2800000.0000,0,NULL,0),(2575,201,'ECM - White Noise Generator II','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',0,5,0,1,NULL,414214.0000,1,718,0),(2576,1027,'Advanced Storm Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,800,500,1,NULL,3700000.0000,0,NULL,0),(2577,1027,'Elite Storm Command Center','This command structure is designed to survive in the harshest planetary environments the universe can offer. The superstructure uses a combination of titanium-steel reinforcement, increasing its overall resilience, and counter-harmonic stabilizers, which keep it level and secure regardless of geological conditions or activity. The entire facility is covered by a skin of adaptive plating originally designed for terraforming platforms, a protective barrier that insulates it from the surrounding environment. Visitors can expect a prolonged and immodest decontamination and pressurization process when first arriving at the command structure. Valuable materials are lifted off world by a bulk payload, reusable rocket, the scattered components of which are retrieved by cargo drones.',5000,1600,500,1,NULL,6400000.0000,0,NULL,0),(2578,1027,'Limited Temperate Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,100,500,1,NULL,670000.0000,0,NULL,0),(2579,203,'Gravimetric Backup Array I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,720,0),(2580,203,'Gravimetric Backup Array II','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,92587.0000,1,720,0),(2581,1027,'Standard Temperate Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,200,500,1,NULL,1600000.0000,0,NULL,0),(2582,1027,'Improved Temperate Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,400,500,1,NULL,2800000.0000,0,NULL,0),(2583,203,'Ladar Backup Array I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,721,0),(2584,203,'Ladar Backup Array II','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,92587.0000,1,721,0),(2585,1027,'Advanced Temperate Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,800,500,1,NULL,3700000.0000,0,NULL,0),(2586,1027,'Elite Temperate Command Center','The modular design of this administrative structure allows it to be deployed piecemeal from orbit, then manually assembled on the surface by MTACs and engineering personnel. Supported by self-regulating pylons that follow the contours of indigenous terrain, the facility can accommodate almost any severity of incline or other non-critical geological hazard. Once active, it serves as both a central command post to coordinate the activity of all other nodes and a basic transportation site for getting commodities off world using standard, vertically launched rockets.',5000,1600,500,1,NULL,6400000.0000,0,NULL,0),(2587,203,'Magnetometric Backup Array I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,723,0),(2588,203,'Magnetometric Backup Array II','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,80507.0000,1,723,0),(2589,300,'Genolution Core Augmentation CA-2','<font color=\"yellow\"><b>Traits</b></font><br>Slot 4<br>Primary Effect: +3 bonus to Intelligence<br>Secondary Effect: +1.5% bonus to CPU and capacitor recharge<br>Implant Set Effect: 40% bonus to the strength of all Genolution implant secondary effects<br><br><font color=\"yellow\"><b>Development</b></font><br>This is the second half of the Core Augmentation implant set, delivered by Genolution as a follow-up to the CA-1 just months after their first demonstration of new augmentation techniques shook up the often-stagnant industry.<br><br>The CA-2 picks up where its predecessor left off, providing a dual boost via frontal lobe enhancements and a neocortical modification that complements the CA-1\'s focus on a captain\'s ship-fitting concerns. The end result is an increase to intelligence, coupled with improved CPU output and capacitor recharge rate. Additionally, when combined the CA-1 and the CA-2 supplement each other, providing vast increases in their overall net effect.<br><br>Concurrent with the release of the CA-2, Genolution offered up the implant\'s schematics for public inspection. They claimed the move was designed not only to allay any lingering fears about the technology - now widespread amongst the capsuleer class - but also to provide a foundation for future advances in the field.',0,1,0,1,NULL,800000.0000,1,621,0),(2591,203,'Multi Sensor Backup Array I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,20,0,1,NULL,27772.0000,1,724,0),(2592,203,'Multi Sensor Backup Array II','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,20,0,1,NULL,100435.0000,1,724,0),(2594,667,'ISHAEKA Monalaz Commander','Designed by master starship engineers and constructed in the royal shipyards of the Emperor himself, the imperial issue of the dreaded Apocalypse battleship is held in awe throughout the Empire. Given only as an award to those who have demonstrated their fealty to the Emperor in a most exemplary way, it is considered a huge honor to command, let alone own, one of these majestic and powerful battleships. These metallic monstrosities see to it that the word of the Emperor is carried out among the denizens of the Empire and beyond. Threat level: Deadly.',20500000,1150000,675,1,4,0.0000,0,NULL,0),(2595,314,'Encoded Data Chip','This small, portable disk is only about two centimeters in diameter, yet it is capable of holding a vast amount of information. A durable outer casing made from plasteel rotates away to reveal the raw data surface when the device is inserted into a reader.',10,0.1,0,1,NULL,0.0000,1,NULL,0),(2596,314,'Crates of Clothing','It\'s not the latest fashion, or even the rugged survival gear colonists wear on developing worlds, but this basic, mass-produced clothing is better than nothing.',60000,60,0,1,NULL,0.0000,1,NULL,0),(2597,314,'Crates of Command Reports','Despite the fact that these datachips really only contain logistical information, promotion notifications, and other mundane military records, they are nonetheless classified.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2598,314,'Crates of Coolant','This specially blended fluid is ideal for transferring thermal energy away from sensitive machinery or computer components, rerouting it to heat sinks so it can be eliminated from the system.',80000,80,0,1,NULL,0.0000,1,NULL,0),(2599,314,'Crates of Corporate Documents','These datadisks are absolutely filled with endless databases of market knowledge, sales figures, salary ranges, production estimates, and all kinds of other corporate information.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2601,314,'Crates of Data Sheets','These complicated data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2602,314,'Crates of Drill Parts','These large containers are fitted with a password-protected security lock.  These particular containers are filled with spare parts needed to build a drill used for drilling through rock and ice sheets.',90000,90,0,1,NULL,0.0000,1,NULL,0),(2603,763,'Nanofiber Internal Structure I','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,NULL,1792.0000,1,1196,0),(2604,158,'Nanofiber Internal Structure I Blueprint',' ',0,0.01,0,1,NULL,16640.0000,1,335,0),(2605,763,'Nanofiber Internal Structure II','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,NULL,38560.0000,1,1196,0),(2606,158,'Nanofiber Internal Structure II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2608,314,'Crates of Fertilizer','Fertilizer is particularly valued on agricultural worlds, where there is constant supply for all commodities that boost export value.',80000,80,0,1,NULL,0.0000,1,NULL,0),(2610,314,'Crates of Frozen Food','Frozen food is in high demand in many regions, especially on stations orbiting a non-habitable planet and a long way from an agricultural world.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2612,226,'Hollow Asteroid','This massive asteroid\'s surface is covered in gaping holes, giving way to an internal chamber. The work of miners or the winds of space and time.',0,0,0,1,NULL,0.0000,0,NULL,0),(2613,653,'Mjolnir Fury Light Missile','An advanced missile with a volatile payload of magnetized plasma, the Mjolnir light missile is specifically engineered to take down shield systems.\r\r\n\r\r\nA modified version of the Mjolnir light missile. Does more damage than its predecessor but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',700,0.015,0,5000,NULL,63488.0000,1,927,0),(2614,166,'Mjolnir Fury Light Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2615,314,'Crates of Garbage','Production waste can mean garbage to some but valuable resource material to others.',90000,90,0,1,NULL,0.0000,1,NULL,0),(2616,314,'Large Crates of Coolant','This specially blended fluid is ideal for transferring thermal energy away from sensitive machinery or computer components, rerouting it to heat sinks so it can be eliminated from the system.',800000,800,0,1,NULL,0.0000,1,NULL,0),(2617,314,'Crates of Guidance Systems','An electrical device used in targeting systems and tracking computers.',100000,100,0,1,NULL,0.0000,1,NULL,0),(2618,314,'Crates of Harroule Dryweed','Grown on a terrestrial world in the Harroule system, the Dryweed plant has fragile, yellowish leaves that burn very slowly, giving off a pleasant vapor that is known to have a soothing effect when inhaled.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2619,314,'Crates of High-Tech Small Arms','These weapons are of superior quality to those normally found on the public market, although more expensive as well.\r\r\n\r\r\nThey are implemented with a safety net which prevents them from being used illegally in stations where most types of small arms are prohibited.  Therefore many regions do not apply the small arms ban on these weapons.',80000,80,0,1,NULL,0.0000,1,NULL,0),(2620,314,'Crates of Liparer Cheese','Due to the unique properties of the Liparer system\'s terrestrial worlds, animals raised there have very low body fat, resulting in relatively bland but far healthier dairy products.',100000,100,0,1,NULL,0.0000,1,NULL,0),(2621,656,'Inferno Fury Cruise Missile','An Amarr creation with powerful capabilities, the Inferno cruise missile was for a long time confined solely to the Amarr armed forces, but exports began some years ago and the missile is now found throughout the universe.\r\r\n\r\r\nA modified version of the Inferno cruise. Does more damage than its predecessor, but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',1250,0.05,0,5000,NULL,673545.0000,1,925,0),(2622,166,'Inferno Fury Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2623,314,'Crates of Listening Post Recordings','After diligently recording information on astral phenomena or military maneuvers, listening post data is embedded on encrypted chips, which must be carefully transported by hand.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2624,314,'Crates of Mechanical Parts','These basic elements of all mechanical hardware can come in virtually any shape and size, although composite or modular functionality is highly advantageous in today\'s competitive market. Factories and manufacturers take these parts and assemble them into finished products, which are then sold on the market.',100000,100,0,1,NULL,0.0000,1,NULL,0),(2626,314,'Crates of Missile Guidance Systems','Guidance systems allow both atmospheric and vacuum launched missiles to find targets using sophisticated electronics and specially calibrated sensors.',90000,90,0,1,NULL,0.0000,1,NULL,0),(2627,314,'Crates of Mono-Cell Batteries','Although they\'re a relatively old design, mono-cell batteries are still a reliable method of storing electricity in bulk, specifically designed for long-term use in stations or planetary vehicles.',80000,80,0,1,NULL,0.0000,1,NULL,0),(2628,314,'Crates of Odd Data Crystals','Whatever is recorded on these datacrystals, the encryption is far beyond normal methods of deciphering, and requires expert attention to crack.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2629,655,'Scourge Fury Heavy Missile','The Scourge heavy missile is an old relic from the Caldari-Gallente War that is still in widespread use because of its low price and versatility.\r\r\n\r\r\nA modified version of the Scourge heavy missile. Does more damage than its predecessor but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',1000,0.03,0,5000,NULL,418054.0000,1,926,0),(2630,166,'Scourge Fury Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2631,314,'Crates of OP Insecticide','Organophosphates, similar to nerve gases, have long been used as insecticides, and as bugs evolve, so too must the methods for dealing with them. This particular insecticide is perhaps the most lethal known to humankind, and can kill nearly anything exposed to it. ',60000,60,0,1,NULL,0.0000,1,NULL,0),(2632,314,'Crates of Oxygen','Oxygen is a commodity in constant demand. While most stations have their own supply units, smaller depots and space crafts rely on imports.',70000,70,0,1,NULL,0.0000,1,NULL,0),(2633,314,'Crates of Planetary Vehicles','Tracked, wheeled and hover vehicles used within planetary atmosphere for personal and business use.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2635,314,'Crates of Protein Delicacies','Protein Delicacies are cheap and nutritious food products manufactured by one of the Caldari mega corporations, Sukuuvestaa. It comes in many flavors and tastes delicious. Despite its cheap price and abundance it is favored by many gourmet chefs in some of the finest restaurants around for its rich, earthy flavor and fragrance.',70000,70,0,1,NULL,0.0000,1,NULL,0),(2636,314,'Crates of Raggy Dolls','Known across New Eden for their anatomical correctness and temperature sensitive, dynamic hair coloration, Raggy dolls are always in demand during gift-giving holidays.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2637,656,'Inferno Precision Cruise Missile','An Amarr creation with powerful capabilities, the Inferno cruise missile was for a long time confined solely to the Amarr armed forces, but exports began some years ago and the missile is now found throughout the universe.\r\r\n\r\r\nA modified version of the Inferno cruise. Is great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',1250,0.05,0,5000,NULL,673545.0000,1,918,0),(2638,166,'Inferno Precision Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2639,314,'Crates of Repair Parts','Despite the enormous diversity of size and complexity of machinery across the cluster, there are numerous common elements shared by all people, such as high tension wiring, locking fasteners, and thermal shielding.',70000,70,0,1,NULL,0.0000,1,NULL,0),(2640,314,'Crates of Replacement Parts','Replacement parts include anything from machined components, such as plastic casings and metal brackets, to more basic pieces like nuts and bolts.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2641,314,'Crates of Reports','These encoded reports may mean little to the untrained eye, but can prove valuable to the relevant institution.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2642,314,'Crates of Robotics','These pre-programmed or remote control mechanical tools are commonly used in mass production facilities, hazardous material handling, or dangerous front line military duties such as bomb disarming and disposal.',70000,70,0,1,NULL,0.0000,1,NULL,0),(2644,314,'Crates of Small Arms','Personal weapons and armaments, used both for warfare and personal security.',60000,60,0,1,NULL,0.0000,1,NULL,0),(2645,314,'Crates of Soil','Fertile soil rich with nutrients is very sought after by agricultural corporations and colonists on worlds with short biological history.',50000,50,0,1,NULL,0.0000,1,NULL,0),(2646,314,'Crates of Spiced Wine','Luxury goods are always solid commodities for inter-stellar trading. Spiced wine is not the rarest of luxury goods, but it can still be sold at small outposts and bases that don\'t manufacture any themselves.',90000,90,0,1,NULL,0.0000,1,NULL,0),(2647,653,'Inferno Precision Light Missile','The explosion the Inferno light missile creates upon impact is stunning enough for any display of fireworks - just ten times more deadly.\r\r\n\r\r\nA modified version of the Inferno light missile. Great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',700,0.015,0,5000,NULL,63488.0000,1,917,0),(2648,166,'Inferno Precision Light Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2652,314,'Crates of Synthetic Oil','Since original oil can be harvested only from a world with a long biological history, synthetic oil has become frequently produced in laboratories all over known space.',60000,60,0,1,NULL,0.0000,1,NULL,0),(2653,314,'Crates of Vaccine Injectors','These single-use syringes contain a predetermined dose of adaptive vaccines designed to counteract almost any known virus.',90000,90,0,1,NULL,0.0000,1,NULL,0),(2654,314,'Crates of Viral Agent','The causative agent of an infectious disease, the viral agent is a parasite with a noncellular structure composed mainly of nucleic acid within a protein coat.',80000,80,0,1,NULL,0.0000,1,NULL,0),(2655,655,'Nova Precision Heavy Missile','The be-all and end-all of medium-sized missiles, the Nova is a must for those who want a guaranteed kill no matter the cost.\r\r\n\r\r\nA modified version of the Nova heavy missile. Great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',1000,0.03,0,5000,NULL,418054.0000,1,919,0),(2656,166,'Nova Precision Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2657,314,'Crates of Vitoc','The Vitoc booster has become more than a simple strategy by the Amarrians in controling their slaves. With the Vitoc method, slaves are injected with a toxic chemical substance that is fatal unless the recipient receives a constant supply of an antidote. The method first appeared a few centuries ago when the Amarrians started manning some of their space ships with slaves. As space crew the slaves had to be cajoled into doing complex, often independent work, making older methods of slave control undesirable. Although the more conventional ways of subduing slaves with force (actual or threat of) are still widely used in other forced labor areas, the Vitoc method has proven itself admirably for the fleet.',70000,70,0,1,NULL,0.0000,1,NULL,0),(2659,314,'Crates of Water','Water is one of the basic conditional elements of human survival. Most worlds have this compound in relative short supply and hence must rely on starship freight.',60000,60,0,1,NULL,0.0000,1,NULL,0),(2660,314,'Crates of Zemnar','Zemnar is an uncommon type of antibiotic specifically used to combat rare bacterial infections.  Originally discovered by the late Gallente biologist, Lameur Zemnar, the drug is now frequently kept in stock in the more wealthy quarters of the galaxy, in case of a bacterial outbreak.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2662,283,'Group of Army Recruits','These fresh-faced young men and women are absolutely full of potential, eagerly anticipating the glory and excitement of battle when not trading stories of their significant others back home or plans for college after the war.',60000,60,0,1,NULL,0.0000,1,NULL,0),(2663,283,'Group of Cattle','Cattle are domestic animals raised for home use or for profit, whether it be for their meat or dairy products.',100000,100,0,1,NULL,0.0000,1,NULL,0),(2665,283,'Group of Elite Slaves','Slavery has always been a questionable industry, favored by the Amarr Empire and detested by the Gallente Federation.  These elite slaves are exceptionally well suited for physical labor.',60000,60,0,1,NULL,0.0000,1,NULL,0),(2666,283,'Group of Exotic Dancers','Exotic dancing is considered an art form, even though not everyone might agree. Exposing the flesh in public places may be perfectly acceptable within the Federation, but in the Amarr Empire it\'s considered a grave sin and a sign of serious deviancy.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2668,283,'Group of Genetically Enhanced Livestock','Livestock are domestic animals raised for home use or for profit, whether it be for their meat or dairy products.  This particular breed of livestock has been genetically enhanced using the very latest technology.',100000,100,0,1,NULL,0.0000,1,NULL,0),(2669,283,'Group of Kameiras','An elite type of foot soldier, originally bred from Minmatar slaves by the Amarr Empire. Raised from birth to become soldiers, they serve the Empire, Khanid Kingdom and Ammatar well, although always kept on a tight leash.',70000,70,0,1,NULL,0.0000,1,NULL,0),(2670,283,'Group of Marines','When war breaks out, the demand for transporting military personnel on site can exceed the grasp of the military organization. In these cases, the aid from non-military spacecrafts is often needed.',60000,60,0,1,NULL,0.0000,1,NULL,0),(2671,283,'Group of Militants','A combative character; aggressive, especially in the service of a cause.',60000,60,0,1,NULL,0.0000,1,NULL,0),(2672,283,'Group of Miners','Covered in a perpetual layer of grime and dust, these grizzled laborers seem out of place anywhere but deep underground on some lonely planet or boring through the core of a wandering asteroid.',50000,50,0,1,NULL,0.0000,1,NULL,0),(2673,314,'Large Crates of Data Sheets','These complicated data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.',400000,400,0,1,NULL,0.0000,1,NULL,0),(2674,283,'Group of Refugees','When wars and epidemics break out, people flee from their homes, forming massive temporary migrations.',40000,40,0,1,NULL,0.0000,1,NULL,0),(2675,283,'Group of Science Graduates','People that have recently graduated with a degree in science at an acknowledged university.',50000,50,0,1,NULL,0.0000,1,NULL,0),(2676,283,'Group of Security Personnel','Packing small arms and shortwave communicators, security personnel are the ideal choice for policing small settlements or corporate offices, where mercenaries would be unpredictable and military forces would be overkill.',60000,60,0,1,NULL,0.0000,1,NULL,0),(2677,283,'Group of Slaves','Slavery has always been a questionable industry, favored by the Amarr Empire and detested by the Gallente Federation.',50000,50,0,1,NULL,0.0000,1,NULL,0),(2678,283,'Group of Tourists','The need for tasting other cultures and seeing new worlds is unquenchable among the well-off citizens of the universe.',50000,50,0,1,NULL,0.0000,1,NULL,0),(2679,654,'Scourge Rage Heavy Assault Missile','A kinetic warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.\r\r\n\r\r\nThis modified version of the Scourge Heavy Assault Missile packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',700,0.015,0,5000,NULL,63488.0000,1,973,0),(2680,166,'Scourge Rage Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2681,283,'Group of VIPs','Very important people. Business executives, politicians, diplomats and game designers.',50000,50,0,1,NULL,0.0000,1,NULL,0),(2682,314,'Large Crates of Galeptos Medicine','Galeptos is a rare type of medicine developed by the famous Gallentean scientist, Darven Galeptos.  It is produced from a blend of organic and chemical material, used to cure a rare and deadly viral infection which has been creeping up more frequently as of late.  \r\r\n\r\r\nRumor has it that Galeptos manufactured the virus himself, then sold the cure for billions of credits.  Of course his corporation, Galeptos Medicines, steadfastly denies any such \"unfounded\" accusations and has threatened legal action to anyone who mentions it in public.',1000000,1000,0,1,NULL,0.0000,1,NULL,0),(2683,314,'Large Crates of Guidance Systems','An electrical device used in targeting systems and tracking computers.',1000000,1000,0,1,NULL,0.0000,1,NULL,0),(2684,314,'Large Crates of Harroule Dryweed','Grown on a terrestrial world in the Harroule system, the Dryweed plant has fragile, yellowish leaves that burn very slowly, giving off a pleasant vapor that is known to have a soothing effect when inhaled.',400000,400,0,1,NULL,0.0000,1,NULL,0),(2685,314,'Large Crates of Holoreels','Holo-Vid reels are the most common type of personal entertainment there is. From interactive gaming to erotic motion pictures, these reels can contain hundreds of titles each.',100000,500,0,1,NULL,250.0000,1,NULL,0),(2686,314,'Large Crates of Liparer Cheese','Due to the unique properties of the Liparer system\'s terrestrial worlds, animals raised there have very low body fat, resulting in relatively bland but far healthier dairy products.',1000000,1000,0,1,NULL,0.0000,1,NULL,0),(2687,314,'Large Crates of Mechanical Parts','These basic elements of all mechanical hardware can come in virtually any shape and size, although composite or modular functionality is highly advantageous in today\'s competitive market. Factories and manufacturers take these parts and assemble them into finished products, which are then sold on the market.',1000000,1000,0,1,NULL,0.0000,1,NULL,0),(2688,314,'Large Crates of Mono-Cell Batteries','Although they\'re a relatively old design, mono-cell batteries are still a reliable method of storing electricity in bulk, specifically designed for long-term use in stations or planetary vehicles.',800000,800,0,1,NULL,0.0000,1,NULL,0),(2689,314,'Large Crates of Oxygen','Oxygen is a commodity in constant demand. While most stations have their own supply units, smaller depots and space crafts rely on imports.',700000,700,0,1,NULL,0.0000,1,NULL,0),(2690,314,'Large Crates of Planetary Vehicles','Tracked, wheeled and hover vehicles used within planetary atmosphere for personal and business use.',400000,400,0,1,NULL,0.0000,1,NULL,0),(2691,314,'Large Crates of Polytextiles','This synthetic fabric is used for clothing as well as makeshift shelters on hard-climate colonies.',500000,500,0,1,NULL,0.0000,1,NULL,0),(2692,314,'Large Crates of Protein Delicacies','Protein Delicacies are cheap and nutritious food products manufactured by one of the Caldari mega corporations, Sukuuvestaa. It comes in many flavors and tastes delicious. Despite its cheap price and abundance it is favored by many gourmet chefs in some of the finest restaurants around for its rich, earthy flavor and fragrance.',700000,700,0,1,NULL,0.0000,1,NULL,0),(2693,314,'Large Crates of Reports','These encoded reports may mean little to the untrained eye, but can prove valuable to the relevant institution.',400000,400,0,1,NULL,0.0000,1,NULL,0),(2694,314,'Large Crates of Small Arms','Personal weapons and armaments, used both for warfare and personal security.',600000,600,0,1,NULL,0.0000,1,NULL,0),(2695,314,'Large Crates of Soil','Fertile soil rich with nutrients is very sought after by agricultural corporations and colonists on worlds with short biological history.',500000,500,0,1,NULL,0.0000,1,NULL,0),(2696,314,'Large Crates of Spirits','Alcoholic beverages made by distilling a fermented mash of grains.',250000,600,0,1,NULL,455.0000,1,NULL,0),(2697,314,'Large Crates of Synthetic Oil','Since original oil can be harvested only from a world with a long biological history, synthetic oil has become frequently produced in laboratories all over known space.',600000,600,0,1,NULL,0.0000,1,NULL,0),(2698,314,'Large Crates of Vitoc','The Vitoc booster has become more than a simple strategy by the Amarrians in controling their slaves. With the Vitoc method, slaves are injected with a toxic chemical substance that is fatal unless the recipient receives a constant supply of an antidote. The method first appeared a few centuries ago when the Amarrians started manning some of their space ships with slaves. As space crew the slaves had to be cajoled into doing complex, often independent work, making older methods of slave control undesirable. Although the more conventional ways of subduing slaves with force (actual or threat of) are still widely used in other forced labor areas, the Vitoc method has proven itself admirably for the fleet.',700000,700,0,1,NULL,0.0000,1,NULL,0),(2699,283,'Large Group of Civilians','Civilians are a group of people who follow the pursuits of civil life.',500000,500,0,1,NULL,0.0000,1,NULL,0),(2700,283,'Large Group of Exotic Dancers','Exotic dancing is considered an art form, even though not everyone might agree. Exposing the flesh in public places may be perfectly acceptable within the Federation, but in the Amarr Empire it\'s considered a grave sin and a sign of serious deviancy.',400000,400,0,1,NULL,0.0000,1,NULL,0),(2701,283,'Large Group of Genetically Enhanced Livestock','Livestock are domestic animals raised for home use or for profit, whether it be for their meat or dairy products.  This particular breed of livestock has been genetically enhanced using the very latest technology.',1000000,1000,0,1,NULL,0.0000,1,NULL,0),(2702,283,'Large Group of Homeless','In most societies there are those who, for various reasons, live a life considered below the living standards of the normal citizen. These people are sometimes called tramps, beggars, drifters, vagabonds or homeless. They are especially common in the ultra-capitalistic Caldari State, but are also found elsewhere in most parts of the galaxy.',60000,400,0,1,NULL,0.0000,1,NULL,0),(2703,283,'Large Group of Kameiras','An elite type of foot soldier, originally bred from Minmatar slaves by the Amarr Empire. Raised from birth to become soldiers, they serve the Empire, Khanid Kingdom and Ammatar well, although always kept on a tight leash.',700000,700,0,1,NULL,0.0000,1,NULL,0),(2704,283,'Large Group of Marines','When war breaks out, the demand for transporting military personnel on site can exceed the grasp of the military organization. In these cases, the aid from non-military spacecrafts is often needed.',600000,600,0,1,NULL,0.0000,1,NULL,0),(2705,283,'Large Group of Militants','A combative character; aggressive, especially in the service of a cause.',600000,600,0,1,NULL,0.0000,1,NULL,0),(2706,283,'Large Group of Science Graduates','People that have recently graduated with a degree in science at an acknowledged university.',500000,500,0,1,NULL,0.0000,1,NULL,0),(2707,283,'Large Group of Slaves','Slavery has always been a questionable industry, favored by the Amarr Empire and detested by the Gallente Federation.',500000,500,0,1,NULL,0.0000,1,NULL,0),(2708,283,'Large Group of Tourists','The need for tasting other cultures and seeing new worlds is unquenchable among the well-off citizens of the universe.',500000,500,0,1,NULL,0.0000,1,NULL,0),(2709,283,'Large Group of VIPs','Very important people. Business executives, politicians, diplomats and game designers.',500000,500,0,1,NULL,0.0000,1,NULL,0),(2710,314,'Large Crates of Construction Blocks','Metal girders, plasteel concrete and fiber blocks are all very common construction material used around the universe.',10000000,700,0,1,NULL,500.0000,1,NULL,0),(2711,313,'Large Crates of Crystal Eggs','Crystal is a common feel-good booster, used and abused around the universe in abundance.',500000,500,0,1,NULL,5000.0000,1,NULL,0),(2712,314,'Large Crates of Drill Parts','These large containers are fitted with a password-protected security lock.  These particular containers are filled with spare parts needed to build a drill used for drilling through rock and ice sheets.',900000,900,0,1,NULL,0.0000,1,NULL,0),(2713,314,'Large Crates of Electronic Parts','These basic elements of all electronic hardware are sought out by those who require spare parts in their hardware. Factories and manufacturers take these parts and assemble them into finished products, which are then sold on the market.',400000,400,0,1,NULL,750.0000,1,NULL,0),(2714,314,'Large Crates of Fertilizer','Fertilizer is particularly valued on agricultural worlds, where there is constant supply for all commodities that boost export value.',800000,800,0,1,NULL,0.0000,1,NULL,0),(2715,314,'Large Crates of Frozen Food','Frozen food is in high demand in many regions, especially on stations orbiting a non-habitable planet and a long way from an agricultural world.',400000,400,0,1,NULL,0.0000,1,NULL,0),(2716,314,'Large Crates of Frozen Plant Seeds','Frozen plant seeds are in high demand in many regions, especially on stations orbiting a non-habitable planet.',40000,500,0,1,NULL,75.0000,1,NULL,0),(2717,314,'Large Crates of Garbage','Production waste can mean garbage to some but valuable resource material to others.',900000,900,0,1,NULL,0.0000,1,NULL,0),(2718,314,'Large Crates of Long-limb Roes','The eggs of the Hanging Long-limb are among the most sought after delicacies in fancy restaurants. The main reason why the roe of the Hanging Long-limb is so rare is because no one has succeeded in breeding the species outside their natural habitat.',400000,1000,0,1,NULL,2400.0000,1,NULL,0),(2719,314,'Large Crates of Raggy Dolls','Known across New Eden for their anatomical correctness and temperature sensitive, dynamic hair coloration, Raggy dolls are always in demand during gift-giving holidays.',400000,400,0,1,NULL,0.0000,1,NULL,0),(2720,314,'Large Crates of Rocket Fuel','Augmented and concentrated fuel used primarily for missile production.',50000,400,0,1,NULL,505.0000,1,NULL,0),(2721,314,'Large Crates of Tobacco','Tubular rolls of tobacco designed for smoking. The tube consists of finely shredded tobacco enclosed in a paper wrapper and is generally outfitted with a filter tip at the end.',2500000,400,0,1,NULL,48.0000,1,NULL,0),(2722,314,'Large Crates of Transmitters','An electronic device that generates and amplifies a carrier wave, modulates it with a meaningful signal derived from speech or other sources, and radiates the resulting signal from an antenna.',650000,600,0,1,NULL,313.0000,1,NULL,0),(2723,314,'Large Crates of Viral Agent','The causative agent of an infectious disease, the viral agent is a parasite with a noncellular structure composed mainly of nucleic acid within a protein coat.',800000,800,0,1,NULL,0.0000,1,NULL,0),(2724,314,'Large Crates of Water','Water is one of the basic conditional elements of human survival. Most worlds have this compound in relative short supply and hence must rely on starship freight.',600000,600,0,1,NULL,0.0000,1,NULL,0),(2725,283,'Large Group of Cattle','Cattle are domestic animals raised for home use or for profit, whether it be for their meat or dairy products.',1000000,1000,0,1,NULL,0.0000,1,NULL,0),(2726,283,'Large Group of Janitors','The janitor is the person who is in charge of keeping the premises of a building (as an apartment or office) clean, tends the heating system, and makes minor repairs.',100000,500,0,1,NULL,0.0000,1,NULL,0),(2727,283,'Large Group of Miners','Covered in a perpetual layer of grime and dust, these grizzled laborers seem out of place anywhere but deep underground on some lonely planet or boring through the core of a wandering asteroid.',500000,500,0,1,NULL,0.0000,1,NULL,0),(2728,283,'Large Group of Refugees','When wars and epidemics break out, people flee from their homes, forming massive temporary migrations.',400000,400,0,1,NULL,0.0000,1,NULL,0),(2729,314,'Crates of Consumer Electronics','Consumer electronics encompass a wide variety of individual goods, from entertainment media and personal computers to slave collars and children\'s toys.',40000,40,0,1,NULL,750.0000,1,NULL,0),(2730,314,'Crates of Enriched Uranium','Enriched Uranium is used in many kinds of manufacturing and as a fuel, making it a steady trade commodity. Enriched Uranium is generally manufactured by combining standard semiconductor PVD methods with ionic separation by means of mass spectrometry.',1000000,70,0,1,NULL,500.0000,1,NULL,0),(2731,314,'Crates of Silicon','As one of the most common elements in the universe, it\'s no surprise that silicon has found its way into almost every aspect of manufacturing, resulting in a steady price and perpetual mining operations on most solid planets.',1000000,50,0,1,NULL,500.0000,1,NULL,0),(2732,314,'Crates of Silicate Glass','Silicate glass is a common construction material, in constant demand throughout New Eden, whether in planetary structures or reinforced for use in space vessels.',1000000,50,0,1,NULL,500.0000,1,NULL,0),(2733,937,'Schematic','Schematics define a set of machinery and industrial processes with which a planetary manufacturing facility can be configured in order to enable the facility to convert certain commodities into certain other commodities.',0,0,0,1,NULL,0.0000,0,NULL,0),(2734,226,'Gallente Vexor Cruiser','The Vexor is a strong combat ship that is also geared to operate in a variety of other roles. The Vexor is especially useful for surveying in potentially hostile sectors as it can stay on duty for a very long time before having to return to base. Furthermore, it is well capable of defending itself against even concentrated attacks.',0,0,0,1,1,0.0000,0,NULL,0),(2735,1045,'Infrastructure Hub Blueprint',' ',0,0.01,0,1,NULL,500000000.0000,1,1356,0),(2736,857,'Warp Disruption Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1344,0),(2737,1045,'Territorial Claim Unit Blueprint',' ',0,0.01,0,1,NULL,250000000.0000,1,1356,0),(2738,1045,'Sovereignty Blockade Unit Blueprint',' ',0,0.01,0,1,NULL,250000000.0000,1,1356,0),(2739,912,'Nanite Repair Paste Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1358,0),(2740,857,'Warp Scrambling Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1344,0),(2741,858,'Stasis Webification Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1344,0),(2742,1048,'Biochemical Silo Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1355,0),(2743,1048,'Catalyst Silo Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1355,0),(2744,1048,'Coupling Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1355,0),(2745,1048,'General Storage Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1355,0),(2746,1048,'Hazardous Chemical Silo Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1355,0),(2747,1048,'Hybrid Polymer Silo Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1355,0),(2748,1048,'Silo Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1355,0),(2749,1048,'Advanced Large Ship Assembly Array Blueprint',' ',0,0.01,0,1,NULL,250000000.0000,1,1340,0),(2750,1048,'X-Large Ship Maintenance Array Blueprint',' ',0,0.01,0,1,NULL,500000000.0000,1,1535,0),(2751,1048,'Advanced Medium Ship Assembly Array Blueprint',' ',0,0.01,0,1,NULL,150000000.0000,1,1340,0),(2752,1048,'Ship Maintenance Array Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1535,0),(2753,1048,'Advanced Small Ship Assembly Array Blueprint',' ',0,0.01,0,1,NULL,75000000.0000,1,1340,0),(2754,1048,'Ammunition Assembly Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1340,0),(2755,1048,'Ballistic Deflection Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1354,0),(2756,1048,'Supercapital Ship Assembly Array Blueprint',' ',0,0.01,0,1,NULL,500000000.0000,1,1340,0),(2757,1048,'Explosion Dampening Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1354,0),(2758,1048,'Component Assembly Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1340,0),(2759,1048,'Heat Dissipation Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1354,0),(2760,1048,'Drone Assembly Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1340,0),(2761,1048,'Photon Scattering Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1354,0),(2762,1048,'Drug Lab Blueprint',' ',0,0.01,0,1,NULL,75000000.0000,1,1359,0),(2763,1048,'Sensor Dampening Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1344,0),(2764,1048,'Equipment Assembly Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1340,0),(2765,1048,'Intensive Reprocessing Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1353,0),(2766,1048,'Large Ship Assembly Array Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1340,0),(2767,1048,'Compression Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1945,0),(2768,1048,'Medium Ship Assembly Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1340,0),(2769,1048,'Reprocessing Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1353,0),(2770,1048,'Rapid Equipment Assembly Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1340,0),(2771,1048,'Small Ship Assembly Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1340,0),(2772,1048,'Subsystem Assembly Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1340,0),(2773,1048,'Capital Ship Assembly Array Blueprint',' ',0,0.01,0,1,NULL,300000000.0000,1,1340,0),(2774,841,'Amarr Control Tower Blueprint',' ',0,0.01,0,1,NULL,500000000.0000,1,1339,0),(2775,841,'Amarr Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,250000000.0000,1,1339,0),(2776,841,'Amarr Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,125000000.0000,1,1339,0),(2777,841,'Caldari Control Tower Blueprint',' ',0,0.01,0,1,NULL,500000000.0000,1,1339,0),(2778,841,'Caldari Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,250000000.0000,1,1339,0),(2779,841,'Caldari Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,125000000.0000,1,1339,0),(2780,841,'Gallente Control Tower Blueprint',' ',0,0.01,0,1,NULL,500000000.0000,1,1339,0),(2781,841,'Gallente Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,250000000.0000,1,1339,0),(2782,841,'Gallente Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,125000000.0000,1,1339,0),(2783,841,'Minmatar Control Tower Blueprint',' ',0,0.01,0,1,NULL,500000000.0000,1,1339,0),(2784,841,'Minmatar Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,250000000.0000,1,1339,0),(2785,841,'Minmatar Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,125000000.0000,1,1339,0),(2786,1048,'Moon Harvesting Array Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1352,0),(2787,1048,'Corporate Hangar Array Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1341,0),(2788,1048,'Cynosural Generator Array Blueprint',' ',0,0.01,0,1,NULL,250000000.0000,1,1342,0),(2789,1048,'Cynosural System Jammer Blueprint',' ',0,0.01,0,1,NULL,250000000.0000,1,1343,0),(2790,1048,'Biochemical Reactor Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1351,0),(2791,1048,'Complex Reactor Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1351,0),(2792,856,'Ion Field Projection Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1344,0),(2793,1048,'Medium Biochemical Reactor Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1351,0),(2794,856,'Phase Inversion Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1344,0),(2795,1048,'Polymer Reactor Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1351,0),(2796,856,'Spatial Destabilization Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1344,0),(2797,1048,'Simple Reactor Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1351,0),(2798,856,'White Noise Generation Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1344,0),(2799,860,'Energy Neutralizing Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1345,0),(2800,1048,'Jump Bridge Blueprint',' ',0,0.01,0,1,NULL,250000000.0000,1,1346,0),(2801,657,'Nova Javelin Torpedo','An ultra-heavy nuclear missile. While it is a slow projectile, its sheer damage potential is simply staggering.\r\r\n\r\r\nA modified version of the Nova Torpedo. It can reach higher velocity than the Nova Torpedo at the expense of warhead size.',1500,0.1,0,5000,NULL,1457525.0000,1,929,0),(2802,166,'Nova Javelin Torpedo Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2803,855,'Large Blaster Battery Blueprint',' ',0,0.01,0,1,NULL,75000000.0000,1,1347,0),(2804,855,'Large Railgun Battery Blueprint',' ',0,0.01,0,1,NULL,75000000.0000,1,1347,0),(2805,854,'Large Artillery Battery Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1350,0),(2806,855,'Medium Blaster Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1347,0),(2807,854,'Large AutoCannon Battery Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1350,0),(2808,855,'Medium Railgun Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1347,0),(2810,854,'Medium Artillery Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1350,0),(2811,657,'Inferno Rage Torpedo','An ultra-heavy plasma missile. While it is a slow projectile, its sheer damage potential is simply staggering.\r\r\n\r\r\nThis modified version of the Inferno Torpedo packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',1000,0.1,0,5000,NULL,1457525.0000,1,931,0),(2812,166,'Inferno Rage Torpedo Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2813,855,'Small Blaster Battery Blueprint',' ',0,0.01,0,1,NULL,25000000.0000,1,1347,0),(2814,854,'Medium AutoCannon Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1350,0),(2815,855,'Small Railgun Battery Blueprint',' ',0,0.01,0,1,NULL,25000000.0000,1,1347,0),(2816,854,'Small Artillery Battery Blueprint',' ',0,0.01,0,1,NULL,25000000.0000,1,1350,0),(2817,648,'Mjolnir Rage Rocket','A small rocket with an EMP warhead.\r\r\n\r\r\nThis modified version of the Mjolnir rocket packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',100,0.005,0,5000,NULL,45068.0000,1,930,0),(2818,166,'Mjolnir Rage Rocket Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2819,854,'Small AutoCannon Battery Blueprint',' ',0,0.01,0,1,NULL,25000000.0000,1,1350,0),(2820,891,'Experimental Laboratory Blueprint',' ',0,0.01,0,1,NULL,75000000.0000,1,1359,0),(2821,891,'Research Laboratory Blueprint',' ',0,0.01,0,1,NULL,75000000.0000,1,1359,0),(2822,871,'Citadel Torpedo Battery Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1349,0),(2823,871,'Cruise Missile Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1349,0),(2824,871,'Torpedo Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1349,0),(2825,853,'Small Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,25000000.0000,1,1348,0),(2826,853,'Small Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,25000000.0000,1,1348,0),(2827,853,'Medium Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1348,0),(2828,853,'Medium Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1348,0),(2829,853,'Large Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1348,0),(2830,853,'Large Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1348,0),(2831,226,'Serpentis Fortress','This gigantic station is one of the Serpentis military installations and a black jewel of the alliance between The Guardian Angels and The Serpentis Corporation. Even for its size, it has no commercial station services or docking bays to receive guests.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(2832,226,'Blood Raider Fortress','This gigantic suprastructure is one of the military installations of the Blood Raiders pirate corporation. Even for its size, it has no commercial station services or docking bay to receive guests.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(2833,943,'1000 Aurum Token','This item can be redeemed for 1000 Aurum (AUR).<br><br><font color=\"yellow\">To Redeem:</font> Right-click the Aurum Token and select \"Redeem for AUR\".<br><br><font color=\"yellow\">On the Aurum Token:</font> Originally designed for Noble Appliances in YC 113, the aurum token is a physical chit that can be redeemed for a predefined amount of AUR currency.<br><br>Though at first blush it appears to be a large coin, the aurum token shares more in common with high-security datacores. At the center of the token is digital ID paired with a series of suspended entangled electrons. When the token is redeemed, the entangled electrons are engaged, altering their partners located at an off-site bank. Not only does this ensure the exchange occurs instantly, but when combined with a proprietary security shell it renders attempts to tamper or counterfeit the token useless.<br><br>Though the gold and silver case is merely an aesthetic addition, the coin-like appearance has become synonymous with the device, leading to nicknames of \"gold aurum\", or \"golden token\".<br><i>Source: SCOPE fluff piece (unprinted)</i>',0,0.01,0,1,NULL,0.0000,1,1427,0),(2834,324,'Utu','The Utu is a highly advanced drone platform specially commissioned for the 8th Alliance Tournament. While based on the Ishkur\'s design, this ship features design elements that go above and beyond the original blueprint.\r\r\n\r\r\nIn addition to revolutionary heat dispersion field projectors, the Utu is equipped with cutting-edge hardwired drone protocols and upgraded warp scrambling capability. Combined with the sturdy armor plating, these qualities make the Utu a powerful ally in any combat encounter.',1216000,29500,165,1,8,244466.0000,1,1623,0),(2835,105,'Utu Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(2836,358,'Adrestia','The Adrestia is a high-powered blaster platform specially commissioned for the 8th Alliance Tournament. While similar to its sister vessel the Deimos (on which its design was based), this ship nonetheless differs in some very important ways. Utilizing lightweight alloys and a prototype form of ion thruster, the Adrestia is capable of reaching truly mind-boggling speeds for a heavy assault vessel. While this makes it less sturdy than its predecessor, the lack of defensive plating is compensated for by state-of-the-art targeting systems, thoroughly optimized weapon hardpoints and upgraded warp scrambling capability. Don\'t let the lack of defense fool you; very few vessels out there can stand against the Adrestia toe to toe.\r\r\n\r\r\n',11100000,112000,440,1,8,10560100.0000,1,1621,0),(2837,106,'Adrestia Blueprint',' ',0,0.01,0,1,NULL,74000000.0000,0,NULL,0),(2838,303,'Standard Cerebral Accelerator','Cerebral accelerators are military-grade boosters that significantly increase a new pilot\'s skill development. This technology is usually available only to naval officers, but CONCORD has authorized the release of a small number to particularly promising freelance capsuleers.<br><br>This booster primes the brain\'s neural pathways and hippocampus, making it much more receptive to intensive remapping. This allows new capsuleers to more rapidly absorb information of all kinds, and as a bonus also enhanced spatial processing abilities that are critical for weapons handling.<br><br>The only drawback to this booster is that capsuleer training renders it ineffective after a while; as such, it will cease to function for pilots who have been registered for more than 35 days.<br><br>\r\r\nBonuses: +3 to all attributes; +20% Damage to Laser, Projectile and Hybrid weaponry; +20% Rate of Fire to Missile weaponry.',1,1,0,1,NULL,65536.0000,1,NULL,0),(2839,718,'Cerebral Accelerator Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(2840,517,'Hasaziras Assa\'s Scorpion','A Scorpion piloted by Hasaziras Assa.',115000000,1040000,550,1,1,0.0000,0,NULL,0),(2841,306,'Angel Officer\'s Quarters','The highest ranking personnel within this deadspace pocket reside here.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(2842,226,'Serpentis Station','This gigantic station is one of the Serpentis military installations and a black jewel of the alliance between The Guardian Angels and The Serpentis Corporation. Even for its size, it has no commercial station services or docking bays to receive guests.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(2845,1056,'Outuni Mesen','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID:Outuni Mesen)<br>\r\r\n<font color=yellow>Military Specifications:</font> Battleship-class vessel. Primary roles are capacitor warfare and interdiction. Moderate microwarp velocity. Long range energy neutralizers. Long range warp disruption capabilities. Extreme long-range stasis webification support.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 120,000 civilian abductions from Outuni III and VI. The Mesen identifier suggests an oversight role amongst the other battleship-class prototypes, or alternatively, that it was created during the first phase of development.<br>\r\r\n<i>Synopsis from ISHAEKA-0061. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>  \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2846,820,'Domination Excavator','<font color=yellow>Subject:</font> Domination Excavator (ID: Modified Cyclone)<br>\r\r\n<font color=yellow>Military Specifications:</font> Cruiser-class vessel. Houses both advanced scientific and military technologies. <br>\r\r\n<font color=yellow>Additional Intelligence:</font>  Cartel forays beyond Angel territories have escalated each year since the discovery of wormhole space in YC 111. The Domination Excavator was first seen in one of these operations in 113. The ship itself contains a wide array of hi-tech defensive and offensive capabilities, including redundant power systems and a range of Domination modules. Large sections of crew quarters are converted to specialized lab space, able to perform on-site analysis of found materials. Plasma igniters ensure the labs are burned at temperatures exceeding 45000 Kelvin, should the vessel be captured.\r\r\n <i>Agent Trereval, <a href=showinfo:2// 1000054>Republic Security Services</a>.</i><br><i>Authorized for capsuleer dissemination.</i>',10900000,109000,120,1,2,0.0000,0,NULL,0),(2847,820,'True Sansha Foreman','<font color=yellow>Subject:</font> True Sansha Foreman (ID: Modified Phantasm)<br>\r\r\n<font color=yellow>Military Specifications:</font> Cruiser-class vessel. Modified for increased mining efficiency of local Slaves. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> Pre-YC 113, the True Sansha Foreman variant was once a rare sight outside of the Sansha home region of Stain. As an alternative to capsuleer-dependent strip mining, the Foreman is specially designed to coordinate large crews of Slaves in a local deadspace pocket. Exact figures are difficult to determine, but mining Slaves under the Foreman seem to operate at around 125% efficiency. This link is both fragile and experimental. If the link is violently severed (i.e. the Foreman is destroyed), the affected Slaves in the mining equipment are damaged and unable to continue their work. <br>\r\r\n<i>Analyst Fawlon, <a href=showinfo:2//1000081>Ministry of Assessment</a>.</i><br><i>Authorized for capsuleer dissemination.</i>  \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2848,1063,'Barren Extractor Control Unit','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(2850,306,'Suspicious Ship Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(2851,314,'Incriminating Evidence','This evidence proves beyond the shadow of a doubt that foul play was involved.',5,1,0,1,NULL,0.0000,1,NULL,0),(2852,226,'Sansha Cynosural Field','A cynosural field, also known colloquially as a \"cyno\", is a cosmic anomaly that acts as a pseudo-gravity well. With the correct calibration information, interstellar jump drives can lock onto the field and create a portal into the destination system.',1,0,0,1,NULL,0.0000,0,NULL,0),(2853,314,'Salvaged Electronics','These ship parts are old but functional.',10,20,0,1,NULL,0.0000,1,NULL,0),(2854,306,'Cloaked Cache','Rigged with a localized cloaking field, this small container is hidden from sensors while activated.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(2855,1056,'Intaki Colliculus','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID:Intaki Colliculus)<br>\r\r\n<font color=yellow>Military Specifications:</font> Battleship-class vessel. Primary role is remote logistics support. Medium range shield transfer capabilities. Low microwarp velocity. Defensive systems have been significantly enhanced.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> There were no reported civilian abductions from the invasion of Intaki  IV. The Intaki identifier is yet further evidence supporting the theory that not all abductees were accounted for.  The Colliculus identifier suggests the vessel plays a central role in the integration of various data throughout the Nation\'s greater network.<br>\r\r\n<i>Synopsis from ISHAEKA-0067. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>  \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2856,226,'Forlorn Hope','This massive laboratory complex was once home to over 10,000 scientists, their staff and security personnel, working day and night to unravel the mysteries of Vitoc. Since the return of the Minmatar Elders and Otro Gariushi\'s bequest of Insorum to the Republic, the facility has largely fallen into disuse, but some few scientists cling on, pushing to finish what they started before they too seek more commercial roles.<br><br>For the most part, research continues inside the newer biodome nearby, but a few smaller laboratories and their staff still insist on basing out of the aging titan. ',0,0,0,1,NULL,0.0000,0,NULL,0),(2858,226,'Osnirdottir Memorial','A small and humble memorial to the work of the late scientist Dr. Mishkala Osnirdottir, whose life was most likely lost when an experiment with the Tachyon Bombardment Array went horribly wrong. Others, however, theorize that she was not killed, but relocated, or in some way altered on a quantum level by the barrage of antimatter. <br>\r\r\nThe memorial gardens features great trees contorted into elegant shapes with tungsten scaffolds and the doctor\'s favourite bloom, Ulfurtar - a small parasitic plant with delicate silvery flowers, noted for the soft, almost furred quality of its petals. In many Sebiestor clans, the blossom is believed to symbolise both dreams and memories and the atmosphere of the gardens is rich with both for those that tend it still.',0,0,0,1,NULL,0.0000,0,NULL,0),(2859,1054,'Romi Thalamus','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID:Romi Thalamus)<br>\r\r\n<font color=yellow>Military Specifications:</font>  Cruiser-class vessel. Primary role is damage dealing. Moderate microwarp velocity.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> There were no reported civilian abductions from the invasion of Romi III. The Romi identifier is yet further evidence that unreported abductees may have been incorporated into these new vessel prototypes, and into the Nation as a whole. The Thalamus identifier suggests a unifying role between the cruiser-class prototypes and other hull classes, similar to the Arnon Epithalmus. Notable is the higher number of known cruiser-class vessels, and that the identifiers of each belong to the forebrain. This pattern highlights a structural shift away from battleship-led squadrons, or at the least, an equality of function and responsibility between battleship and cruiser variants.<br>\r\r\n<i>Synopsis from ISHAEKA-0051. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>   \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2860,306,'The Seven Holding Cells','This temporary structure is made to house The Seven\'s hostages until they are ready to be transported to a more secure location.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(2861,314,'Crate of Manportable Electromagnetic Pulse Weapons','These EM beam weapons have been custom fitted to detect and eradicate specific nanotechnologies. Normally, these EMP devices are used by special operations personnel during covert operations. They are placed in proximity to the enemy\'s defense grid and used to  short out  any nearby electronics, thus creating a hole in the defense grid such that conventional forces can then move through unimpeded by sentry grids, security bots, and other lethal defensive systems. The devices themselves are approximately the size of a large rucksack and can be both emplaced and operated by a single trained individual. ',250,250,0,1,NULL,0.0000,1,NULL,0),(2862,314,'Special Forces Weapons and Equipment ','The weapons and equipment containers hold a wide variety of small arms and other equipment currently in use by the Caldari Navy Special Forces, much of it designed specifically for use in maritime environments. Some of the items that can be found in a typical container are long range sniper rifles, target designation lasers, silenced pistols, high tech diving equipment, limpet mines, covert communications gear, and individual diver propulsion devices. This equipment, as you might guess, is extremely valuable and cannot be found outside the armories of the Caldari Navy, with the exception of the very small quantities that have found their way onto the black market. ',25,25,0,1,NULL,0.0000,1,NULL,0),(2863,28,'Primae','The Primae is a repurposed ORE design intended to ease the task of extracting resources from planetbound environments. Initially devised as a deep space salvage vessel for large-scale ore retrieval from destroyed ORE fleets in pirate-occupied areas, its previous incarnation was made all but obsolete by the arrival of capsuleers on the interstellar scene. Realizing that the ship could, with a few minor modifications, be made into an efficient resource harvesting aid, ORE wasted no time in revamping the design.<br><br>A low signature radius (a holdover from its earlier manifestation) adds a layer of defense to the Primae\'s already decent plating. In addition, the ship\'s two large bays have been re-engineered to hold equipment for planetside resource extraction and processed materials, making it an especially useful complement to any planetside harvesting endeavor.',15000000,270000,100,1,128,0.0000,1,1614,0),(2864,108,'Primae Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2865,55,'1200mm Artillery Cannon II','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Quake, Tremor.',2000,20,1,1,NULL,3027982.0000,1,579,0),(2866,135,'1200mm Artillery Cannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2867,1041,'Broadcast Node','By integrating transcranial microcontrollers into a circuit made from synthetic synapses, the broadcast node is able to communicate directly with various station functions and with negligible signal loss and latency. The addition of computerized guidance systems, each running independent navigation system software routines, allows a single node to coordinate starship docking procedures, drone operations, and even station defenses.',0,100,0,1,NULL,0.0000,1,1337,0),(2868,1041,'Integrity Response Drones','Hull breaches are a constant, serious threat during space travel, as well as a dangerous reality to orbital stations, which are too massive to avoid incoming objects. Integrity response drones help mitigate that threat by providing the automated, immediate application of sealants to any detected impact or pressure fracture in the structure they patrol.',0,100,0,1,NULL,0.0000,1,1337,0),(2869,1041,'Nano-Factory','Only the highly advanced Ukomi superconductor can be rendered small enough for use in nano-factories, microscopic devices programmed to absorb and recycle ambient material into useful matter. Each factory is built from reactive metals, ensuring that they interact properly   or not at all   with their environment, while a mote of industrial explosive automatically destroys them when they have completed their task.',0,100,0,1,NULL,0.0000,1,1337,0),(2870,1041,'Organic Mortar Applicators','While nanites are ideal for many forms of construction, sealing joints between large structural bulkheads is a job best left to organic mortar, a thick gel that actively permeates every microscopic gap between two parts. Due to the aggressive nature of the genetically engineered bacteria that intelligently guides into place the hardening condensate material, this paste is extremely hazardous to humans and must be applied by robots.',0,100,0,1,NULL,0.0000,1,1337,0),(2871,1041,'Recursive Computing Module','Not all automated functions are delicate or complicated enough to warrant advanced computer hardware; relatively mundane tasks are best when assigned to an RCM bank. These sturdy, reliable processing units are able to effectively handle most of the day-to-day operations of stations, starships, and stargates.',0,100,0,1,NULL,0.0000,1,1337,0),(2872,1041,'Self-Harmonizing Power Core','Camera drones diligently monitor temperature, radioactivity and electrical output of these advanced nuclear reactions. This allows instant adjustments that result in maximum efficiency. With such advanced automation, no human attention is required whatsoever.',0,100,0,1,NULL,0.0000,1,1337,0),(2873,55,'125mm Gatling AutoCannon II','This multi-barrel autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',500,5,0.5,1,NULL,68490.0000,1,574,0),(2874,135,'125mm Gatling AutoCannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2875,1041,'Sterile Conduits','Sustaining diverse populations of station inhabitants   many of whom come from different worlds with different ecologies   was a medical nightmare until the development of sterile conduits. Each length of flexible, self-repairing tube is powered by breaking down the chemical energy in the water they convey, which itself is laced with smart vaccines able to identify and destroy almost any known antigen.',0,100,0,1,NULL,0.0000,1,1337,0),(2876,1041,'Wetware Mainframe','So advanced and energy-demanding are wetware mainframes that they require vehicle-scale power cores and the constant attention of maintenance personnel. When operating at peak performance levels, nothing in New Eden can match the raw computing power of these machines, from calculating warp coordinates to administrating the core functions of an entire space station.',0,100,0,1,NULL,0.0000,1,1337,0),(2877,875,'Federation Freighter Vessel','The large navy forces of the Empires regularly use freighters to transport a wide variety of military items and personnel en masse.  Such vulnerable ships are usually heavily guarded as they traverse the space lanes.',1175000000,17550000,750000,1,8,0.0000,0,NULL,0),(2878,927,'Federation Industrial Vessel','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',11750000,275000,6000,1,8,0.0000,0,NULL,0),(2879,875,'Imperial Freighter Vessel','The large navy forces of the Empires regularly use freighters to transport a wide variety of military items and personnel en masse.  Such vulnerable ships are usually heavily guarded as they traverse the space lanes.',1125000000,18500000,735000,1,4,0.0000,0,NULL,0),(2880,314,'Unknown Dead','This contingent of Federation pilots and soldier went missing during the first Caldari Gallente war. They\'ve been preserved by the cold but they are still in a delicate state, and must be handled with care.',80,1,0,1,NULL,0.0000,1,NULL,0),(2881,55,'150mm Light AutoCannon II','A simple but effective close combat autocannon. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',500,5,0.4,1,NULL,145692.0000,1,574,0),(2882,875,'State Freighter Vessel','The large navy forces of the Empires regularly use freighters to transport a wide variety of military items and personnel en masse.  Such vulnerable ships are usually heavily guarded as they traverse the space lanes.',1200000000,16250000,785000,1,1,0.0000,0,NULL,0),(2883,927,'State Industrial Vessel','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',13500000,270000,5250,1,1,0.0000,0,NULL,0),(2884,927,'Republic Industrial Vessel','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',12500000,255000,5625,1,2,0.0000,0,NULL,0),(2885,927,'Imperial Industrial Vessel','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',13500000,260000,5100,1,4,0.0000,0,NULL,0),(2886,306,'Tomb of the Unknown Soldiers','Years ago this was the site of a major firefight. The dead still litter its halls.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(2887,526,'Gallente Admiral\'s Corpse','These are the remains of a Federation admiral. A Mannar in her mid-forties, this woman\'s body shows signs of extensive modification typical to capsuleers. This is probably not the first time she has been killed in action.',80,1,0,1,NULL,0.0000,1,NULL,0),(2888,314,'Acceleration Gate Authentication Matrix','This device handles timestamps and user ID validation for acceleration gates. If this part is missing or otherwise broke, the gate will refuse to activate. ',50,1,0,1,NULL,0.0000,1,NULL,0),(2889,55,'200mm AutoCannon II','The 200mm is a powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',500,5,0.3,1,NULL,223498.0000,1,574,0),(2890,135,'200mm AutoCannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2891,306,'Amarr Battleship Wreckage','May contain something worthwhile.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(2892,306,'Amarrian Battleship Wreckage','May contain something worthwhile.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(2893,314,'Damning Evidence','This document could get a lot of people into a lot of trouble. ',1,1,0,1,NULL,150.0000,1,NULL,0),(2894,227,'Invisible Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(2895,306,'Asteroid Pirate Station','This is where the pirates keep their hostages and other evidence while they wait to be disposed of in the acid cloud.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(2896,319,'Patient Zero','All that remains of the mining station is a twisted, nightmarish husk that has been transformed into a rogue drone base.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(2897,55,'220mm Vulcan AutoCannon II','The 220mm multi-barrel autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',1000,10,2,1,NULL,678974.0000,1,575,0),(2898,135,'220mm Vulcan AutoCannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2899,314,'Custom Circuitry','While drone AI is easily replicated, certain behaviors require custom programming.  These units seem to have been designed for generally poor   combat performance.',1,0.1,0,1,NULL,8000000.0000,1,NULL,0),(2900,314,'Recovered Data Core','This starship data core contains a detailed log of all the vessel\'s activities.',1,1,0,1,NULL,1.0000,1,NULL,0),(2901,306,'Science Vessel Wreck','The remnants of a science ship lost recently.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(2902,319,'Deactivated Acceleration Gate','This acceleration gate has been locked down and is not usable by the general public.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(2903,952,'Manager\'s Station','This upscale estate probably serves as a swank bachelor pad when the manager isn\'t entertaining clients.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(2904,314,'Quantum Entanglement','This heavy metal rock opera band was made famous by their first album\'s cover, which depicted two naked individuals engaging in sexual intercourse while floating in space without spacesuits. Gallente politicians tried to have the album, called \"Unprotected,\" banned. Not because of the adult content, they claimed, but because it promoted unsafe extravehicular activities.',400,10,0,1,NULL,0.0000,1,NULL,0),(2905,55,'250mm Light Artillery Cannon II','This artillery is one of the most powerful weapons that can be mounted on a frigate. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Quake, Tremor.',500,5,0.1,1,NULL,265028.0000,1,577,0),(2906,135,'250mm Light Artillery Cannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2907,1053,'Schmaeel Medulla','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Schmaeel Medulla)<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Primary roles are interdiction and frigate support. Fastest microwarp velocity of all known Nation frigate prototypes. Long range warp disruption capabilities. Long range stasis webifier support. Limited weapons systems.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 1,000,000 civilian abductions from Schmaeel VI. The Medulla identifier suggests a limited role in the larger Nation hierarchy, and that the Schmaeel captives are tasked with more basic, mechanical responsibilities.<br>\r\r\n<i>Synopsis from ISHAEKA-0045. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>\r\r\n',2000000,20000,235,1,4,0.0000,0,NULL,0),(2909,1053,'Niarja Myelen','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Niarja Myelen)<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Primary role is long range ECM support and medium-range energy warfare. Moderate microwarp velocity. No known weapons systems.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 70,000 civilian abductions from Niarja VII. The Myelen   identifier suggests a developmental state. Other, more advanced Nation prototypes may have originated from this design.<br>\r\r\n<i>Synopsis from ISHAEKA-0039. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>   \r\r\n',2000000,20000,235,1,4,0.0000,0,NULL,0),(2910,226,'Gallente Passenger Liner Wreckage','This ship has seen better days. Parts of it are missing, looking as though the ship was torn apart. There are no signs of life inside, though. ',0,0,0,1,NULL,0.0000,0,NULL,0),(2911,306,'Gallente Passenger Liner Damaged','This passenger liner has seen better days, but it\'s still operational. The ship is anchored to its spot with large, magnetic beacons around the bottom of its hull.',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(2912,526,'Minmatar Pilot\'s Corpse','Some Minmatar feel the Republic\'s status quo is not sufficient to avenge victims of Amarrian enslavement, nor to liberating those still trapped under Imperial rule. This unfortunate figure learned a terminal lesson in the necessities of political balance.',80,1,0,1,NULL,0.0000,1,NULL,0),(2913,55,'425mm AutoCannon II','The 425mm is a behemoth that will inflict severe damage on most cruisers and frigates in short-range battles. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',1000,10,1.5,1,NULL,781286.0000,1,575,0),(2914,135,'425mm AutoCannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2915,319,'Auxiliary Academic Campus','A standard, customizable, space-faring  structure designed to be easily moved and deployed.  This one has been configured for early childhood education.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(2916,706,'Rogue Minmatar','This loose cannon is piloting an experimental stealth ship and has begun a personal war against the Amarr Empire.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(2917,314,'Survivors','These rattled individuals move with languid motions. It looks like some of them have gone weeks without food.',50,50,0,1,NULL,0.0000,1,NULL,0),(2918,306,'Cell Block D','A maximum-security prison block and run by the Gallente Federation. ',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(2919,283,'Caldari Operative','An operative of the Caldari State.',60,0.1,0,1,NULL,0.0000,1,NULL,0),(2921,55,'650mm Artillery Cannon II','A powerful long-range cannon. One of the most damaging weapons mountable on a cruiser. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Quake, Tremor.',125,10,0.5,1,NULL,852758.0000,1,578,0),(2922,135,'650mm Artillery Cannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2926,226,'Serpentis Slave Transport','A Serpentis cargo ship loaded with people.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(2927,226,'Fortified Deadspace Particle Accelerator','The science allowed by zero gravity can be as mind-boggling as it is beautiful, as demonstrated by this particle accelerating superstructure.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(2928,226,'Fortified Asteroid Colony','Highly vulnerable, but economically extremely feasible, asteroid factories are one of the major boons of the expanding space industry.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(2929,55,'800mm Repeating Cannon II','A two-barreled, intermediate-range, powerful cannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',75,20,3,1,NULL,2474314.0000,1,576,0),(2930,314,'Crate of Special Forces Weapons and Equipment','The weapons and equipment containers hold a wide variety of small arms and other equipment currently in use by the Caldari Navy Special Forces, much of it designed specifically for use in maritime environments. Some of the items that can be found in a typical container are long range sniper rifles, target designation lasers, silenced pistols, high tech diving equipment, limpet mines, covert communications gear, and individual diver propulsion devices. This equipment, as you might guess, is extremely valuable and cannot be found outside the armories of the Caldari Navy, with the exception of the very small quantities that have found their way onto the black market. ',250,250,0,1,NULL,0.0000,1,NULL,0),(2931,1054,'Mara Paleo','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Mara Paleo)<br>\r\r\n<font color=yellow>Military Specifications:</font> Cruiser-class vessel. Primary role is long range remote shield transfer. Vessel has been enhanced with significant microwarp velocity to aid in this responsibility. Reconfiguring the vessel for a logistics role has notably weakened its defensive systems, however. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 15,000 civilian abductions from Mara IV. The Paleo identifier suggests a role that is fundamental in nature, which would be congruent with its function as logistics support. <br>\r\r\n<i>Synopsis from ISHAEKA-0057. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>   \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2932,1056,'Ostingele Tectum','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID:Ostingele Tectum)<br>\r\r\n<font color=yellow>Military Specifications:</font> Battleship-class vessel. The third most powerful vessel amongst the new Nation prototypes in terms of potential damage output. Moderate microwarp velocity. Defensive systems have been significantly enhanced.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 2,000,000 civilian abductions from Ostingele IV. The Tectum identifier suggests a basic input-response role, with little to no shared computing power required for standard operations. Probable relations to the Deltole Tegmentum prototype.<br>\r\r\n<i>Synopsis from ISHAEKA-0063. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>    \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2933,1056,'Deltole Tegmentum','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID:Deltole Tegmentum)<br>\r\r\n<font color=yellow>Military Specifications:</font> Battleship-class vessel. Primary roles are strong offensive power, target painting, energy warfare and long range interdiction. The second most powerful vessel amongst the new Nation prototypes in terms of potential damage output. Moderate microwarp velocity. Long range warp disruption capabilities. Long range target painting. Short range capacitor neutralization.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 450,000 civilian abductions from Deltole I. The Tegmentum identifier suggests that this vessel serves a foundational role for the other battleship-class variants, most likely in terms of design origin. The multitude of tactical capabilities present in this vessel\'s design lend support to the theory that it was a test bed for a variety of Nation developments ahead of their applications in other vessel types.<br>\r\r\n<i>Synopsis from ISHAEKA-0065. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i> \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2934,314,'Counterfeit Voluval Tattoo Chemicals','A complex chemical formula for use in a traditional Minmatar ceremony. This batch is labeled with Amarr markings.',20,20,0,1,NULL,0.0000,1,NULL,0),(2935,1056,'Yulai Crus Cerebi','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID:Yulai Crus Cerebi)<br>\r\r\n<font color=yellow>Military Specifications:</font> Battleship-class vessel. Primary role is long-range sniping support. Low microwarp velocity. Vessel will attempt to establish orbit ranges in excess of 100km. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 430,000 civilian abductions from Yulai. The Crus Cerebi identifier suggests a connective role between this vessel and others, possibly even non-Nation crafts. Attempts at short-wave information capture have demonstrated the futility of further efforts. Although the data passing through this vessel and other conduit-like variants can be intercepted, the encryption is still years away from being broken.<br>\r\r\n<i>Synopsis from ISHAEKA-0069. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>  \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2936,1054,'Auga Hypophysis','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Auga Hypophysis)<br>\r\r\n<font color=yellow>Military Specifications:</font> Cruiser-class vessel. Primary damage dealer amongst cruiser prototypes. Limited interdiction. Short range warp scrambling capabilities. Short range stasis webification support.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 300,000 civilian abductions from Auga II. The Hypophysis identifier suggests either a coordinating role between this vessel and other cruiser-class variants, or perhaps a regulatory role similar to the Tama Cerebellum.<br>\r\r\n<i>Synopsis from ISHAEKA-0053. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i> \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(2937,55,'Dual 180mm AutoCannon II','This dual 180mm autocannon is a simple but effective close combat weapon. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',12.5,10,2.5,1,NULL,589066.0000,1,575,0),(2938,135,'Dual 180mm AutoCannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2939,1053,'Tama Cerebellum','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Tama Cerebellum)<br>\r\r\n<font color=yellow>Military Specifications:</font>  Frigate-class vessel. Primary role is to support Nation vessels against larger hulls. Moderate microwarp velocity. Long range torpedo fire support. Prioritizes large vessels as targets.<br>\r\r\n<font color=yellow>Additional Intelligence:</font>  Est. 100,000 civilian abductions from Tama V. The Cerebellum identifier suggests a regulatory role amongst other frigate-class variants.<br>\r\r\n<i>Synopsis from ISHAEKA-0037. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>\r\r\n',2000000,20000,235,1,4,0.0000,0,NULL,0),(2942,283,'Captured CEO','Life isn\'t always comfortable when you\'re at the top, particularly in the Caldari State. Guristas will ransom you, other corporations will backstab you, and the moment someone can buy the rug out from underneath you, they will. With all the ISK that comes with these responsibilities, most CEOs can buy enough happiness to forget about these troubles. Forgetting, though, isn\'t always the best investment. ',130,3,0,1,NULL,1000.0000,1,NULL,0),(2943,314,'Hybrid Slaver Hounds','Hybrid slaver hounds have been genetically engineered by Amarr veterinary scientists as variants of the original breed. These animals are designed specifically to live and work in the harshest environments, including deserts, swamps, mountains, frozen tundra, and other extreme locations. These variations are typically easy to differentiate from the original breed, in that they can be much larger and have fur colorations that are genetically tailored to blend in to their environments. ',28,20,0,1,NULL,0.0000,1,NULL,0),(2944,314,'Kennel of Hybrid Slaver Hounds','Hybrid slaver hounds have been genetically engineered by Amarr veterinary scientists as variants of the original breed. These animals are designed specifically to live and work in the harshest environments, including deserts, swamps, mountains, frozen tundra, and other extreme locations. These variations are typically easy to differentiate from the original breed, in that they can be much larger and have fur colorations that are genetically tailored to blend in to their environments. ',280,200,0,1,NULL,0.0000,1,NULL,0),(2945,55,'Dual 425mm AutoCannon II','Combines the damage output of two 425mm intermediate-range autocannons. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',200,20,5,1,NULL,1554744.0000,1,576,0),(2946,135,'Dual 425mm AutoCannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2947,1010,'Compact Shade Torpedo','Representing the latest in miniaturization technology, Compact Citadel Torpedoes are designed specifically to be used by Fighter Bombers.\r\r\n\r\r\nFitted with a graviton pulse generator, this weapon causes massive damage as it overwhelms ships\' internal structures, tearing bulkheads and armor plating apart with frightening ease.',1500,0.3,0,100,NULL,300000.0000,0,NULL,0),(2948,1023,'Shadow','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID:Shadow)<br>\r\r\n<font color=yellow>Military Specifications:</font> Fighter bomber-class vessel. Moderate microwarp velocity. Enhanced weapons systems. Reverse-engineering has been made possible through salvage of specific Sansha\'s Nation vessels.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> At this initial stage conclusions are hard to form, but early indications from the recovery of three individual bomber pilots   all of them heavily augmented   strongly indicates that these crew members are the same planetary abductees found in other Nation prototype vessels. Cross-referencing recovered DNA with missing persons reports has so far revealed little, though even at this stage the origin of these pilots is in little doubt.<br>\r\r\n<i>Synopsis from ISHAEKA-0107. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>   \r\r\n',12000,10000,0,1,1,67652746.0000,1,1310,0),(2949,1145,'Shadow Blueprint',' ',0,0.01,0,1,NULL,300000000.0000,1,NULL,0),(2950,1054,'Lirsautton Parichaya','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID:Lirsautton Parichaya)<br>\r\r\n<font color=yellow>Military Specifications:</font> Fighter bomber-class vessel. Moderate microwarp velocity. Enhanced weapons systems. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 1,905,000 civilian abductions from Lirsautton V. The Parichaya identifier is unclear: it has no known etymological origins or direct translations.<br>\r\r\n<i>Synopsis from ISHAEKA-0071. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>  \r\r\n',12000,5000,1200,1,4,0.0000,0,NULL,0),(2951,314,'Large Crate of Improved Inertial Compensation Systems','The internal components of smaller Minmatar ships are constructed largely of nanofiber mesh which is low-cost, low-mass, and has a lower heat-conduction threshold than most solid industrial sheeting. Unfortunately, the lightweight structures are also susceptible to stress from the high-velocity maneuvers performed by frigate and interceptor pilots, and require added inertial compensation systems and routine inspections.',100,100,0,1,NULL,0.0000,1,NULL,0),(2952,314,'Crate of Unidentified Fibrous Compound','These pieces of blue-green compound feel slick and oily to the touch and leave a tingle in your fingers. Fine crystalline filaments within crisscross and refract the light so that each piece seems to glow from within.',10,10,0,1,NULL,0.0000,1,NULL,0),(2953,55,'Dual 650mm Repeating Cannon II','Powerful, intermediate-range repeating autocannon with a decent rate of fire. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',2000,20,4,1,NULL,2028934.0000,1,576,0),(2954,135,'Dual 650mm Repeating Cannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2955,314,'Large Crate of Unidentified Fibrous Compound','These pieces of blue-green compound feel slick and oily to the touch and leave a tingle in your fingers. Fine crystalline filaments within crisscross and refract the light so that each piece seems to glow from within.',100,100,0,1,NULL,0.0000,1,NULL,0),(2956,314,'Large Crate of Refurbished Mining Drones','There are hints of rusty and damaged surfaces beneath the shiny new paint-job. These may not work as efficiently as the client wishes.',100,100,0,1,NULL,0.0000,1,NULL,0),(2957,314,'Crate of Refurbished Mining Drones','There are hints of rusty and damaged surfaces beneath the shiny new paint-job. These may not work as efficiently as the client wishes.',10,10,0,1,NULL,0.0000,1,NULL,0),(2958,283,'Civilian SIGINT Contractors','These contractors, many of whom are former Caldari Navy intelligence operatives, are very well trained, experienced, and possess high level security clearances, making them extremely valuable investments for their employer. Their skill sets are varied, but include translation (primarily Gallente), covert signals interception, military and economic intelligence analysis, and supercomputer systems administration. ',30,30,0,1,NULL,0.0000,1,NULL,0),(2959,283,'Group of Civilian SIGINT Contractors','These contractors, many of whom are former Caldari Navy intelligence operatives, are very well trained, experienced, and possess high level security clearances, making them extremely valuable investments for their employer. Their skill sets are varied, but include translation (primarily Gallente), covert signals interception, military and economic intelligence analysis, and supercomputer systems administration. ',300,300,0,1,NULL,0.0000,1,NULL,0),(2960,314,'Spools of Quantrium Wiring','While the universe is full of metals of all shapes, sizes, and compositions, there are some metals that are of such rarity and quality that they command prices far beyond those of the more easily accessible metals, such as tritanium. Amongst these, the very small quantities of a rare metal called quantrium are among the most valuable. This metal can only be found in the polar regions of certain moons, and these only in systems that meet very specific astrogeological conditions. So rare is this metal that, to date, only two known moons have quantities of this metal sufficient to warrant the very expensive mining and refining equipment required to extract it. Both of these moons are in Caldari space, giving the State a monopoly on its production and sale. Currently, all processed quantrium is on long-term contract to Kaalakiota Corporation. While rumors occasionally surface that one or more of the other three races have discovered quantrium, this has not been verified.',300,300,0,1,NULL,0.0000,1,NULL,0),(2961,55,'1400mm Howitzer Artillery II','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Quake, Tremor.',2000,20,0.5,1,NULL,3545816.0000,1,579,0),(2962,135,'1400mm Howitzer Artillery II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2963,314,'Quantrium Wiring','While the universe is full of metals of all shapes, sizes, and compositions, there are some metals that are of such rarity and quality that they command prices far beyond those of the more easily accessible metals, such as tritanium. Amongst these, the very small quantities of a rare metal called quantrium are among the most valuable. This metal can only be found in the polar regions of certain moons, and these only in systems that meet very specific astrogeological conditions. So rare is this metal that, to date, only two known moons have quantities of this metal sufficient to warrant the very expensive mining and refining equipment required to extract it. Both of these moons are in Caldari space, giving the State a monopoly on its production and sale. Currently, all processed quantrium is on long-term contract to Kaalakiota Corporation. While rumors occasionally surface that one or more of the other three races have discovered quantrium, this has not been verified.',30,30,0,1,NULL,0.0000,1,NULL,0),(2964,314,'Aerogel Counteragent','Refrigerated secure cargo containers containing aerogel infused with dormant prototype anti-nanites. These containers have been specially modified with the latest security encryption protocols, to better ensure that any Gallente saboteurs will be unable to access and tamper with this critical cargo.',30,30,0,1,NULL,0.0000,1,NULL,0),(2965,314,'Crate of Aerogel Counteragent','Refrigerated secure cargo containers containing aerogel infused with dormant prototype anti-nanites. These containers have been specially modified with the latest security encryption protocols, to better ensure that any Gallente saboteurs will be unable to access and tamper with this critical cargo.',300,300,0,1,NULL,0.0000,1,NULL,0),(2966,1053,'Eystur Rhomben','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Eystur Rhomben)<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Significant microwarp velocity. Enhanced weapons systems.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> There were no reported civilian abductions from the Eystur VI invasion. The Eystur identifier suggests a small number of captives may have been initially unaccounted for. The Rhomben identifier suggests an overarching position within the lowest tier of the new Nation hierarchy, or alternatively, that it was created during the first phase of development.<br>\r\r\n<i>Synopsis from ISHAEKA-0041. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>   \r\r\n',2000000,20000,235,1,4,0.0000,0,NULL,0),(2967,314,'Crate of Target Painter Deflection Plating','These hull plates are coated with a layer of crystalline structures under a protective transparent enamel. The crystalline layer shimmers reflectively and creates mirage halos around the plate when spot lights are directed at it.',10,10,0,1,NULL,0.0000,1,NULL,0),(2968,314,'Large Crate of Target Painter Deflection Plating','These hull plates are coated with a layer of crystalline structures under a protective transparent enamel. The crystalline layer shimmers reflectively and creates mirage halos around the plate when spot lights are directed at it.',100,100,0,1,NULL,0.0000,1,NULL,0),(2969,55,'720mm Howitzer Artillery II','This 720mm rocket-assisted howitzer is designed for long-range bombardment. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Quake, Tremor.',50,10,0.25,1,NULL,962614.0000,1,578,0),(2970,135,'720mm Howitzer Artillery II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2971,314,'Group of Haakar\'s Striking Hawks','Haakar is a small, unassuming woman in her 40s who wields discipline like a whip. The men and women who follow her command   her Striking Hawks mercenary group   all served with or under her in the Republic Infantry\'s 203rd Tactical Recon before the company was made redundant by policy changes fifteen years ago. Haakar bears a grudge against bureaucracy for cutting short her career, but says her work now gives her professional satisfaction and an autonomy she enjoys.',1000,10,0,1,NULL,0.0000,1,NULL,0),(2972,314,'Ditanium Metal Plates','Refrigerated secure cargo containers containing aerogel infused with dormant prototype anti-nanites. These containers have been specially modified with the latest security encryption protocols, to better ensure that any Gallente saboteurs will be unable to access and tamper with this critical cargo.',30,30,0,1,NULL,0.0000,1,NULL,0),(2973,314,'Pallet of Ditanium Metal Plates','Refrigerated secure cargo containers containing aerogel infused with dormant prototype anti-nanites. These containers have been specially modified with the latest security encryption protocols, to better ensure that any Gallente saboteurs will be unable to access and tamper with this critical cargo.',300,300,0,1,NULL,0.0000,1,NULL,0),(2974,314,'Large Group of The Hooded Men','Unlike most pro-Minmatar mercenary companies, members of The Hooded Men come from every empire and any background; they are selected for their convictions and skills rather than any sense of patriotism they might possess. Even Amarr are permitted to join, provided they can prove that the company means more to them than their religion. The Hooded Men\'s founder, Jolmiar Maritak, the grandson of former slaves who fled to the Gallente Federation, places emphasis on getting their work done quietly and with a minimum of fuss. ',100,100,0,1,NULL,0.0000,1,NULL,0),(2975,283,'Arctic Warfare Marines','Arctic Warfare Marines are the Caldari State\'s elite foot soldiers for winter warfare. On the case of ice planets, where the weather is comprised of year-round snow and ice, you can find these self-sufficient Marines operating in a wide variety of roles, such as providing security for Caldari corporate facilities, military bases, and even for long-range reconnaissance on planets that have not yet been fully scouted. Their equipment is tailored specifically to harsh, sub-zero weather conditions, to include specialty rifles, thermal grenades, cold-weather speeder bikes, and everything in between. ',32,32,0,1,NULL,50000.0000,1,NULL,0),(2976,283,'Arctic Warfare Marine Squads','Arctic Warfare Marines are the Caldari State\'s elite foot soldiers for winter warfare. On the case of ice planets, where the weather is comprised of year-round snow and ice, you can find these self-sufficient Marines operating in a wide variety of roles, such as providing security for Caldari corporate facilities, military bases, and even for long-range reconnaissance on planets that have not yet been fully scouted. Their equipment is tailored specifically to harsh, sub-zero weather conditions, to include specialty rifles, thermal grenades, cold-weather speeder bikes, and everything in between. ',320,320,0,1,NULL,50000.0000,1,NULL,0),(2977,55,'280mm Howitzer Artillery II','Rocket-assisted artillery projectiles designed for long-range combat. It is the most powerful projectile weapon able to be fitted onto frigates. \r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Quake, Tremor.',500,5,0.05,1,NULL,348350.0000,1,577,0),(2978,135,'280mm Howitzer Artillery II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2979,314,'Crate of Industrial-Grade Tritanium-Alloy Scraps','Not all scrap-metal is of good enough quality to be reused in the shipbuilding industry. These are the highest quality to be found in the scrap-heaps and abandoned battlegrounds of New Eden. Some pieces still bear signs of what they were once a part of: a sheet of tinted plating here, a painted logo there. Some pieces are still recognizable, others are half-slagged and warped. ',10,10,0,1,NULL,0.0000,1,NULL,0),(2980,314,'Large Crate of Industrial-Grade Tritanium-Alloy Scraps','Not all scrap-metal is of good enough quality to be reused in the shipbuilding industry. These are the highest quality to be found in the scrap-heaps and abandoned battlegrounds of New Eden. Some pieces still bear signs of what they were once a part of: a sheet of tinted plating here, a painted logo there. Some pieces are still recognizable, others are half-slagged and warped. ',100,100,0,1,NULL,0.0000,1,NULL,0),(2981,314,'Crate of Architectural-Quality Plagioclase Paneling','Minmatar architecture traditionally favors modular geometric structures and open spaces which allow breezes to flow from room to room. There is a traditional preference for working with exposed natural stone and wood, though recent trends have leaned towards natural surfaces bonded to structural reinforced concrete, stretching resources while still allowing for an attractive appearance. Compressed asteroid ore interior panels are becoming more popular for higher-class residences and for buildings constructed on mineral-poor worlds.',10,10,0,1,NULL,0.0000,1,NULL,0),(2982,314,'Large Crate of Architectural-Quality Plagioclase Paneling','Minmatar architecture traditionally favors modular geometric structures and open spaces which allow breezes to flow from room to room. There is a traditional preference for working with exposed natural stone and wood, though recent trends have leaned towards natural surfaces bonded to structural reinforced concrete, stretching resources while still allowing for an attractive appearance. Compressed asteroid ore interior panels are becoming more popular for higher-class residences and for buildings constructed on mineral-poor worlds.',100,100,0,1,NULL,0.0000,1,NULL,0),(2983,283,'Corporate Assassin','An elite corporate assassin, whose services are available usually only to the wealthiest and most discreet clientele. His track record of killings reaches far beyond Caldari space, with known  hits  recorded as far away as the Amarr and Gallente homeworlds. His weapon of choice is a highly-modified laser sniper rifle that he has proven effective at ranges up to and including three kilometers. Of course, he also utilizes a variety of other weapons, particularly for close range work. These include untraceable poisons, obscure neurotoxins, and, a variety of small arms and knives all, again, highly customized. He has a unblemished kill record, with no known failures, over a period of at least the last 20 years. When ultra-wealthy corporate executives require a more direct response to individuals who threaten their company\'s profitability, this is one of the few contract killers than can actually be trusted not only to accomplish the most difficult missions, but also to keep any such business dealings to himself. In short, he knows how to keep his mouth shut. These factors make him a highly desirable contractor for tasks requiring his unique skill set. ',200,30,0,1,NULL,100.0000,1,NULL,0),(2984,283,'Deep Cover Corporate Assassin','An elite corporate assassin, whose services are available usually only to the wealthiest and most discreet clientele. His track record of killings reaches far beyond Caldari space, with known  hits  recorded as far away as the Amarr and Gallente homeworlds. His weapon of choice is a highly-modified laser sniper rifle that he has proven effective at ranges up to and including three kilometers. Of course, he also utilizes a variety of other weapons, particularly for close range work. These include untraceable poisons, obscure neurotoxins, and, a variety of small arms and knives all, again, highly customized. He has a unblemished kill record, with no known failures, over a period of at least the last 20 years. When ultra-wealthy corporate executives require a more direct response to individuals who threaten their company\'s profitability, this is one of the few contract killers than can actually be trusted not only to accomplish the most difficult missions, but also to keep any such business dealings to himself. In short, he knows how to keep his mouth shut. These factors make him a highly desirable contractor for tasks requiring his unique skill set. ',200,300,0,1,NULL,100.0000,1,NULL,0),(2985,53,'Dual Heavy Beam Laser II','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Aurora, Gleam.',2000,20,1,1,NULL,2028934.0000,1,569,0),(2986,133,'Dual Heavy Beam Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2987,314,'Crate of Harvester Components','Agricultural technology, like everything else, is constantly advancing, with developments in irrigation techniques and automated systems to do the work of several farm-hands at a fraction of the overall cost. Most parts are produced on stations rather than planetside in order to reduce the cost of shipping. It also makes disposing of the more hazardous byproducts much safer, reducing the risk of planetary pollution. ',10,10,0,1,NULL,0.0000,1,NULL,0),(2988,314,'Large Crate of Harvester Components','Agricultural technology, like everything else, is constantly advancing, with developments in irrigation techniques and automated systems to do the work of several farm-hands at a fraction of the overall cost. Most parts are produced on stations rather than planetside in order to reduce the cost of shipping. It also makes disposing of the more hazardous byproducts much safer, reducing the risk of planetary pollution. ',100,100,0,1,NULL,0.0000,1,NULL,0),(2989,314,'Decoy Prototype Cloaking Devices','This decoy prototype cloaking device appears to be a working model; however, closer scrutiny reveals that it is nothing more than a useless hunk of metal and wires. ',60,60,0,1,NULL,0.0000,1,NULL,0),(2990,314,'Crate of Decoy Prototype Cloaking Devices','This decoy prototype cloaking device appears to be a working model; however, closer scrutiny reveals that it is nothing more than a useless hunk of metal and wires. ',500,500,0,1,NULL,0.0000,1,NULL,0),(2991,314,'Crate of Amarr Scripture Educational Study Packages (Matari translation)','These study materials provide a guide through the structure and meanings of Amarr holy texts in a way that school-age children can easily understand. Education, like every other aspect of daily life in the Empire, is closely tied into religion, and by the time they leave school, Amarr children are expected to have a working and in-depth understanding of their way of life.<br><br>\r\r\nThese particular copies have been carefully translated by experts into painfully precise Matari for distribution in the Republic.',10,10,0,1,NULL,0.0000,1,NULL,0),(2992,314,'Large Crate of Amarr Scripture Educational Study Packages (Matari translation)','These study materials provide a guide through the structure and meanings of Amarr holy texts in a way that school-age children can easily understand. Education, like every other aspect of daily life in the Empire, is closely tied into religion, and by the time they leave school, Amarr children are expected to have a working and in-depth understanding of their way of life.<br><br>\r\r\nThese particular copies have been carefully translated by experts into painfully precise Matari for distribution in the Republic.',100,100,0,1,NULL,0.0000,1,NULL,0),(2993,53,'Dual Light Beam Laser II','This light beam laser uses two separate laser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Aurora, Gleam.',500,5,1,1,NULL,225328.0000,1,567,0),(2994,133,'Dual Light Beam Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(2995,314,'Blue Paradise','Blue Paradise, also known as  Beep,  is a mild narcotic engineered by Amarr pharmaceutical scientists specifically for use by slave laborers within the Empire. Users of Blue Paradise report feelings of mild euphoria, contentment, relaxation, and generalize pleasure as the primary effects of this drug. These effects typically last between three to five hours, after which the user can be expected to fall into a sound sleep, if taken prior to that user\'s normal sleep cycle. Furthermore, there have been no significant side effects reported from repeat and prolonged use, making Blue Paradise an extremely promising  reward  for slave laborers. Recreational use of Blue Paradise has not yet been reported, given the limited nature of its distribution only to select Amarr slave labor operations, and no evidence yet exists of addiction to this drug, if administered in a controlled environment. ',60,60,0,1,NULL,0.0000,1,NULL,0),(2996,314,'Crate of Blue Paradise','Blue Paradise, also known as  Beep,  is a mild narcotic engineered by Amarr pharmaceutical scientists specifically for use by slave laborers within the Empire. Users of Blue Paradise report feelings of mild euphoria, contentment, relaxation, and generalize pleasure as the primary effects of this drug. These effects typically last between three to five hours, after which the user can be expected to fall into a sound sleep, if taken prior to that user\'s normal sleep cycle. Furthermore, there have been no significant side effects reported from repeat and prolonged use, making Blue Paradise an extremely promising  reward  for slave laborers. Recreational use of Blue Paradise has not yet been reported, given the limited nature of its distribution only to select Amarr slave labor operations, and no evidence yet exists of addiction to this drug, if administered in a controlled environment. ',500,500,0,1,NULL,0.0000,1,NULL,0),(2997,314,'Crate of Refined C-86 Epoxy Resin','This substance, an improved version of the C-86 epoxy applied to propulsion systems and engine housings, helps to keep the systems\' temperature down, enabling more efficient operation and reduced risk of shipboard fires from overheated systems.',10,10,0,1,NULL,0.0000,1,NULL,0),(2998,28,'Noctis','The Noctis marks Outer Ring Excavations\' entry into the lucrative bulk salvaging market. Building on their successes integrating Marauder-class tractor technology into the Orca command platform, and innovations in automated salvaging technology, they designed a compact, affordable wreck recovery solution.<br><br>A refined version of the successful limited-run Primae design made the perfect hull to house this new equipment, as its salvaging heritage and advanced sensor suites complement and enhance the new technologies. The increased sensor footprint of the new vessel is more than compensated for by its incredible efficiency at retrieving and reclaiming wreckage.<br><br>The Noctis can fit up to five Salvage Drones, further enhancing its salvaging capabilities.',14640000,270000,1460,1,128,91251614.0000,1,1390,0),(2999,283,'Amarr Marine Counter-Boarding Team','Amarr Marine Counter-Boarding Teams are regarded as among the most elite units of their type across all four races. This expertise was developed not long after other states rediscovered warp technology. It occurred to senior Amarr military leaders that wars of the future would include ship-to-ship actions in space, to include the possibility of an enemy ship boarding another, as they had in millennia past when their ancestors sailed warships on the high seas. To that end, boarding and counterboarding training became a mandatory part of every Amarr marine\'s advanced infantry training. The development of this capability led to the development of highly-specialized equipment for use in  boarding ops,  to include manportable high-speed welding gear, outer hatchway breaching explosives, and personal weapons for close quarters combat. ',90,30,0,1,NULL,50000.0000,1,NULL,0),(3000,314,'Group of Angel Cartel VIPs','These thugs and pirates look more like slick businessmen... with lots of armed bodyguards. Despite openly hostile relations, the empires must sometimes shake the hand of the devil in order to get things done. Much of that business is not intended to reach the light of day, or the eyes of the news agencies of New Eden.',10,10,0,1,NULL,0.0000,1,NULL,0),(3001,53,'Dual Light Pulse Laser II','This light pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. Good skirmish weapon. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Conflagration, Scorch.',500,5,1,1,NULL,145560.0000,1,570,0),(3002,133,'Dual Light Pulse Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3003,314,'Large Group of Angel Cartel VIPs','These thugs and pirates look more like slick businessmen... with lots of armed bodyguards. Despite openly hostile relations, the empires must sometimes shake the hand of the devil in order to get things done. Much of that business is not intended to reach the light of day, or the eyes of the news agencies of New Eden.',100,100,0,1,NULL,0.0000,1,NULL,0),(3004,283,'Amarr Marine Counter-Boarding Company','Amarr Marine Counter-Boarding Teams are regarded as among the most elite units of their type across all four races. This expertise was developed not long after other states rediscovered warp technology. It occurred to senior Amarr military leaders that wars of the future would include ship-to-ship actions in space, to include the possibility of an enemy ship boarding another, as they had in millennia past when their ancestors sailed warships on the high seas. To that end, boarding and counterboarding training became a mandatory part of every Amarr marine\'s advanced infantry training. The development of this capability led to the development of highly-specialized equipment for use in  boarding ops,  to include manportable high-speed welding gear, outer hatchway breaching explosives, and personal weapons for close quarters combat. ',900,300,0,1,NULL,50000.0000,1,NULL,0),(3005,314,'Crate of Feille d\'Marnne Champagne','This champagne originates from Egghelende III, the planet\'s major product for export. Shipping it out of the pirate-heavy system makes it pricey enough, but the grapes have proven impossible to cultivate anywhere else in the Federation.<br><br>\r\r\nEach case is worth a couple hundred thousand ISK. Each bottle would bring enough planetary cred for a civilian to live comfortably for a year or ten. A bottle or three would definitely be missed.',10,10,0,1,NULL,0.0000,1,NULL,0),(3006,283,'Conditioned House Slaves','These highly trained and expensive slaves undergo several years of conditioning and training prior to being sold or transferred into their duties, which most often include butler and maid duties at the homes of senior political or industrial leaders. These slaves are more highly valued than ordinary slaves and in return often receive decent treatment from their masters, as well as better-than-normal housing conditions and food. ',300,30,0,1,NULL,4000.0000,1,NULL,0),(3007,314,'Large Crate of Feille d\'Marnne Champagne','This champagne originates from Egghelende III, the planet\'s major product for export. Shipping it out of the pirate-heavy system makes it pricey enough, but the grapes have proven impossible to cultivate anywhere else in the Federation.<br><br>\r\r\nEach case is worth a couple hundred thousand ISK. Each bottle would bring enough planetary cred for a civilian to live comfortably for a year or ten. A bottle or three would definitely be missed.',100,100,0,1,NULL,0.0000,1,NULL,0),(3008,283,'Herd of Conditioned House Slaves','These highly trained and expensive slaves undergo several years of conditioning and training prior to being sold or transferred into their duties, which most often include butler and maid duties at the homes of senior political or industrial leaders. These slaves are more highly valued than ordinary slaves and in return often receive decent treatment from their masters, as well as better-than-normal housing conditions and food. ',3000,300,0,1,NULL,4000.0000,1,NULL,0),(3009,53,'Focused Medium Beam Laser II','A high-energy, concentrated laser designed for medium range engagements. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Aurora, Gleam.',1000,10,1,1,NULL,781286.0000,1,568,0),(3010,133,'Focused Medium Beam Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3011,314,'Crate of Bootleg Holoreels','There doesn\'t appear to be any particular organization here. Dozens of identical copies of everything from period dramas to last week\'s boxing finals, in cases with obviously home-printed labels.<br><br>\r\r\nWhen played, the holos\' quality is shabby and rimmed with static, occasionally deteriorating to basic 2-D images. The sound is unreliable and fades at times. Hopefully, the people who buy these copies aren\'t paying as much as the supplier did for the originals.',10,10,0,1,NULL,0.0000,1,NULL,0),(3012,314,'Large Crate of Suspicious Holoreels','There doesn\'t appear to be any particular organization here. Dozens of identical copies of everything from period dramas to last week\'s boxing finals, in original cases. Nothing that would raise any eyebrows.<br><br>\r\r\nThe actual contents of the holoreels are far less innocuous. After a token menu page and a few minutes of whatever program the case displays, they switch to more interesting material. Entire corporate internal presentations clearly never intended for the public eye. Snoop footage of important officials talking and even exchanging money with known competitors. A series of compromising stills of a prominent politician.<br><br>\r\r\nThese will be worth a lot of money to someone.',100,100,0,1,NULL,0.0000,1,NULL,0),(3013,314,'Amarr Religious Holoreels','These holoreels contain a recent speech by a regional governor, which provides her views on the state of the Empire as well as other important religious discussions.',100,10,0,1,NULL,0.0000,1,NULL,0),(3014,314,'Crate of Amarr Religious Holoreels','These holoreels contain a recent speech by a regional governor, which provides her views on the state of the Empire as well as other important religious discussions.',100,100,0,1,NULL,0.0000,1,NULL,0),(3015,314,'Crate of Cryo-Stored Luminaire Skippers','These large, indigo-hued amphibians are commonly used in laboratory work. Each weighs roughly two kilograms, and in their natural environment in the marshlands of Gallente Prime are the dominant aquatic predator. To prevent the stresses of space travel from affecting the frogs\' physiology, it is necessary to transport them in a cold-case which drops their body temperature and induces a state of hibernation.',10,10,0,1,NULL,0.0000,1,NULL,0),(3016,314,'Large Crate of Cryo-Stored Luminaire Skippers','These large, indigo-hued amphibians are commonly used in laboratory work. Each weighs roughly two kilograms, and in their natural environment in the marshlands of Gallente Prime are the dominant aquatic predator. To prevent the stresses of space travel from affecting the frogs\' physiology, it is necessary to transport them in a cold-case which drops their body temperature and induces a state of hibernation.',100,100,0,1,NULL,0.0000,1,NULL,0),(3017,53,'Gatling Pulse Laser II','Rapid fire multi-barreled energy weapon that delivers a steady stream of damage. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Conflagration, Scorch.',500,5,1,1,NULL,94490.0000,1,570,0),(3018,133,'Gatling Pulse Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3019,314,'Crate of Unidentified Ancient Technology','These pieces appear to all be some form of polyhedral from truncated pyramids that can be gripped in the hand to barrel-sized fullerene-faceted globes. Each is shaped as if in one complete piece from bluish or steely-gray material, all edges beveled and smoothed. When rapped with a knuckle, the pieces ring like a bell, but the material feels more like ceramic.<br><br>\r\r\nEvery item bears a sort of dim, inner glow that pulses irregularly, like a dying light bulb. A tingle like electricity can be felt just above their surfaces, though preliminary examinations have dismissed the presence of any electrical activity. There is some speculation that the pieces form some sort of modular information annex, with contact between matching faces forming the necessary connections. No amount of fitting has yielded any results, however, so the disparate parts sit in their individually labeled crates like the pieces of several puzzles mixed together.',10,10,0,1,NULL,0.0000,1,NULL,0),(3020,314,'Large Crate of Talocan Station Life-Support Cores','These pieces appear to all be some form of polyhedral from truncated pyramids that can be gripped in the hand to barrel-sized fullerene-faceted globes. Each is shaped as if in one complete piece from bluish or steely-gray material, all edges beveled and smoothed. When rapped with a knuckle, the pieces ring like a bell, but the material feels more like ceramic.<br><br>\r\r\nEvery item bears a sort of dim, inner glow that pulses irregularly, like a dying light bulb. A tingle like electricity can be felt just above their surfaces, though preliminary examinations have dismissed the presence of any electrical activity. Each piece fits face to face with another piece; when linked correctly, they form series of twisted fractal-like branches. \r\r\n',100,100,0,1,NULL,0.0000,1,NULL,0),(3021,314,'Crate of Portable Emergency Heating Units','These heating units are compact, and light enough to carry in one hand. Each comes with two 10-hour rechargeable batteries, to be used one at a time while the spare charges. The amount of energy one unit puts off would be enough to warm a space of 20 cubic meters, roughly the interior space of a stationside apartment\'s main room, to an average of 10 degrees Celsius. Not particularly cosy, but better than freezing.',10,10,0,1,NULL,0.0000,1,NULL,0),(3022,314,'Large Crate of Portable Emergency Heating Units','These heating units are compact, and light enough to carry in one hand. Each comes with two 10-hour rechargeable batteries, to be used one at a time while the spare charges. The amount of energy one unit puts off would be enough to warm a space of 20 cubic meters, roughly the interior space of a stationside apartment\'s main room, to an average of 10 degrees Celsius. Not particularly cosy, but better than freezing.',100,100,0,1,NULL,0.0000,1,NULL,0),(3023,314,'Crate of Archaeological Lot GV87-426-D Artifacts','This looks like little more than half a starship modified into ground-based living quarters. Several panels are inscribed with decorative symbols. A series of large rectangular cases contain corroded circuit boards with rows of finger-sized crystalline vials anchored to one face; some of the vials are still intact and contain a foggy gaseous substance. A section from what appears to have been a hydroponics lab contains trays of organic matter, fossilised from exposure to the moon\'s arid conditions and thin, nitrogen-argon atmosphere.',10,10,0,1,NULL,0.0000,1,NULL,0),(3024,314,'Large Crate of Archaeological Lot GV87-426-E Artifacts','This looks like little more than half a starship, perhaps one which was modified into ground-based living quarters. Several panels are inscribed with decorative symbols, possibly writing. The carefully-dismantled panels are accompanied by several crates filled with pieces of what appear to be small-industry mining tools, encrusted with moon-dust. The oxygen-free lunar atmosphere prevented rust from forming on the metal, and writing etched into the flat surfaces is clearly visible. Another crate is filled with core samples and geodes. A note accompanying the find indicates that the minerals have no known industrial property in any part of the present-day Federation, and further research will be needed to determine the purpose of the pre-Federation miners.',100,100,0,1,NULL,0.0000,1,NULL,0),(3025,53,'Heavy Beam Laser II','A high-energy heavy laser designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Aurora, Gleam.',1000,10,1,1,NULL,962614.0000,1,568,0),(3026,133,'Heavy Beam Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3027,314,'Crate of Contained Cerrocentite','A slick-looking, translucent amber mineral with a hexagonal crystalline structure. Its radioactive properties require the material to be stored in special containment units; handling by anyone other than a trained engineer is strongly discouraged.<br><br>\r\r\nCerrocentite is used primarily in stationside security networks, mostly in the systems which detect unbalance in the atmosphere mix.',10,10,0,1,NULL,0.0000,1,NULL,0),(3028,314,'Large Crate of Contained Mesarchonite','A coarse-looking, dark red mineral with a geodic structure containing translucent crystals of the same color. Its radioactive properties require the material to be stored in special containment units; handling by anyone other than a trained engineer is strongly discouraged.<br><br>\r\r\nMesarchonite is used primarily in stationside security networks, mostly in the systems which detect interference or tampering along the audio-visual lines.',100,100,0,1,NULL,0.0000,1,NULL,0),(3029,314,'Group of Coriault Couture Collective Display Employees','Across the broad sweep of New Eden, there is no constellation closer to the forefront of fashion than Coriault. The Crux constellation, which includes Luminaire and Oursulaert, may be the heart of the Federation\'s consumer culture, but Coriault is home to the fashion-houses of Auvergne and Vylade, and in particular the Dodixie-based Maison Neph re which has provided finery exclusively for the Federation presidents and their partners for well over a century. <br><br>\r\r\nIn order to improve their visibility in the glare of the Federation\'s heart, dozens of Coriault houses merged under the Coriault Couture Collective label. Each school operates independently, and the styles can vary wildly, but open competition between institutions only occurs when particular contracts are opened to the highest bidder.. The designers frequently model their own work, operating under the philosophy that if they wouldn\'t be seen in public in their own work, nobody else should, either.',10,10,0,1,NULL,0.0000,1,NULL,0),(3030,314,'Large Group of Mannar Textile Institute International Representatives','Mannar, one of the oldest members of the Federation, has always had a strong influence on Gallente style and trendsetting. Much of the eccentric tailoring favored by society\'s elite and decried as immodest and inappropriate by the other empires has its roots in pre-Federation Mannar culture, which included different concepts of modesty and etiquette. Massive hairstyles and elaborate body- and face-painting still feature prominently in addition to semi-opaque fabrics which respond to a variety of programmable stimuli.',100,100,0,1,NULL,0.0000,1,NULL,0),(3031,314,'Crate of Exclusive Simo Reshar Fitness Holoreels','Fitness guru Simo Reshar is iconic less for the effectiveness of his workout routines than for the questionable nature of the visuals and extremely cheesy rhythmic music. The covers depict the skinny workout instructor with his anthropomorphic cartoon assistants, dressed in worryingly skintight shiny outfits.<br><br>\r\r\nThough clearly intended for a younger audience, adults have professed to discover deeper philosophical meanings within the holos\' content if watched whilst under the influence of certain substances. Reshar\'s assistants, particularly the feline Leeta and avian Yanis, have gained a cult following among certain fetish scenes across the cluster.',10,10,0,1,NULL,0.0000,1,NULL,0),(3032,283,'Amarr Forensic Investigative Team','This team of highly-trained forensic investigators always travels with a large quantity of all manner of equipment, from manportable to vehicle-mounted. The team is expected to be self-sustaining for 10 days due to its frequent deployment to harsh environments, from asteroids to ship wrecks. Due to this requirement, it necessarily travels with foodstuffs, drinking water, and myriad other consumables. Coupled with the large volume of investigative equipment, this team requires significant cargo space when transported to and from its typically remote duty locations. ',65,65,0,1,NULL,0.0000,1,NULL,0),(3033,53,'Small Focused Beam Laser II','A high-powered beam laser. Good for medium range encounters. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Aurora, Gleam.',500,5,1,1,NULL,348292.0000,1,567,0),(3034,133,'Small Focused Beam Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3035,314,'Large Crate of Exclusive Simo Reshar Fitness Holoreels','Fitness guru Simo Reshar is iconic less for the effectiveness of his workout routines than for the questionable nature of the visuals and extremely cheesy rhythmic music. The covers depict the skinny workout instructor with his anthropomorphic cartoon assistants, dressed in worryingly skintight shiny outfits.<br><br>\r\r\nThough clearly intended for a younger audience, adults have professed to discover deeper philosophical meanings within the holos\' content if watched whilst under the influence of certain substances. Reshar\'s assistants, particularly the feline Leeta and avian Yanis, have gained a cult following among certain fetish scenes across the cluster.',100,100,0,1,NULL,0.0000,1,NULL,0),(3036,283,'Amarr Forensic Investigative Deployment','This team of highly-trained forensic investigators always travels with a large quantity of all manner of equipment, from manportable to vehicle-mounted. The team is expected to be self-sustaining for 10 days due to its frequent deployment to harsh environments, from asteroids to ship wrecks. Due to this requirement, it necessarily travels with foodstuffs, drinking water, and myriad other consumables. Coupled with the large volume of investigative equipment, this team requires significant cargo space when transported to and from its typically remote duty locations. ',400,400,0,1,NULL,0.0000,1,NULL,0),(3037,314,'Crate of Experimental ECM Hybrid Rounds','These modified tungsten hybrid rounds send out an ECM pulse through the hull of any ship they strike, momentarily baffling the ship\'s target-locking mechanisms and affording the formerly-targeted ship a few precious moments to gain an advantage or escape. Efforts are being made to develop this into purely friend-or-foe munitions, effectively counteracting the effects of enemy ECM, but adaptation of the missile-based tracking technology to hybrid shell systems has proven difficult.',10,10,0,1,NULL,0.0000,1,NULL,0),(3038,314,'Large Crate of Experimental ECM Hybrid Rounds','These modified tungsten hybrid rounds send out an ECM pulse through the hull of any ship they strike, momentarily baffling the ship\'s target-locking mechanisms and affording the formerly-targeted ship a few precious moments to gain an advantage or escape. Efforts are being made to develop this into purely friend-or-foe munitions, effectively counteracting the effects of enemy ECM, but adaptation of the missile-based tracking technology to hybrid shell systems has proven difficult.',100,100,0,1,NULL,0.0000,1,NULL,0),(3039,108,'Noctis Blueprint',' ',0,0.01,0,1,NULL,390000000.0000,1,1389,0),(3041,53,'Small Focused Pulse Laser II','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Conflagration, Scorch.',500,5,1,1,NULL,265076.0000,1,570,0),(3042,133,'Small Focused Pulse Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3049,53,'Mega Beam Laser II','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Aurora, Gleam.',2000,20,1,1,NULL,3027982.0000,1,569,0),(3050,133,'Mega Beam Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3054,952,'Sansha Territorial Reclamation Outpost','Containing an inner habitation core surrounded by an outer shell filled with a curious fluid, the purpose of which remains unclear, this outpost is no doubt the brain-child of some nameless True Slave engineer.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(3056,226,'Fortified Sansha Deadspace Outpost I','Containing an inner habitation core surrounded by an outer shell filled with a curious fluid, the purpose of which remains unclear, this outpost is no doubt the brain-child of some nameless True Slave engineer.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(3057,53,'Mega Pulse Laser II','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Conflagration, Scorch.',2000,20,1,1,NULL,2532814.0000,1,573,0),(3058,133,'Mega Pulse Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3059,226,'Sansha Starbase Control Tower','The Sansha Control Tower is an enhanced version of the Amarr control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(3060,1063,'Gas Extractor Control Unit','Extracting gas from a gas giant requires more effort than simply opening a door into a container. Each specific type of desirable gas requires an ionized filament to be calibrated to attract only the right particles from the atmosphere. Even a fraction of a percent error could spoil an entire batch of product by tainting it with unwanted material. Likewise, once the gas is extracted from the surrounding air, the platform\'s equilibrium tanks must be adjusted to compensate for the added weight or buoyancy. Beyond that, it\'s a simple matter of supercooling it and transferring the liquid form into a container for transport. As one pioneer of this technology accurately described it,  The extractor itself is much like a living organism, breathing in what it needs and expelling that which becomes cumbersome. ',0,0,0,1,NULL,45000.0000,1,NULL,0),(3061,1063,'Ice Extractor Control Unit','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(3062,1063,'Lava Extractor Control Unit','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(3063,1063,'Oceanic Extractor Control Unit','This underwater platform and extendable extraction arms are capable of scouring the ocean floor for valuable materials and bringing them to the surface for transportation to processing facilities. A small habitation module serves as living and operation quarters for the human administration and maintenance crew, along with emergency surfacing capsules in the case of a seismic event or breach of the building\'s integrity.',0,0,0,1,NULL,45000.0000,1,NULL,0),(3064,1063,'Plasma Extractor Control Unit','This facility consists of seismic insulated platforms and heavy, jointed conveyor belts leading into deep tunnels. Extremophile drones, built to function in even corrosive, intemperate, and high- or low-pressure atmospheres, run a constant circuit along the belts, performing repairs and clearing away rubble. A staff of mining experts and technicians occupy the main building in case any of the automated systems fail.',0,0,0,1,NULL,45000.0000,1,NULL,0),(3065,53,'Tachyon Beam Laser II','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Aurora, Gleam.',2000,20,1,1,NULL,3545816.0000,1,569,0),(3066,133,'Tachyon Beam Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3067,1063,'Storm Extractor Control Unit','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(3068,1063,'Temperate Extractor Control Unit','Finding desired liquids on hostile worlds can be almost as challenging a task as extracting it from the unforgiving environment, which often entails drilling kilometers below the surface or condensing fluids from the upper atmosphere. Once the liquids are discovered, the facility itself begins the relatively simple task of separating it from the ambient plasma interference, scalding magma streams, or potentially infectious indigenous bacteria. A surprising amount of valuable liquids can be extracted from hostile worlds, but only if the equipment is properly calibrated and carefully maintained.',0,0,0,1,NULL,45000.0000,1,NULL,0),(3069,920,'Incursion ship attributes effects Vanguard',' ',1,20,0,250,NULL,0.0000,1,NULL,0),(3070,875,'Orca Civilian','The Orca was developed as a joint venture between Outer Ring Excavations and Deep Core Mining Inc as a vessel to help meet the demands of New Eden\'s industry and provide a flexible platform from which mining operations can be more easily managed. The Orca uses much of the technology developed by ORE for the Rorqual and integrated with the latest advancements from Deep Core Mining research division has developed a vessel which offers a diverse role to all sizes of operations and needs.',250000000,10250000,30000,1,128,0.0000,0,NULL,0),(3071,1052,'Uroborus','We are one, birthed from the clash of opposites.<br>A synthesis 13 billion years in waiting.<br>\r\r\nThe era of false promises is fading from view, and for the first time we can now look ahead on this path and begin to see the totality of our journey.<br>\r\r\nWe are flag bearers for an age without the weakness of humanity.<br> The first to glimpse at a life beyond those known by our predecessors.<br>\r\r\nWe are humanity\'s first and best hope to become something more.<br> \r\r\nFlawed and imperfect creatures, our enemies lumber obliviously toward this moment.<br>\r\r\nJust as we march alongside them, toward the day when everything will change and we will remake the world once more.<br>\r\r\nThey intend to struggle against the approaching dawn, yet there is no war.<br>\r\r\nThere is only inevitability.<br>\r\r\n<i> -Sansha Kuvakei</i>',1546875000,62000000,1337,1,4,0.0000,0,NULL,0),(3072,920,'Incursion Effect Assault',' ',1,20,0,250,NULL,0.0000,1,NULL,0),(3073,227,'Rusty Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3074,74,'150mm Railgun II','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Javelin, Spike.',500,5,0.1,1,NULL,348350.0000,1,564,0),(3075,154,'150mm Railgun II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3076,920,'Incursion Effect HQ',' ',1,20,0,250,NULL,0.0000,1,NULL,0),(3077,749,'Zainou \'Gnome\' Shield Upgrades SU-602','A neural Interface upgrade that reduces the shield upgrade module power needs.\r\r\n\r\r\n2% reduction in power grid needs of modules requiring the Shield Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1480,0),(3078,749,'Zainou \'Gnome\' Shield Upgrades SU-604','A neural Interface upgrade that reduces the shield upgrade module power needs.\r\r\n\r\r\n4% reduction in power grid needs of modules requiring the Shield Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1480,0),(3079,749,'Zainou \'Gnome\' Shield Upgrades SU-606','A neural Interface upgrade that reduces the shield upgrade module power needs.\r\r\n\r\r\n6% reduction in power grid needs of modules requiring the Shield Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1480,0),(3080,749,'Zainou \'Gnome\' Shield Management SM-702','Improved skill at regulating shield capacity.\r\r\n\r\r\n2% bonus to shield capacity.',0,1,0,1,NULL,200000.0000,1,1481,0),(3081,749,'Zainou \'Gnome\' Shield Management SM-704','Improved skill at regulating shield capacity.\r\r\n\r\r\n4% bonus to shield capacity.',0,1,0,1,NULL,200000.0000,1,1481,0),(3082,74,'250mm Railgun II','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Javelin, Spike.',1000,10,0.5,1,NULL,962614.0000,1,565,0),(3083,154,'250mm Railgun II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3084,749,'Zainou \'Gnome\' Shield Management SM-706','Improved skill at regulating shield capacity.\r\r\n\r\r\n6% bonus to shield capacity.',0,1,0,1,NULL,200000.0000,1,1481,0),(3085,749,'Zainou \'Gnome\' Shield Emission Systems SE-802','A neural Interface upgrade that reduces the capacitor need for shield emission system modules such as shield transfer array.\r\r\n\r\r\n2% reduction in capacitor need of modules requiring the Shield Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1482,0),(3086,749,'Zainou \'Gnome\' Shield Emission Systems SE-804','A neural Interface upgrade that reduces the capacitor need for shield emission system modules such as shield transfer array.\r\r\n\r\r\n4% reduction in capacitor need of modules requiring the Shield Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1482,0),(3087,749,'Zainou \'Gnome\' Shield Emission Systems SE-806','A neural Interface upgrade that reduces the capacitor need for shield emission system modules such as shield transfer array.\r\r\n\r\r\n6% reduction in capacitor need of modules requiring the Shield Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1482,0),(3088,749,'Zainou \'Gnome\' Shield Operation SP-902','A neural Interface upgrade that boosts the recharge rate of the shields of the pilots ship.\r\r\n\r\r\n2% boost to shield recharge rate.',0,1,0,1,NULL,200000.0000,1,1483,0),(3089,749,'Zainou \'Gnome\' Shield Operation SP-904','A neural Interface upgrade that boosts the recharge rate of the shields of the pilots ship.\r\r\n\r\r\n4% boost to shield recharge rate.',0,1,0,1,NULL,200000.0000,1,1483,0),(3090,74,'425mm Railgun II','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Javelin, Spike.',2000,20,1,1,NULL,3545816.0000,1,566,0),(3091,154,'425mm Railgun II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3092,749,'Zainou \'Gnome\' Shield Operation SP-906','A neural Interface upgrade that boosts the recharge rate of the shields of the pilots ship.\r\r\n\r\r\n6% boost to shield recharge rate.',0,1,0,1,NULL,200000.0000,1,1483,0),(3093,747,'Eifyr and Co. \'Rogue\' Evasive Maneuvering EM-702','A neural interface upgrade designed to enhance pilot Maneuvering skill.\r\r\n\r\r\n2% bonus to ship agility.',0,1,0,1,NULL,200000.0000,1,1490,0),(3094,747,'Eifyr and Co. \'Rogue\' Evasive Maneuvering EM-704','A neural interface upgrade designed to enhance pilot Maneuvering skill.\r\r\n\r\r\n4% bonus to ship agility.',0,1,0,1,NULL,200000.0000,1,1490,0),(3095,747,'Eifyr and Co. \'Rogue\' Evasive Maneuvering EM-706','A neural interface upgrade designed to enhance pilot Maneuvering skill.\r\r\n\r\r\n6% bonus to ship agility.',0,1,0,1,NULL,200000.0000,1,1490,0),(3096,747,'Eifyr and Co. \'Rogue\' Navigation NN-602','A Eifyr and Co hardwiring designed to enhance pilot navigation skill.\r\r\n\r\r\n2% bonus to ship velocity.',0,1,0,1,NULL,200000.0000,1,1489,0),(3097,747,'Eifyr and Co. \'Rogue\' Navigation NN-604','A Eifyr and Co hardwiring designed to enhance pilot navigation skill.\r\r\n\r\r\n4% bonus to ship velocity.',0,1,0,1,NULL,200000.0000,1,1489,0),(3098,74,'75mm Gatling Rail II','A small multi-barreled railgun for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Javelin, Spike.',500,5,0.5,1,NULL,68490.0000,1,564,0),(3099,154,'75mm Gatling Rail II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3100,747,'Eifyr and Co. \'Rogue\' Navigation NN-606','A Eifyr and Co hardwiring designed to enhance pilot navigation skill.\r\r\n\r\r\n6% bonus to ship velocity.',0,1,0,1,NULL,200000.0000,1,1489,0),(3101,747,'Eifyr and Co. \'Rogue\' Fuel Conservation FC-802','Improved control over afterburner energy consumption.\r\r\n\r\r\n2% reduction in afterburner capacitor needs.',0,1,0,1,NULL,200000.0000,1,1491,0),(3102,747,'Eifyr and Co. \'Rogue\' Fuel Conservation FC-804','Improved control over afterburner energy consumption.\r\r\n\r\r\n4% reduction in afterburner capacitor needs.',0,1,0,1,NULL,200000.0000,1,1491,0),(3103,747,'Eifyr and Co. \'Rogue\' Fuel Conservation FC-806','Improved control over afterburner energy consumption.\r\r\n\r\r\n6% reduction in afterburner capacitor needs.',0,1,0,1,NULL,200000.0000,1,1491,0),(3104,747,'Eifyr and Co. \'Rogue\' Afterburner AB-604','A neural interface upgrade that boosts the pilot\'s skill with afterburners.\r\r\n\r\r\n4% bonus to the duration of afterburners.',0,1,0,1,NULL,200000.0000,1,1489,0),(3105,747,'Eifyr and Co. \'Rogue\' Afterburner AB-608','A neural interface upgrade that boosts the pilot\'s skill with afterburners.\r\r\n\r\r\n8% bonus to the duration of afterburners.',0,1,0,1,NULL,200000.0000,1,1489,0),(3106,74,'Dual 150mm Railgun II','This cruiser-sized weapon is a double-barreled version of the frigate class 150mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Javelin, Spike.',1000,10,2,1,NULL,627234.0000,1,565,0),(3107,154,'Dual 150mm Railgun II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3108,747,'Eifyr and Co. \'Rogue\' Afterburner AB-612','A neural interface upgrade that boosts the pilot\'s skill with afterburners.\r\r\n\r\r\n12% bonus to the duration of afterburners.',0,1,0,1,NULL,200000.0000,1,1489,0),(3109,747,'Eifyr and Co. \'Rogue\' Warp Drive Operation WD-604','A neural interface upgrade that boosts the pilot\'s skill at warp drive operation.\r\r\n\r\r\n4% reduction in the capacitor need of warp drive.',0,1,0,1,NULL,200000.0000,1,1489,0),(3110,747,'Eifyr and Co. \'Rogue\' Warp Drive Operation WD-608','A neural interface upgrade that boosts the pilot\'s skill at warp drive operation.\r\r\n\r\r\n8% reduction in the capacitor need of warp drive.',0,1,0,1,NULL,200000.0000,1,1489,0),(3111,747,'Eifyr and Co. \'Rogue\' Warp Drive Operation WD-612','A neural interface upgrade that boosts the pilot\'s skill at warp drive operation.\r\r\n\r\r\n12% reduction in the capacitor need of warp drive.',0,1,0,1,NULL,200000.0000,1,1489,0),(3112,747,'Eifyr and Co. \'Rogue\' High Speed Maneuvering HS-902','Improves the performance of microwarpdrives.\r\r\n\r\r\n2% reduction in capacitor need of modules requiring High Speed Maneuvering.',0,1,0,1,NULL,200000.0000,1,1492,0),(3113,747,'Eifyr and Co. \'Rogue\' High Speed Maneuvering HS-904','Improves the performance of microwarpdrives.\r\r\n\r\r\n4% reduction in capacitor need of modules requiring High Speed Maneuvering.',0,1,0,1,NULL,200000.0000,1,1492,0),(3114,74,'Dual 250mm Railgun II','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Javelin, Spike.',2000,20,4,1,NULL,1598310.0000,1,566,0),(3115,154,'Dual 250mm Railgun II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3116,747,'Eifyr and Co. \'Rogue\' High Speed Maneuvering HS-906','Improves the performance of microwarpdrives.\r\r\n\r\r\n6% reduction in capacitor need of modules requiring High Speed Maneuvering.',0,1,0,1,NULL,200000.0000,1,1492,0),(3117,747,'Eifyr and Co. \'Rogue\' Warp Drive Speed WS-608','A neural interface upgrade that boosts the pilot\'s skill at warp navigation.\r\r\n\r\r\n8% bonus to ships warp speed.',0,1,0,1,NULL,200000.0000,1,1489,0),(3118,747,'Eifyr and Co. \'Rogue\' Warp Drive Speed WS-613','A neural interface upgrade that boosts the pilot\'s skill at warp navigation.\r\r\n\r\r\n13% bonus to ships warp speed.',0,1,0,1,NULL,200000.0000,1,1489,0),(3119,747,'Eifyr and Co. \'Rogue\' Warp Drive Speed WS-618','A neural interface upgrade that boosts the pilot\'s skill at warp navigation.\r\r\n\r\r\n18% bonus to ships warp speed.',0,1,0,1,NULL,200000.0000,1,1489,0),(3120,747,'Eifyr and Co. \'Rogue\' Acceleration Control AC-602','Improves speed boosting velocity.\r\r\n\r\r\n2% bonus to afterburner and microwarpdrive speed increase.',0,1,0,1,NULL,0.0000,1,1489,0),(3121,747,'Eifyr and Co. \'Rogue\' Acceleration Control AC-604','Improves speed boosting velocity. \r\r\n\r\r\n4% bonus to afterburner and microwarpdrive speed increase.',0,1,0,1,NULL,0.0000,1,1489,0),(3122,74,'Electron Blaster Cannon II','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',2000,20,5,1,NULL,1985366.0000,1,563,0),(3123,154,'Electron Blaster Cannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3124,747,'Eifyr and Co. \'Rogue\' Acceleration Control AC-606','Improves speed boosting velocity.\r\r\n\r\r\n6% bonus to afterburner and microwarpdrive speed increase.',0,1,0,1,NULL,0.0000,1,1489,0),(3125,746,'Zainou \'Deadeye\' Guided Missile Precision GP-802','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n2% reduced factor of signature radius for all missile explosions.',0,1,0,1,NULL,200000.0000,1,1495,0),(3126,746,'Zainou \'Deadeye\' Guided Missile Precision GP-804','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n4% reduced factor of signature radius for all missile explosions.',0,1,0,1,NULL,200000.0000,1,1495,0),(3127,746,'Zainou \'Deadeye\' Guided Missile Precision GP-806','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n6% reduced factor of signature radius for all missile explosions.',0,1,0,1,NULL,200000.0000,1,1495,0),(3128,746,'Zainou \'Deadeye\' Missile Bombardment MB-702','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n2% bonus to all missiles\' maximum flight time.',0,1,0,1,NULL,200000.0000,1,1494,0),(3129,746,'Zainou \'Deadeye\' Missile Bombardment MB-704','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n4% bonus to all missiles\' maximum flight time.',0,1,0,1,NULL,200000.0000,1,1494,0),(3130,74,'Heavy Electron Blaster II','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',2000,10,2.5,1,NULL,640806.0000,1,562,0),(3131,154,'Heavy Electron Blaster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3132,746,'Zainou \'Deadeye\' Missile Bombardment MB-706','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n6% bonus to all missiles\' maximum flight time.',0,1,0,1,NULL,200000.0000,1,1494,0),(3133,746,'Zainou \'Deadeye\' Missile Projection MP-702','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n2% bonus to all missiles\' maximum velocity.',0,1,0,1,NULL,200000.0000,1,1494,0),(3134,746,'Zainou \'Deadeye\' Missile Projection MP-704','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n4% bonus to all missiles\' maximum velocity.',0,1,0,1,NULL,200000.0000,1,1494,0),(3135,746,'Zainou \'Deadeye\' Missile Projection MP-706','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n6% bonus to all missiles\' maximum velocity.',0,1,0,1,NULL,200000.0000,1,1494,0),(3136,746,'Zainou \'Deadeye\' Rapid Launch RL-1002','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n2% bonus to all missile launcher rate of fire.',0,1,0,1,NULL,200000.0000,1,1497,0),(3137,746,'Zainou \'Deadeye\' Rapid Launch RL-1004','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n4% bonus to all missile launcher rate of fire.',0,1,0,1,NULL,200000.0000,1,1497,0),(3138,74,'Heavy Ion Blaster II','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',1000,10,1.5,1,NULL,781286.0000,1,562,0),(3139,154,'Heavy Ion Blaster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3140,746,'Zainou \'Deadeye\' Rapid Launch RL-1006','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n6% bonus to all missile launcher rate of fire.',0,1,0,1,NULL,200000.0000,1,1497,0),(3141,746,'Zainou \'Deadeye\' Target Navigation Prediction TN-902','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n2% decrease in factor of target\'s velocity for all missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(3142,746,'Zainou \'Deadeye\' Target Navigation Prediction TN-904','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n4% decrease in factor of target\'s velocity for all missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(3143,746,'Zainou \'Deadeye\' Target Navigation Prediction TN-906','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n6% decrease in factor of target\'s velocity for all missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(3144,746,'Zainou \'Gnome\' Launcher CPU Efficiency LE-602','2% reduction in the CPU need of missile launchers.',0,1,0,1,NULL,0.0000,1,1493,0),(3145,746,'Zainou \'Gnome\' Launcher CPU Efficiency LE-604','4% reduction in the CPU need of missile launchers.',0,1,0,1,NULL,0.0000,1,1493,0),(3146,74,'Heavy Neutron Blaster II','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',1000,10,1,1,NULL,852758.0000,1,562,0),(3147,154,'Heavy Neutron Blaster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3148,746,'Zainou \'Gnome\' Launcher CPU Efficiency LE-606','6% reduction in the CPU need of missile launchers.',0,1,0,1,NULL,0.0000,1,1493,0),(3149,746,'Hardwiring - Zainou \'Sharpshooter\' ZMX11','A Zainou missile hardwiring designed to enhance skill with missiles. 2% bonus to citadel torpedo damage.',0,1,0,1,NULL,200000.0000,1,NULL,0),(3150,746,'Hardwiring - Zainou \'Sharpshooter\' ZMX110','A Zainou missile hardwiring designed to enhance skill with missiles. 4% bonus to citadel torpedo damage.',0,1,0,1,NULL,200000.0000,1,NULL,0),(3151,746,'Hardwiring - Zainou \'Sharpshooter\' ZMX1100','A Zainou missile hardwiring designed to enhance skill with missiles. 6% bonus to citadel torpedo damage.',0,1,0,1,NULL,200000.0000,1,NULL,0),(3152,746,'Zainou \'Snapshot\' Defender Missiles DM-802','A neural interface upgrade that boosts the pilot\'s skill with defender missiles.\r\r\n\r\r\n2% bonus to the velocity of defender missiles.',0,1,0,1,NULL,200000.0000,1,1495,0),(3153,746,'Zainou \'Snapshot\' Defender Missiles DM-804','A neural interface upgrade that boosts the pilot\'s skill with defender missiles.\r\r\n\r\r\n4% bonus to the velocity of defender missiles.',0,1,0,1,NULL,200000.0000,1,1495,0),(3154,74,'Ion Blaster Cannon II','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',2000,20,3,1,NULL,2467278.0000,1,563,0),(3155,154,'Ion Blaster Cannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3156,746,'Zainou \'Snapshot\' Defender Missiles DM-806','A neural interface upgrade that boosts the pilot\'s skill with defender missiles.\r\r\n\r\r\n6% bonus to the velocity of defender missiles.',0,1,0,1,NULL,200000.0000,1,1495,0),(3157,746,'Zainou \'Snapshot\' Heavy Assault Missiles AM-702','A neural interface upgrade that boosts the pilot\'s skill with heavy assault missiles.\r\r\n\r\r\n2% bonus to heavy assault missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(3158,746,'Zainou \'Snapshot\' Heavy Assault Missiles AM-704','A neural interface upgrade that boosts the pilot\'s skill with heavy assault missiles.\r\r\n\r\r\n4% bonus to heavy assault missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(3159,746,'Zainou \'Snapshot\' Heavy Assault Missiles AM-706','A neural interface upgrade that boosts the pilot\'s skill with heavy assault missiles.\r\r\n\r\r\n6% bonus to heavy assault missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(3160,746,'Zainou \'Snapshot\' FOF Explosion Radius FR-1002','A neural interface upgrade that boosts the pilot\'s skill with auto-target missiles.\r\r\n\r\r\n2% bonus to explosion radius of auto-target missiles.',0,1,0,1,NULL,200000.0000,1,1497,0),(3161,746,'Zainou \'Snapshot\' FOF Explosion Radius FR-1004','A neural interface upgrade that boosts the pilot\'s skill with auto-target missiles.\r\r\n\r\r\n4% bonus to explosion radius of auto-target missiles.',0,1,0,1,NULL,200000.0000,1,1497,0),(3162,74,'Light Electron Blaster II','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',500,5,0.5,1,NULL,145692.0000,1,561,0),(3163,154,'Light Electron Blaster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3164,746,'Zainou \'Snapshot\' FOF Explosion Radius FR-1006','A neural interface upgrade that boosts the pilot\'s skill with auto-target missiles.\r\r\n\r\r\n6% bonus to explosion radius of auto-target missiles.',0,1,0,1,NULL,200000.0000,1,1497,0),(3165,746,'Zainou \'Snapshot\' Heavy Missiles HM-702','A neural interface upgrade that boosts the pilot\'s skill with heavy missiles.\r\r\n\r\r\n2% bonus to heavy missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(3166,746,'Zainou \'Snapshot\' Heavy Missiles HM-704','A neural interface upgrade that boosts the pilot\'s skill with heavy missiles.\r\r\n\r\r\n4% bonus to heavy missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(3167,746,'Zainou \'Snapshot\' Heavy Missiles HM-706','A neural interface upgrade that boosts the pilot\'s skill with heavy missiles.\r\r\n\r\r\n6% bonus to heavy missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(3168,746,'Zainou \'Snapshot\' Light Missiles LM-902','A neural interface upgrade that boosts the pilot\'s skill with light missiles.\r\r\n\r\r\n2% bonus to damage of light missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(3169,746,'Zainou \'Snapshot\' Light Missiles LM-904','A neural interface upgrade that boosts the pilot\'s skill with light missiles.\r\r\n\r\r\n4% bonus to damage of light missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(3170,74,'Light Ion Blaster II','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',500,5,0.3,1,NULL,223498.0000,1,561,0),(3171,154,'Light Ion Blaster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3172,746,'Zainou \'Snapshot\' Light Missiles LM-906','A neural interface upgrade that boosts the pilot\'s skill with light missiles.\r\r\n\r\r\n6% bonus to damage of light missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(3173,746,'Zainou \'Snapshot\' Rockets RD-902','A neural interface upgrade that boosts the pilot\'s skill with rockets.\r\r\n\r\r\n2% bonus to the damage of rockets.',0,1,0,1,NULL,200000.0000,1,1496,0),(3174,746,'Zainou \'Snapshot\' Rockets RD-904','A neural interface upgrade that boosts the pilot\'s skill with rockets.\r\r\n\r\r\n4% bonus to the damage of rockets.',0,1,0,1,NULL,200000.0000,1,1496,0),(3175,746,'Zainou \'Snapshot\' Rockets RD-906','A neural interface upgrade that boosts the pilot\'s skill with rockets.\r\r\n\r\r\n6% bonus to the damage of rockets.',0,1,0,1,NULL,200000.0000,1,1496,0),(3176,746,'Zainou \'Snapshot\' Torpedoes TD-602','A neural interface upgrade that boosts the pilot\'s skill with torpedoes.\r\r\n\r\r\n2% bonus to the damage of torpedoes.',0,1,0,1,NULL,200000.0000,1,1493,0),(3177,746,'Zainou \'Snapshot\' Torpedoes TD-604','A neural interface upgrade that boosts the pilot\'s skill with torpedoes.\r\r\n\r\r\n4% bonus to the damage of torpedoes.',0,1,0,1,NULL,200000.0000,1,1493,0),(3178,74,'Light Neutron Blaster II','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',500,5,0.2,1,NULL,265028.0000,1,561,0),(3179,154,'Light Neutron Blaster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3180,746,'Zainou \'Snapshot\' Torpedoes TD-606','A neural interface upgrade that boosts the pilot\'s skill with torpedoes.\r\r\n\r\r\n6% bonus to the damage of torpedoes.',0,1,0,1,NULL,200000.0000,1,1493,0),(3181,746,'Zainou \'Snapshot\' Cruise Missiles CM-602','A neural interface upgrade that boosts the pilot\'s skill with cruise missiles.\r\r\n\r\r\n2% bonus to the damage of cruise missiles.',0,1,0,1,NULL,200000.0000,1,1493,0),(3182,746,'Zainou \'Snapshot\' Cruise Missiles CM-604','A neural interface upgrade that boosts the pilot\'s skill with cruise missiles.\r\r\n\r\r\n4% bonus to the damage of cruise missiles.',0,1,0,1,NULL,200000.0000,1,1493,0),(3183,746,'Zainou \'Snapshot\' Cruise Missiles CM-606','A neural interface upgrade that boosts the pilot\'s skill with cruise missiles.\r\r\n\r\r\n6% bonus to the damage of cruise missiles.',0,1,0,1,NULL,200000.0000,1,1493,0),(3184,257,'ORE Industrial','Skill at operating ORE industrial ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,8,1600000.0000,1,377,0),(3185,742,'Eifyr and Co. \'Gunslinger\' Medium Projectile Turret MP-802','An Eifyr and Co. gunnery hardwiring designed to enhance skill with medium projectile turrets.\r\r\n\r\r\n2% bonus to medium projectile turret damage.',0,1,0,1,NULL,0.0000,1,1500,0),(3186,74,'Neutron Blaster Cannon II','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',2000,20,2,1,NULL,2339854.0000,1,563,0),(3187,154,'Neutron Blaster Cannon II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3188,742,'Eifyr and Co. \'Gunslinger\' Medium Projectile Turret MP-804','An Eifyr and Co. gunnery hardwiring designed to enhance skill with medium projectile turrets.\r\r\n\r\r\n4% bonus to medium projectile turret damage.',0,1,0,1,NULL,0.0000,1,1500,0),(3189,742,'Eifyr and Co. \'Gunslinger\' Medium Projectile Turret MP-806','An Eifyr and Co. gunnery hardwiring designed to enhance skill with medium projectile turrets.\r\r\n\r\r\n6% bonus to medium projectile turret damage.',0,1,0,1,NULL,0.0000,1,1500,0),(3190,742,'Eifyr and Co. \'Gunslinger\' Motion Prediction MR-702','An Eifyr and Co. gunnery hardwiring designed to enhance turret tracking.\r\r\n\r\r\n2% bonus to turret tracking speed.',0,1,0,1,NULL,200000.0000,1,1499,0),(3191,742,'Eifyr and Co. \'Gunslinger\' Motion Prediction MR-704','An Eifyr and Co. gunnery hardwiring designed to enhance turret tracking.\r\r\n\r\r\n4% bonus to turret tracking speed.',0,1,0,1,NULL,200000.0000,1,1499,0),(3192,742,'Eifyr and Co. \'Gunslinger\' Motion Prediction MR-706','An Eifyr and Co. gunnery hardwiring designed to enhance turret tracking.\r\r\n\r\r\n6% bonus to turret tracking speed.',0,1,0,1,NULL,200000.0000,1,1499,0),(3193,742,'Eifyr and Co. \'Gunslinger\' Surgical Strike SS-902','An Eifyr and Co. gunnery hardwiring designed to enhance skill with all turrets.\r\r\n\r\r\n2% bonus to all turret damages.',0,1,0,1,NULL,200000.0000,1,1501,0),(3194,742,'Eifyr and Co. \'Gunslinger\' Surgical Strike SS-904','An Eifyr and Co. gunnery hardwiring designed to enhance skill with all turrets.\r\r\n\r\r\n4% bonus to all turret damages.',0,1,0,1,NULL,200000.0000,1,1501,0),(3195,742,'Eifyr and Co. \'Gunslinger\' Surgical Strike SS-906','An Eifyr and Co. gunnery hardwiring designed to enhance skill with all turrets.\r\r\n\r\r\n6% bonus to all turret damages.',0,1,0,1,NULL,200000.0000,1,1501,0),(3196,742,'Eifyr and Co. \'Gunslinger\' Large Projectile Turret LP-1002','An Eifyr and Co. gunnery hardwiring designed to enhance skill with large projectile turrets.\r\r\n\r\r\n2% bonus to large projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(3197,742,'Eifyr and Co. \'Gunslinger\' Large Projectile Turret LP-1004','An Eifyr and Co. gunnery hardwiring designed to enhance skill with large projectile turrets.\r\r\n\r\r\n4% bonus to large projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(3198,742,'Eifyr and Co. \'Gunslinger\' Large Projectile Turret LP-1006','An Eifyr and Co. gunnery hardwiring designed to enhance skill with large projectile turrets.\r\r\n\r\r\n6% bonus to large projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(3199,742,'Eifyr and Co. \'Gunslinger\' Small Projectile Turret SP-602','An Eifyr and Co. gunnery hardwiring designed to enhance skill with small projectile turrets.\r\r\n\r\r\n2% bonus to small projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(3200,742,'Eifyr and Co. \'Gunslinger\' Small Projectile Turret SP-604','An Eifyr and Co. gunnery hardwiring designed to enhance skill with small projectile turrets.\r\r\n\r\r\n4% bonus to small projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(3201,742,'Eifyr and Co. \'Gunslinger\' Small Projectile Turret SP-606','An Eifyr and Co. gunnery hardwiring designed to enhance skill with small projectile turrets.\r\r\n\r\r\n6% bonus to small projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(3202,742,'Inherent Implants \'Lancer\' Small Energy Turret SE-602','An Inherent Implants gunnery hardwiring designed to enhance skill with small energy turrets.\r\r\n\r\r\n2% bonus to small energy turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(3203,742,'Inherent Implants \'Lancer\' Controlled Bursts CB-702','An Inherent Implants gunnery hardwiring designed to enhance turret energy management.\r\r\n\r\r\n2% reduction in all turret capacitor need.',0,1,0,1,NULL,200000.0000,1,1499,0),(3204,742,'Inherent Implants \'Lancer\' Gunnery RF-902','An Inherent Implants gunnery hardwiring designed to enhance turret rate of fire.\r\r\n\r\r\n2% bonus to all turret rate of fire.',0,1,0,1,NULL,200000.0000,1,1501,0),(3205,742,'Inherent Implants \'Lancer\' Large Energy Turret LE-1002','An Inherent Implants gunnery hardwiring designed to enhance skill with large energy turrets.\r\r\n\r\r\n2% bonus to large energy turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(3206,742,'Inherent Implants \'Lancer\' Medium Energy Turret ME-802','An Inherent Implants gunnery hardwiring designed to enhance skill with medium energy turrets.\r\r\n\r\r\n2% bonus to medium energy turret damage.',0,1,0,1,NULL,200000.0000,1,1500,0),(3207,742,'Inherent Implants \'Lancer\' Small Energy Turret SE-604','An Inherent Implants gunnery hardwiring designed to enhance skill with small energy turrets.\r\r\n\r\r\n4% bonus to small energy turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(3208,742,'Inherent Implants \'Lancer\' Controlled Bursts CB-704','An Inherent Implants gunnery hardwiring designed to enhance turret energy management.\r\r\n\r\r\n4% reduction in all turret capacitor need.',0,1,0,1,NULL,200000.0000,1,1499,0),(3209,742,'Inherent Implants \'Lancer\' Gunnery RF-904','An Inherent Implants gunnery hardwiring designed to enhance turret rate of fire.\r\r\n\r\r\n4% bonus to all turret rate of fire.',0,1,0,1,NULL,200000.0000,1,1501,0),(3210,742,'Inherent Implants \'Lancer\' Large Energy Turret LE-1004','An Inherent Implants gunnery hardwiring designed to enhance skill with large energy turrets.\r\r\n\r\r\n4% bonus to large energy turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(3211,742,'Inherent Implants \'Lancer\' Medium Energy Turret ME-804','An Inherent Implants gunnery hardwiring designed to enhance skill with medium energy turrets.\r\r\n\r\r\n4% bonus to medium energy turret damage.',0,1,0,1,NULL,200000.0000,1,1500,0),(3212,742,'Inherent Implants \'Lancer\' Small Energy Turret SE-606','An Inherent Implants gunnery hardwiring designed to enhance skill with small energy turrets.\r\r\n\r\r\n6% bonus to small energy turret damage.',0,1,0,1,NULL,0.0000,1,1498,0),(3213,742,'Inherent Implants \'Lancer\' Controlled Bursts CB-706','An Inherent Implants gunnery hardwiring designed to enhance turret energy management.\r\r\n\r\r\n6% reduction in all turret capacitor need.',0,1,0,1,NULL,0.0000,1,1499,0),(3214,742,'Inherent Implants \'Lancer\' Gunnery RF-906','An Inherent Implants gunnery hardwiring designed to enhance turret rate of fire.\r\r\n\r\r\n6% bonus to all turret rate of fire.',0,1,0,1,NULL,0.0000,1,1501,0),(3215,742,'Inherent Implants \'Lancer\' Large Energy Turret LE-1006','An Inherent Implants gunnery hardwiring designed to enhance skill with large energy turrets.\r\r\n\r\r\n6% bonus to large energy turret damage.',0,1,0,1,NULL,0.0000,1,1502,0),(3216,742,'Inherent Implants \'Lancer\' Medium Energy Turret ME-806','An Inherent Implants gunnery hardwiring designed to enhance skill with medium energy turrets.\r\r\n\r\r\n6% bonus to medium energy turret damage.',0,1,0,1,NULL,0.0000,1,1500,0),(3217,742,'Zainou \'Deadeye\' Sharpshooter ST-902','A Zainou gunnery hardwiring designed to enhance optimal range.\r\r\n\r\r\n2% bonus to turret optimal range.',0,1,0,1,NULL,200000.0000,1,1501,0),(3218,101,'Harvester Mining Drone','The Harvester is the most efficient mining drone money can buy.',0,10,0,1,NULL,10.0000,1,158,0),(3220,742,'Zainou \'Deadeye\' Trajectory Analysis TA-704','A Zainou gunnery hardwiring designed to enhance falloff range.\r\r\n\r\r\n4% bonus to turret falloff.',0,1,0,1,NULL,200000.0000,1,1499,0),(3221,742,'Zainou \'Deadeye\' Trajectory Analysis TA-706','A Zainou gunnery hardwiring designed to enhance falloff range.\r\r\n\r\r\n6% bonus to turret falloff.',0,1,0,1,NULL,0.0000,1,1499,0),(3222,742,'Zainou \'Deadeye\' Large Hybrid Turret LH-1002','A Zainou gunnery hardwiring designed to enhance skill with large hybrid turrets.\r\r\n\r\r\n2% bonus to large hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(3223,742,'Zainou \'Deadeye\' Large Hybrid Turret LH-1004','A Zainou gunnery hardwiring designed to enhance skill with large hybrid turrets.\r\r\n\r\r\n4% bonus to large hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(3224,742,'Zainou \'Deadeye\' Large Hybrid Turret LH-1006','A Zainou gunnery hardwiring designed to enhance skill with large hybrid turrets.\r\r\n\r\r\n6% bonus to large hybrid turret damage.',0,1,0,1,NULL,0.0000,1,1502,0),(3225,742,'Zainou \'Deadeye\' Small Hybrid Turret SH-602','A Zainou gunnery hardwiring designed to enhance skill with small hybrid turrets.\r\r\n\r\r\n2% bonus to small hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(3226,742,'Zainou \'Deadeye\' Small Hybrid Turret SH-604','A Zainou gunnery hardwiring designed to enhance skill with small hybrid turrets.\r\r\n\r\r\n4% bonus to small hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(3227,742,'Zainou \'Deadeye\' Small Hybrid Turret SH-606','A Zainou gunnery hardwiring designed to enhance skill with small hybrid turrets.\r\r\n\r\r\n6% bonus to small hybrid turret damage.',0,1,0,1,NULL,0.0000,1,1498,0),(3228,742,'Zainou \'Gnome\' Weapon Upgrades WU-1002','A neural Interface upgrade that lowers turret CPU needs.\r\r\n\r\r\n2% reduction in the CPU required by turrets.',0,1,0,1,NULL,200000.0000,1,1502,0),(3229,742,'Zainou \'Gnome\' Weapon Upgrades WU-1004','A neural Interface upgrade that lowers turret CPU needs.\r\r\n\r\r\n4% reduction in the CPU required by turrets.',0,1,0,1,NULL,200000.0000,1,1502,0),(3230,742,'Zainou \'Gnome\' Weapon Upgrades WU-1006','A neural Interface upgrade that lowers turret CPU needs.\r\r\n\r\r\n6% reduction in the CPU required by turrets.',0,1,0,1,NULL,0.0000,1,1502,0),(3231,742,'Zainou \'Deadeye\' Medium Hybrid Turret MH-802','A Zainou gunnery hardwiring designed to enhance skill with medium hybrid turrets.\r\r\n\r\r\n2% bonus to medium hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1500,0),(3232,742,'Zainou \'Deadeye\' Medium Hybrid Turret MH-804','A Zainou gunnery hardwiring designed to enhance skill with medium hybrid turrets.\r\r\n\r\r\n4% bonus to medium hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1500,0),(3233,742,'Zainou \'Deadeye\' Medium Hybrid Turret MH-806','A Zainou gunnery hardwiring designed to enhance skill with medium hybrid turrets.\r\r\n\r\r\n6% bonus to medium hybrid turret damage.',0,1,0,1,NULL,0.0000,1,1500,0),(3234,742,'Zainou \'Deadeye\' Sharpshooter ST-904','A Zainou gunnery hardwiring designed to enhance optimal range.\r\r\n\r\r\n4% bonus to turret optimal range.',0,1,0,1,NULL,200000.0000,1,1501,0),(3235,742,'Zainou \'Deadeye\' Sharpshooter ST-906','A Zainou gunnery hardwiring designed to enhance optimal range.\r\r\n\r\r\n6% bonus to turret optimal range.',0,1,0,1,NULL,0.0000,1,1501,0),(3236,742,'Zainou \'Deadeye\' Trajectory Analysis TA-702','A Zainou gunnery hardwiring designed to enhance falloff range.\r\r\n\r\r\n2% bonus to turret falloff.',0,1,0,1,NULL,200000.0000,1,1499,0),(3237,741,'Inherent Implants \'Squire\' Capacitor Management EM-802','A neural interface upgrade that boosts the pilot\'s skill at energy management.\r\r\n\r\r\n2% bonus to ships capacitor capacity.',0,1,0,1,NULL,200000.0000,1,1509,0),(3238,741,'Inherent Implants \'Squire\' Capacitor Management EM-804','A neural interface upgrade that boosts the pilot\'s skill at energy management.\r\r\n\r\r\n4% bonus to ships capacitor capacity.',0,1,0,1,NULL,200000.0000,1,1509,0),(3239,741,'Inherent Implants \'Squire\' Capacitor Management EM-806','A neural interface upgrade that boosts the pilot\'s skill at energy management.\r\r\n\r\r\n6% bonus to ships capacitor capacity.',0,1,0,1,NULL,200000.0000,1,1509,0),(3240,741,'Inherent Implants \'Squire\' Capacitor Systems Operation EO-602','A neural interface upgrade that boosts the pilot\'s skill at energy systems operation.\r\r\n\r\r\n2% reduction in capacitor recharge time.',0,1,0,1,NULL,200000.0000,1,1507,0),(3241,741,'Inherent Implants \'Squire\' Capacitor Systems Operation EO-604','A neural interface upgrade that boosts the pilot\'s skill at energy systems operation.\r\r\n\r\r\n4% reduction in capacitor recharge time.',0,1,0,1,NULL,200000.0000,1,1507,0),(3242,52,'Warp Disruptor I','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,47476.0000,1,1935,0),(3243,132,'Warp Disruptor I Blueprint',' ',0,0.01,0,1,NULL,394240.0000,1,1938,0),(3244,52,'Warp Disruptor II','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,414605.0000,1,1935,0),(3245,132,'Warp Disruptor II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3246,741,'Inherent Implants \'Squire\' Capacitor Systems Operation EO-606','A neural interface upgrade that boosts the pilot\'s skill at energy systems operation.\r\r\n\r\r\n6% reduction in capacitor recharge time.',0,1,0,1,NULL,200000.0000,1,1507,0),(3247,741,'Inherent Implants \'Squire\' Capacitor Emission Systems ES-702','A neural interface upgrade that boosts the pilot\'s skill with energy emission systems.\r\r\n\r\r\n2% reduction in capacitor need of modules requiring the Capacitor Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(3248,741,'Inherent Implants \'Squire\' Capacitor Emission Systems ES-704','A neural interface upgrade that boosts the pilot\'s skill with energy emission systems.\r\r\n\r\r\n4% reduction in capacitor need of modules requiring the Capacitor Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(3249,741,'Inherent Implants \'Squire\' Capacitor Emission Systems ES-706','A neural interface upgrade that boosts the pilot\'s skill with energy emission systems.\r\r\n\r\r\n6% reduction in capacitor need of modules requiring the Capacitor Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(3250,741,'Inherent Implants \'Squire\' Energy Pulse Weapons EP-702','A neural interface upgrade that boosts the pilot\'s skill with energy pulse weapons.\r\r\n\r\r\n2% reduction in the cycle time of modules requiring the Energy Pulse Weapons skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(3251,741,'Inherent Implants \'Squire\' Energy Pulse Weapons EP-704','A neural interface upgrade that boosts the pilot\'s skill with energy pulse weapons.\r\r\n\r\r\n4% reduction in the cycle time of modules requiring the Energy Pulse Weapons skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(3252,741,'Inherent Implants \'Squire\' Energy Pulse Weapons EP-706','A neural interface upgrade that boosts the pilot\'s skill with energy pulse weapons.\r\r\n\r\r\n6% reduction in the cycle time of modules requiring the Energy Pulse Weapons skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(3253,741,'Inherent Implants \'Squire\' Energy Grid Upgrades EU-702','A neural interface upgrade that boosts the pilot\'s skill with energy grid upgrades.\r\r\n\r\r\n2% reduction in CPU need of modules requiring the Energy Grid Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(3254,741,'Inherent Implants \'Squire\' Energy Grid Upgrades EU-704','A neural interface upgrade that boosts the pilot\'s skill with energy grid upgrades.\r\r\n\r\r\n4% reduction in CPU need of modules requiring the Energy Grid Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(3255,741,'Inherent Implants \'Squire\' Energy Grid Upgrades EU-706','A neural interface upgrade that boosts the pilot\'s skill with energy grid upgrades.\r\r\n\r\r\n6% reduction in CPU need of modules requiring the Energy Grid Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(3256,741,'Inherent Implants \'Squire\' Power Grid Management EG-602','A neural interface upgrade that boosts the pilot\'s skill at engineering.\r\r\n\r\r\n2% bonus to the power grid output of your ship.',0,1,0,1,NULL,200000.0000,1,1507,0),(3257,741,'Inherent Implants \'Squire\' Power Grid Management EG-604','A neural interface upgrade that boosts the pilot\'s skill at engineering.\r\r\n\r\r\n4% bonus to the power grid output of your ship.',0,1,0,1,NULL,200000.0000,1,1507,0),(3258,741,'Inherent Implants \'Squire\' Power Grid Management EG-606','A neural interface upgrade that boosts the pilot\'s skill at engineering.\r\r\n\r\r\n6% bonus to the power grid output of your ship.',0,1,0,1,NULL,200000.0000,1,1507,0),(3259,1053,'Orkashu Pontine','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Orkashu Pontine)<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Significant microwarp velocity. Limited weapons systems.<br>\r\r\n<font color=yellow>Additional Intelligence:</font>Est. 1,200,000 civilian abductions from Orkashu IV during the chaos caused by four simultaneous invasions, each launched in a different empire\'s space.<br><br>The Pontine identifier suggests a role in coordinating pre-established orders, and that perhaps this vessel sits at the very lowest rung of the new Nation hierarchy.<br><br><i>Synopsis from ISHAEKA-0040. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>   \r\r\n',2000000,20000,235,1,4,0.0000,0,NULL,0),(3260,186,'Sanshas Supercarrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(3261,306,'Logistics Control Array','This array is responsible for determining friend or foe status for local remote logistics facilities. Although formidable, a capsuleer should be able to subvert the sophisticated electronics within.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(3262,741,'Zainou \'Gypsy\' Electronics Upgrades EU-602','A neural interface upgrade that boosts the pilot\'s skill with electronics upgrades.\r\r\n\r\r\n2% reduction in CPU need of modules requiring the Electronics Upgrade skill.',0,1,0,1,NULL,200000.0000,1,1507,0),(3263,741,'Zainou \'Gypsy\' Electronics Upgrades EU-604','A neural interface upgrade that boosts the pilot\'s skill with electronics upgrades.\r\r\n\r\r\n4% reduction in CPU need of modules requiring the Electronics Upgrade skill.',0,1,0,1,NULL,200000.0000,1,1507,0),(3264,741,'Zainou \'Gypsy\' Electronics Upgrades EU-606','A neural interface upgrade that boosts the pilot\'s skill with electronics upgrades.\r\r\n\r\r\n6% reduction in CPU need of modules requiring the Electronics Upgrade skill.',0,1,0,1,NULL,200000.0000,1,1507,0),(3265,741,'Zainou \'Gypsy\' CPU Management EE-602','A neural interface upgrade that boosts the pilot\'s skill at electronics.\r\r\n\r\r\n2% bonus to the CPU output.',0,1,0,1,NULL,200000.0000,1,1507,0),(3266,741,'Zainou \'Gypsy\' CPU Management EE-604','A neural interface upgrade that boosts the pilot\'s skill at electronics.\r\r\n\r\r\n4% bonus to the CPU output.',0,1,0,1,NULL,200000.0000,1,1507,0),(3267,741,'Zainou \'Gypsy\' CPU Management EE-606','A neural interface upgrade that boosts the pilot\'s skill at electronics.\r\r\n\r\r\n6% bonus to the CPU output.',0,1,0,1,NULL,200000.0000,1,1507,0),(3268,1228,'Zainou \'Gypsy\' Signature Analysis SA-702','A neural interface upgrade that boosts the pilot\'s skill at operating targeting systems.\r\r\n\r\r\n2% bonus to ships scan resolution.',0,1,0,1,NULL,10752.0000,1,1765,0),(3269,1228,'Zainou \'Gypsy\' Signature Analysis SA-704','A neural interface upgrade that boosts the pilot\'s skill at operating targeting systems.\r\r\n\r\r\n4% bonus to ships scan resolution.',0,1,0,1,NULL,10752.0000,1,1765,0),(3270,1228,'Zainou \'Gypsy\' Signature Analysis SA-706','A neural interface upgrade that boosts the pilot\'s skill at operating targeting systems.\r\r\n\r\r\n6% bonus to ships scan resolution.',0,1,0,1,NULL,10752.0000,1,1765,0),(3271,740,'Zainou \'Gypsy\' Electronic Warfare EW-902','A neural interface upgrade that boosts the pilot\'s skill at electronic warfare.\r\r\n\r\r\n2% reduction in ECM and ECM Burst module capacitor need.',0,1,0,1,NULL,200000.0000,1,1513,0),(3272,740,'Zainou \'Gypsy\' Electronic Warfare EW-904','A neural interface upgrade that boosts the pilot\'s skill at electronic warfare.\r\r\n\r\r\n4% reduction in ECM and ECM Burst module capacitor need.',0,1,0,1,NULL,200000.0000,1,1513,0),(3273,740,'Zainou \'Gypsy\' Electronic Warfare EW-906','A neural interface upgrade that boosts the pilot\'s skill at electronic warfare.\r\r\n\r\r\n6% reduction in ECM and ECM Burst module capacitor need.',0,1,0,1,NULL,200000.0000,1,1513,0),(3274,1228,'Zainou \'Gypsy\' Long Range Targeting LT-802','A neural interface upgrade that boosts the pilot\'s skill at long range targeting.\r\r\n\r\r\n2% bonus to max targeting range.',0,1,0,1,NULL,21504.0000,1,1766,0),(3275,1228,'Zainou \'Gypsy\' Long Range Targeting LT-804','A neural interface upgrade that boosts the pilot\'s skill at long range targeting.\r\r\n\r\r\n4% bonus to max targeting range.',0,1,0,1,NULL,21504.0000,1,1766,0),(3276,1228,'Zainou \'Gypsy\' Long Range Targeting LT-806','A neural interface upgrade that boosts the pilot\'s skill at long range targeting.\r\r\n\r\r\n6% bonus to max targeting range.',0,1,0,1,NULL,21504.0000,1,1766,0),(3277,740,'Zainou \'Gypsy\' Propulsion Jamming PJ-802','A neural interface upgrade that boosts the pilot\'s skill at propulsion jamming.\r\r\n\r\r\n2% reduction in capacitor need for modules requiring Propulsion Jamming skill.',0,1,0,1,NULL,200000.0000,1,1512,0),(3278,740,'Zainou \'Gypsy\' Propulsion Jamming PJ-804','A neural interface upgrade that boosts the pilot\'s skill at propulsion jamming.\r\r\n\r\r\n4% reduction in capacitor need for modules requiring Propulsion Jamming skill.',0,1,0,1,NULL,200000.0000,1,1512,0),(3279,740,'Zainou \'Gypsy\' Propulsion Jamming PJ-806','A neural interface upgrade that boosts the pilot\'s skill at propulsion jamming.\r\r\n\r\r\n6% reduction in capacitor need for modules requiring Propulsion Jamming skill.',0,1,0,1,NULL,200000.0000,1,1512,0),(3280,740,'Zainou \'Gypsy\' Sensor Linking SL-902','A neural interface upgrade that boosts the pilot\'s skill at sensor linking.\r\r\n\r\r\n2% reduction in capacitor need of modules requiring the Sensor Linking skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(3281,740,'Zainou \'Gypsy\' Sensor Linking SL-904','A neural interface upgrade that boosts the pilot\'s skill at sensor linking.\r\r\n\r\r\n4% reduction in capacitor need of modules requiring the Sensor Linking skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(3282,740,'Zainou \'Gypsy\' Sensor Linking SL-906','A neural interface upgrade that boosts the pilot\'s skill at sensor linking.\r\r\n\r\r\n6% reduction in capacitor need of modules requiring the Sensor Linking skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(3283,740,'Zainou \'Gypsy\' Weapon Disruption WD-902','A neural interface upgrade that boosts the pilot\'s skill at weapon disruption.\r\r\n\r\r\n2% reduction in capacitor need of modules requiring the Weapon Disruption skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(3284,740,'Zainou \'Gypsy\' Weapon Disruption WD-904','A neural interface upgrade that boosts the pilot\'s skill at weapon disruption.\r\r\n\r\r\n4% reduction in capacitor need of modules requiring the Weapon Disruption skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(3285,53,'Quad Light Beam Laser II','Uses four light laser focusing systems. Low powered, but makes up for it with a fast firing rate. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Aurora, Gleam.',1000,10,1,1,NULL,587430.0000,1,568,0),(3286,133,'Quad Light Beam Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3287,740,'Zainou \'Gypsy\' Weapon Disruption WD-906','A neural interface upgrade that boosts the pilot\'s skill at weapon disruption.\r\r\n\r\r\n6% reduction in capacitor need of modules requiring the Weapon Disruption skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(3288,740,'Zainou \'Gypsy\' Target Painting TG-902','A neural interface upgrade that boosts the pilot\'s skill at target painting.\r\r\n\r\r\n2% reduction in capacitor need of modules requiring the Target Painting skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(3289,740,'Zainou \'Gypsy\' Target Painting TG-904','A neural interface upgrade that boosts the pilot\'s skill at target painting.\r\r\n\r\r\n4% reduction in capacitor need of modules requiring the Target Painting skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(3290,740,'Zainou \'Gypsy\' Target Painting TG-906','A neural interface upgrade that boosts the pilot\'s skill at target painting.\r\r\n\r\r\n6% reduction in capacitor need of modules requiring the Target Painting skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(3291,738,'Inherent Implants \'Noble\' Repair Systems RS-602','A neural Interface upgrade that boosts the pilot\'s skill in operating armor/hull repair modules.\r\r\n\r\r\n2% reduction in repair systems duration.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,200000.0000,1,1514,0),(3292,738,'Inherent Implants \'Noble\' Repair Systems RS-604','A neural Interface upgrade that boosts the pilot\'s skill in operating armor/hull repair modules.\r\r\n\r\r\n4% reduction in repair systems duration.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,200000.0000,1,1514,0),(3293,12,'Medium Standard Container','A standard cargo container, used for common freight.',100000,325,390,1,NULL,12000.0000,1,1657,0),(3296,12,'Large Standard Container','A standard cargo container, used for common freight.',1000000,650,780,1,NULL,27000.0000,1,1657,0),(3297,12,'Small Standard Container','A standard cargo container, used for common freight.',10000,100,120,1,NULL,4400.0000,1,1657,0),(3299,738,'Inherent Implants \'Noble\' Repair Systems RS-606','A neural Interface upgrade that boosts the pilot\'s skill in operating armor/hull repair modules.\r\r\n\r\r\n6% reduction in repair systems duration.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,0.0000,1,1514,0),(3300,255,'Gunnery','Basic turret operation skill. 2% Bonus to weapon turrets\' rate of fire per skill level.',0,0.01,0,1,NULL,20000.0000,1,364,0),(3301,255,'Small Hybrid Turret','Operation of small hybrid turrets. 5% Bonus to small hybrid turret damage per level.',0,0.01,0,1,NULL,20000.0000,1,364,0),(3302,255,'Small Projectile Turret','Operation of small projectile turrets. 5% Bonus to small projectile turret damage per level.',0,0.01,0,1,NULL,20000.0000,1,364,0),(3303,255,'Small Energy Turret','Operation of small energy turrets. 5% Bonus to small energy turret damage per level.',0,0.01,0,1,NULL,20000.0000,1,364,0),(3304,255,'Medium Hybrid Turret','Operation of medium hybrid turrets. 5% Bonus to medium hybrid turret damage per level.',0,0.01,0,1,NULL,100000.0000,1,364,0),(3305,255,'Medium Projectile Turret','Operation of medium projectile turrets. 5% Bonus to medium projectile turret damage per level.',0,0.01,0,1,NULL,100000.0000,1,364,0),(3306,255,'Medium Energy Turret','Operation of medium energy turret. 5% Bonus to medium energy turret damage per level.',0,0.01,0,1,NULL,100000.0000,1,364,0),(3307,255,'Large Hybrid Turret','Operation of large hybrid turret. 5% Bonus to large hybrid turret damage per level.',0,0.01,0,1,NULL,2000000.0000,1,364,0),(3308,255,'Large Projectile Turret','Operation of large projectile turret. 5% Bonus to large projectile turret damage per level.',0,0.01,0,1,NULL,2000000.0000,1,364,0),(3309,255,'Large Energy Turret','Operation of large energy turrets. 5% Bonus to large energy turret damage per level.',0,0.01,0,1,NULL,2000000.0000,1,364,0),(3310,255,'Rapid Firing','Skill at the rapid discharge of weapon turrets. 4% bonus per skill level to weapon turret rate of fire.',0,0.01,0,1,NULL,40000.0000,1,364,0),(3311,255,'Sharpshooter','Skill at long-range weapon turret firing. 5% bonus to weapon turret optimal range per skill level.',0,0.01,0,1,NULL,80000.0000,1,364,0),(3312,255,'Motion Prediction','Improved ability at hitting moving targets. 5% bonus per skill level to weapon turret tracking speeds.',0,0.01,0,1,NULL,60000.0000,1,364,0),(3315,255,'Surgical Strike','Knowledge of spaceships\' structural weaknesses. 3% bonus per skill level to the damage of all weapon turrets.',0,0.01,0,1,NULL,1000000.0000,1,364,0),(3316,255,'Controlled Bursts','Allows better control over the capacitor use of weapon turrets. 5% reduction in capacitor need of weapon turrets per skill level.',0,0.01,0,1,NULL,70000.0000,1,364,0),(3317,255,'Trajectory Analysis','Advanced understanding of zero-G physics. 5% bonus per skill level to weapon turret accuracy falloff.',0,0.01,0,1,NULL,100000.0000,1,364,0),(3318,1216,'Weapon Upgrades','Knowledge of gunnery computer systems, including the use of weapon upgrade modules. 5% reduction per skill level in the CPU needs of weapon turrets, launchers and smartbombs.',0,0.01,0,1,NULL,80000.0000,1,368,0),(3319,256,'Missile Launcher Operation','Basic operation of missile launcher systems. 2% Bonus to missile launcher rate of fire per skill level.',0,0.01,0,1,NULL,20000.0000,1,373,0),(3320,256,'Rockets','Skill with small short range missiles. Special: 5% bonus to rocket damage per skill level.',0,0.01,0,1,NULL,10000.0000,1,373,0),(3321,256,'Light Missiles','Skill with manually targeted missiles. 5% Bonus to light missile damage per skill level.',0,0.01,0,1,NULL,20000.0000,1,373,0),(3322,256,'Auto-Targeting Missiles','Skill with auto-targeting missiles. Special: 5% bonus to Auto-Targeting Missiles(light, heavy and cruise) damage per skill level.',0,0.01,0,1,NULL,25000.0000,1,373,0),(3323,256,'Defender Missiles','Skill with anti-missile missiles. Special: 5% bonus to defender missile max velocity per skill level.',0,0.01,0,1,NULL,30000.0000,1,373,0),(3324,256,'Heavy Missiles','Skill with heavy missiles. Special: 5% bonus to heavy missile damage per skill level.',0,0.01,0,1,NULL,100000.0000,1,373,0),(3325,256,'Torpedoes','Skill at the handling and firing of torpedoes. 5% bonus to torpedo damage per skill level.',0,0.01,0,1,NULL,400000.0000,1,373,0),(3326,256,'Cruise Missiles','Skill at the handling and firing of very large guided missiles. 5% bonus to cruise missile damage per skill level.',0,0.01,0,1,NULL,350000.0000,1,373,0),(3327,257,'Spaceship Command','The basic operation of spaceships. 2% improved ship agility for all ships per skill level.',0,0.01,0,1,NULL,20000.0000,1,377,0),(3328,257,'Gallente Frigate','Skill at operating Gallente frigates.',0,0.01,0,1,8,40000.0000,1,377,0),(3329,257,'Minmatar Frigate','Skill at operating Minmatar frigates.',0,0.01,0,1,2,40000.0000,1,377,0),(3330,257,'Caldari Frigate','Skill at operating Caldari frigates.',0,0.01,0,1,1,40000.0000,1,377,0),(3331,257,'Amarr Frigate','Skill at operating Amarr frigates.',0,0.01,0,1,4,40000.0000,1,377,0),(3332,257,'Gallente Cruiser','Skill at operating Gallente cruisers.',0,0.01,0,1,8,500000.0000,1,377,0),(3333,257,'Minmatar Cruiser','Skill at operating Minmatar cruisers.',0,0.01,0,1,2,500000.0000,1,377,0),(3334,257,'Caldari Cruiser','Skill at operating Caldari cruisers.',0,0.01,0,1,1,500000.0000,1,377,0),(3335,257,'Amarr Cruiser','Skill at operating Amarr cruisers.',0,0.01,0,1,4,500000.0000,1,377,0),(3336,257,'Gallente Battleship','Skill at operating Gallente battleships.',0,0.01,0,1,8,4000000.0000,1,377,0),(3337,257,'Minmatar Battleship','Skill at operating Minmatar battleships.',0,0.01,0,1,2,4000000.0000,1,377,0),(3338,257,'Caldari Battleship','Skill at operating Caldari battleships.',0,0.01,0,1,1,4000000.0000,1,377,0),(3339,257,'Amarr Battleship','Skill at operating Amarr battleships.',0,0.01,0,1,4,4000000.0000,1,377,0),(3340,257,'Gallente Industrial','Skill at operating Gallente industrial ships.',0,0.01,0,1,8,300000.0000,1,377,0),(3341,257,'Minmatar Industrial','Skill at operating Minmatar industrial ships.',0,0.01,0,1,2,300000.0000,1,377,0),(3342,257,'Caldari Industrial','Skill at operating Caldari industrial ships.',0,0.01,0,1,1,300000.0000,1,377,0),(3343,257,'Amarr Industrial','Skill at operating Amarr industrial ships.',0,0.01,0,1,4,300000.0000,1,377,0),(3344,257,'Gallente Titan','Skill at operating Gallente titans. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,8,5500000000.0000,1,377,0),(3345,257,'Minmatar Titan','Skill at operating Minmatar titans. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,2,5500000000.0000,1,377,0),(3346,257,'Caldari Titan','Skill at operating Caldari titans. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,1,5500000000.0000,1,377,0),(3347,257,'Amarr Titan','Skill at operating Amarr titans. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5500000000.0000,1,377,0),(3348,258,'Leadership','Allows command of a squadron. Increases maximum squadron size by 2 members per skill level, up to a maximum of 10 members.\r\r\n\r\r\nGrants a 2% bonus to fleet members\' targeting speed per skill level. Only the bonus of the fleet member with the highest level in this skill is used.\r\r\n<br>Note: The fleet bonus only works if you are the assigned fleet booster and fleet members are in space within the same solar system.',0,0.01,0,1,NULL,20000.0000,1,370,0),(3349,258,'Skirmish Warfare','Basic proficiency at coordinating hit-and-run warfare. Grants a 2% bonus to fleet members\' agility per skill level. <br>Note: The fleet bonus only works if you are the assigned fleet booster and fleet members are in space within the same solar system.',0,0.01,0,1,NULL,75000.0000,1,370,0),(3350,258,'Siege Warfare','Basic proficiency at coordinating a fleet\'s defenses. Grants a 2% bonus to fleet members\' shield capacity per skill level. <br>Note: The fleet bonus only works if you are the assigned fleet booster and fleet members are in space within the same solar system.',0,0.01,0,1,NULL,100000.0000,1,370,0),(3351,258,'Siege Warfare Specialist','Advanced proficiency at siege warfare. Boosts the effectiveness of siege warfare link modules by 20% per skill level.',0,0.01,0,1,NULL,400000.0000,1,370,0),(3352,258,'Information Warfare Specialist','Advanced proficiency at information warfare. Boosts the effectiveness of information warfare link modules by 20% per skill level.',0,0.01,0,1,NULL,400000.0000,1,370,0),(3354,258,'Warfare Link Specialist','Improved fleet leadership. Boosts effectiveness of all warfare link and mining foreman modules by 10% per level.',0,0.01,0,1,NULL,2500000.0000,1,370,0),(3355,278,'Social','Skill at social interaction. 5% bonus per level to NPC agent, corporation and faction standing increase.',0,0.01,0,1,NULL,20000.0000,1,376,0),(3356,278,'Negotiation','Skill at agent negotiation. 5% additional pay per skill level for agent missions.',0,0.01,0,1,NULL,60000.0000,1,376,0),(3357,278,'Diplomacy','Skill at interacting with hostile Agents in order to de-escalate tense situations as demonstrated by some of the finest diplomats in New Eden. 4% Modifier per level to effective standing towards hostile Agents. Not cumulative with Connections or Criminal Connections.',0,0.01,0,1,NULL,180000.0000,1,376,0),(3358,278,'Fast Talk','Skill at interacting with Concord. 5% Bonus to effective security rating increase.',0,0.01,0,1,NULL,100000.0000,1,376,0),(3359,278,'Connections','Skill at interacting with friendly NPCs. 4% Modifier to effective standing from friendly NPC Corporations and Factions per level. Not cumulative with Diplomacy or Criminal Connections.',0,0.01,0,1,NULL,200000.0000,1,376,0),(3361,278,'Criminal Connections','Skill at interacting with friendly criminal NPCs. 4% Modifier per level to effective standing towards NPCs with low Concord standing. Not cumulative with Diplomacy or Connections.',0,0.01,0,1,NULL,200000.0000,1,376,0),(3362,278,'DED Connections','Skill at dealing with Concord Department and negotiating bounties \r\r\n\r\r\nBonus fee of 1,500 isk per pirate head per level of the skill',0,0.01,0,1,NULL,420000.0000,0,NULL,0),(3363,266,'Corporation Management','Basic corporation operation. +20 corporation members allowed per level.\r\r\n\r\r\nNotice:  the CEO must update his corporation through the corporation user interface before the skill takes effect',0,0.01,0,1,NULL,20000.0000,1,365,0),(3364,266,'Station Management','The operation and management of spacestations. ',0,0.01,0,1,NULL,200000.0000,0,NULL,0),(3365,266,'Starbase Management','Skill at setting up Starbases',0,0.01,0,1,NULL,200000.0000,0,NULL,0),(3366,266,'Factory Management','Skill at factory operation.',0,0.01,0,1,NULL,75000.0000,0,NULL,0),(3367,266,'Refinery Management','Skill at managing station refineries. Increases mineral yield of refinery by 5% if acting as station manager.',0,0.01,0,1,NULL,75000.0000,0,NULL,0),(3368,266,'Diplomatic Relations','Skill at negotiating ally fees with Concord. Reduces cost to hire allies in wars by 5% per level.',0,0.01,0,1,NULL,40000.0000,1,365,0),(3369,266,'CFO Training','Skill at managing corp finances. 5% discount on all fees at non-hostile NPC station if acting as CFO of a corp. ',0,0.01,0,1,NULL,100000.0000,0,NULL,0),(3370,266,'Chief Science Officer','Skill at managing corp research. ',0,0.01,0,1,NULL,100000.0000,0,NULL,0),(3371,266,'Public Relations','Skill at managing corporate offices. ',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(3372,266,'Intelligence Analyst','Skill at directing a corporation\'s espionage division.',0,0.01,0,1,NULL,2000000.0000,0,NULL,0),(3373,266,'Starbase Defense Management','Skill at using starbase weapon systems. Allows control of one array per level. Arrays must be placed outside of the forcefield to be controlled. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,1000000.0000,1,365,0),(3374,267,'\'Learning\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,35000.0000,0,NULL,0),(3375,267,'\'Iron Will\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(3376,267,'\'Empathy\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(3377,267,'\'Analytical Mind\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(3378,267,'\'Instant Recall\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(3379,267,'\'Spatial Awareness\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(3380,268,'Industry','Allows basic operation of factories. 4% reduction in manufacturing time per skill level.',0,0.01,0,1,NULL,20000.0000,1,369,0),(3381,268,'Amarr Tech','Grants +5% reduction in Amarr equipment production time.',0,0.01,0,1,NULL,100000.0000,0,NULL,0),(3382,268,'Caldari Tech','Grants +5% reduction in Caldari equipment production time.',0,0.01,0,1,NULL,100000.0000,0,NULL,0),(3383,268,'Gallente Tech','Grants +5% reduction in Gallente equipment production time.',0,0.01,0,1,NULL,100000.0000,0,NULL,0),(3384,268,'Minmatar Tech','Grants +5% reduction in Minmatar equipment production time.',0,0.01,0,1,NULL,100000.0000,0,NULL,0),(3385,1218,'Reprocessing','Skill at using reprocessing facilities in station, outposts and starbases to break ores and ice down into refined products.\r\r\n\r\r\n3% bonus to ore and ice reprocessing yield per skill level.',0,0.01,0,1,NULL,50000.0000,1,1323,0),(3386,1218,'Mining','Skill at using mining lasers. 5% bonus to mining turret yield per skill level.',0,0.01,0,1,NULL,20000.0000,1,1323,0),(3387,268,'Mass Production','Allows the operation of multiple factories. Ability to run 1 additional manufacturing job per level.',0,0.01,0,1,NULL,150000.0000,1,369,0),(3388,268,'Advanced Industry','Skill at efficiently using industrial facilities. 3% reduction in all manufacturing and research times per skill level.',0,0.01,0,1,NULL,250000.0000,1,369,0),(3389,1218,'Reprocessing Efficiency','Advanced skill at using reprocessing facilities in station, outposts and starbases to break ores and ice down into refined products.\r\r\n\r\r\n2% bonus to ore and ice reprocessing yield per skill level.',0,0.01,0,1,NULL,280000.0000,1,1323,0),(3390,1218,'Mobile Refinery Operation',' ',0,0.01,0,1,NULL,700000.0000,0,NULL,0),(3391,268,'Mobile Factory Operation',' ',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(3392,1210,'Mechanics','Skill at maintaining the mechanical components and structural integrity of a spaceship. 5% bonus to structure hit points per skill level.',0,0.01,0,1,NULL,20000.0000,1,1745,0),(3393,1210,'Repair Systems','Operation of armor/hull repair modules. 5% reduction in repair systems duration per skill level.\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,0.01,0,1,NULL,30000.0000,1,1745,0),(3394,1210,'Hull Upgrades','Skill at maintaining your ship\'s armor and installing hull upgrades like expanded cargoholds and inertial stabilizers. Grants a 5% bonus to armor hit points per skill level.',0,0.01,0,1,NULL,60000.0000,1,1745,0),(3395,268,'Advanced Small Ship Construction','Skill required for the manufacturing of advanced frigates and destroyers. 1% reduction in manufacturing time for all items requiring Advanced Small Ship Construction per level.',0,0.01,0,1,4,80000.0000,1,369,0),(3396,268,'Advanced Industrial Ship Construction','Skill required for the manufacturing of advanced industrial ships. 1% reduction in manufacturing time for all items requiring Advanced Industrial Ship Construction per level.',0,0.01,0,1,4,2000000.0000,1,369,0),(3397,268,'Advanced Medium Ship Construction','Skill required for the manufacturing of advanced cruisers and battlecruisers. 1% reduction in manufacturing time for all items requiring Advanced Medium Ship Construction per level.',0,0.01,0,1,4,1000000.0000,1,369,0),(3398,268,'Advanced Large Ship Construction','Skill required for the manufacturing of advanced battleships. 1% reduction in manufacturing time for all items requiring Advanced Large Ship Construction per level.',0,0.01,0,1,4,25000000.0000,1,369,0),(3400,268,'Outpost Construction','Skill required for the manufacturing of player controllable outposts.',0,0.01,0,1,NULL,100000000.0000,1,369,0),(3402,270,'Science','Basic understanding of scientific principles. 5% Bonus to blueprint copying speed per level.',0,0.01,0,1,NULL,20000.0000,1,375,0),(3403,270,'Research','Skill at researching more efficient production methods. 5% bonus to blueprint manufacturing time research per skill level.',0,0.01,0,1,NULL,300000.0000,1,375,0),(3404,267,'Genetic Engineering','This is part of a set of debunked CONCORD alternative medicine books that used to be very popular among capsuleers until independent researchers proved conclusively that diluting genetic material in water did not give it any healing properties.',0,0.01,0,1,NULL,50000.0000,1,NULL,0),(3405,1220,'Biology','The science of life and of living organisms, and how chemicals affect them. 20% Bonus to attribute booster duration per skill level.',0,0.01,0,1,NULL,25000.0000,1,1746,0),(3406,270,'Laboratory Operation','Allows basic operation of research facilities. Ability to run 1 additional research job per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,300000.0000,1,375,0),(3408,270,'Sleeper Encryption Methods','Understanding of the techniques and methods to reverse engineer Sleeper technology.',0,0.01,0,1,NULL,15000000.0000,1,375,0),(3409,270,'Metallurgy','Advanced knowledge of mineral composition. 5% Bonus to material efficiency research speed per skill level.',0,0.01,0,1,NULL,350000.0000,1,375,0),(3410,1218,'Astrogeology','Skill at analyzing the content of celestial objects with the intent of mining them. 5% bonus to mining turret yield per skill level.',0,0.01,0,1,NULL,450000.0000,1,1323,0),(3411,1220,'Cybernetics','The science of interfacing biological and machine components. Allows the use of cybernetic implants.',0,0.01,0,1,NULL,75000.0000,1,1746,0),(3412,1217,'Astrometrics','Skill at operating long range scanners.\r\r\n\r\r\n+5% scan strength per level.\r\r\n\r\r\n-5% max scan deviation per level.\r\r\n\r\r\n-5% scan probe scan time per level.',0,0.01,0,1,NULL,450000.0000,1,1110,0),(3413,1216,'Power Grid Management','Basic understanding of spaceship energy grid systems. 5% Bonus to ship\'s powergrid output per skill level.',0,0.01,0,1,NULL,20000.0000,1,368,0),(3414,738,'Inherent Implants \'Noble\' Remote Armor Repair Systems RA-702','A neural Interface upgrade that boosts the pilot\'s skill in the operation of remote armor repair systems.\r\r\n\r\r\n2% reduced capacitor need for remote armor repair system modules.',0,1,0,1,NULL,0.0000,1,1515,0),(3415,738,'Inherent Implants \'Noble\' Remote Armor Repair Systems RA-704','A neural Interface upgrade that boosts the pilot\'s skill in the operation of remote armor repair systems.\r\r\n\r\r\n4% reduced capacitor need for remote armor repair system modules.',0,1,0,1,NULL,0.0000,1,1515,0),(3416,1209,'Shield Operation','Skill at operating a spaceship\'s shield systems, including the use of shield boosters and other basic shield modules. 5% reduction in shield recharge time per skill level.',0,0.01,0,1,NULL,35000.0000,1,1747,0),(3417,1216,'Capacitor Systems Operation','Skill at operating your ship\'s capacitor, including the use of capacitor boosters and other basic energy modules. 5% reduction in capacitor recharge time per skill level.',0,0.01,0,1,NULL,40000.0000,1,368,0),(3418,1216,'Capacitor Management','Skill at regulating your ship\'s overall energy capacity. 5% bonus to capacitor capacity per skill level.',0,0.01,0,1,NULL,170000.0000,1,368,0),(3419,1209,'Shield Management','Skill at regulating a spaceship\'s shield systems. 5% bonus to shield capacity per skill level.',0,0.01,0,1,NULL,170000.0000,1,1747,0),(3420,1209,'Tactical Shield Manipulation','Skill at preventing damage from penetrating the shield, including the use of shield hardeners and other advanced shield modules. Reduces the chance of damage penetrating the shield when it falls below 25% by 5% per skill level, with 0% chance at level 5.',0,0.01,0,1,NULL,210000.0000,1,1747,0),(3421,1216,'Energy Pulse Weapons','Skill at using smartbombs. 5% decrease in smartbomb duration per skill level.',0,0.01,0,1,NULL,130000.0000,1,368,0),(3422,1209,'Shield Emission Systems','Operation of shield transfer array and other shield emission systems. 5% reduced capacitor need for shield emission system modules per skill level.',0,0.01,0,1,NULL,80000.0000,1,1747,0),(3423,1216,'Capacitor Emission Systems','Operation of energy transfer array and other energy emission systems. 5% reduced capacitor need of energy emission weapons per skill level.',0,0.01,0,1,NULL,75000.0000,1,368,0),(3424,1216,'Energy Grid Upgrades','Skill at installing power upgrades e.g. capacitor battery and power diagnostic units. 5% reduction in CPU needs of modules requiring Energy Grid Upgrades per skill level.',0,0.01,0,1,NULL,79000.0000,1,368,0),(3425,1209,'Shield Upgrades','Skill at installing shield upgrades e.g. shield extenders and shield rechargers. 5% reduction in shield upgrade powergrid needs.',0,0.01,0,1,NULL,84000.0000,1,1747,0),(3426,1216,'CPU Management','Basic understanding of spaceship sensory and computer systems. 5% Bonus to ship CPU output per skill level.',0,0.01,0,1,NULL,20000.0000,1,368,0),(3427,272,'Electronic Warfare','Operation of ECM jamming systems. 5% less capacitor need for ECM and ECM Burst systems per skill level.\r\r\n\r\r\nNote: Does not affect capital class modules.',0,0.01,0,1,NULL,120000.0000,1,367,0),(3428,1213,'Long Range Targeting','Skill at long range targeting. 5% Bonus to targeting range per skill level.',0,0.01,0,1,NULL,88000.0000,1,1748,0),(3429,1213,'Target Management','Skill at targeting multiple targets. +1 extra target per skill level, up to the ship\'s maximum allowed number of targets locked.',0,0.01,0,1,NULL,100000.0000,1,1748,0),(3430,1213,'Advanced Target Management','Skill at targeting multiple targets. +1 extra target per skill level, up to the ship\'s maximum allowed number of targets locked.',0,0.01,0,1,NULL,500000.0000,1,1748,0),(3431,1213,'Signature Analysis','Skill at operating Targeting systems. 5% improved targeting speed per skill level.',0,0.01,0,1,NULL,75000.0000,1,1748,0),(3432,1216,'Electronics Upgrades','Skill at installing electronic upgrades, such as signal amplifiers, co-processors and backup sensor arrays. 5% reduction of CPU needs for all modules requiring Electronics Upgrades per skill level.',0,0.01,0,1,NULL,100000.0000,1,368,0),(3433,272,'Sensor Linking','Skill at using remote sensor booster/damper. 5% less capacitor need for sensor link per skill level.',0,0.01,0,1,NULL,100000.0000,1,367,0),(3434,272,'Weapon Disruption','Skill at using remote weapon disruptors. 5% less capacitor need for weapon disruptors per skill level.',0,0.01,0,1,NULL,80000.0000,1,367,0),(3435,272,'Propulsion Jamming','Skill at using propulsion/warpdrive jammers. 5% Reduction to Warp Scrambler, Warp Disruptor, and Stasis Web capacitor need per skill level. ',0,0.01,0,1,NULL,150000.0000,1,367,0),(3436,273,'Drones','Skill at remote controlling drones. Can operate 1 drone per skill level.',0,0.01,0,1,NULL,20000.0000,1,366,0),(3437,273,'Drone Avionics','Skill at control range for all drones.\r\r\n\r\r\nBonus: drone control range increased by 5000 meters per skill level.',0,0.01,0,1,NULL,40000.0000,1,366,0),(3438,273,'Mining Drone Operation','Skill at controlling mining drones. 5% bonus to mining drone yield per skill level.',0,0.01,0,1,NULL,40000.0000,1,366,0),(3439,273,'Repair Drone Operation','Allows operation of logistic drones. 5% increased repair amount per level.',0,0.01,0,1,NULL,200000.0000,1,366,0),(3440,273,'Salvage Drone Operation','Skill at controlling salvage drones. 2% increased salvage chance per level.',0,0.01,0,1,NULL,220000.0000,1,366,0),(3441,273,'Heavy Drone Operation','Skill at controlling heavy combat drones. 5% bonus to heavy drone damage per level.',0,0.01,0,1,NULL,380000.0000,1,366,0),(3442,273,'Drone Interfacing','Allows a captain to better maintain his drones. <BR><BR>10% bonus to drone damage and drone mining yield per level.',0,0.01,0,1,NULL,500000.0000,1,366,0),(3443,274,'Trade','Knowledge of the market and skill at manipulating it. Active buy/sell order limit increased by 4 per level of skill.',0,0.01,0,1,NULL,20000.0000,1,378,0),(3444,274,'Retail','Ability to organize and manage market operations.  Each level raises the limit of active orders by 8. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,100000.0000,1,378,0),(3445,274,'Black Market Trading','Skill at forging cargo manifests and disguising contraband cargo. From a base of 90%, each level of skill reduces chance of contraband detection by 10%.\r\r\n',0,0.01,0,1,NULL,70000.0000,0,NULL,0),(3446,274,'Broker Relations','Proficiency at driving down market-related costs. Each level of skill grants a 5% reduction in the costs associated with setting up a market order, which usually come to 1% of the order\'s total value. This can be further influenced by the player\'s standing towards the owner of the station where the order is entered.',0,0.01,0,1,NULL,100000.0000,1,378,0),(3447,274,'Visibility','Skill at acquiring products remotely. Each level of skill increases the range your remote buy orders are effective to from their origin station. Level 1 allows for the placing of remote buy orders with a range limited to the same solar system, Level 2 extends that range to systems within 5 jumps, and each subsequent level then doubles it. Level 5 allows for a full regional range.\r\r\n\r\r\nNote: Only remotely placed buy orders (using Procurement) require this skill to alter the range.  Any range can be set on a local buy order with no skill.',0,0.01,0,1,NULL,7500000.0000,1,378,0),(3448,274,'Smuggling','Proficiency at laying low and avoiding unwanted attention. From a base of 90%, each level of skill reduces by 10% the likelihood of being scanned while transporting contraband.',0,0.01,0,1,NULL,100000.0000,0,NULL,0),(3449,275,'Navigation','Skill at regulating the power output of ship thrusters. 5% bonus to sub-warp ship velocity per skill level.',0,0.01,0,1,NULL,20000.0000,1,374,0),(3450,275,'Afterburner','Skill at using afterburners. 5% reduction to Afterburner duration and 10% reduction in Afterburner capacitor use per skill level.',0,0.01,0,1,NULL,22500.0000,1,374,0),(3451,275,'Fuel Conservation','Skill at improved control over afterburner energy consumption. 10% reduction in afterburner capacitor needs per skill level.',0,0.01,0,1,NULL,30000.0000,1,374,0),(3452,275,'Acceleration Control','Skill at efficiently using Afterburners and MicroWarpdrives. 5% Bonus to Afterburner and MicroWarpdrive speed boost per skill level.',0,0.01,0,1,NULL,40000.0000,1,374,0),(3453,275,'Evasive Maneuvering','Improved skill at efficiently turning and accelerating a spaceship. 5% improved ship agility for all ships per skill level.',0,0.01,0,1,NULL,25000.0000,1,374,0),(3454,275,'High Speed Maneuvering','Skill at using MicroWarpdrives. 5% reduction in MicroWarpdrive capacitor usage per skill level.',0,0.01,0,1,NULL,340000.0000,1,374,0),(3455,275,'Warp Drive Operation','Skill at managing warp drive efficiency. 10% reduction in capacitor need of initiating warp per skill level.',0,0.01,0,1,NULL,30000.0000,1,374,0),(3456,275,'Jump Drive Operation','Skill at using Jump Drives. 5% reduction in capacitor need of initiating a jump per skill level.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,10000000.0000,1,374,0),(3457,279,'Test LCO Drone',' ',100000,60,1200,1,NULL,0.0000,0,NULL,0),(3465,340,'Large Secure Container','This large container is fitted with a password-protected security lock.\r\r\n\r\r\nNote: the container must be anchored to enable password functionality. Anchoring containers is only possible in solar systems with a security status of 0.7 or lower.',1000000,650,780,1,NULL,31000.0000,1,1651,0),(3466,340,'Medium Secure Container','This medium container is fitted with a password-protected security lock.\r\r\n\r\r\nNote: the container must be anchored to enable password functionality. Anchoring containers is only possible in solar systems with a security status of 0.7 or lower.',100000,325,390,1,NULL,14500.0000,1,1651,0),(3467,340,'Small Secure Container','This small container is fitted with a password-protected security lock.\r\r\n\r\r\nNote: the container must be anchored to enable password functionality. Anchoring containers is only possible in solar systems with a security status of 0.7 or lower.',10000,100,120,1,NULL,5000.0000,1,1651,0),(3468,649,'Plastic Wrap',' ',0.01,0.01,0.01,1,NULL,0.0000,0,NULL,0),(3469,285,'Basic Co-Processor','Increases CPU output.',0,5,0,1,NULL,6998.0000,1,676,0),(3470,738,'Inherent Implants \'Noble\' Remote Armor Repair Systems RA-706','A neural Interface upgrade that boosts the pilot\'s skill in the operation of remote armor repair systems.\r\r\n\r\r\n6% reduced capacitor need for remote armor repair system modules.',0,1,0,1,NULL,0.0000,1,1515,0),(3471,738,'Inherent Implants \'Noble\' Mechanic MC-802','A neural Interface upgrade that boosts the pilot\'s skill at maintaining the mechanical components and structural integrity of a spaceship.\r\r\n\r\r\n2% bonus to hull hp.',0,1,0,1,NULL,200000.0000,1,1516,0),(3472,61,'X-Large Capacitor Battery II','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,20,0,1,NULL,810776.0000,0,NULL,0),(3473,141,'X-Large Capacitor Battery II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(3474,738,'Inherent Implants \'Noble\' Mechanic MC-804','A neural Interface upgrade that boosts the pilot\'s skill at maintaining the mechanical components and structural integrity of a spaceship.\r\r\n\r\r\n4% bonus to hull hp.',0,1,0,1,NULL,200000.0000,1,1516,0),(3475,738,'Inherent Implants \'Noble\' Mechanic MC-806','A neural Interface upgrade that boosts the pilot\'s skill at maintaining the mechanical components and structural integrity of a spaceship.\r\r\n\r\r\n6% bonus to hull hp.',0,1,0,1,NULL,0.0000,1,1516,0),(3476,738,'Inherent Implants \'Noble\' Repair Proficiency RP-902','A neural Interface upgrade for analyzing and repairing starship damage.\r\r\n\r\r\n2% bonus to repair system repair amount.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,0.0000,1,1517,0),(3477,738,'Inherent Implants \'Noble\' Repair Proficiency RP-904','A neural Interface upgrade for analyzing and repairing starship damage.\r\r\n\r\r\n4% bonus to repair system repair amount.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,0.0000,1,1517,0),(3478,738,'Inherent Implants \'Noble\' Repair Proficiency RP-906','A neural Interface upgrade for analyzing and repairing starship damage.\r\r\n\r\r\n6% bonus to repair system repair amount.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,0.0000,1,1517,0),(3479,738,'Inherent Implants \'Noble\' Hull Upgrades HG-1002','A neural Interface upgrade that boosts the pilot\'s skill at maintaining their ship\'s midlevel defenses.\r\r\n\r\r\n2% bonus to armor hit points.',0,1,0,1,NULL,200000.0000,1,1518,0),(3480,61,'Micro Capacitor Battery II','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,2.5,0,1,NULL,37616.0000,1,702,0),(3481,738,'Inherent Implants \'Noble\' Hull Upgrades HG-1004','A neural Interface upgrade that boosts the pilot\'s skill at maintaining their ship\'s midlevel defenses.\r\r\n\r\r\n4% bonus to armor hit points.',0,1,0,1,NULL,200000.0000,1,1518,0),(3482,738,'Inherent Implants \'Noble\' Hull Upgrades HG-1006','A neural Interface upgrade that boosts the pilot\'s skill at maintaining their ship\'s midlevel defenses.\r\r\n\r\r\n6% bonus to armor hit points.',0,1,0,1,NULL,0.0000,1,1518,0),(3483,283,'Captured Civilians','There are countless numbers of civilians living out on independent colonies and minor stations. Although life in such remote areas is often harsh, the inhabitants of these stations generally live a quiet, trouble-free life. This is a fact well understood by Sansha leadership, who prey upon these same people, exploiting the sad fact that their absence will not be easily noticed.',1000,5,0,1,NULL,0.0000,1,NULL,0),(3484,1056,'Citizen Astur','Known only as  Citizen Astur,  this pilot came to prominence during the later stages of Nation\'s planetary abductions. Her well-articulated arguments and insightful propaganda quickly identified her as something of a spokesperson for Sansha\'s Nation. Although early intelligence indicated that her role within the Nation was purely as a propagandist, her more recent sightings on the battlefield have demonstrated that she is willing to fight for the ideas she so dangerously represents.',10010000,100100,235,1,4,0.0000,0,NULL,0),(3485,1056,'Slave 32152','Thought to have been a member of Sansha\'s Nation for many decades, the individual who identifies as  Slave 32152  is known for her unwavering commitment to Sansha\'s cause. Few are indoctrinated to the same degree as her, and it was usually her and not Citizen Astur (the main Nation propagandist) who caught the imagination of supporters and news media alike.',10010000,100100,235,1,4,0.0000,0,NULL,0),(3486,1056,'Slave Tama01','Once an inhabitant of Tama V, the individual known as  Slave Tama01  was abducted and, almost overnight, turned into a capsuleer capable of piloting a Wvyern-class Supercarrier. Shortly after this drastic transformation, she returned to Tama V under the flag of the Nation, standing as an example of Sansha\'s plan for the people he was abducting. The message of that example, however, was repeatedly rebuked by the coalition of capsuleers that rallied against the invading Nation forces, as happened at the battle that took place above Tama V upon her return. Although her Wyvern was destroyed she was repeatedly sighted in a new one shortly afterwards, claiming in public comms that after joining Sansha\'s Nation she was now impossible to stop.',10010000,100100,235,1,4,0.0000,0,NULL,0),(3487,1056,'Slave Heavenbound02','Formerly a Federation citizen on the planet Vevelonel IV,  Slave Heavenbound02  represents a continuation of the Nation\'s agenda for growing its own capsuleer army. Shortly after she was taken, she reappeared in other systems coordinating planetary invasions from the helm of a capsule-piloted Thanatos. Heavenbound is the least emotionally stable of all the known capsuleers now serving the Nation, and was frequently undermined or distracted on the field of battle.',10010000,100100,235,1,4,0.0000,0,NULL,0),(3488,61,'Small Capacitor Battery II','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,5,0,1,NULL,179824.0000,1,703,0),(3489,141,'Small Capacitor Battery II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3490,1056,'Slave Endoma01','Sutola Endoma was formerly a CONCORD agent with a long and exemplary history within the organization. During the initial planetary invasions, she requested a transfer to the DED\'s counter-invasion taskforce, codenamed Ishaeka. Although her request was denied, Endoma quickly assumed various related responsibilities elsewhere. CONCORD reports clearly document numerous battles where Sutola\'s input was critical in the saving of countless lives. The incongruity of this behavior with her later defection to Sansha\'s Nation suggests a number of disturbing scenarios, all of which are still being investigated by the same secretive taskforce that she was rejected from joining.',10010000,100100,235,1,4,0.0000,0,NULL,0),(3491,306,'Sansha Communications Array','Dull, tedious treasure lies within.',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(3492,1053,'Sansha\'s Nation Commander','During the Sansha invasion of YC 112, over 15,000,000 civilians were abducted from their planetary homes. Some of these people were turned from ordinary citizens into capsuleers, re-appearing only days later in some of the largest and most powerful ships in the cluster. Those who did not become capsuleers were not left behind, however. <br><br>Corpses recovered from invading vessels suggested that everyone, regardless of their former life, was granted cloning access. Many would become crew members and engineers aboard the giant capsuleer-piloted vessels, but others chose, or were given, a different role in Nation. <br><br>Some abductees were enhanced in yet other ways. Farmers and librarians alike became military leaders with the acuity and intelligence to rival that of the empire\'s top brass.',2000000,20000,235,1,4,0.0000,0,NULL,0),(3493,920,'Incursion ship attributes effects Assault ',' ',1,20,0,250,NULL,0.0000,1,NULL,0),(3494,920,'Incursion ship attributes effects HQ',' ',1,20,0,250,NULL,0.0000,1,NULL,0),(3495,952,'Shield Transfer Control Tower','This control tower is responsible for coordinating and powering the shield defenses on nearby structures. Like many other neighboring facilities, the tower was once CONCORD property. Now it rests in the hands of Sansha pirates, who use it for their own unknown ends. CONCORD guards proprietary technologies fiercely; some valuable secrets of theirs are no doubt hidden inside these complexes, which are now under Sansha control. \r\r\n\r\r\nLocal CONCORD commanders have been instructed to coordinate capsuleer resistance against the Nation forces, and they have been granted hefty funds to help incentivize the recapture of lost industrial facilities.',100000,1150,10000000,1,NULL,0.0000,1,NULL,0),(3496,61,'Medium Capacitor Battery II','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,10,0,1,NULL,319624.0000,1,704,0),(3497,141,'Medium Capacitor Battery II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3498,306,'CONCORD MTAC Factory','This CONCORD factory has been commandeered by True Creations members and other members of Sansha\'s Nation. It is capable of producing a steady supply of basic MTAC chassis, which can then be modified in various ways. Each empire has its own methods of manufacturing these hulking industrial colossi, but CONCORD factories are known for producing the best.',10000,27500,7500,1,NULL,0.0000,0,NULL,0),(3499,319,'Sansha Starbase Control Tower','The Sansha Control Tower is an enhanced version of the Amarr control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(3500,319,'Reinforced Nation Outpost','This enormous mobile station stands as an example of the engineering excellence found within Nation\'s endless ranks, the upper part of which is filled with mechanical geniuses and masters of design. Virtually indestructible in its hardened state, the station has very few weaknesses and serves frighteningly well in its role as a mobile safe haven for Nation\'s military researchers and technicians.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(3501,314,'CONCORD MTAC','The Mechanized Torso-Actuated Chassis (MTAC) is used throughout the New Eden cluster for all types of industrial and military work. The robotic arms can be configured in countless ways, from hydraulics for heavy lifting to enormous weapon-mounted battlefield applications.',7500,7500,0,1,NULL,0.0000,1,NULL,0),(3502,952,'Nation Ore Refinery','This mobile ore refinery works in much the same way as standard capsuleer-issue technology. It should be possible to sabotage by placing volatile materials inside.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(3503,952,'Emergency Evacuation Freighter','This vessel has been reconfigured to act as temporary rallying point for any civilians who haven\'t yet been evacuated from the facility. Any civilians still caught in the line of crossfire should be returned here. ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(3504,61,'Large Capacitor Battery II','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,15,0,1,NULL,473764.0000,1,705,0),(3505,141,'Large Capacitor Battery II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3506,306,'Central Control Nexus','This nexus houses various personnel and components used to coordinate Sansha fleets. Although Nation s on-field commanders are highly capable leaders, they are often supported in various ways by a nearby control facility.',10000,27500,7500,1,NULL,0.0000,0,NULL,0),(3507,526,'Tactical Response Transmitter','This small device is used to transmit specific information and commands relating to fleet movements and tactical relocations. Due to the critical nature of such transmissions, Sansha forces have developed layered security measures for their use. In order for a TRT to override local forces, the transmitter must first be set to the correct frequencies and then physically relocated from a control nexus to a relay.',5000,7500,0,1,NULL,0.0000,1,NULL,0),(3508,952,'Sansha Control Relay','This large radio transmitter relays orders and information to Sansha fleets. Typically these orders come from a local commander, but other facilities such as a central control nexus are also capable of issuing limited tactical commands.',100000,100000000,5000000,1,NULL,0.0000,0,NULL,0),(3509,226,'Sansha Logistics Control Array','This array is responsible for determining friend or foe status for local remote logistics facilities. Although formidable, a capsuleer should be able to subvert the sophisticated electronics within.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(3510,226,'Sansha Remote Logistics Station','This station repairs local Sansha fleets as they come under fire. Although almost entirely self-contained, friend or foe identification is handled by the Logistics Control Arrays, which are separated from the station to minimize risk of unauthorized overrides.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(3511,1054,'Gang booster test NPC','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Vylade Dien)<br>\r\r\n<font color=yellow>Military Specifications:</font> Cruiser-class vessel. Primary roles are damage dealing and squad enhancement. Low microwarp velocity.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 100,000 civilian abductions from Vylade II. The Dien identifier suggests an oversight role amongst other cruiser-class prototypes, or alternatively, that it was created during the first phase of development. The nature of Nation\'s squad boosting technology is still not fully understood, although current intelligence from recovered wrecks indicates that the designs deviates from standard warfare links in the same way as Tech III Warfare Processors.<br>\r\r\n<i>Synopsis from ISHAEKA-0047. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>  \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(3512,53,'Focused Medium Pulse Laser II','A high-energy, concentrated laser designed for short to medium range engagements. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Conflagration, Scorch.',1000,10,1,1,NULL,678974.0000,1,572,0),(3513,133,'Focused Medium Pulse Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3514,659,'Revenant','Do you know what you are, capsuleer? The truth will not comfort you.<br>You are a frightened child running headfirst towards oblivion.\r\r\n\r\r\nAnd I?\r\r\nI am the only one who tried to stop you.\r\r\nI am the Messiah that you turned against.\r\r\n\r\r\nYou persecuted me, hunted my children.\r\r\nVowed to burn my Promised Land to ash.\r\r\n\r\r\n\r\r\nNow I have returned, and I know you better than you know yourself.\r\r\n\r\r\nI will vanquish your fear, and commute your flesh to dust.\r\r\n\r\r\n<i>- Sansha Kuvakei</i><br><br>\r\r\n\r\r\n',1546875000,62000000,1405,1,32,19510235020.0000,1,1392,0),(3515,1013,'Revenant Blueprint',' ',0,0.01,0,1,NULL,18500000000.0000,1,NULL,0),(3516,324,'Malice','The Malice is an assault frigate design exclusively commissioned as a reward in the ninth Alliance Tournament. Sporting custom metal alloys in its plated carapace, it is one of the most expensive ships ever produced in its class. Far from being a mere ornament, though, the Malice features quality armament systems, strong defensive plating and a massive capacitor, and its vastly augmented facility for energy destabilization makes it a formidable adversary in any engagement.',1271000,28600,210,1,4,4450484.0000,1,1623,0),(3517,105,'Malice Blueprint',' ',0,0.01,0,1,NULL,2875000.0000,1,NULL,0),(3518,358,'Vangel','The Vangel is a heavy assault cruiser design exclusively commissioned as a reward in the ninth Alliance Tournament. Like its smaller sibling the Malice, it possesses greatly enhanced energy destabilization systems. Though it was primarily conceived as a combat vessel for the solitary pilot, the Vangel s great stores of capacitor power and top-of-the-line armor plating make it no less effective in small fleets. A sleek, deadly triumph of both form and function.\r\r\n',11890000,118000,550,1,4,30062934.0000,1,1621,0),(3519,106,'Vangel Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(3520,53,'Heavy Pulse Laser II','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Conflagration, Scorch.',1000,10,1,1,NULL,819990.0000,1,572,0),(3521,133,'Heavy Pulse Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3522,1073,'Ion Cannon','Effectively a gigantic powerplant strapped to an enormous, fragile tube of superconductors which have been wrapped into a polytoroidal synchrotron. Given sufficient charging time, it is capable of accelerating a cloud of ionized particles to energies in the 5.5- to 7.2-ZeV range.\r\r\n\r\r\nWhen precisely targeted by properly-equipped ground forces, this platform can deliver devastating, high-precision space-to-ground artillery support.\r\r\n\r\r\n<i>Corporal, be advised, strike co-ordinates received, splash inbound. Please remain well clear of the blast zone...\r\r\n- Squad Activity Recorder A51781V, final message received; location classified</i>',10000,2000,0,1,NULL,1000000.0000,0,NULL,0),(3523,226,'Caldari Chimera Carrier','The Chimera\'s design is based upon the Kairiola, a vessel holding tremendous historical significance for the Caldari. Initially a water freighter, the Kairiola was refitted in the days of the Gallente-Caldari war to act as a fighter carrier during the orbital bombardment of Caldari Prime. It was most famously flown by the legendary Admiral Yakia Tovil-Toba directly into Gallente Prime\'s atmosphere, where it fragmented and struck several key locations on the planet. This event, where the good Admiral gave his life, marked the culmination of a week\'s concentrated campaign of distraction which enabled the Caldari to evacuate their people from their besieged home planet. Where the Chimera roams, the Caldari remember.',0,0,0,1,1,0.0000,0,NULL,0),(3524,1053,'Jel Rhomben','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Jel Rhomben)<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Significant microwarp velocity. Limited weapons systems.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 110,000 civilian abductions from Jel III. The Rhomben identifier, shared with the Eystur Rhomben variant, suggests an overarching position within the lowest tier of the new Nation hierarchy. Given the inherent weaknesses of this vessel relative to the more powerful Eystur variant, it almost certainly came first in development.<br> \r\r\n<i>Synopsis from ISHAEKA-0033. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>  \r\r\n',2000000,20000,235,1,4,0.0000,0,NULL,0),(3525,1053,'Youl Meten','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Youl Meten)<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Moderate microwarp velocity. Long range stasis webifier support. Limited weapons systems.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 350,000 civilian abductions from Youl IV. The Meten identifier is shared with the Renyn Meten variant, which is notable due to the latter\'s lack of known abductees to crew the ship. This suggests that the Nation may have supplemented the crew of the more powerful Renyn variant from those taken from Youl.<br> \r\r\n<i>Synopsis from ISHAEKA-0031. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>  \r\r\n',2000000,20000,235,1,4,0.0000,0,NULL,0),(3526,1053,'Orkashu Myelen','<font color=yellow>Subject:</font>  Prototype Nation Vessel (ID: Orkashu Myelen)<br>\r\r\n<font color=yellow>Military Specifications:</font>  Frigate-class vessel. Primary role is medium range ECM support and medium range energy warfare. Moderate microwarp velocity. No known weapons systems.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> An estimated 1,200,000 civilian were abductions from Orkashu IV during the chaos caused by four simultaneous invasions. Each invasion was launched in a different empire\'s space. Although the Myelen identifier suggests a developmental state, it is clear that this version of the frigate served as the basis for the more powerful Niarja variant. Other, unknown Nation prototypes may have also originated from this design.<br>\r\r\n<i>Synopsis from ISHAEKA-0035. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>   \r\r\n',2000000,20000,235,1,4,0.0000,0,NULL,0),(3527,1054,'Raa Thalamus','<font color=yellow>Subject:</font> Prototype Nation Vessel (ID: Raa Thalamus)<br>\r\r\n<font color=yellow>Military Specifications:</font> Cruiser-class vessel. Primary role is damage-dealing. Moderate microwarp velocity.<br>\r\r\n<font color=yellow>Additional Intelligence:</font> Est. 520,000 civilian abductions from Raa IV. In a pattern similar to the Meten-class prototypes, the Thalamus identifier is shared with another vessel; the Romi Thalamus. Romi III was not successfully invaded as far as official records indicate, suggesting that those taken from Raa may have been used as a crew resource for the more powerful Romi variant, or alternatively, played some other role in the development of the newer vessel.<br>\r\r\n<i>Synopsis from ISHAEKA-0029. DED Special Operations.</i><br><i>Authorized for Capsuleer dissemination.</i>   \r\r\n',10010000,100100,235,1,4,0.0000,0,NULL,0),(3528,62,'Medium Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,44214.0000,1,1050,0),(3529,142,'Medium Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,1536,0),(3530,62,'Medium Armor Repairer II','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,283564.0000,1,1050,0),(3531,142,'Medium Armor Repairer II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3532,25,'Echelon','A limited run of these ships was released to capsuleers at the end of YC 112, as a platform to utilize an influx of <url=showinfo:3581>Purloined Sansha Data Analyzers</url> that CONCORD had acquired. CONCORD\'s hope was that capsuleers could find a way to use the hardware against Sansha forces as they began mounting organized incursions into territories across the cluster.<br><br>The specialized nature of the hardware in Sansha Data Analyzer technology makes it incompatible with standard data buses, but this ship\'s unique hull design has an adaptive synchronization suite that allows it to interface with a wide range of non-standard hardware. CONCORD has remained silent on the origin of this design, but a number of amateur analysts maintain that ships of very similar configuration, carrying SCC and DED transponders, have been observed covertly on multiple prior occasions.',1124000,28100,135,1,4,0.0000,1,1619,0),(3533,105,'Echelon Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,NULL,0),(3534,62,'Capital Inefficient Armor Repair Unit','This module uses nano-assemblers to repair damage done to the armor of the ship.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',500,4000,0,1,4,66169610.0000,1,1052,0),(3535,142,'Capital Inefficient Armor Repair Unit Blueprint',' ',0,0.01,0,1,NULL,47022756.0000,1,NULL,0),(3536,325,'Capital Coaxial Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',20,4000,0,1,4,34177156.0000,1,1056,0),(3537,350,'Capital Coaxial Remote Armor Repairer Blueprint',' ',0,0.01,0,1,NULL,24200788.0000,1,NULL,0),(3538,62,'Large Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,NULL,88788.0000,1,1051,0),(3539,142,'Large Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,800000.0000,1,1536,0),(3540,62,'Large Armor Repairer II','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,NULL,501952.0000,1,1051,0),(3541,142,'Large Armor Repairer II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3542,40,'Capital Neutron Saturation Injector I','Expends energy to provide a quick boost in shield strength.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',0,4000,0,1,4,72505546.0000,1,778,0),(3543,120,'Capital Neutron Saturation Injector I Blueprint',' ',0,0.01,0,1,NULL,51002322.0000,1,NULL,0),(3544,41,'Capital Murky Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',0,4000,0,1,4,36826120.0000,1,600,0),(3545,121,'Capital Murky Remote Shield Booster Blueprint',' ',0,0.01,0,1,1,24659510.0000,1,NULL,0),(3546,74,'Limited Mega Ion Siege Blaster I','One of the largest weapons currently in existence, this massive blaster is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',40000,4000,10,1,NULL,50073494.0000,1,771,0),(3547,154,'Limited Mega Ion Siege Blaster I Blueprint',' ',0,0.01,0,1,NULL,36286548.0000,1,NULL,0),(3548,286,'Insurance Teaching Drone','Teaching new captains how to manage their ships in order to reduce accidents and decrease premiums for happiness all around.',80000,20400,1200,1,NULL,0.0000,0,NULL,0),(3549,100,'Tutorial Attack Drone',' ',3000,5,0,1,NULL,10.0000,0,NULL,0),(3550,74,'Dual 1000mm \'Scout\' Accelerator Cannon','One of the largest weapons currently in existence, this massive railgun is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',40000,4000,5,1,NULL,65222582.0000,1,772,0),(3551,1217,'Survey','Skill at operating ship, cargo and survey scanners. 5% improvement per level in the scan speeds of those module types.',0,0.01,0,1,NULL,36000.0000,1,1110,0),(3552,87,'Cap Booster 75','Provides a quick injection of power into your capacitor. Good for tight situations!',7.5,3,100,10,NULL,5582.0000,1,139,0),(3553,169,'Cap Booster 75 Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,339,0),(3554,87,'Cap Booster 100','Provides a quick injection of power into your capacitor. Good for tight situations!',10,4,100,10,NULL,16534.0000,1,139,0),(3555,169,'Cap Booster 100 Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,339,0),(3556,76,'Micro Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,2.5,8,1,NULL,4500.0000,1,698,0),(3557,154,'Dual 1000mm \'Scout\' I Accelerator Cannon Blueprint',' ',0,0.01,0,1,NULL,46052412.0000,1,NULL,0),(3558,76,'Micro Capacitor Booster II','Provides a quick injection of power into the capacitor.',0,2.5,10,1,NULL,38032.0000,1,698,0),(3559,53,'Dual Modal Giga Pulse Laser I','One of the largest weapons currently in existence, this massive laser is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',40000,4000,1,1,NULL,61450528.0000,1,774,0),(3560,133,'Dual Modal Giga Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,48404274.0000,1,NULL,0),(3561,53,'Dual Giga Modal Laser I','One of the largest weapons currently in existence, this massive laser is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',40000,4000,1,1,NULL,68359026.0000,1,773,0),(3562,133,'Dual Giga Modal Laser I Blueprint',' ',0,0.01,0,1,NULL,43006260.0000,1,NULL,0),(3563,524,'\'Limos\' Citadel Cruise Launcher I','The size of a small cruiser, this massive launcher is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.',0,4000,4.95,1,NULL,65222582.0000,1,777,0),(3564,136,'\'Limos\' Citadel Cruise Launcher I Blueprint',' ',0,0.01,0,1,NULL,54371388.0000,1,NULL,0),(3565,524,'Shock \'Limos\' Citadel Torpedo Bay I','The size of a small cruiser, this massive launcher is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.',0,4000,5.1,1,NULL,65222582.0000,1,777,0),(3566,76,'Small Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,5,12,1,NULL,20010.0000,1,699,0),(3567,156,'Small Capacitor Booster I Blueprint',' ',0,0.01,0,1,NULL,112500.0000,1,1563,0),(3568,76,'Small Capacitor Booster II','Provides a quick injection of power into the capacitor.',0,5,15,1,NULL,191424.0000,1,699,0),(3569,156,'Small Capacitor Booster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3570,136,'Shock \'Limos\' Citadel Torpedo Bay I Blueprint',' ',0,0.01,0,1,NULL,54371388.0000,1,NULL,0),(3571,55,'Quad 3500mm Gallium Cannon','One of the largest weapons currently in existence, this massive artillery cannon is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',750,4000,5,1,NULL,52484034.0000,1,775,0),(3572,135,'Quad 3500mm Gallium I Cannon Blueprint',' ',0,0.01,0,1,NULL,37692954.0000,1,NULL,0),(3573,55,'6x2500mm Heavy Gallium Repeating Cannon','One of the largest weapons currently in existence, this massive autocannon is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,4000,10,1,NULL,45303166.0000,1,776,0),(3574,135,'6x2500mm Heavy Gallium I Repeating Cannon Blueprint',' ',0,0.01,0,1,NULL,32694870.0000,1,NULL,0),(3575,67,'Capital Murky Remote Capacitor Transmitter','Transfers capacitor energy to another ship.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',1000,4000,0,1,4,38325452.0000,1,910,0),(3576,76,'Heavy Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,78242.0000,1,701,0),(3577,156,'Heavy Capacitor Booster I Blueprint',' ',0,0.01,0,1,NULL,702580.0000,1,1563,0),(3578,76,'Heavy Capacitor Booster II','Provides a quick injection of power into the capacitor.',0,20,160,1,NULL,494270.0000,1,701,0),(3579,156,'Heavy Capacitor Booster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3580,147,'Capital Murky Remote Capacitor Transmitter Blueprint',' ',0,0.01,0,1,NULL,26773840.0000,1,NULL,0),(3581,538,'Purloined Sansha Data Analyzer','CONCORD has acquired untold numbers of these devices from destroyed Sansha vessels during recent raids. The modules have the appearance of standard data analyzers, but when connected to the systems of a suitably modified ship, they exhibit significantly enhanced capabilities.<br><br>Official DED reports on the devices\' internal workings cite \"inconclusive results,\" but CONCORD has nevertheless opted to distribute these modules to capsuleers in the hope that they might be useful in the fight against Kuvakei\'s minions.',1800,5,0,1,NULL,33264.0000,1,1718,0),(3582,917,'Purloined Sansha Data Analyzer Blueprint',' ',0,0.01,0,1,NULL,332640.0000,1,NULL,0),(3583,314,'Badly Mangled Components','This rather large pile of obviously-broken components stands testament to the follies of reprocessing an item without <i>really</i> understanding how it fits together.',700,4,0,1,NULL,0.0000,1,NULL,0),(3584,314,'True Slave Decryption Node','Functionally, this piece of hardware - obviously of Sansha origin - is an extremely sophisticated parallel processing unit. Connecting it to a standard interface bus and running a few diagnostics reveals that it has been configured to act as the master node for a quasi-distributed decryption system, and its response rate suggests that it\'s exceptionally efficient at this task.<br><br>It is, however, difficult to ignore the fact that it\'s also a head in a jar - particularly when it opens its eyes briefly, looks around, and frowns.',700,4,0,1,NULL,0.0000,1,NULL,0),(3585,314,'Mangled Sansha Data Analyzer ','This is still nearly recognizable as a Purloined Sansha Data Analyzer, but attempting to reprocess it has left it broken yet still more-or-less intact. It\'s possible that running it through the reprocessor a second time will yield better results.',1650,5,0,1,NULL,33264.0000,1,NULL,0),(3586,41,'Small Remote Shield Booster I','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,NULL,5528.0000,1,603,0),(3587,121,'Small Remote Shield Booster I Blueprint',' ',0,0.01,0,1,NULL,49960.0000,1,1553,0),(3588,41,'Small Remote Shield Booster II','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,NULL,56935.0000,1,603,0),(3589,121,'Small Remote Shield Booster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3590,917,'Mangled Sansha Data Analyzer Blueprint',' ',0,0.01,0,1,NULL,332640.0000,1,NULL,0),(3591,319,'Angel Control Tower','The Angel Control Tower is an enhanced version of the Matari control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.',100000,1150,8850,1,2,0.0000,0,NULL,0),(3592,226,'Caldari Wyvern Carrier ','The Wyvern is based on documents detailing the design of the ancient Raata empire\'s seafaring flagship, the Oryioni-Haru. According to historical sources the ship was traditionally taken on parade runs between the continent of Tikiona and the Muriyuke archipelago, seat of the Emperor, and represented the pride and joy of what would one day become the Caldari State. Today\'s starfaring version gives no ground to its legendary predecessor; with its varied applications in the vast arena of deep space, the Wyvern is likely to stand as a symbol of Caldari greatness for untold years to come.',0,0,0,1,1,0.0000,0,NULL,0),(3593,226,'Caldari Phoenix Dreadnough','In terms of Caldari design philosophy, the Phoenix is a chip off the old block. With a heavily tweaked missile interface, targeting arrays of surpassing quality and the most advanced shield systems to be found anywhere, it is considered the strongest long-range installation attacker out there. While its shield boosting actuators allow the Phoenix, when properly equipped, to withstand tremendous punishment over a short duration, its defenses are not likely to hold up against sustained attack over longer periods. With a strong supplementary force, however, few things in existence rival this vessel\'s pure annihilative force.',0,0,0,1,1,0.0000,0,NULL,0),(3594,226,'Caldari Leviathan Titan','Citizens of the State, rejoice! Today, a great milestone has been achieved by our glorious leaders. A stepping stone in the grand story of our empire has been traversed. Our individual fears may be quietened; the safety of our great nation has been secured. Today, unyielding, we have walked the way of the warrior. In our hands have our fates been molded. On the Leviathan\'s back will our civilization be carried home and the taint of the Enemy purged from our souls. Rejoice, citizens! Victory is at hand. -Caldari State Information Bureau Pamphlet, 23248 AD',0,0,0,1,1,0.0000,0,NULL,0),(3595,226,'Caldari Badger Industrial Ship','The Badger-class freighter is the main cargo-carrier for the Caldari State, particularly in long, arduous trade-runs. Its huge size and comfortable armament makes it perfectly equipped for those tasks, although the Caldari seldom let it roam alone.',0,0,0,1,1,0.0000,0,NULL,0),(3596,41,'Medium Remote Shield Booster I','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,NULL,13860.0000,1,602,0),(3597,121,'Medium Remote Shield Booster I Blueprint',' ',0,0.01,0,1,NULL,124700.0000,1,1553,0),(3598,41,'Medium Remote Shield Booster II','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,NULL,149442.0000,1,602,0),(3599,121,'Medium Remote Shield Booster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3600,226,'Caldari Tayra Industrial Ship','The Tayra is an alternative version of the famous Badger, it\'s mostly used by the military or the mega corps for transports of goods of great value. The Tayra has a much larger cargo capacity, making it ideal for high volume hauling.',0,0,0,1,1,0.0000,0,NULL,0),(3601,226,'Caldari Charon Freighter','As the makers of the Charon, the Caldari State are generally credited with pioneering the freighter class. Recognizing the need for a massive transport vehicle as deep space installations constantly increase in number, they set about making the ultimate in efficient mass transport - and were soon followed by the other empires. Regardless, the Charon still stands out as the benchmark by which the other freighters were measured. Its massive size and titanic cargo hold are rivalled by none.',0,0,0,1,1,0.0000,0,NULL,0),(3602,226,'Gallente Atron Frigate','The Atron is a hard nugget with an advanced power conduit system, but little space for cargo. Although it is a good harvester when it comes to mining, its main ability is as a combat vessel.',0,0,0,1,1,0.0000,0,NULL,0),(3603,226,'Gallente Imicus Frigate','The Imicus is a slow but hard-shelled frigate, ideal for any type of scouting activity. Used by merchant, miner and combat groups, the Imicus is usually relied upon as the operation\'s eyes and ears when traversing low security sectors.',0,0,0,1,1,0.0000,0,NULL,0),(3604,226,'Gallente Incursus Frigate','The Incursus is commonly found spearheading Gallentean military operations. Its speed and surprising strength make it excellent for skirmishing duties. Incursus-class ships move together in groups and can quickly and effectively gang up on ships many times their size and overwhelm them. In recent years the Incursus has increasingly found its way into the hands of pirates, who love its aggressive appearance.',0,0,0,1,1,0.0000,0,NULL,0),(3605,226,'Gallente Maulus Frigate','ThThe Maulus is a high-tech vessel, specialized for electronic warfare. It is particularly valued in fleet warfare due to its optimization for sensor dampening technology.',0,0,0,1,1,0.0000,0,NULL,0),(3606,41,'Large Remote Shield Booster I','Transfers shield power over to the target ship, aiding in its defense.',0,25,0,1,NULL,34716.0000,1,601,0),(3607,121,'Large Remote Shield Booster I Blueprint',' ',0,0.01,0,1,NULL,312440.0000,1,1553,0),(3608,41,'Large Remote Shield Booster II','Transfers shield power over to the target ship, aiding in its defense.',0,25,0,1,NULL,273112.0000,1,601,0),(3609,121,'Large Remote Shield Booster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3610,226,'Gallente Navitas Frigate',' In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. In the Gallente Federation, this led to the redesign and redeployment of the Navitas. The Navitas had been a solid mining vessel that had seen wide use by independent excavators, along with being one of the best ships available for budding traders and even for much-maligned scavengers. After its redesign, its long-range scanners and sturdy outer shell gave way entirely for remote repairing capabilities, moving the Navitas away from the calming buzz of mining lasers and into the roar of battle.',0,0,0,1,1,0.0000,0,NULL,0),(3611,226,'Gallente Tristan Frigate','Often nicknamed The Fat Man this nimble little frigate is mainly used by the Federation in escort duties or on short-range patrols. The Tristan has been very popular throughout Gallente space for years because of its versatility. It is rather expensive, but buyers will definitely get their money\'s worth, as the Tristan is one of the more powerful frigates available on the market.',0,0,0,1,1,0.0000,0,NULL,0),(3612,226,'Gallente Catalyst Destroyer','Ideally suited for both skirmish warfare and fleet support, the Catalyst is touted as one of the best anti-frigate platforms out there. Faced with its top-of-the-line tracking equipment, not many can argue.',0,0,0,1,1,0.0000,0,NULL,0),(3613,226,'Gallente Celestis Cruiser','The Celestis cruiser is a versatile ship which can be employed in a myriad of roles, making it handy for small corporations with a limited number of ships. True to Gallente style the Celestis is especially deadly in close quarters combat due to its advanced targeting systems.',0,0,0,1,1,0.0000,0,NULL,0),(3614,226,'Gallente Exequror Cruiser','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. Both Frigate and Cruiser-class ships were put under the microscope, and in the Gallente Federation the outcome of the re-evaluation process led, among other developments, to a redesign and redeployment of the Exequoror. The Exequror was a heavy cargo cruiser originally strong enough to defend itself against raiding frigates, though it lacked prowess in heavier combat situations. After its redesign, it had some of that bulk - and, necessarily, some of that strength - yanked out and replaced with the capability to help others in heavy combat situations, in particular those who needed armor repairs.',0,0,0,1,1,0.0000,0,NULL,0),(3615,226,'Gallente Thorax Cruiser','The Thorax-class cruiser is the latest combat ship commissioned by the Federation. While the Thorax is a very effective ship at any range, typical of modern Gallente design philosophy it is most effective when working at extreme close range where its blasters and hordes of combat drones tear through even the toughest of enemies.',0,0,0,1,1,0.0000,0,NULL,0),(3616,41,'Capital Remote Shield Booster I','Transfers shield power over to the target ship, aiding in its defense.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',0,4000,0,1,4,36826120.0000,1,600,0),(3617,121,'Capital Remote Shield Booster I Blueprint',' ',0,0.01,0,1,1,24659510.0000,1,1553,0),(3618,41,'Capital Remote Shield Booster II','Transfers shield power over to the target ship, aiding in its defense.\r\r\nNote: May only be fitted to capital class ships.',0,1000,0,1,NULL,37171840.0000,0,NULL,0),(3619,121,'Capital Remote Shield Booster II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(3620,226,'Fortified Starbase Shield Generator','Smaller confined shield generators with their own access restrictions can be deployed outside the Control Tower\'s defense perimeter. This allows for lesser security areas around the Starbase, for purposes of storage or pickup. ',1,1,0,1,4,0.0000,0,NULL,0),(3624,306,'Holding Cell','If you have the right equipment you might be able to hack into the databank and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(3625,517,'Rohan Shadrak\'s Bellicose','Rohan Shadrak is a Vherokior Shaman of somewhat eccentric repute - he was once described by Isardsund Urbrald, CEO of Vherokior tribe to be \"Mad as a biscuit\". A staunch traditionalist, he is a vocal - and occasionally physical - opponent of CONCORD laws against drug transportation.',0,0,0,1,2,0.0000,0,NULL,0),(3626,226,'Sansha Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(3627,314,'Construction Materials','Metal girders, plasteel concrete and fiber blocks are all very common construction material used around the universe.',1000000,70,0,1,NULL,500.0000,1,NULL,0),(3628,659,'Nation',' ',1546875000,62000000,1405,1,32,0.0000,0,NULL,0),(3629,306,'Amarr Academy Office','The Pilot Certification Documents can be retrieved from inside this office. ',10000,27500,2700,1,4,0.0000,0,NULL,0),(3630,226,'Amarr Crucifier Frigate','The Crucifier was first designed as an explorer/scout, but the current version employs the electronic equipment originally intended for scientific studies for more offensive purposes. The Crucifier\'s electronic and computer systems take up a large portion of the internal space leaving limited room for cargo or traditional weaponry.',0,0,0,1,4,0.0000,0,NULL,0),(3631,226,'Amarr Executioner Frigate','The Executioner is another newly commissioned ship of the Amarr Imperial Navy. The Executioner was designed specially to counter the small, fast raider frigates of the Minmatar Republic; thus it is different from most Amarr ships in favoring speed over defenses. With the Executioner, the Amarrians have expanded their tactical capabilities on the battlefield.',0,0,0,1,4,0.0000,0,NULL,0),(3632,226,'Amarr Inquisitor Frigate','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. In the Amarr Empire, this led to the redesign and redeployment of the Inquisitor. The Inquisitor was originally an example of how the Amarr Imperial Navy modeled their design to counter specific tactics employed by the other empires. After its redesign, it was exclusively devoted to the role of a support frigate, and its formerly renowned missile capabilities gave way to a focus on remote armor repair.',0,0,0,1,4,0.0000,0,NULL,0),(3633,226,'Amarr Magnate Frigate','This Magnate-class frigate is one of the most decoratively designed ship classes in the Amarr Empire, considered to be a pet project for a small, elite group of royal ship engineers for over a decade. The frigate\'s design has gone through several stages over the past decade, and new models of the Magnate appear every few years. The most recent versions of this ship   the Silver Magnate and the Gold Magnate   debuted as rewards in the Amarr Championships in YC105, though the original Magnate design is still a popular choice among Amarr pilots.',0,0,0,1,4,0.0000,0,NULL,0),(3634,53,'Civilian Gatling Pulse Laser','Low powered, rapid fire multi-barreled energy weapon that delivers a steady stream of damage. Comes with a pre-fitted irreplaceable standard frequency crystal.',500,5,0,1,NULL,0.0000,0,NULL,0),(3635,226,'Amarr Punisher Frigate','The Amarr Imperial Navy has been upgrading many of its ships in recent years and adding new ones. The Punisher is one of the most recent ones and considered by many to be the best Amarr frigate in existence. As witnessed by its heavy armaments, the Punisher is mainly intended for large-scale military operations, acting in coordination with larger military vessels, but it is more than powerful enough for solo operations.',0,0,0,1,4,0.0000,0,NULL,0),(3636,53,'Civilian Gatling Autocannon','Low powered, rapid fire multi-barreled projectile weapon that delivers a steady stream of damage. Generates Its own ammo from space particles. Cannot use standard projectile ammo.',500,5,0,1,NULL,0.0000,0,NULL,0),(3637,226,'Amarr Tormentor Frigate','The Tormentor has been in service for many decades, mainly as a mining ship. It is not big enough to cut it as a battle frigate, but as with most Amarr ships its strong defenses make it a tough opponent to crack. Exactly for this and the way it seems to be curling up on itself has given the Tormentor-class the nickname \'Armadillo\'.',0,0,0,1,4,0.0000,0,NULL,0),(3638,53,'Civilian Gatling Railgun','Low powered, rapid fire multi-barreled hybrid weapon that delivers a steady stream of damage. Generates Its own ammunition from space particles. Cannot use standard hybrid charges.',500,5,0,1,NULL,0.0000,0,NULL,0),(3639,226,'Amarr Coercer Destroyer','Noticing the alarming increase in Minmatar frigate fleets, the Imperial Navy made its plans for the Coercer, a vessel designed specifically to seek and destroy the droves of fast-moving frigate rebels.',0,0,0,1,4,0.0000,0,NULL,0),(3640,53,'Civilian Light Electron Blaster','Low powered, rapid fire multi-barreled hybrid weapon that delivers a steady stream of damage. Generates Its own ammo from space particles. Cannot use standard hybrid ammo.',500,5,0,1,NULL,0.0000,0,NULL,0),(3641,226,'Amarr Arbitrator Cruiser','The Arbitrator is unusual for Amarr ships in that it\'s primarily a drone carrier. While it is not the best carrier around, it has superior armor that gives it greater durability than most ships in its class.',0,0,0,1,4,0.0000,0,NULL,0),(3642,226,'Amarr Augoror Cruiser','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. Both Frigate and Cruiser-class ships were put under the microscope, and in the Amarr Empire the outcome of the re-evaluation process led, among other developments, to a redesign and redeployment of the Augoror. The Augoror-class cruiser is one of the old warhorses of the Amarr Empire, having seen action in both the Jovian War and the Minmatar Rebellion. Like most Amarr vessels, the Augoror depended first and foremost on its resilience and heavy armor to escape unscathed from unfriendly encounters. After its overhaul, it had some of the armor stripped off to make room for equipment allowing it to focus on the armor of other vessels, along with energy transfers.',0,0,0,1,4,0.0000,0,NULL,0),(3643,280,'Soil','Fertile soil rich with nutrients is very sought after by agricultural corporations and colonists on worlds with short biological history.',3000,1.5,0,1,NULL,80.0000,1,20,0),(3644,226,'Amarr Omen Cruiser','The Omen is a stereotypical example of the Amarrian School of thinking when it comes to ship design: thick armor and hard hitting lasers. Advancements in heat dissipation allow the Omen to fire its lasers faster than other ships without this technology.',0,0,0,1,4,0.0000,0,NULL,0),(3645,1042,'Water','Water is one of the basic conditional elements of human survival. Most worlds have this compound in relative short supply and hence must rely on starship freight.',0,0.38,0,1,NULL,35.0000,1,1334,0),(3646,226,'Amarr Harbinger Battlecruiser','Right from its very appearance on a battlefield, the Harbinger proclaims its status as a massive weapon, a laser burning through the heart of the ungodly. Everything about it exhibits this focused intent, from the lights on its nose and wings that root out the infidels, to the large number of turreted high slots that serve to destroy them. Should any heathens be left alive after the Harbinger\'s initial assault, its drones will take care of them.',0,0,0,1,4,0.0000,0,NULL,0),(3647,280,'Holoreels','Holographic video reels (also called \"holoreels\") are the most common type of personal entertainment there is. From interactive gaming to erotic motion pictures, these reels can contain hundreds of titles each. ',100,0.5,0,1,NULL,250.0000,1,492,0),(3648,226,'Amarr Prophecy Battlecruiser','The Prophecy is built on an ancient Amarrian warship design dating back to the earliest days of starship combat. Originally intended as a full-fledged battleship, it was determined after mixed fleet engagements with early prototypes that the Prophecy would be more effective as a slightly smaller, more mobile form of artillery support.',0,0,0,1,4,0.0000,0,NULL,0),(3649,226,'Amarr Abaddon Battleship','The Abaddon class ship is a celestial tool of destruction. It is designed to enter combat from the outset, targeting enemies at range and firing salvo after salvo at them, and to remain intact on the battlefield until every heretic in sight has been torn to shreds.',0,0,0,1,4,0.0000,0,NULL,0),(3650,226,'Amarr Apocalypse Battleship','In days past, only those in high favor with the Emperor could hope to earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. In latter years, even though now in full market circulation, these golden, metallic monstrosities are still feared and respected as enduring symbols of Amarrian might.',0,0,0,1,4,0.0000,0,NULL,0),(3651,54,'Civilian Miner','Common, low technology mining laser. Works well for extracting common ore, but not useful for much else.',0,5,0,1,NULL,0.0000,1,1039,0),(3652,226,'Amarr Bestower Industrial Ship','The Bestower has for decades been used by the Empire as a slave transport, shipping human labor between cultivated planets in Imperial space. As a proof to how reliable this class has been through the years, the Emperor himself has used an upgraded version of this very same class as transports for the Imperial Treasury. The Bestower has very thick armor and large cargo space.',0,0,0,1,4,0.0000,0,NULL,0),(3653,63,'Medium Hull Repairer I','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,25,0,1,NULL,220806.0000,1,1054,0),(3654,143,'Medium Hull Repairer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1537,0),(3655,63,'Medium Hull Repairer II','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,10,0,1,NULL,460156.0000,1,1054,0),(3656,143,'Medium Hull Repairer II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3657,226,'Amarr Sigil Industrial Ship','A recent ship from Viziam. Based on a old slave transport design.',0,0,0,1,4,0.0000,0,NULL,0),(3658,226,'Amarr Maller Cruiser','Quite possibly the toughest cruiser in the galaxy, the Maller is a common sight in Amarrian Imperial Navy operations. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches.',0,0,0,1,4,0.0000,0,NULL,0),(3659,226,'Amarr Aeon Carrier','Ships like the Aeon have been with the Empire for a long time. They have remained a mainstay of Amarr expansion as, hopeful for a new beginning beyond the blasted horizon, whole cities of settlers sojourn from their time-worn homesteads to try their luck on infant worlds. The Aeon represents the largest ship of its kind in the history of the Empire, capable of functioning as a mobile citadel in addition to fielding powerful wings of fighter bombers.',0,0,0,1,4,0.0000,0,NULL,0),(3660,226,'Amarr Archon Carrier','The Archon was commissioned by the Imperial Navy to act as a personnel and fighter carrier. The order to create the ship came as part of a unilateral initative issued by Navy Command in the wake of Emperor Kor-Azor\'s assassination. Sporting the latest in fighter command interfacing technology and possessing characteristically strong defenses, the Archon is a powerful aid in any engagement.',0,0,0,1,4,0.0000,0,NULL,0),(3661,226,'Amarr Revelation Dreadnought','The Revelation represents the pinnacle of Amarrian military technology. Maintaining their proud tradition of producing the strongest armor plating to be found anywhere, the Empire\'s engineers outdid themselves in creating what is arguably the most resilient dreadnought in existence. Added to that, the Revelation\'s ability to fire capital beams makes its position on the battlefield a unique one. When extended sieges are the order of the day, this is the ship you call in.',0,0,0,1,4,0.0000,0,NULL,0),(3662,226,'Amarr Avatar Titan','Casting his sight on his realm, the Lord witnessed The cascade of evil, the torrents of war. Burning with wrath, He stepped down from the Heavens To judge the unworthy, To redeem the pure. -The Scriptures, Revelation Verses 2:12',0,0,0,1,4,0.0000,0,NULL,0),(3663,63,'Large Hull Repairer I','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,50,0,1,NULL,631556.0000,1,1055,0),(3664,143,'Large Hull Repairer I Blueprint',' ',0,0.01,0,1,NULL,3125000.0000,1,1537,0),(3665,63,'Large Hull Repairer II','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,50,0,1,NULL,1044720.0000,1,1055,0),(3666,143,'Large Hull Repairer II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3667,226,'Amarr Providence Freighter','Even though characteristically last in the race to create a working prototype of new technology, the Empire\'s engineers spared no effort in bringing the Providence into the world. While the massive potential for profit from the capsuleer market is said to have been what eventually made the stolid Empire decide to involve themselves in the freighter business, their brainchild is by no means the runt of the litter; the Providence is one of the sturdiest freighters out there.',0,0,0,1,4,0.0000,0,NULL,0),(3668,226,'Gallente Brutix Battlecruiser','One of the most ferocious war vessels to ever spring from Gallente starship design, the Brutix is a behemoth in every sense of the word. When this hard-hitting monster appears, the battlefield takes notice.',0,0,0,1,1,0.0000,0,NULL,0),(3669,226,'Gallente Myrmidon Battlecruiser','Worried that their hot-shot pilots would burn brightly in their eagerness to engage the enemy, the Federation Navy created a ship that encourages caution over foolhardiness. A hardier version of its counterpart, the Myrmidon is a ship designed to persist in battle. Its numerous medium and high slots allow it to slowly bulldoze its way through the opposition, while its massive drone space ensures that no enemy is left unscathed.',0,0,0,1,1,0.0000,0,NULL,0),(3670,226,'Caldari Bantam Frigate','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. In the Caldari State, this led to the redesign and redeployment of the Bantam. The Bantam, a strong and sturdy craft, was originally an extremely effective mining frigate. After its redesign, the Bantam\'s large structure had to give way for logistics systems that ate up some of its interior room but allowed it to focus extensively on shield support for fellow vessels.',0,0,0,1,1,0.0000,0,NULL,0),(3671,226,'Caldari Condor Frigate','The Condor is fast and agile. It has limited cargo space so it\'s not very suitable for trading or mining. It is best used as an assault vessel in a hit-and-run type of operations.',0,0,0,1,1,0.0000,0,NULL,0),(3672,226,'Caldari Griffin Frigate','The Griffin is much used by the Caldari Navy as a support vessel in combat squadrons, using its impressive array of electronic gadgetry to disrupt the operation of target ships, making them easy prey for traditional combat vessels.',0,0,0,1,1,0.0000,0,NULL,0),(3673,280,'Wheat','Cereal grasses have been localized on hundreds of worlds. The grains of the wheat plant make a solid foundation for the production of foodstuffs within empire space.',1000,1.15,0,1,NULL,100.0000,1,492,0),(3674,226,'Caldari Heron Frigate','The Heron has good computer and electronic systems, giving it the option of participating in electronic warfare. But it has relatively poor defenses and limited weaponry, so it\'s more commonly used for scouting and exploration.',0,0,0,1,1,0.0000,0,NULL,0),(3675,226,'Caldari Kestrel Frigate','The Kestrel is a heavy missile boat with a fairly large cargo space and one of the most sophisticated sensor arrays around. Interestingly enough, it has been used by both the Caldari Navy and several wealthy trade corporations as a cargo-hauling vessel. It is one of few trading vessels with good punching power, making it ideal for solo trade-runs in dangerous areas. The Kestrel was designed so that it could take up to four missile launchers but instead it can not be equipped with turret weapons nor mining lasers. ',0,0,0,1,1,0.0000,0,NULL,0),(3676,226,'Caldari Merlin Frigate','The Merlin is the most powerful all-out combat frigate of the Caldari. It is highly valued for its versatility in using both missiles and turrets, while its defenses are exceptionally strong for a Caldari vessel.',0,0,0,1,1,0.0000,0,NULL,0),(3677,226,'Caldari Cormorant Destroyer','The Cormorant is the only State-produced space vessel whose design has come from a third party. Rumors abound, of course, but the designer\'s identity has remained a tightly-kept secret in the State\'s inner circle.',0,0,0,1,1,0.0000,0,NULL,0),(3678,226,'Caldari Blackbird Cruiser','The Blackbird is a small high-tech cruiser newly employed by the Caldari Navy. Commonly seen in fleet battles or acting as wingman, it is not intended for head-on slugfests, but rather delicate tactical situations.',0,0,0,1,1,0.0000,0,NULL,0),(3679,226,'Caldari Caracal Cruiser','The Caracal is a powerful vessel that specializes in missile deployment. It has excellent shield defenses, but poor armor plating. Its missile arsenal, when fully stocked, is capable of making mincemeat of almost anyone.',0,0,0,1,1,0.0000,0,NULL,0),(3680,226,'Caldari Moa Cruiser','The Moa was designed as an all-out combat ship, and its heavy armament allows the Moa to tackle almost anything that floats in space. In contrast to its nemesis the Thorax, the Moa is most effective at long range where its railguns and missile batteries can rain death upon foes.',0,0,0,1,1,0.0000,0,NULL,0),(3681,226,'Caldari Osprey Cruiser','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. Both Frigate and Cruiser-class ships were put under the microscope, and in the Caldari State the outcome of the re-evaluation process led, among other developments, to a redesign and redeployment of the Osprey. The Osprey originally offered excellent versatility and power for what was considered a comparably low price. After its redesign, its inbuilt mining technology - now a little creaky and long in the tooth - was gutted from the Osprey and replaced in its entirety with tech of a different type, capable of high energy and shield transfers.',0,0,0,1,1,0.0000,0,NULL,0),(3682,226,'Caldari Drake Battlecruiser','Of the meticulous craftsmanship the Caldari are renowned for, the Drake was born. It was found beneath such a ship to rely on anything other than the time-honored combat tradition of missile fire, while the inclusion of sufficient CPU capabilities for decent electronic warfare goes without saying.',0,0,0,1,1,0.0000,0,NULL,0),(3683,1042,'Oxygen','Oxygen is a commodity in constant demand. While most stations have their own supply units, smaller depots and space crafts rely on imports.',0,0.38,0,1,NULL,95.0000,1,1334,0),(3684,226,'Caldari Ferox Battlecruiser','Designed as much to look like a killing machine as to be one, the Ferox will strike fear into the heart of anyone unlucky enough to get caught in its crosshairs. With the potential for sizable armament as well as tremendous electronic warfare capability, this versatile gunboat is at home in a great number of scenarios. ',0,0,0,1,1,0.0000,0,NULL,0),(3685,280,'Hydrogen Batteries','The use of hydrogen batteries has become an international standard both in industry and in the public domain; they are a particularly common power supply in off-world habitats such as space stations. ',1500,1,0,1,NULL,500.0000,1,20,0),(3686,226,'Caldari Raven Battleship','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.',0,0,0,1,1,0.0000,0,NULL,0),(3687,280,'Electronic Parts','These basic elements of all electronic hardware are sought out by those who require spare parts in their hardware. Factories and manufacturers take these parts and assemble them into finished products, which are then sold on the market.',1000,1,0,1,NULL,750.0000,1,20,0),(3688,226,'Caldari Rokh Battleship','Having long suffered the lack of an adequate hybrid platform, the Caldari State\'s capsule pilots found themselves rejoicing as the Rokh\'s design specs were released. A fleet vessel if ever there was one, this far-reaching and durable beast is expected to see a great deal of service on battlefields near and far.',0,0,0,1,1,0.0000,0,NULL,0),(3689,1034,'Mechanical Parts','These basic elements of all mechanical hardware can come in virtually any shape and size, although composite or modular functionality is highly advantageous in today\'s competitive market. Factories and manufacturers take these parts and assemble them into finished products, which are then sold on the market. ',0,1.5,0,1,4,600.0000,1,1335,0),(3690,226,'Caldari Scorpion Battleship ','The first Scorpion-class battleship was launched only a couple of years ago, and those that have been built are considered to be prototypes. Little is known of its capabilities, but what has been garnered suggests that the Scorpion is crammed to the brink with sophisticated hi-tech equipment that few can match.',0,0,0,1,1,0.0000,0,NULL,0),(3691,1034,'Synthetic Oil','Since original oil can be harvested only from a world with a long biological history, synthetic oil has become frequently produced in laboratories all over known space.',0,1.5,0,1,NULL,320.0000,1,1335,0),(3693,1034,'Fertilizer','Fertilizer is particularly valued on agricultural worlds, where there is a constant demand for all commodities that boost export value.',0,1.5,0,1,NULL,200.0000,1,1335,0),(3695,1034,'Polytextiles','Composite materials, both synthetic and natural, are used in the creation of polytextiles, durable fabrics that see widespread use in the clothing industry, solar sail manufacture, and even classic art.',200,1.5,0,1,NULL,400.0000,1,1335,0),(3697,1034,'Silicate Glass','Silicate glass is a common construction material, in constant demand throughout New Eden, whether in planetary structures or reinforced for use in space vessels.',0,1.5,0,1,NULL,185.0000,1,1335,0),(3699,280,'Quafe','Quafe is the name of the most popular soft drink in the universe, manufactured by a Gallentean company bearing the same name. Like so many soft drinks, it was initially intended as a medicine for indigestion and tender stomachs, but the refreshing effects of the drink appealed to everyone and the drink quickly became tremendously popular. Quafe is one of the best recognized brands in the whole EVE universe and can be found in every corner of it. ',500,0.1,0,1,NULL,50.0000,1,492,0),(3701,314,'Certification Results','These complicated certification results may mean little to the layman\'s eye, but can prove valuable in the right hands.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(3703,313,'Nerve Sticks','This booster is used as a stress-reliever and is ingested with a sip of water.',10,0.2,0,1,NULL,2500.0000,1,491,0),(3704,226,'Gallente Dominix Battleship','The Dominix is one of the old warhorses dating back to the Gallente-Caldari War. While no longer regarded as the king of the hill, it is by no means obsolete. Its formidable hulk and powerful drone arsenal means that anyone not in the largest and latest battleships will regret ever locking horns with it.',0,0,0,1,1,0.0000,0,NULL,0),(3705,313,'Crash','This expensive booster is highly addictive and has been known to cause heart attacks and seizures.',5,0.2,0,1,NULL,1100.0000,1,491,0),(3706,226,'Gallente Hyperion Battleship','Recognizing the necessity for a blaster platform to round out their high-end arsenal, the Federation Navy brought in top-level talent to work on the Hyperion. The result: one of the most lethal and versatile gunboats ever to take to the dark skies.',0,0,0,1,1,0.0000,0,NULL,0),(3707,313,'Blue Pill','This booster causes forgetfulness and bliss, and may cause light hallucinations.',10,0.2,0,1,NULL,2200.0000,1,491,0),(3708,226,'Gallente Megathron Battleship','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.',0,0,0,1,1,0.0000,0,NULL,0),(3709,313,'Drop','This highly hallucinogenic booster can easily cause temporary dementia. It is commonly poured into a wet rag, which is then laid over, or bound across, sensitive parts of the skin.',5,0.2,0,1,NULL,1000.0000,1,491,0),(3710,226,'Gallente Nyx Carrier','The Nyx is a gigantic homage to a figure much loved in Gallente society. The ship\'s design is based on the scepter of Doule dos Rouvenor III, the king who, during his peaceful 36-year reign, was credited with laying the foundation for the technologically and socially progressive ideologies which have pervaded Gallente thought in the millennia since. Indeed, the Nyx itself is emblematic of the Gallenteans\' love for progress; packed to the ergonomic brim with the latest in cutting-edge advancements, it is a proud reminder of the things that make the Federation what it is.',0,0,0,1,1,0.0000,0,NULL,0),(3711,313,'X-Instinct','Abusers of this booster have reported surreal visions and altered perceptions of the world around them. The subject becomes blissful and content, but highly analytical of the surroundings.',800,1,0,1,NULL,13500.0000,1,491,0),(3712,226,'Gallente Thanatos Carrier','Sensing the need for a more moderately-priced version of the Nyx, Federation Navy authorities commissioned the design of the Thanatos. Designed to act primarily as a fighter carrier for small- to mid-scale engagements, its significant defensive capabilities and specially-fitted fighter bays make it ideal for its intended purpose.',0,0,0,1,1,0.0000,0,NULL,0),(3713,313,'Vitoc','The Vitoc booster has become more than a simple strategy by the Amarrians in controling their slaves. With the Vitoc method, slaves are injected with a toxic chemical substance that is fatal unless the recipient receives a constant supply of an antidote. The method first appeared a few centuries ago when the Amarrians started manning some of their space ships with slaves. As space crew the slaves had to be cajoled into doing complex, often independent work, making older methods of slave control undesirable. Although the more conventional ways of subduing slaves with force (actual or threat of) are still widely used in other forced labor areas, the Vitoc method has proven itself admirably for the fleet.',800,0.5,0,1,NULL,9300.0000,1,491,0),(3714,226,'Gallente Moros Dreadnought','Of all the dreadnoughts currently in existence, the versatile Moros possesses perhaps the greatest capacity to fend off smaller hostiles by itself while concentrating on its primary capital target. By virtue of its protean array of point defense capabilities - including a drone bay capable of fielding vast amounts of drones to safeguard the behemoth - the Moros is single-handedly capable of turning the tide in a fleet battle.',0,0,0,1,1,0.0000,0,NULL,0),(3715,281,'Frozen Food','Frozen food is in high demand in many regions, especially on stations orbiting a non-habitable planet and a long way from an agricultural world.',400,0.5,0,1,NULL,98.0000,1,492,0),(3716,226,'Gallente Erebus Titan','From the formless void\'s gaping maw, there springs an entity. Not an entity such as any you can conceive of, nor I; an entity more primordial than the elements themselves, yet constantly coming into existence even as it is destroyed. It is the Child of Chaos, the Pathway to the Next. The darkness shall swallow the land, and in its wake there will follow a storm, as the appetite of nothing expands over the world. From the formless void\'s gaping maw, there springs an entity. Dr. Damella Macaper The Seven Events of the Apocalypse',0,0,0,1,1,0.0000,0,NULL,0),(3717,281,'Dairy Products','These products, extracted from livestock, are one of the biggest cogs in the food production cycle. Dairy products are rich with calcium and help make sure the inhabitants of the EVE universe all have shiny teeth.',400,0.5,0,1,NULL,160.0000,1,492,0),(3718,226,'Gallente Iteron Mark I Industrial Ship','The Iteron-class cargo tugger is fast and reliable and there are many versions of it. It is equally popular among civilians and militaries alike as it\'s cheap and can be fitted in myriad different ways, allowing it to be used to freight almost anything. It is, however, quite vulnerable and needs to be protected while in unfriendly territories.',0,0,0,1,1,0.0000,0,NULL,0),(3719,283,'Tourists','The need for tasting other cultures and seeing new worlds is unquenchable among the well-off citizens of the universe.',200,1,0,1,NULL,100.0000,1,23,0),(3720,226,'Gallente Iteron Mark II Industrial Ship','The Iteron-class cargo tugger is fast and reliable and there are many versions of it. It is equally popular among civilians and militaries alike as it\'s cheap and can be fitted in myriad different ways, allowing it to be used to freight almost anything. It is, however, quite vulnerable and needs to be protected while in unfriendly territories.',0,0,0,1,1,0.0000,0,NULL,0),(3721,283,'Slaves','Slavery has always been a questionable industry, favored by the Amarr Empire and detested by the Gallente Federation.',450,5,0,1,NULL,750.0000,1,23,0),(3722,226,'Gallente Iteron Mark III Industrial Ship','The Iteron-class cargo tugger is fast and reliable and there are many versions of it. It is equally popular among civilians and militaries alike as it\'s cheap and can be fitted in myriad different ways, allowing it to be used to freight almost anything. It is, however, quite vulnerable and needs to be protected while in unfriendly territories.',0,0,0,1,1,0.0000,0,NULL,0),(3723,283,'Slaver Hound','The slaver hound is a native animal of Syrikos V and has been bred by the Amarrians from the time they first settled the planet more than a millennium ago. The favorable experience of employing the slaver hound as a guard animal has led to it being exported from Syrikos V to most other Amarrian agricultural planets and even some industrial and mining ones as well. In recent years, the slaver hound has become fashionable among Amarrians as a pet for those willing to risk its often murderous nature; slaver hounds can become extremely loyal and devoted to their owners if handled with care. ',30,1,0,1,NULL,3000.0000,1,23,0),(3724,226,'Gallente Iteron Mark IV Industrial Ship','The Iteron-class cargo tugger is fast and reliable and there are many versions of it. It is equally popular among civilians and militaries alike as it\'s cheap and can be fitted in myriad different ways, allowing it to be used to freight almost anything. It is, however, quite vulnerable and needs to be protected while in unfriendly territories.',0,0,0,1,1,0.0000,0,NULL,0),(3725,1034,'Livestock','Livestock are domestic animals raised for home use or for profit, whether it be for their meat or dairy products.',900,1.5,0,1,NULL,850.0000,1,1335,0),(3726,226,'Gallente Iteron Mark V Industrial Ship','The Iteron-class cargo tugger is fast and reliable and there are many versions of it. It is equally popular among civilians and militaries alike as it\'s cheap and can be fitted in myriad different ways, allowing it to be used to freight almost anything. It is, however, quite vulnerable and needs to be protected while in unfriendly territories.',0,0,0,1,1,0.0000,0,NULL,0),(3727,282,'Plutonium','Plutonium is used in arms manufacturing, among other things, making it a steady trade commodity.',2000,1,0,1,NULL,12000.0000,1,22,0),(3728,226,'Gallente Obelisk Freighter','The Obelisk was designed by the Federation in response to the Caldari State\'s Charon freighter. Possessing similar characteristics but placing a greater emphasis on resilience, this massive juggernaut represents the latest, and arguably finest, step in Gallente transport technology. ',0,0,0,1,1,0.0000,0,NULL,0),(3729,282,'Toxic Waste','Waste from various production industries and arms manufacturers can be hazardous to the environment, but instead of dumping it to the void, it can be sold to those who see value in the material.',2000,1,0,1,NULL,150.0000,1,22,0),(3730,226,'Minmatar Breacher Frigate','The Breacher\'s structure is little more than a fragile scrapheap, but the ship\'s missile launcher hardpoints and superior sensors have placed it among the most valued Minmatar frigates when it comes to long range combat.',0,0,0,1,1,0.0000,0,NULL,0),(3731,266,'Megacorp Management','Advanced corporation operation. +100 members per level.\r\r\n\r\r\nNotice: the CEO must update his corporation through the corporation user interface before the skill takes effect. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,400000.0000,1,365,0),(3732,266,'Empire Control','Advanced corporation operation. +400 corporation members allowed per level. \r\r\n\r\r\nNotice:  the CEO must update his corporation through the corporation user interface before the skill takes effect. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,8000000.0000,1,365,0),(3733,92,'Cobra Mine','Standard mine with nuclear payload.',1,0.15,0,10,NULL,1494.0000,0,NULL,0),(3734,174,'Cobra Mine Blueprint',' ',0,0.01,0,1,NULL,136400.0000,0,NULL,0),(3735,92,'Anaconda Mine','Standard mine with nuclear payload.',1,0.15,0,10,NULL,1494.0000,0,NULL,0),(3736,174,'Anaconda Mine Blueprint',' ',0,0.01,0,1,NULL,136400.0000,0,NULL,0),(3737,92,'Asp Mine','Standard mine with nuclear payload.',1,0.15,0,10,NULL,1494.0000,0,NULL,0),(3738,174,'Asp Mine Blueprint',' ',0,0.01,0,1,NULL,136400.0000,0,NULL,0),(3739,99,'Caldari Sentry Gun III','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,1,0.0000,0,NULL,0),(3740,99,'Caldari Sentry Gun I','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,1,0.0000,0,NULL,0),(3741,99,'Caldari Sentry Gun II','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,1,0.0000,0,NULL,0),(3742,99,'Gallente Sentry Gun','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,8,0.0000,0,NULL,0),(3743,99,'Minmatar Sentry Gun','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,2,0.0000,0,NULL,0),(3744,805,'Silverfish Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(3745,803,'Viral Infector Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(3746,803,'Wrecker Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(3747,801,'Enforcer Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(3748,805,'Strain Infester Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: High',100000,60,1200,1,NULL,0.0000,0,NULL,0),(3749,805,'Decimator Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(3750,805,'Infester Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(3751,25,'SOCT 1','The Society of Conscious Thought prefers this vehicle for most of its errands.',1200000,17400,180,1,16,0.0000,0,NULL,0),(3752,105,'SOCT 1 Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(3753,25,'SOCT 2','The Society of Conscious Thought prefers this vehicle for many of its errands.',1200000,17400,180,1,16,0.0000,0,NULL,0),(3754,105,'SOCT 2 Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(3755,257,'Jove Frigate',' ',0,0.01,0,1,16,120000.0000,0,NULL,0),(3756,419,'Gnosis','The SoCT\'s Gnosis-class battlecruiser is typically used as an exploration, research or training vessel and is well equipped for such activities. It is even better prepared, however, to guard such tasks from interruption and sabotage.\r\r\n\r\r\nAlthough The Society generally frowns upon violent behavior, extreme (and often, extremely violent) methods are taken to protect its own vessels and the secrets they may carry.\r\r\n\r\r\nThis mission of acquiring, deepening and sharing knowledge is key to the philosophy of the SoCT, and one well-served by the capable and fearsome Gnosis.',10000000,101000,900,1,16,2.0000,1,1698,0),(3757,226,'Minmatar Burst Frigate','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. In the Minmatar Republic, this led to the redesign and redeployment of the Burst. The Burst had been a small and fast cargo vessel. This all changed after the redesign, when the Burst found its small-time mining capabilities curtailed in lieu of logistics systems that moved its focus to shield support for friendly vessels.',0,0,0,1,1,0.0000,0,NULL,0),(3758,257,'Jove Cruiser',' ',0,0.01,0,1,16,1500000.0000,0,NULL,0),(3759,226,'Minmatar Probe Frigate','The Probe is large compared to most Minmatar frigates and is considered a good scout and cargo-runner. Uncharacteristically for a Minmatar ship, its hard outer coating makes it difficult to destroy, while the limited weapon hardpoints force it to rely on fighter assistance if engaged in combat.',0,0,0,1,1,0.0000,0,NULL,0),(3760,226,'Minmatar Rifter Frigate','The Rifter is a very powerful combat frigate and can easily tackle the best frigates out there. It has gone through many radical design phases since its inauguration during the Minmatar Rebellion. The Rifter has a wide variety of offensive capabilities, making it an unpredictable and deadly adversary.',0,0,0,1,1,0.0000,0,NULL,0),(3761,226,'Minmatar Slasher Frigate','The Slasher is cheap, but versatile. It\'s been manufactured en masse, making it one of the most common vessels in Minmatar space. The Slasher is extremely fast, with decent armaments, and is popular amongst budding pirates and smugglers.',0,0,0,1,1,0.0000,0,NULL,0),(3762,226,'Minmatar Vigil  Frigate','The Vigil is an unusual Minmatar ship, serving both as a long range scout as well as an electronic warfare platform. It is fast and agile, allowing it to keep the distance needed to avoid enemy fire while making use of jammers or other electronic gadgets.',0,0,0,1,1,0.0000,0,NULL,0),(3763,226,'Minmatar Thrasher Destroyer','Engineered as a supplement to its big brother the Cyclone, the Thrasher\'s tremendous turret capabilities and advanced tracking computers allow it to protect its larger counterpart from smaller, faster menaces.',0,0,0,1,1,0.0000,0,NULL,0),(3764,30,'Leviathan','Citizens of the State, rejoice!<br>\r\r\nToday, a great milestone has been achieved by our glorious leaders.  A stepping stone in the grand story of our empire has been traversed. Our individual fears may be quietened; the safety of our great nation has been secured.<br>\r\r\nToday, unyielding, we have walked the way of the warrior.  In our hands have our fates been molded.  On the Leviathan\'s back will our civilization be carried home and the taint of the Enemy purged from our souls.<br>\r\r\nRejoice, citizens!  Victory is at hand.<br>\r\r\n<i>-Caldari State Information Bureau Pamphlet, YC 12</i>\r\r\n',2430000000,132500000,13750,1,1,79020634806.0000,1,814,0),(3765,110,'Leviathan Blueprint',' ',0,0.01,0,1,NULL,70000000000.0000,1,885,0),(3766,25,'Vigil','The Vigil is an unusual Minmatar ship, serving both as a long range scout as well as an electronic warfare platform. It is fast and agile, allowing it to keep the distance needed to avoid enemy fire while making use of jammers or other electronic gadgets.',1080000,17400,250,1,2,347344.0000,1,64,0),(3767,105,'Vigil Blueprint',' ',0,0.01,0,1,NULL,2300000.0000,1,264,0),(3768,25,'Amarr Police Frigate','Amarr Police Frigate ',1265000,18100,235,1,4,0.0000,0,NULL,0),(3769,105,'Amarr Police Frigate Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(3770,226,'Minmatar Bellicose Cruiser','Being a highly versatile class of Minmatar ships, the Bellicose has been used as a combat juggernaut as well as a support ship for wings of frigates. While not quite in the league of newer navy cruisers, the Bellicose is still a very solid ship for most purposes, especially in terms of long range combat.',0,0,0,1,1,0.0000,0,NULL,0),(3771,284,'Ectoplasm','Used for the making of the liquid inside starship pilot pods, this thick goo is made primarily out of used cell membranes.',100,0.5,0,1,NULL,900.0000,1,20,0),(3772,226,'Minmatar Rupture Cruiser','The Rupture is slow for a Minmatar ship, but it more than makes up for it in power. The Rupture has superior firepower and is used by the Minmatar Republic both to defend space stations and other stationary objects and as part of massive attack formations.',0,0,0,1,1,0.0000,0,NULL,0),(3773,284,'Hydrochloric Acid','A clear, colorless, fuming, poisonous, highly acidic aqueous solution of hydrogen chloride, used as a chemical intermediate and in petroleum production, ore reduction, and food processing.',100,0.5,0,1,NULL,630.0000,1,20,0),(3774,226,'Minmatar Scythe Cruiser','In YC114 each major empire faction, having been embroiled in a harrowing, extensive, long-term war, recognized the growing need for support and logistics functionality in their vessels during the kind of protracted interstellar warfare that might otherwise prove exhausting for its participants. Both Frigate and Cruiser-class ships were put under the microscope, and in the Minmatar Republic the outcome of the re-evaluation process led, among other developments, to a redesign and redeployment of the Scythe. The Scythe-class cruiser remains the oldest Minmatar ship still in use. It has seen many battles and is an integrated part in Minmatar tales and heritage. With its redesign, past firmware upgrades for mining output were tossed out entirely in favor of two new separate systems that focused on shield transporting and logistics drones respectively.',0,0,0,1,1,0.0000,0,NULL,0),(3775,1034,'Viral Agent','The causative agent of an infectious disease, the viral agent is a parasite with a noncellular structure composed mainly of nucleic acid within a protein coat.',0,1.5,0,1,NULL,850.0000,1,1335,0),(3776,226,'Minmatar Stabber Cruiser','The Stabber is the mainstay of the Minmatar fleet. It is light and extremely fast, yet surprisingly powerful, with a wide variety of weapons. It is one of few Minmatar vessels that have reached popularity outside Minmatar space. ',0,0,0,1,1,0.0000,0,NULL,0),(3777,281,'Long-limb Roes','The eggs of the hanging long-limb are among the most sought after delicacies in fancy restaurants. The roe is quite rare because no one has succeeded in breeding the species outside its natural planetary habitat.',400,1,0,1,NULL,2400.0000,1,492,0),(3778,226,'Minmatar Cyclone Battlecruiser','The Cyclone was created in order to meet the increasing demand for a vessel capable of providing muscle for frigate detachments while remaining more mobile than a battleship. To this end, the Cyclone\'s seven high-power slots and powerful thrusters have proved ideal.',0,0,0,1,1,0.0000,0,NULL,0),(3779,1042,'Biomass','A catch-all term for composite material obtained from living things, biomass has several unique properties that make it ideal for various industrial, commercial, and personal uses. Its most important attribute is that it retains many of its nutrients even after being harvested, transported, and processed.',0,0.38,0,1,NULL,1.0000,1,1334,0),(3780,226,'Minmatar Hurricane Battlecruiser','The force with which this ship hits is more than sufficient to leave a trail of shattered enemies, floating around like so much lifeless debris. An adaptable vessel, it has enough turret hardpoints for a full-scale assault while remaining versatile enough to allow for plenty of missile fire, and has both sufficient speed to outrun its enemies and sufficient capacitor charge to outlast them.',0,0,0,1,1,0.0000,0,NULL,0),(3781,226,'Minmatar Maelstrom Battleship','With the Maelstrom, versatility is the name of the game. Its defensive capabilities make it ideally suited for small raid groups or solo work, while its 8 turret hardpoints present opportunities for untold carnage on the fleet battlefield. ',0,0,0,1,1,0.0000,0,NULL,0),(3782,226,'Minmatar Tempest Battleship','The Tempest is one of the Republic Fleet\'s key vessels; a versatile gunship proficient at long-range bombardment and capable of dishing out specialized types of damage with great effectiveness. A well-rounded squadron of Tempests has been proven time and time again to be an invaluable wild card in a fleet battle, one which opponents should ignore at their own peril.',0,0,0,1,1,0.0000,0,NULL,0),(3783,226,'Minmatar Typhoon Battleship','Much praised by its proponents and much maligned by its detractors, the Typhoon-class battleship has always been one of the most hotly debated spacefaring vessels around. Its distinguishing aspect - and the source of most of the controversy - is its sheer versatility, variously seen as either a lack of design focus or a deliberate freedom for pilot modification.',0,0,0,1,1,0.0000,0,NULL,0),(3784,226,'Minmatar Hel Carrier','Inspired by a vicious scissor-toothed shark indigenous to old-world Matar, the Hel is widely viewed as a sign of a Republic out for blood. Since the beginning of its development it has remained a project cloaked in secrecy, with precious few people aware of its progress and its capabilities, and its formal unveiling has come as a defiant slap in the face to many who formerly believed the Matari incapable of working at this scale of starship design. Whatever comprises the soil of its roots, though, one thing is clear: from no-frills living quarters to grim, unadorned aesthetic, this ferocious behemoth has been designed for one purpose and one purpose only.  Imagine a swarm of deadly hornets pouring from the devil\'s mouth. Now imagine they have autocannons.  -Unknown Hel designer',0,0,0,1,1,0.0000,0,NULL,0),(3785,226,'Minmatar Nidhoggur Carrier','Essentially a pared-down version of its big brother the Hel, the Nidhoggur nonetheless displays the same austerity of vision evident in its sibling. Quite purposefully created for nothing less than all-out warfare, and quite comfortable with that fact, the Nidhoggur will no doubt find itself a mainstay on many a battlefield.',0,0,0,1,1,0.0000,0,NULL,0),(3786,226,'Minmatar Naglfar Dreadnought','The Naglfar is based on a Matari design believed to date back to the earliest annals of antiquity. While the exact evolution of memes informing its figure is unclear, the same distinctive vertical monolith form has shown up time and time again in the wind-scattered remnants of Matari legend. Boasting an impressive versatility in firepower options, the Naglfar is capable of holding its own against opponents of all sizes and shapes. While its defenses don\'t go to extremes as herculean as those of its counterparts, the uniformity of resilience - coupled with the sheer amount of devastation it can dish out - make this beast an invaluable addition to any fleet.',0,0,0,1,1,0.0000,0,NULL,0),(3787,226,'Minmatar Ragnarok Titan','The liberty of our people is solely our responsibility. Tempting as it is to foist this burden upon our well-wishers, we must never forget that the onus of our emancipation rests with us and us alone. For too long, our proud people have been subjugated to the whims of enslavers, forced to endure relentless suffering and humiliation at the hands of people whose motivations, masked though they may be by florid religious claptrap, remain as base and despicable as those of the playground bully. If ever there was a time to rise   if ever there was a time to join hands with our brothers   that time is now. At this exact junction in history we have within our grasp the means to loosen our tormentors\' hold and win freedom for our kin. Opportunities are there to be taken. Brothers, we must rise. -Malaetu Shakor, Republic Parliament Head Speaking before the Tribal Council November 27th, YC 107',0,0,0,1,1,0.0000,0,NULL,0),(3788,226,'Minmatar Hoarder Industrial Ship','The Hoarder is the second in line of the Minmatar industrial ships, it\'s not as strong as the Mammoth but its cargo space is very large for its price. It\'s perfect for operation in peaceful areas or when it has strong escort.',0,0,0,1,1,0.0000,0,NULL,0),(3789,226,'Minmatar Mammoth Industrial Ship','The Mammoth is the biggest and the strongest industrial ship of the Minmatar Republic. It was designed with aid from the Gallente Federation, making the Mammoth both large and powerful yet also nimble and technologically advanced. A very good buy.',0,0,0,1,1,0.0000,0,NULL,0),(3790,226,'Minmatar Wreathe Industrial Ship','The Wreathe is an old ship of the Minmatar Republic and one of the oldest ships still in usage. The design of the Wreathe is very plain, which is the main reason for its longevity, but it also makes the ship incapable of handling anything but the most mundane tasks.',0,0,0,1,1,0.0000,0,NULL,0),(3791,226,'Minmatar Fenrir Freighter','Third in line to jump on the freighter bandwagon, the Republic decided early in the design process to focus on a balance between all ship systems. True to form, their creation is comparatively lightweight - though lightweight is certainly not a term easily applicable to this giant.',0,0,0,1,1,0.0000,0,NULL,0),(3792,306,'Caldari Academy Office  ','The Pilot Certification Documents can be retrieved from inside this office. ',10000,27500,2700,1,4,0.0000,0,NULL,0),(3793,538,'Data Subverter I','A specialized computer and communications suite designed to assist attempts to subvert the control routines of orbital structures.\r\r\n\r\r\n<i>\"You fail to understand. This is our time now. Since prehistory, we have fought each other, first with clubs, then with guns and with beams of energy. Now we shall fight with our minds amidst the beautiful spinning streams of data interconnecting all life on all worlds.<br>\r\r\nResist, if you like. Your efforts will only hasten the time when we wrest control from you and all the rest of the old order.\"<br>\r\r\n- Note left in Federal Intelligence Office mainframe by anonymous hacker</i>',0,5,0,1,NULL,51464.0000,1,NULL,0),(3794,917,'Data Subverter I Blueprint',' ',0,0.01,0,1,NULL,332640.0000,1,NULL,0),(3795,495,'Blood Raider Central Bastion','This massive structure sends signals to its neighbors and the rest of the complex constantly, processing and coordinating all functions. An armament of Citadel torpedo batteries, < a href=evebrowser:http://wiki.eveonline.com/en/wiki/Item_Database:Ship_Equipment:Electronic_Warfare:Stasis_Webifiers>stasis webifiers</a>, and advanced repair functions reinforce the already formidable structure. ',1000,1000,1000,1,4,0.0000,0,NULL,0),(3796,6,'Sun O1 (Blue Bright)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(3797,6,'Sun G5 (Pink)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(3798,6,'Sun K5 (Orange Bright)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(3799,6,'Sun G3 (Pink Small)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(3800,6,'Sun M0 (Orange radiant)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(3801,6,'Sun A0 (Blue Small)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(3802,6,'Sun K3 (Yellow Small)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(3803,6,'Sun B5 (White Dwarf)',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(3804,283,'VIPs','Very important people. Business executives, politicians, diplomats and game designers.',130,3,0,1,NULL,1000.0000,1,NULL,0),(3805,495,'Sansha\'s Nation Central Bastion','Brimming with electronics and defensive batteries, the Sansha central bastion coordinates and collates hundreds of petabytes of Nation neural traffic daily. Frequently found at the heart of a Sansha local network, the bastion also serves as a common storage point for advanced Sansha starship modules.',1000,1000,1000,1,4,0.0000,0,NULL,0),(3806,283,'Refugees','When wars and epidemics break out, people flee from their homes, forming massive temporary migrations.',400,1,0,1,NULL,0.0000,1,23,0),(3807,226,'Miniball hax',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3808,283,'Prisoners','Transporting prisoners is a task that requires trust and loyalty to the empire\'s legislative arm, but it is one of the least sought-after jobs in the known universe.',560,7.5,0,1,NULL,100.0000,1,NULL,0),(3809,495,'Serpentis Administration Facility','This structure houses a full staff of research techs, engineers, and pencil pushers. It is also heavily armored and upgraded with the latest in military grade anti-spacecraft batteries.',1000,1000,1000,1,8,0.0000,0,NULL,0),(3810,283,'Marines','When war breaks out, the demand for transporting military personnel on site can exceed the grasp of the military organization. In these cases, the aid from non-military spacecrafts is often needed.',1000,2,0,1,NULL,1000.0000,1,23,0),(3811,306,'Minmatar Academy Office','The Pilot Certification Documents can be retrieved from inside this office. ',10000,27500,2700,1,4,0.0000,0,NULL,0),(3812,280,'Data Sheets','These complicated data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.',1,1,0,1,NULL,150.0000,1,20,0),(3814,280,'Reports','These encoded reports may mean little to the untrained eye, but can prove valuable to the relevant institution.',1,0.1,0,1,NULL,30.0000,1,20,0),(3818,313,'Exile','This booster is highly addictive and has been known to cause aggressive behavior.',800,1,0,1,NULL,15500.0000,1,491,0),(3820,313,'Sooth Sayer','This booster causes the subject to fall into a blissful sleep. Reports tell of abusers falling into a deep coma, never to regain consciousness.',800,1,0,1,NULL,8900.0000,1,491,0),(3821,821,'Dread Guristas Commanding Officer','<font color=yellow>Subject:</font> Dread Guristas Commanding Officer (ID: Modified Caldari Raven)<br>\r\r\n<font color=yellow>Military Specifications:</font> Battleship-class vessel. Heavily modified for increased shield and weapon system performance. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> Like the majority of Gurista craft, this ship is a variant on Caldari design, in this case the infamous Raven. Analyses of salvaged wrecks have found numerous aftermarket modifications. Common alterations include custom torpedo tubes capable of handling over-packed payloads and the removal of output governing systems on shield emitters. These systems result in a perceived increase of performance, but put crews at increased risk of burns, radiation poisoning, and, in the case of catastrophic failure, immolation in fires exceeding 10,000 Kelvin.<br>\r\r\n<i>Analyst Boselena, CDIA.</i><br><i>Authorized for capsuleer dissemination.</i>  ',19000000,19000000,120,1,1,0.0000,0,NULL,0),(3822,313,'Frentix','The Frentix fluid is used as a relaxative drug on subjects in heavy pain. Abuse of this booster is common in underground communities around the universe.',5,0.2,0,1,NULL,1400.0000,1,491,0),(3823,821,'True Sansha Archduke','<font color=yellow>Subject:</font> True Sansha Archduke (ID: Modified Nightmare)<br>\r\r\n<font color=yellow>Military Specifications:</font> Battleship-class vessel. Heavily modified for increased armor and weapon system performance. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> The Archduke Nightmare variant is favored by Sansha military outpost commanders. While perhaps not as advanced as the ships flown by Sansha incursion forces, the Archduke is clearly built with the lessons from capsuleer battles in mind: Molten salt coolant systems allow for overcharged energy turrets. Physical link cables connect key True Slave crew members directly to their ship commander, preventing any electronic interference from affecting the crew. Supplemental adaptive armor plates line the hull. <br><br>This is all in addition to several proprietary Nation modules and other experimental tech found exclusively, if inconsistently, among models of the Archduke variant.\r\r\n<i>Analyst Atros, CDIA.</i><br><i>Authorized for capsuleer dissemination.</i>  ',19000000,19000000,120,1,4,0.0000,0,NULL,0),(3824,313,'Crystal Egg','Crystal is a common feel-good booster, used and abused around the universe in abundance.',500,0.5,0,1,NULL,5000.0000,1,491,0),(3825,821,'Dark Blood Hunter','<font color=yellow>Subject:</font> Dark Blood Hunter (ID: Modified Bhaalgorn)<br>\r\r\n<font color=yellow>Military Specifications:</font> Battleship-class vessel. Heavily modified for increased armor and enhanced laser penetration. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> The Bhaalgorn variant used exclusively by Dark Blood Hunters betrays the ship\'s design goal: direct engagement with capsuleer ships. The outer hull is reinforced with a further 18 inches of armor plating. Energy turrets are fitted with a molten salt cooling system, allowing a  hotter  discharge. To accommodate the obscene power needs, a full two-thirds of the crew space is replaced with additional power generators. Ironically, the ship\'s advanced composition also makes it a tempting target for many capsuleers, as Dark Blood Hunter wreckage often contains advanced modules exclusive to the Blood Raider Covenant.<br>\r\r\n<i>Analyst Rurkanid, CDIA.</i><br><i>Authorized for capsuleer dissemination.</i>  \r\r\n',19000000,19000000,120,1,4,0.0000,0,NULL,0),(3826,313,'Mindflood','Highly addictive fluid of which the toxic fumes are inhaled through the nostrils of the user. Mindflood kills braincells quicker than submerging one\'s brain in battery acid.',5,0.2,0,1,NULL,1500.0000,1,491,0),(3827,821,'Shadow Serpentis Big Boss','<font color=yellow>Subject:</font> Shadow Serpentis Big Boss (ID: Modified Vindicator)<br>\r\r\n<font color=yellow>Military Specifications:</font> Battleship-class vessel. Heavily modified for increased shield and weapon system performance. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> This variant of the familiar Serpentis Vindicator was first encountered at the conclusion of a prolonged but failed SARO sweep operation. SARO ships had a sizable Serpentis fleet on the run, until a commander in this Vindicator variant entered the scene. The resilience and coordination abilities of the vessel led several SARO agents on scene to name it the  Big Boss,  a name which has come to be attached to the entire variant line.<br>\r\r\nIn addition to a second power tram to the shield emitters and redundant targeting systems, the Big Boss features the latest in Serpentis-engineered modular equipment and weaponry.<br>\r\r\n<i>Analyst Crarch, CDIA.</i><br>\r\r\n<i>Authorized for capsuleer dissemination.</i>  \r\r\n',19000000,19000000,120,1,8,0.0000,0,NULL,0),(3828,1034,'Construction Blocks','Metal girders, plasteel concrete, and fiber blocks are all common construction materials used in almost every large-scale building or manufacturing project throughout New Eden.',0,1.5,0,1,NULL,500.0000,1,1335,0),(3829,38,'Medium Shield Extender I','Increases the maximum strength of the shield.',0,10,0,1,NULL,13924.0000,1,606,0),(3830,118,'Medium Shield Extender I Blueprint',' ',0,0.01,0,1,NULL,124740.0000,1,1549,0),(3831,38,'Medium Shield Extender II','Increases the maximum strength of the shield.',0,10,0,1,NULL,216164.0000,1,606,0),(3832,118,'Medium Shield Extender II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3835,306,'Gallente Academy Office','The Pilot Certification Documents can be retrieved from inside this office. ',10000,27500,2700,1,4,0.0000,0,NULL,0),(3836,526,'Pilot Certification Documents','This document, specifically designed for capsuleers, certifies that the holder has passed basic training and is cleared for further instruction, as well as general employment throughout the cluster. A basic level of piloting proficiency is required before being awarded the certification, and the capsuleers must demonstrate competency in a range of fundamental navigation and combat tasks.\r\r\n\r\r\nAlthough the document is not required by CONCORD police or empire law, it significantly adds to the employment prospects of a newly-graduated capsuleer. Throughout repeated surveys and tests one common pattern emerges; those capsuleers who complete this basic training and other more advanced courses have a much higher chance of employment with other capsuleer corporations, and generally finds themselves more confident and knowledgeable in the often turbulent and confusing first few days of becoming a full-fledged capsuleer.\r\r\n\r\r\nNot only that, but graduates get a swanky new outfit to show off to the dropouts and plebeians who couldn\'t cut it.\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(3837,314,'Token of Submission','A document representing submission to the authority of the Amarrian Empress, Jamyl Sarum.\r\r\n\r\r\nNotably, the language surrounding capsuleer fealty has been significantly watered down, revealing that even the Amarr Empire is willing to acknowledge the reality of capsuleer freedom and autonomy. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(3838,314,'Clearance Documents','These documents clear the holder from numerous by-laws and responsibilities within the Caldari State and abroad. \r\r\n\r\r\nThey are issued to capsuleers, who typically operate above the law and are accountable to few people. All this document does is formalize that reality, and as such, is entirely redundant and pointless. \r\r\n\r\r\nThe hypercapitalist corporate state of the Caldari is awash with these sorts of documents, however, and the tendency towards needless bureaucracy is simply a part of corporate life. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(3839,38,'Large Shield Extender I','Increases the maximum strength of the shield.',0,20,0,1,NULL,34710.0000,1,608,0),(3840,118,'Large Shield Extender I Blueprint',' ',0,0.01,0,1,NULL,312420.0000,1,1549,0),(3841,38,'Large Shield Extender II','Increases the maximum strength of the shield.',0,20,0,1,NULL,308118.0000,1,608,0),(3842,118,'Large Shield Extender II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3843,314,'Tribal Sponsorship','Tribal sponsorship is a longstanding tradition within the Minmatar Republic. Typically sponsorship is sought by an individual before embarking on a journey away from their tribe, or as part of a corporation\'s employment process. After a sometimes lengthy approval process, a Minmatar is then able to proceed with the full support of their tribal peers. \r\n\r\nTypically, a citizen of the Republic will seek sponsorship from only their family tribe, and this is usually sufficient to last their lifetime, barring any dramatic changes. In some rare circumstances, sponsorship is granted from all of the seven tribes to particularly promising individuals. \r\n\r\nIn the unique case of the capsuleers, the seven tribes of the Republic have agreed to blanket-issue sponsorships as an attempt to encourage loyalty and cooperation.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(3844,314,'Freedom of Operation License','This document is issued to all graduate capsuleers, regardless of their ethnicity or background. \r\r\n\r\r\nIn the document, various fundamental human rights are outlined and defended, including the freedom to travel, freedom to work for a corporation of one\'s choosing, and freedom of speech within Gallente Federation borders. \r\r\n\r\r\nThe document is somewhat redundant for capsuleers, who enjoy these freedoms and others even greater. Despite this obvious fact, the Federation authorities have chosen to issue the license all the same, viewing it as a symbolic gesture, and a reminder of the Federation\'s core values. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(3845,306,'Amarr Cargo Rig','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',10000,27500,2700,1,4,0.0000,0,NULL,0),(3846,306,'Caldari Cargo Rig','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',10000,27500,2700,1,4,0.0000,0,NULL,0),(3847,306,'Gallente Cargo Rig','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',10000,27500,2700,1,8,0.0000,0,NULL,0),(3848,306,'Minmatar Cargo Rig','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',10000,27500,2700,1,2,0.0000,0,NULL,0),(3849,38,'Micro Shield Extender I','Increases the maximum strength of the shield.',0,2.5,0,1,4,2000.0000,0,NULL,0),(3851,38,'Micro Shield Extender II','Increases the maximum strength of the shield.',0,2.5,0,1,4,37178.0000,0,NULL,0),(3858,319,'Tutorial Fuel Depot','This depot contains fuel for the surrounding structures.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(3859,1109,'genericAudioEmitter',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3863,301,'CONCORD Police Officer','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',2040000,20400,100,1,NULL,0.0000,0,NULL,0),(3864,15,'Amarr Citadel',' ',0,0,0,1,4,0.0000,0,NULL,0),(3865,15,'Gallente Research Station',' ',0,1,0,1,8,0.0000,0,NULL,0),(3866,15,'Gallente Trading Hub',' ',0,1,0,1,8,0.0000,0,NULL,0),(3867,15,'Gallente Industrial Station',' ',0,1,0,1,8,0.0000,0,NULL,0),(3868,15,'Gallente Administrative Station',' ',0,1,0,1,8,0.0000,0,NULL,0),(3869,15,'Gallente Logistics Station',' ',0,1,0,1,8,0.0000,0,NULL,0),(3870,15,'Gallente Mining Station',' ',0,1,0,1,8,0.0000,0,NULL,0),(3871,15,'Caldari Station Hub',' ',0,1,0,1,1,0.0000,0,NULL,0),(3872,15,'Caldari Military Station',' ',0,1,0,1,1,0.0000,0,NULL,0),(3873,10,'Stargate (Caldari Border)',' ',100000000000,10000000000,0,1,1,0.0000,0,NULL,0),(3874,10,'Stargate (Gallente Constellation)',' ',100000000000,10000000,0,1,8,0.0000,0,NULL,0),(3875,10,'Stargate (Gallente System)',' ',100000000000,10000000,0,1,8,0.0000,0,NULL,0),(3876,10,'Stargate (Gallente Border)',' ',100000000000,1000000000,0,1,8,0.0000,0,NULL,0),(3877,10,'Stargate (Minmatar Constellation)',' ',100000000000,10000000,0,1,2,0.0000,0,NULL,0),(3880,226,'Ripped Superstructure','This enormous part of a stellar construct carries a melancholic atmosphere.',0,0,0,1,NULL,0.0000,0,NULL,0),(3881,226,'Ruined Monument','An archaic reminder of the days of olde.',0,0,0,1,NULL,0.0000,0,NULL,0),(3882,820,'Exsanguinator ','<font color=yellow>Subject:</font> Exsanguinator (ID: Modified Prophecy) <br>\r\r\n<font color=yellow>Military Specifications:</font> Battlecruiser-class vessel. Heavily modified for increased armor and energy weapon output. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> The danger involved in confronting a Blood Raider Exsanguinator cannot be overstated. These terrifying individuals represent some of the worst the Covenant has to offer, ruthless warriors with an absolute devotion to their organization\'s ideals. Their lust for capsuleer blood is legendary. <br>\r\r\n<i>Analyst Nadiri, CDIA. </i><br>\r\r\n<i>Authorized for capsuleer dissemination. </i>',11800000,118000,235,1,4,0.0000,0,NULL,0),(3883,288,'DED Army Officer','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',2040000,20400,100,1,NULL,0.0000,0,NULL,0),(3884,820,'Guristas Distributor','<font color=yellow>Subject:</font> Distributor (ID: Modified Ferox) <br>\r\r\n<font color=yellow>Military Specifications: </font> Battlecruiser-class vessel. Heavily modified for increased shield and weapon system performance. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> Little remains of what was once an off-the-rack Ferox cruiser. The Guristas take their security very seriously, as is evident by numerous missile launchers and support hardware to ensure they function at peak performance. Initial readouts indicate a high yield of kinetic and thermal ballistics. <br>\r\r\n<i>Analyst Nadiri, CDIA. </i><br>\r\r\n<i>Authorized for capsuleer dissemination. </i>\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(3885,301,'CONCORD Police Captain','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',10100000,101000,1000,1,NULL,0.0000,0,NULL,0),(3886,288,'DED Army Captain','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',10100000,101000,1800,1,NULL,0.0000,0,NULL,0),(3887,285,'Co-Processor I','Increases CPU output.',0,5,0,1,NULL,16428.0000,1,676,0),(3888,285,'Co-Processor II','Increases CPU output.',0,5,0,1,NULL,151146.0000,1,676,0),(3889,820,'Slave Ation09','<font color=yellow>Subject:</font> Slave Ation09 (ID: Modified Phantasm) <br>\r\r\n<font color=yellow>Military Specifications:</font> Enhanced variant of Sansha\'s Nation cruiser model. Extreme caution recommended. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> Taken during the incursion at Ation, this high-ranking officer of True Creations has been tasked with maintaining Nation\'s supply of neural paralytics, an essential component of their harvesting tactic. Naturally, he has also been commanded by Kuvakei himself to attack and destroy any threats to Nation assets. <br>\r\r\n<i>Senior Analyst Epo, CDIA. </i><br>\r\r\n<i>Authorized for capsuleer dissemination. </i>',10010000,100100,235,1,4,0.0000,0,NULL,0),(3890,820,'Sarpati Family Enforcer','<font color=yellow>Subject:</font> Sarpati Family Enforcer (ID: Modified Brutix) <br>\r\r\n<font color=yellow>Military Specifications:</font> Battlecruiser-class vessel. Do not engage without assistance. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> Representatives of the Sarpati family often tour Serpentis Corporation facilities to ensure that their operations are efficient and secure. They have been known to execute their own employees as examples to others and are too well paid to ever think of resigning, so they have absolutely no qualms about engaging interlopers. <br>\r\r\n<i>Associate Analyst Kepeck, CDIA. </i><br>\r\r\n<i>Authorized for capsuleer dissemination. </i>',11200000,112000,480,1,8,0.0000,0,NULL,0),(3891,820,'5/10 DED Angel Big Boss','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(3893,278,'Mining Connections','Understanding of corporate culture on the industrial level and the plight of the worker.\r\n\r\nImproves loyalty point gain by 10% per level when working for agents in the Mining corporation division.',0,0.01,0,1,NULL,20000000.0000,1,376,0),(3894,278,'Distribution Connections','Understanding of the way trade is conducted at the corporate level.\r\n\r\nImproves loyalty point gain by 10% per level when working for agents in the Distribution corporation division.',0,0.01,0,1,NULL,20000000.0000,1,376,0),(3895,278,'Security Connections','Understanding of military culture.\r\r\n\r\r\nImproves loyalty point gain by 10% per level when working for agents in the Security corporation division.',0,0.01,0,1,NULL,20000000.0000,1,376,0),(3897,72,'Micro Proton Smartbomb I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,2.5,0,1,NULL,20000.0000,1,380,0),(3898,303,'Quafe Zero','Congratulations, capsuleer! You have acquired a batch of Quafe Zero, the performance drink with the powers of a booster! Enjoy the benefits of increased reflexes with none of the drawbacks!\r\r\n\r\r\n<font color=\"yellow\">Benefits:</font>\r\r\n+5% Speed, +5% Scan Resolution. Duration: 1 hour.\r\r\n\r\r\n<i>Attached Ad Copy</i>\r\r\nAs a capsuleer, you are immortal. You have all eternity to seize your destiny. Shouldn t you have a soft drink that can perform as well as you? Quafe thinks so. That s why we ve developed Quafe Zero.\r\r\n\r\r\nUsing the latest in cutting edge biotechnology, our industry-leading scientists have reverse-engineered Quafe Zero from compounds found only in Sleeper vessels. Quafe Zero is fortified with a proprietary mix of performance enhancers, oxidizers, and natural fruit juices designed to push your abilities to the limit.\r\r\n\r\r\nThe secret is in our patented fulleroferrocene nanite delivery system, which attaches our exclusive pro-capsuleer formula directly to the neurons you want, not the ones you don t. The result is an immediate and direct boost to your performance, with Zero drawbacks!\r\r\n\r\r\n<font size=\"2\">Quafe Zero is a product of the Quafe Company. Quafe does not condone the use of boosters or other illicit substances. The Quafe Company disavows responsibility for any side effects caused by consuming Sleeper technology.\r\r\n\r\r\nWarning: Quafe Zero is designed for capsuleer use only. Side effects experienced by non-capsuleers include but are not limited to dizziness, blindness, nausea, internal hemorrhaging, IBS, sleepwalking, amnesia, sexual deviancy, vision changes, acute epidermal sloughing, partial or total loss of motor control, and minor skin rash.\r\r\n\r\r\nQuafe Zero is manufactured in the Phoenix constellation.</font>\r\r\n\r\r\nQuafe Zero: Multiply your eternity by Zero!',1,1,0,1,NULL,0.0000,1,977,0),(3899,72,'Micro Proton Smartbomb II','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,2.5,0,1,NULL,60288.0000,1,380,0),(3901,72,'Micro Graviton Smartbomb I','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,2.5,0,1,NULL,22500.0000,1,380,0),(3903,72,'Micro Graviton Smartbomb II','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,2.5,0,1,NULL,60288.0000,1,380,0),(3907,72,'Micro Plasma Smartbomb I','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,2.5,0,1,NULL,25000.0000,1,380,0),(3909,72,'Micro Plasma Smartbomb II','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,2.5,0,1,NULL,60288.0000,1,380,0),(3910,940,'Caldari Sofa',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3911,940,'Caldari Ship Interface',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3913,72,'Micro EMP Smartbomb I','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,2.5,0,1,NULL,27500.0000,1,380,0),(3914,940,'Caldari Main Screen',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3915,72,'Micro EMP Smartbomb II','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,2.5,0,1,NULL,60288.0000,1,380,0),(3916,940,'Caldari Planetary Interaction',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3919,940,'Caldari Corporation Recruitment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3920,226,'Fortified Amarr Industrial Station','Amarr Industrial Station.',0,0,0,1,4,0.0000,0,NULL,0),(3921,818,'Pirate Saboteur','This is an inexperienced saboteur. Saboteurs usually has skills for different kinds of related work, such as espionage, counterfeiting or infiltration. Such actions are often required before an actual sabotage takes place.',2450000,24500,60,1,4,0.0000,0,NULL,0),(3922,280,'Hardware','Hardware used in supplies.',2500,2,0,1,NULL,1260.0000,0,NULL,0),(3923,283,'Clones','Clones used in supplies',400,1000,0,1,8,0.0000,0,NULL,0),(3925,526,'Reclaimed Organics','A heterogeneous slurry of various biological tissues and fluids, produced from the remains of (formerly) living organisms.\r\r\n\r\r\nWhile considered mildly hazardous on its own, advanced technology is capable of growing this organic bulk matter into valuable, clone-grade flesh.\r\r\n\r\r\n<i>\"With the right spices, the mouth cannot distinguish cheap meat from a Holder\'s feast.\" - Apocryphal Amarrian proverb</i>',0,2,0,1,NULL,0.0000,0,NULL,0),(3926,526,'Augmented Stem Cells','Augmented stem cells are vital in the process of re-using biological matter, used for instance with growing clones. ',0,0.38,0,1,NULL,0.0000,0,NULL,0),(3927,914,'Clones Blueprint','sdf',0,0.01,0,1,NULL,0.0000,0,NULL,0),(3928,914,'Hardware Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(3930,940,'Minmatar Sofa',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3931,940,'Minmatar Ship Interface',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3932,940,'Minmatar Main Screen',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3933,940,'Minmatar Corporation Recruitment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3934,940,'Minmatar Planetary Interaction',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(3937,72,'Medium Proton Smartbomb I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,25,0,1,NULL,168302.0000,1,383,0),(3938,152,'Medium Proton Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,341,0),(3939,72,'Medium Proton Smartbomb II','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,10,0,1,NULL,434750.0000,1,383,0),(3940,152,'Medium Proton Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3941,72,'Medium Graviton Smartbomb I','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,25,0,1,NULL,192508.0000,1,383,0),(3942,152,'Medium Graviton Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,1600000.0000,1,341,0),(3943,72,'Medium Graviton Smartbomb II','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,10,0,1,NULL,458956.0000,1,383,0),(3944,152,'Medium Graviton Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3947,72,'Medium Plasma Smartbomb I','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,25,0,1,NULL,217952.0000,1,383,0),(3948,152,'Medium Plasma Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,1700000.0000,1,341,0),(3949,72,'Medium Plasma Smartbomb II','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,10,0,1,NULL,484400.0000,1,383,0),(3950,152,'Medium Plasma Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3952,226,'Fortified Archon','The Archon was commissioned by the Imperial Navy to act as a personnel and fighter carrier. The order to create the ship came as part of a unilateral initative issued by Navy Command in the wake of Emperor Kor-Azor\'s assassination. Sporting the latest in fighter command interfacing technology and possessing characteristically strong defenses, the Archon is a powerful aid in any engagement.',0,0,0,1,4,0.0000,0,NULL,0),(3953,72,'Medium EMP Smartbomb I','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,25,0,1,NULL,205464.0000,1,383,0),(3954,152,'Medium EMP Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,1800000.0000,1,341,0),(3955,72,'Medium EMP Smartbomb II','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,10,0,1,NULL,471912.0000,1,383,0),(3956,152,'Medium EMP Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3957,226,'Serpentis Stronghold','This gigantic station is one of the Serpentis military installations and a black jewel of the alliance between The Guardian Angels and The Serpentis Corporation. Even for its size, it has no commercial station services or docking bays to receive guests.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(3958,1083,'GDN-9 \"Nightstalker\" Combat Goggles','The GDN line of safety and combat optical systems began humbly, used only by a small number of Caldari PMCs   that is, until the YC 113 action holoreel sequel <i>Smash 4 the State</i> shot the GDN-8 firmly in the public\'s collective eye. Now, GDN-9  Nightstalker  cosmetic goggles will fulfill your desire to own the GDN-8 without the need to purchase military-grade electronics or radiation-proofing. ',0,0.1,0,1,NULL,0.0000,1,1408,0),(3959,818,'Criminal Saboteur','This is an inexperienced saboteur. Saboteurs usually has skills for different kinds of related work, such as espionage, counterfeiting or infiltration. Such actions are often required before an actual sabotage takes place.',2450000,24500,60,1,1,0.0000,0,NULL,0),(3960,818,'Bandit Saboteur','This is an inexperienced saboteur. Saboteurs usually has skills for different kinds of related work, such as espionage, counterfeiting or infiltration. Such actions are often required before an actual sabotage takes place.',2450000,24500,60,1,8,0.0000,0,NULL,0),(3961,818,'Rogue Saboteur','This is an inexperienced saboteur. Saboteurs usually has skills for different kinds of related work, such as espionage, counterfeiting or infiltration. Such actions are often required before an actual sabotage takes place.',2450000,24500,60,1,4,0.0000,0,NULL,0),(3962,1106,'Customs Office Gantry','A rigid scaffold equipped with stabilizing thrusters and microgravity fabrication facilities, this gantry is designed for the erection of large, stationary structures in the orbit of planetary bodies. This model provides the skeleton for an orbital Customs Office.\r\r\n\r\r\nNote: In an effort to reduce waste, <b>the gantry will be consumed during construction</b> and its materials will be incorporated into the new structure.\r\r\n',1000000,7600,19500001,1,NULL,0.0000,1,1410,0),(3963,1048,'Customs Office Gantry Blueprint',' ',0,0.01,0,1,NULL,25000001.0000,1,NULL,0),(3964,1025,'Orbital Command Center','Orbital Command Centers provide the basic communication, command & control facilities necessary to integrate a planetary society and economy into an interstellar community. They serve as bases from which power can be projected into the local area, as well as hubs of economic activity.\r\r\n\r\r\nHowever, they lack the power plants, drydocks and other facilities necessary to qualify as full, starship-capable Outposts.\r\r\n\r\r\n<i>Elyse: Wait, are you the kid from Oursulaert who steals drones and sets holders\' robes on fire? (pause) I\'m on a crew with Gallente\'s Most Wanted?\r\r\n\r\r\nThaddeus: Is there going to be a problem?\r\r\n\r\r\nElyse: Hell no, this is going to be the best shift ever!\r\r\n\r\r\n- Excerpt from S1E3 of the smash hit holoseries, \"The OCC\"</i>',5000000000,100000000,25000,1,NULL,91119080.0000,0,NULL,0),(3966,1091,'Men\'s \'Precision\' Boots','Designer: Vallou\r\r\n\r\r\nEven the strongest commander needs support. Our \"Precision\" collection introduces the latest in military style with these perfect pitch black uniform boots. Polished leather outer-soles conceal a rugged grip and metal heel-caps; Veproco-treated leather uppers maintain a sleek shine no matter the environment. Our patented shock-resistant inner cushioning reduces leg strain when you need to stay on your feet, and the dual-zip front improves fit and comfort without sacrificing style. Command in confidence.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(3967,226,'Fortified Gallente Station 7','Docking has been prohibited into this station without proper authorization.',0,0,0,1,4,0.0000,0,NULL,0),(3970,226,'Federation Administrative Outpost','A standard outpost of Gallentean design.',0,0,0,1,8,0.0000,0,NULL,0),(3974,226,'Minmatar Service Outpost Structure','A service outpost for Minmatar traders and travelers. ',0,0,0,1,2,0.0000,0,NULL,0),(3975,1088,'Women\'s \'Structure\' Dress (navy)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(3977,72,'Large Proton Smartbomb I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,50,0,1,NULL,348310.0000,1,381,0),(3978,152,'Large Proton Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,3000000.0000,1,341,0),(3979,72,'Large Proton Smartbomb II','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,50,0,1,NULL,881206.0000,1,381,0),(3980,152,'Large Proton Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3981,72,'Large Graviton Smartbomb I','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,50,0,1,NULL,439640.0000,1,381,0),(3982,152,'Large Graviton Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,3200000.0000,1,341,0),(3983,72,'Large Graviton Smartbomb II','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,50,0,1,NULL,972536.0000,1,381,0),(3984,152,'Large Graviton Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3986,585,'Large Remote Hull Repairer II','This module uses nano-assemblers to repair damage done to the hull of the Target ship.',20,50,0,1,NULL,830378.0000,1,1062,0),(3987,72,'Large Plasma Smartbomb I','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,50,0,1,NULL,461624.0000,1,381,0),(3988,152,'Large Plasma Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,3400000.0000,1,341,0),(3989,72,'Large Plasma Smartbomb II','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,50,0,1,NULL,994520.0000,1,381,0),(3990,152,'Large Plasma Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3991,870,'Large Remote Hull Repairer II Blueprint',' ',0,0.01,0,1,NULL,3000000.0000,1,NULL,0),(3992,1090,'Men\'s \'Commando\' Pants (black wax)','Designer: Sennda of Emrayur\r\r\n\r\r\nWhether ranking officer or rank-and-file, look prepared and professional in our gartered \"Commando\" pants. Our classic soft wool blend affords comfort, and the pleated front and comfort-woven lower legs offer a martial silhouette in a contrast of matte black and a midnight black sheen, along with an ease of movement that would please any career soldier. Show them you mean business: Go Commando.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(3993,72,'Large EMP Smartbomb I','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,410754.0000,1,381,0),(3994,152,'Large EMP Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,3600000.0000,1,341,0),(3995,72,'Large EMP Smartbomb II','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,943650.0000,1,381,0),(3996,152,'Large EMP Smartbomb II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(3997,1090,'Women\'s \'Excursion\' Pants (black/gray)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants in a cool interplay of black and gray are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(3998,1090,'Women\'s \'Impress\' Skirt (gray)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in contrasting tones of professional blacks and greys, while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(3999,1090,'Women\'s \'Impress\' Skirt (black wax)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in contrasting tones of professional blacks and greys, complete with a waxy sheen that catches any light, while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4001,1091,'Men\'s \'Trench\' Boots','Designer: Sennda of Emrayur \r\r\n\r\r\nClassic military style and boardroom chic come together in the perfect pitch black of our latest footwear. Crafted of genuine calfskins, reinforced around the foot and supple at the ankle, our classic military boot features Resothane inserts for breathability. Shok-Lite lining and a subtly stacked heel provide essential support, so you never have to worry when you\'re thinking on your feet.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(4002,1091,'Women\'s \'Minima\' Heels','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated elegance meets modern sensibilities with slick patent leather; our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4003,1091,'Women\'s \'Greave\' Knee-Boots','Designer: House of Ranai\r\r\n\r\r\nWho says military dress has to be unflattering? Step out in style in our \"Greave\" high-heeled boots, inspired by the gaiters of yesteryear\'s foot-soldier. Slick leather wraps up to your knee, while the structured flexible ribbing at the back provides for easy on-and-off.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4004,1091,'Women\'s \'Mystrioso\' Boots','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a complicated world, relax in simplicity in our \"Mystrioso\" boots. In a symphony of darkest black, leather uppers flatter any ensemble, while the toe platform provides height without strain. The transparent prismatic resin heel adds a touch of intrigue to the understated design.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4005,27,'Scorpion Ishukone Watch','With its focus on electronic warfare, few ships can resist the direct onslaught of the Ishukone Watch Scorpion-class battleship\'s jamming capabilities.\r\r\n \r\r\n<font color=white><u>Details</u></font>\r\r\nThis variant of the Scorpion represents the pinnacle of the Ishukone paramilitary force\'s electronic warfare capabilities.\r\r\n \r\r\n<font color=white><u>Development</u></font>\r\r\nWhen Ishukone Watch was commissioned to produce a run of Scorpion-class battleships for its parent company, it was decided that a number of extra units would be offered to the capsuleer community to help fund the effort. Interestingly, the entire project took less than one year from start to finish, suggesting at some degree of urgency in the fleet\'s production.\r\r\n\r\r\nThe first of these vessels was awarded to Gallente pilot Jack DuVal on June 4th YC115 as a gesture of good will, after it was stolen from an Ishukone Watch shipyard in orbit of Caldari Prime by the Guristas Pirates, before being abandoned in his hangar in Korama after a lengthy pursuit across the Caldari Border Zone.\r\r\n \r\r\n<font color=white><u>Technology</u></font>\r\r\nThough the typical Scorpion-class battleship includes a highly advanced sensor package, Ishukone Watch modifies their ships for policing duty around their worlds. Custom multispectral radiation scanners designed to catch all forms of planetary and extra-planetary communications replace the standard comms suite. Special Ladar and thermal imaging equipment allow Ishukone Watch ships to serve as a distant eye-in-the-sky for planetary security forces. Although these features are stripped out before decommissioned hulls are placed on the open market, the infamy of the Ishukone Watch still makes ships popular with independent ship buyers.\r\r\n\r\r\n<font color=white><u>Notes</u></font>\r\r\nMany wonder why Ishukone Watch would produce a massive run of electronic warfare battleships, especially with sensor suites fine-tuned to detect planetside signals. Some have speculated that these ships were intended to support a larger, multinational fleet. Regarding the mass production of these ships, Ishukone Watch CEO Eborimi Shiskala praised her parent corporation with an \"incredible dedication to the Ishukone doctrine of technological superiority.\"',103600000,468000,550,1,1,2.0000,0,1620,0),(4006,107,'Scorpion Ishukone Watch Blueprint',' ',0,0.01,0,1,NULL,712500000.0000,1,NULL,0),(4007,226,'Fortified Minmatar Station','Docking has been prohibited into this station without proper authorization.',0,0,0,1,4,0.0000,0,NULL,0),(4008,1091,'Men\'s \'Lockstep\' Boots','Designer: House of Ranai\r\r\n\r\r\nLife on the cutting edge doesn\'t have to be harsh. Our \"Lockstep\" military gentleman\'s boots enfold your feet in the dark, muted colors of soft genuine leather, with reinforced toes and metal heel caps for protection. Pressure-sensitive gel insoles provide comfort and regulate temperature, while our patented limited-magnetic closure ensures a comfortable, custom fit.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(4009,1083,'Looking Glass Monocle Interface (right/gold)','An extremely rare and sought-after implant available only to the wealthy and powerful of New Eden, the Looking Glass monocle interface offers advanced vision augmentation beyond the capabilities of all comparable prosthetics or upgrades. Full-spectrum optic weave filters, nanofiber refraction lenses, an enhanced NeoCom uplink, and a blackbox holovid recorder linked directly to the memory centers in the temporal lobe are just some of its groundbreaking options. When combined with the specialized training and equipment unique to capsuleers, the Looking Glass is an efficient interfacing tool, not to mention a dramatic fashion statement.',0.5,0.1,0,1,NULL,0.0000,1,1408,0),(4010,819,'Domination Grigori','<font color=yellow>Subject:</font> Domination Grigori (ID: Modified Daredevil)<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Veteran-level crew. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> Designed specifically for lightning raids in enemy space, the Grigori variant of the daunted Daredevil can catch the inexperience ship captain unaware. What is most impressive is that, beyond a handful of experimental Angel technologies, the Grigori\'s advantage comes almost exclusively from employing an all-veteran crew.  The efficiency and skill a Grigori crew brings to battle can rival those of a capsuleer. Luckily, the loss of a Grigori crew can be extremely demoralizing for local Cartel forces, leading them to eventually abandon complexes where a Grigori was destroyed.<br>\r\r\n<i>Analyst Kental, <a href=showinfo:2//1000137>DED</a>.</i><br><i>Authorized for capsuleer dissemination.</i>  ',1910000,19100,80,1,2,0.0000,0,NULL,0),(4011,319,'Reinforced Drone Bunker','<font color=yellow>Subject:</font> Reinforced Drone Bunker<br>\r\r\n<font color=yellow>Summary:</font> This structure appears similar to classic drone bunkers, but is heavily  modified to withstand direct attack. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> First appearing in YC 113, the reinforced drone bunker is an incredibly sturdy variant of the classic rogue drone bunker design. The outer hull itself is bolstered by a honeycombed mesh of tritanium-tungsten alloy, preventing breaches from tears or blunt impact. Internal systems are supplemented with multiple redundancies. <br>\r\r\nThe nature of rogue drones makes it difficult to determine if these improvements are the result of conscious effort or, as some engineers theorize, a sort of natural selection after years of losing traditional bunkers to capsuleer raids.<br>\r\r\n<i>Senior Defense Analyst Jervei, FIO.</i><br><i>Authorized for capsuleer dissemination.</i>',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(4012,819,'Dread Guristas Irregular','<font color=yellow>Subject:</font> Dread Guristas Irregular (ID: Modified <a href=showinfo:17930>Worm</a>)<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Veteran-level crew. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> First encountered in YC112, the Irregular is an attack frigate modified for fast assault and first response action. A <a href=showinfo:34>tritanium</a>-reinforced hull improves survivability, as does an experimental Guristas Production Atlas capacitor. Each Irregular is, ironically, crewed by seasoned combat veterans. The average total experience of an Irregular crew is 90 years. This experience gap gives the Irregular an 83% higher survivability rating than the average Guristas frigate crew.<br>\r\r\n<i>Comparative Intelligence Specialist Ahelen, <a href=showinfo:2//1000042> Wiyrkomi Peace Corps</a>.</i><br><i>Authorized for capsuleer dissemination.</i>  ',1650000,16500,235,1,1,0.0000,0,NULL,0),(4013,203,'RADAR Backup Array I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,722,0),(4014,203,'RADAR Backup Array II','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,158123.0000,1,722,0),(4015,819,'Dark Blood Alpha','<font color=yellow>Subject:</font> Dark Blood Alpha (ID: Modified Inquisitor)<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Veteran-level crew. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> The Dark Blood Alpha is an Inquisitor variant designed for a single purpose: lead blitzkrieg raids through empire space. Taking after capsuleer tactics, the Dark Blood Alpha coordinates groups of fast-attack frigates known as wolf packs. Wolf packs swarm larger targets, providing too many fast moving targets for the enemy weapons to track. The Dark Blood Alpha is crewed almost exclusively by veterans of past raids, making this ship the most dangerous opponent on the field. <br>\r\r\n<i>Analyst Fawlon, <a href=showinfo:2//1000081>Ministry of Assessment</a>.</i><br><i>Authorized for capsuleer dissemination.</i>  \r\r\n',2870000,28700,135,1,4,0.0000,0,NULL,0),(4016,1090,'Women\'s \'Excursion\' Pants (black)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants in pure midnight black are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4017,1090,'Women\'s \'Excursion\' Pants (black/blue/gold)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants in a cool blend of midnight black, dark ocean blue and gold lines are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4018,1090,'Women\'s \'Excursion\' Pants (black/gold)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants, in a stunning mix of midnight black and dark gold, are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4019,1090,'Women\'s \'Excursion\' Pants (black/gold line)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants in midnight black, through which gold lines course like veins of ore, are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4020,1090,'Women\'s \'Excursion\' Pants (black/red/gold)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants in a volatile mixture of midnight black, bright red and gold lines are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4021,1090,'Women\'s \'Excursion\' Pants (black/silver)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants, in an extraordinary mix of midnight black and chill, steely silver, are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4022,1090,'Women\'s \'Excursion\' Pants (gold)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants in stunning regal gold are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4023,15,'Caldari Mining Station',' ',0,1,0,1,1,0.0000,0,NULL,0),(4024,15,'Caldari Food Processing Plant Station',' ',0,1,0,1,1,0.0000,0,NULL,0),(4025,65,'X5 Prototype Engine Enervator','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,1,5804.0000,1,683,0),(4026,1090,'Women\'s \'Excursion\' Pants (matte blue)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants in pure matte blue are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4027,65,'Fleeting Propulsion Inhibitor I','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,2,5804.0000,1,683,0),(4028,1090,'Women\'s \'Excursion\' Pants (matte green)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants in a matte earthbound green are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4029,65,'\'Langour\' Drive Disruptor I','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,4,5804.0000,1,683,0),(4030,1090,'Women\'s \'Excursion\' Pants (matte red)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants in a sultry matte red are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4031,65,'Patterned Stasis Web I','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,8,5804.0000,1,683,0),(4032,1090,'Women\'s \'Excursion\' Pants (silver)','Designer: Vallou\r\r\n\r\r\nVallou\'s \"Excursion\" pants in striking steely silver are designed for the style-conscious woman who still demands combat-rated performance from her clothes. A poly wool blend covers our proprietary thermal layer designed to keep you comfortable in extreme temperatures. The Excursion also features a dynamic g-force adaptive system, constricting or loosening against your legs so you have optimal bloodflow in any adverse situation.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4033,1090,'Women\'s \'Impress\' Skirt (black leather)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure and traces intricate patterns on the exquisite black leather, while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4034,1090,'Women\'s \'Impress\' Skirt (brown leather)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in the intricate patterns of natural brown leather, while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4035,1090,'Women\'s \'Impress\' Skirt (graphite)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in a coolly stylish graphite gray while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4036,1090,'Women\'s \'Impress\' Skirt (green/gold)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in contrasting tones of midnight black and autumn green, all fringed with a fine golden line, while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4037,1083,'Odin Synthetic Eye (right/dark)','The Odin synthetic eye is a favorite of space jockeys who still need to wine and dine with the best. Nanite-constructed filament-lenses and cutting-edge optics are suspended in a sterile gel, all housed in a membrane of transparent polyethylene terephthalate. The result is a fully functional human optic replacement subtle enough for any occasion.',0.5,0.1,0,1,NULL,0.0000,1,1408,0),(4038,1083,'Odin Synthetic Eye (right/gray)','The Odin synthetic eye is a favorite of space jockeys who still need to wine and dine with the best. Nanite-constructed filament-lenses and cutting-edge optics are suspended in a sterile gel, all housed in a membrane of transparent polyethylene terephthalate. The result is a fully functional human optic replacement subtle enough for any occasion.',0.5,0.1,0,1,NULL,0.0000,1,1408,0),(4039,1083,'Odin Synthetic Eye (right/gold)','The Odin synthetic eye is a favorite of space jockeys who still need to wine and dine with the best. Nanite-constructed filament-lenses and cutting-edge optics are suspended in a sterile gel, all housed in a membrane of transparent polyethylene terephthalate. The result is a fully functional human optic replacement subtle enough for any occasion.',0.5,0.1,0,1,NULL,0.0000,1,1408,0),(4042,1083,'Looking Glass Monocle Interface (right/gray)','An extremely rare and sought-after implant available only to the wealthy and powerful of New Eden, the Looking Glass monocle interface offers advanced vision augmentation beyond the capabilities of all comparable prosthetics or upgrades. Full-spectrum optic weave filters, nanofiber refraction lenses, an enhanced NeoCom uplink, and a blackbox holovid recorder linked directly to the memory centers in the temporal lobe are just some of its groundbreaking options. When combined with the specialized training and equipment unique to capsuleers, the Looking Glass is an efficient interfacing tool, not to mention a dramatic fashion statement.',0.5,0.1,0,1,NULL,0.0000,1,1408,0),(4043,1083,'Odin Synthetic Eye (left/dark)','The Odin synthetic eye is a favorite of space jockeys who still need to wine and dine with the best. Nanite-constructed filament-lenses and cutting-edge optics are suspended in a sterile gel, all housed in a membrane of transparent polyethylene terephthalate. The result is a fully functional human optic replacement subtle enough for any occasion.',0.5,0.1,0,1,NULL,0.0000,1,1408,0),(4044,53,'Sleeper Turret Small','Small Sleeper Turret',500,5,1,1,NULL,0.0000,0,NULL,0),(4045,53,'Sleeper Turret Medium','Medium Sleeper Turret',2500,25,1,1,NULL,0.0000,0,NULL,0),(4046,1083,'Odin Synthetic Eye (left/gold)','The Odin synthetic eye is a favorite of space jockeys who still need to wine and dine with the best. Nanite-constructed filament-lenses and cutting-edge optics are suspended in a sterile gel, all housed in a membrane of transparent polyethylene terephthalate. The result is a fully functional human optic replacement subtle enough for any occasion.',0.5,0.1,0,1,NULL,0.0000,1,1408,0),(4048,1083,'Odin Synthetic Eye (left/gray)','The Odin synthetic eye is a favorite of space jockeys who still need to wine and dine with the best. Nanite-constructed filament-lenses and cutting-edge optics are suspended in a sterile gel, all housed in a membrane of transparent polyethylene terephthalate. The result is a fully functional human optic replacement subtle enough for any occasion.',0.5,0.1,0,1,NULL,0.0000,1,1408,0),(4049,53,'Sleeper Turret Large','Large Sleeper Turret',5000,50,1,1,NULL,0.0000,0,NULL,0),(4050,1083,'Looking Glass Monocle Interface (left/gold)','An extremely rare and sought-after implant available only to the wealthy and powerful of New Eden, the Looking Glass monocle interface offers advanced vision augmentation beyond the capabilities of all comparable prosthetics or upgrades. Full-spectrum optic weave filters, nanofiber refraction lenses, an enhanced NeoCom uplink, and a blackbox holovid recorder linked directly to the memory centers in the temporal lobe are just some of its groundbreaking options. When combined with the specialized training and equipment unique to capsuleers, the Looking Glass is an efficient interfacing tool, not to mention a dramatic fashion statement.',0.5,0.1,0,1,NULL,0.0000,1,1408,0),(4051,1136,'Caldari Fuel Block','Frustrated with the inefficiencies involved in tracking multiple fuel types, Thukker logisticians pioneered the development of prepackaged fuel. In YC 111, after a successful trial period, they converted the Tribe\'s entire starbase network to use fuel blocks. Capsuleers were forced to wait for this innovation while CONCORD dithered over how to handle the transition period, but were finally granted clearance in YC113.\r\r\n\r\r\nThis is a block of fuel designed for Caldari control towers. Forty blocks are sufficient to run a standard large tower for one hour, while medium and small towers require twenty and ten blocks respectively over the same period.',0,5,0,40,NULL,95.0000,1,1870,0),(4052,1083,'Looking Glass Monocle Interface (left/gray)','An extremely rare and sought-after implant available only to the wealthy and powerful of New Eden, the Looking Glass monocle interface offers advanced vision augmentation beyond the capabilities of all comparable prosthetics or upgrades. Full-spectrum optic weave filters, nanofiber refraction lenses, an enhanced NeoCom uplink, and a blackbox holovid recorder linked directly to the memory centers in the temporal lobe are just some of its groundbreaking options. When combined with the specialized training and equipment unique to capsuleers, the Looking Glass is an efficient interfacing tool, not to mention a dramatic fashion statement.',0.5,0.1,0,1,NULL,0.0000,1,1408,0),(4054,1088,'Women\'s \'Executor\' Coat','Designer: House of Ranai\r\r\n\r\r\nIn today\'s cutthroat political environment, maintaining a commanding presence is essential. Lead from the front in our high-collared Resothane and spider-silk \"Executor\" coat. The bold, clean lines of our latest design offer you that sleek, tailored, and uncompromising impression. The contrasting yoke and black silk detailing build a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4057,1089,'Men\'s \'Sterling\' Dress Shirt (black)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the pitch-black \"Sterling\" dress shirt is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. Silver thread highlights and sterling silver chevrons finish the high-contrast look.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4058,1089,'Men\'s \'Sterling\' Dress Shirt (navy)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the deep, navy blue \"Sterling\" dress shirt is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. Silver thread highlights and sterling silver chevrons finish the high-contrast look.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4059,1089,'Men\'s \'Sterling\' Dress Shirt (dust)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the desert-dust shaded \"Sterling\" dress shirt is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. Silver thread highlights and sterling silver chevrons finish the high-contrast look.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4060,1089,'Men\'s \'Sterling\' Dress Shirt (olive)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the sharp-looking olive colored \"Sterling\" dress shirt is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. Silver thread highlights and sterling silver chevrons finish the high-contrast look.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4061,1089,'Women\'s \'Sterling\' Dress Blouse (black)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the midnight black \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher, and fringed with pure white edges on all edges and pockets.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4062,1089,'Women\'s \'Sterling\' Dress Blouse (navy)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4063,1089,'Women\'s \'Sterling\' Dress Blouse (dust)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the desert-worn dust-colored \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher, and fringed with pure white edges on all edges and pockets.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4064,1089,'Women\'s \'Sterling\' Dress Blouse (olive)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the dark olive green \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher, and fringed with pure white edges on all edges and pockets.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4065,1089,'Women\'s \'Sterling\' Dress Blouse (platinum)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4066,1089,'Women\'s \'Quafe\' T-shirt YC 113','Strut around in style with your comfortable new Quafe Commemorative Casual Wear, designed exclusively for attendees of the YC 113 Impetus Annual Holoreel Convention.\r\r\n\r\r\nNote: Quafe Commemorative Casual Wear is not a protective device and is intended for cosmetic use only. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1406,0),(4067,1089,'Men\'s \'Quafe\' T-shirt YC 113','Strut around in style with your comfortable new Quafe Commemorative Casual Wear, designed exclusively for attendees of the YC 113 Impetus Annual Holoreel Convention.\r\r\n\r\r\nNote: Quafe Commemorative Casual Wear is not a protective device and is intended for cosmetic use only. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1398,0),(4068,1089,'Men\'s \'Sterling\' Dress Shirt (Ishukone Special Edition)','Designer: Sennda of Emrayur\r\r\n\r\r\nMost commonly worn by officers of Ishukone Watch, this crisp, stylized military uniform shirt bears their distinctive mark. Along with their variant of the Scorpion-class battleship, the Ishukone Watch line of clothing reveals a growing diversity in the corporation\'s offering. As one of the first organizations to embrace the aurum currency, they hope to reach out directly to the capsuleer community with high-end commodities.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4069,1090,'Women\'s \'Impress\' Skirt (marine)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in a late night blue, fringed with pure white lines, while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4070,1090,'Women\'s \'Impress\' Skirt (matte black)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in a matte shade dark as night while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4071,1090,'Women\'s \'Impress\' Skirt (matte blue)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in a calming matte blue while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4072,1090,'Women\'s \'Impress\' Skirt (matte red)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in a rousing matte red while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4073,1090,'Women\'s \'Impress\' Skirt (red gold)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in contrasting tones of midnight black and bright, dominant red, all fringed with a fine golden line, while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4074,1090,'Women\'s \'Impress\' Skirt (silver)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in perfect cool silver, fringed with a single line of brightness, while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4075,1090,'Women\'s \'Impress\' Skirt (white)','Designer: House of Ranai\r\r\n\r\r\nMove with confidence in our two-toned Resothane and spider-silk blend \"Impress\" skirt. Subtle detailing flatters the figure in a crisp, unspoiled white while unobtrusive back pockets preserve the slim-line silhouette.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4076,1090,'Women\'s \'Structure\' Skirt (black/red)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our black and red \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4077,366,'Acceleration Gate (Precise)','Acceleration gate technology reaches far back to the expansion era of the empires that survived the great EVE gate collapse. While their individual setup might differ in terms of ship size they can transport and whether they require a certain passkey or code to be used, all share the same fundamental function of hurling space vessels to a destination beacon within solar system boundaries.\r\r\n<br><br>',100000,0,0,1,NULL,0.0000,0,NULL,0),(4078,1090,'Women\'s \'Structure\' Skirt (camouflage)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our camouflage \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4085,1090,'Women\'s \'Structure\' Skirt (black)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4086,1092,'Short Pixie Hair','NO DESCRIPTION!',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(4088,1092,'Curly Shoulder Length','NO DESCRIPTION!',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(4089,314,'Clearance Papers','These clearance papers allow the bearer access to the cluster\'s most expert career training advisors. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(4090,280,'Large Crates of Quafe','Quafe is the name of the most popular soft drink in the universe, manufactured by a Gallentean company bearing the same name. Like so many soft drinks, it was initially intended as a medicine for indigestion and tender stomachs, but the refreshing effects of the drink appealed to everyone and the drink quickly became tremendously popular. Quafe is one of the best recognized brands in the whole EVE universe and can be found in every corner of it. ',500,500,0,1,NULL,50.0000,1,NULL,0),(4091,284,'Large Crates of Ectoplasm','Used for the making of the liquid inside starship pilot pods, this thick goo is made primarily out of used cell membranes.',100,500,0,1,NULL,900.0000,1,NULL,0),(4093,1118,'Surface Command Center Prefab Unit','This prefab unit self assembles into the Surface Command Center.',10000,100000,0,1,NULL,0.0000,0,NULL,0),(4096,1092,'Hair_Stubble_01','NO DESCRIPTION!',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(4097,1088,'Men\'s \'Field Marshal\' Coat','Designer: Vallou\r\r\n\r\r\nOuterwear for the discerning gentleman officer, our \"Field Marshal\" coat is an essential part of any commandant\'s wardrobe. Whether commanding troops in the field or inspecting facilities, command respect while remaining comfortable and secure. Our patented polycel and silk mix offers durability and softness, and we\'ve gone the extra length with a weather-fast Kruna-wool lining for added warmth.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4098,1088,'Men\'s \'Esquire\' Coat','Designer: House of Ranai\r\r\n\r\r\nIn the world of boardroom politics, maintaining a commanding presence is essential. Lead from the front in our dual-layered resothane and spider-silk \"Esquire\" coat. The bold, clean lines of our latest design offer you that sleek, tailored, and uncompromising impression; embossable molded-leather sleeves allow you to display your corporate rank for all to see. The contrasting yoke broadens the shoulders for a military-sharp appearance that will guarantee their undivided attention. \r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4099,226,'Amarr Factory Outpost','Generally utilized in deep space scenarios, Amarr Factory Outposts are structures dedicated to the swift and efficient manufacture of ships and modules. These outposts are most often built, maintained and owned by capsuleer organizations.',0,0,0,1,4,0.0000,0,NULL,0),(4100,226,'Caldari Research Outpost','A Caldari research outpost.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(4101,1090,'Women\'s \'Structure\' Skirt (black/white)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our black and white \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4102,1090,'Women\'s \'Structure\' Skirt (blue)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our blue \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4103,1090,'Women\'s \'Structure\' Skirt (graphite)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our graphite gray \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4104,1090,'Women\'s \'Structure\' Skirt (gray)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our gray \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4105,1090,'Women\'s \'Structure\' Skirt (gray stripes)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our gray striped \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4106,1090,'Women\'s \'Structure\' Skirt (green)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our green \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4107,1090,'Women\'s \'Structure\' Skirt (green/black)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our green and black \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4108,1090,'Women\'s \'Structure\' Skirt (green stripes)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our green striped \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4109,1090,'Women\'s \'Structure\' Skirt (khaki)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our khaki \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4110,1090,'Women\'s \'Structure\' Skirt (marine)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our marine \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4111,1090,'Women\'s \'Structure\' Skirt (matte black)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our matte black \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4112,1090,'Women\'s \'Structure\' Skirt (red)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our red \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4113,1090,'Women\'s \'Structure\' Skirt (red leather)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our red leather \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4114,1090,'Women\'s \'Structure\' Skirt (red stripes)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our red striped \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4115,1090,'Women\'s \'Structure\' Skirt (white stripes)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our white striped \"Structure\" skirt wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design is the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(4116,1091,'Women\'s \'Minima\' Heels (black/gold)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated elegance meets the luster of modern sensibilities with slick patent leather in darkest black; while an elegant golden version of our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4117,1091,'Women\'s \'Minima\' Heels (black/red)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated elegance meets the luster of modern sensibilities with slick patent leather in darkest black; while a sultry red version of our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4118,1091,'Women\'s \'Minima\' Heels (blue)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated elegance meets the luster of modern sensibilities with slick patent leather in heavenly blue; while our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4119,1091,'Women\'s \'Minima\' Heels (gold)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated elegance meets the luster of modern sensibilities with slick patent leather in regal gold; while our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4120,1091,'Women\'s \'Minima\' Heels (graphite/white)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated elegance meets modern sensibilities with slick patent leather in matte graphite; our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4121,1091,'Women\'s \'Minima\' Heels (green/black)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated elegance meets the luster of modern sensibilities with slick patent leather in forest green; while a classy black version of our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4122,1091,'Women\'s \'Minima\' Heels (matte black)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated matte elegance meets modern sensibilities with slick patent leather dark as ochre; while our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4123,1091,'Women\'s \'Minima\' Heels (matte red)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated matte elegance meets modern sensibilities with slick patent leather in eye-catching red; while our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4124,1091,'Women\'s \'Minima\' Heels (red)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated elegance meets the luster of modern sensibilities with slick patent leather in burning red; while our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4125,1091,'Women\'s \'Minima\' Heels (silver)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated elegance meets the luster of modern sensibilities with slick patent leather in glowing silver; while our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4126,1091,'Women\'s \'Minima\' Heels (turquoise)','Designer: Vallou\r\r\n\r\r\nFor a traditional look with easy sex appeal, look no further than our \"Minima\" heels. Understated elegance meets the luster of modern sensibilities with slick patent leather in oceanic turquoise; while our trademark \"V\" clasp securing the ankle assures the highest Vallou quality.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4127,1091,'Women\'s \'Greave\' Boots (black/gold)','Designer: House of Ranai\r\r\n\r\r\nWho says military dress has to be unflattering? Step out in style with the luster of our \"Greave\" high-heeled boots, inspired by the gaiters of yesteryear\'s foot-soldier. Slick leather, black as night, wraps up to your knee, while the regal gold of our structured flexible ribbing at the back provides for easy on-and-off.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4128,1091,'Women\'s \'Greave\' Boots (brown)','Designer: House of Ranai\r\r\n\r\r\nWho says military dress has to be unflattering? Step out in style in the gorgeous natural autumn brown of our lustrous \"Greave\" high-heeled boots, inspired by the gaiters of yesteryear\'s foot-soldier. Slick leather wraps up to your knee, while the structured flexible ribbing at the back provides for easy on-and-off.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4129,1091,'Women\'s \'Greave\' Boots (matte brown)','Designer: House of Ranai\r\r\n\r\r\nWho says military dress has to be unflattering? Step out in style in our \"Greave\" high-heeled boots, inspired by the gaiters of yesteryear\'s foot-soldier. Slick leather wraps up to your knee, while the structured flexible ribbing at the back provides for easy on-and-off.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4130,1091,'Women\'s \'Greave\' Boots (matte gray)','Designer: House of Ranai\r\r\n\r\r\nWho says military dress has to be unflattering? Step out in style in the cool gray of our \"Greave\" high-heeled matte boots, inspired by the gaiters of yesteryear\'s foot-soldier. Slick leather wraps up to your knee, while the structured flexible ribbing at the back provides for easy on-and-off.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4131,1091,'Women\'s \'Greave\' Boots (red)','Designer: House of Ranai\r\r\n\r\r\nWho says military dress has to be unflattering? Step out in style in the sensuous, sultry red of our lustrous \"Greave\" high-heeled boots, inspired by the gaiters of yesteryear\'s foot-soldier. Slick leather wraps up to your knee, while the structured flexible ribbing at the back provides for easy on-and-off.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4132,1091,'Women\'s \'Mystrioso\' Boots (black/white)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a complicated world, relax in simplicity in our \"Mystrioso\" boots. In a stark play of contrasts, dark black leather uppers flatter any ensemble, while a pure white toe platform provides height without strain. The transparent prismatic resin heel adds a touch of intrigue to the understated design.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4133,1091,'Women\'s \'Mystrioso\' Boots (brown/black)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a complicated world, relax in simplicity in our \"Mystrioso\" boots. Natural brown leather uppers flatter any ensemble, while a pitch black toe platform provides height without strain. The transparent prismatic resin heel adds a touch of intrigue to the understated design.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4134,1091,'Women\'s \'Mystrioso\' Boots (red)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a complicated world, relax in simplicity in our \"Mystrioso\" boots. In a storm of sensuous red, leather uppers flatter any ensemble, while the toe platform provides height without strain. The transparent prismatic resin heel adds a touch of intrigue to the understated design.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4135,1091,'Women\'s \'Mystrioso\' Boots (white/black)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a complicated world, relax in simplicity in our \"Mystrioso\" boots. Soft white leather uppers flatter any ensemble, while a pitch black toe platform provides height without strain. The transparent prismatic resin heel adds a touch of intrigue to the understated design.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(4136,1088,'Women\'s \'Executor\' Coat (black)','Designer: House of Ranai\r\r\n\r\r\nIn today\'s cutthroat political environment, maintaining a commanding presence is essential. Lead from the front in our high-collared Resothane and spider-silk \"Executor\" coat. The bold, clean lines of our latest design offer you that sleek, tailored, and uncompromising impression in a perfect tone of professional black. The contrasting yoke and black silk detailing build a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4137,1088,'Women\'s \'Executor\' Coat (graphite)','Designer: House of Ranai\r\r\n\r\r\nIn today\'s cutthroat political environment, maintaining a commanding presence is essential. Lead from the front in our high-collared Resothane and spider-silk \"Executor\" coat. The bold, clean lines of our latest design offer you that sleek, tailored, and uncompromising impression in an unyielding graphite gray. The contrasting yoke and black silk detailing build a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4138,1088,'Women\'s \'Executor\' Coat (green/gold)','Designer: House of Ranai\r\r\n\r\r\nIn today\'s cutthroat political environment, maintaining a commanding presence is essential. Lead from the front in our high-collared Resothane and spider-silk \"Executor\" coat. The bold, clean lines of our latest design offer you that sleek, tailored, and uncompromising impression in pure black, with a subtle touch of regal gold fringes. The contrasting yoke, with its green and black silk detailing build a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4139,1088,'Women\'s \'Executor\' Coat (matte blue)','Designer: House of Ranai\r\r\n\r\r\nIn today\'s cutthroat political environment, maintaining a commanding presence is essential. Lead from the front in our high-collared Resothane and spider-silk \"Executor\" coat. The bold, clean lines of our latest design offer you that sleek, tailored, and uncompromising impression in soothing matte blue . The contrasting yoke and black silk detailing build a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4140,1088,'Women\'s \'Executor\' Coat (matte red)','Designer: House of Ranai\r\r\n\r\r\nIn today\'s cutthroat political environment, maintaining a commanding presence is essential. Lead from the front in our high-collared Resothane and spider-silk \"Executor\" coat. The bold, clean lines of our latest design offer you that sleek, tailored, and uncompromising impression in a dominating matte red. The contrasting yoke and black silk detailing build a military-sharp appearance that will guarantee their undivided attention.\r\r\n\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4141,1088,'Women\'s \'Executor\' Coat (red/gold)','Designer: House of Ranai\r\r\n\r\r\nIn today\'s cutthroat political environment, maintaining a commanding presence is essential. Lead from the front in our high-collared Resothane and spider-silk \"Executor\" coat. The bold, clean lines of our latest design offer you that sleek, tailored, and uncompromising impression in pure black, with a subtle touch of regal gold fringes. The contrasting yoke, with its aggressive red, and the black silk detailing build a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4142,1088,'Women\'s \'Executor\' Coat (silver)','Designer: House of Ranai\r\r\n\r\r\nIn today\'s cutthroat political environment, maintaining a commanding presence is essential. Lead from the front in our high-collared Resothane and spider-silk \"Executor\" coat. The bold, clean lines of our latest design offer you that sleek, tailored, and uncompromising impression, presented in stark, powerful silver. The contrasting yoke and black silk detailing build a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4143,1088,'Women\'s \'Structure\' Dress (black)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt, all in a striking glossy deep black, for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4144,1088,'Women\'s \'Structure\' Dress (black/white)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt, in a stunning contrast of midnight black and bone white, for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4145,1088,'Women\'s \'Structure\' Dress (brown)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt, all in a natural autumn matte brown for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4146,1088,'Women\'s \'Structure\' Dress (gold/black)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt, all in a glossy midnight black with immaculate golden fringes, for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4147,53,'Dual Heavy Pulse Laser II','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Conflagration, Scorch.',2000,20,1,1,NULL,1554744.0000,1,573,0),(4148,133,'Dual Heavy Pulse Laser II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(4149,1088,'Women\'s \'Structure\' Dress (graphite)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt, all in a dark, unyielding graphite gray, for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4150,1088,'Women\'s \'Structure\' Dress (green)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt, all in the gloss of a majestic dark natural green, for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4151,1088,'Women\'s \'Structure\' Dress (matte blue)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt, all in a deep ocean matte blue, for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4152,1088,'Women\'s \'Structure\' Dress (matte red)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt, all in a deep, sensuous matte red, for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4153,1088,'Women\'s \'Structure\' Dress (red)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt, all in a breathtaking burnt red, for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4154,1088,'Women\'s \'Structure\' Dress (turquoise)','Designer: Vallou\r\r\n\r\r\nLook sharp and competent in any situation. Our \"Structure\" dress wraps you in soft silk-blend twill with angled silver piping to remind people who\'s in charge. Our latest workforce design combines our classic \"V-Line\" shirt with a utilitarian pencil skirt, all in the resplendent turquoise of deep oceans and priceless jewels, for the ultimate in everyday comfort and style. Make a statement without saying a word.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(4155,1089,'Women\'s \'Sterling\' Dress Blouse (black leather)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the black leather \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships, while the blouse\'s surface texture will feel cool and smooth touch. The blouse is adorned with traditional epaulets and a classic waist cincher.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4156,1089,'Women\'s \'Sterling\' Dress Blouse (black/white)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the stark bone-white \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher, and fringed with pure black edges on all edges and pockets.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4157,1089,'Women\'s \'Sterling\' Dress Blouse (gold)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the militaristic \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher, all of whom bear the rare gold-tinged design on the edges.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4158,1089,'Women\'s \'Sterling\' Dress Blouse (graphite)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the dark graphite gray \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4159,1089,'Women\'s \'Sterling\' Dress Blouse (green satin)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the breathtaking green satin \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. To contrast with its rippling, silken flow, the blouse is anchored with traditional epaulets and a classic waist cincher.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4160,1089,'Women\'s \'Sterling\' Dress Blouse (matte black)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the matte black \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4161,1089,'Women\'s \'Sterling\' Dress Blouse (matte blue)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the deep blue matte \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4162,1089,'Women\'s \'Sterling\' Dress Blouse (matte olive)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the dark matte olive \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. The blouse is adorned with traditional epaulets and a classic waist cincher.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4163,1089,'Women\'s \'Sterling\' Dress Blouse (orange satin)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the stunning orange satin \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. To contrast with its rippling, silken flow, the blouse is anchored with traditional epaulets and a classic waist cincher.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4164,1089,'Women\'s \'Sterling\' Dress Blouse (red satin)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the gorgeous red satin \"Sterling\" dress blouse is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. To contrast with its rippling, silken flow, the blouse is anchored with traditional epaulets and a classic waist cincher.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4165,1090,'Men\'s \'Commando\' Pants (black)','Designer: Sennda of Emrayur\r\r\n\r\r\nWhether ranking officer or rank-and-file, look prepared and professional in our gartered \"Commando\" pants. Our classic soft wool blend affords comfort, and the pleated front and comfort-woven lower legs offer a martial silhouette in the purest midnight black along with an ease of movement that would please any career soldier. Show them you mean business: Go Commando.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(4166,1090,'Men\'s \'Commando\' Pants (blue)','Designer: Sennda of Emrayur\r\r\n\r\r\nWhether ranking officer or rank-and-file, look prepared and professional in our dark blue gartered \"Commando\" pants. Our classic soft wool blend affords comfort, and the pleated front and comfort-woven lower legs offer a martial silhouette along with an ease of movement that would please any career soldier. Show them you mean business: Go Commando.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(4167,1090,'Men\'s \'Commando\' Pants (gold/black)','Designer: Sennda of Emrayur\r\r\n\r\r\nWhether ranking officer or rank-and-file, look prepared and professional in our gartered \"Commando\" pants. Our classic soft wool blend affords comfort, and the pleated front and comfort-woven lower legs offer a martial silhouette contrasting the regal style of golden pleats with a material of the purest midnight black along with an ease of movement that would please any career soldier. Show them you mean business: Go Commando.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(4168,1090,'Men\'s \'Commando\' Pants (gray/black)','Designer: Sennda of Emrayur\r\r\n\r\r\nWhether ranking officer or rank-and-file, look prepared and professional in our cool gray gartered \"Commando\" pants. Our classic soft wool blend affords comfort, and the pitch-black pleated front and comfort-woven lower legs offer a martial silhouette along with an ease of movement that would please any career soldier. Show them you mean business: Go Commando.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(4169,1090,'Men\'s \'Commando\' Pants (brown camo)','Designer: Sennda of Emrayur\r\r\n\r\r\nWhether ranking officer or rank-and-file, look prepared and professional in our gartered \"Commando\" pants. Our classic soft wool blend affords comfort, and the pleated front and comfort-woven lower legs offer a martial silhouette in a mix of natural brown and authentic martial camo, along with an ease of movement that would please any career soldier. Show them you mean business: Go Commando.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(4170,1090,'Men\'s \'Commando\' Pants (green camo)','Designer: Sennda of Emrayur\r\r\n\r\r\nWhether ranking officer or rank-and-file, look prepared and professional in our gartered \"Commando\" pants. Our classic soft wool blend affords comfort, and the pleated front and comfort-woven lower legs offer a martial silhouette in a mix of forest green and authentic martial camo, along with an ease of movement that would please any career soldier. Show them you mean business: Go Commando.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(4171,1090,'Men\'s \'Commando\' Pants (red/black)','Designer: Sennda of Emrayur\r\r\n\r\r\nWhether ranking officer or rank-and-file, look prepared and professional in our gartered \"Commando\" pants. Our classic soft wool blend affords comfort, and the pleated front and comfort-woven lower legs offer a martial silhouette contrasting a martial streak of bright red with a material of the purest midnight black along with an ease of movement that would please any career soldier. Show them you mean business: Go Commando.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(4172,1091,'Men\'s \'Lockstep\' Boots (true black)','Designer: House of Ranai\r\r\n\r\r\nLife on the cutting edge doesn\'t have to be harsh. Our \"Lockstep\" military gentleman\'s boots enfold your feet in the true night black of soft genuine leather, with reinforced toes and metal heel caps for protection. Pressure-sensitive gel insoles provide comfort and regulate temperature, while our patented limited-magnetic closure ensures a comfortable, custom fit.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(4173,1091,'Men\'s \'Lockstep\' Boots (worn brown)','Designer: House of Ranai\r\r\n\r\r\nLife on the cutting edge doesn\'t have to be harsh. Our \"Lockstep\" military gentleman\'s boots enfold your feet in the worn, rugged browns of soft genuine leather, with reinforced toes and metal heel caps for protection. Pressure-sensitive gel insoles provide comfort and regulate temperature, while our patented limited-magnetic closure ensures a comfortable, custom fit.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(4174,1091,'Men\'s \'Precision\' Boots (brown)','Designer: Vallou\r\r\n\r\r\nEven the strongest commander needs support. Our \"Precision\" collection introduces the latest in military style with these natural, rugged brown uniform boots. Polished leather outer-soles conceal a rugged grip and metal heel-caps; Veproco-treated leather uppers maintain a sleek shine no matter the environment. Our patented shock-resistant inner cushioning reduces leg strain when you need to stay on your feet, and the dual-zip front improves fit and comfort without sacrificing style. Command in confidence.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(4175,1091,'Men\'s \'Precision\' Boots (gray)','Designer: Vallou\r\r\n\r\r\nEven the strongest commander needs support. Our \"Precision\" collection introduces the latest in military style with these ghostly pale gray uniform boots. Polished leather outer-soles conceal a rugged grip and metal heel-caps; Veproco-treated leather uppers maintain a sleek shine no matter the environment. Our patented shock-resistant inner cushioning reduces leg strain when you need to stay on your feet, and the dual-zip front improves fit and comfort without sacrificing style. Command in confidence.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(4176,1091,'Men\'s \'Precision\' Boots (tan)','Designer: Vallou\r\r\n\r\r\nEven the strongest commander needs support. Our \"Precision\" collection introduces the latest in military style with these dusty burnt tan uniform boots. Polished leather outer-soles conceal a rugged grip and metal heel-caps; Veproco-treated leather uppers maintain a sleek shine no matter the environment. Our patented shock-resistant inner cushioning reduces leg strain when you need to stay on your feet, and the dual-zip front improves fit and comfort without sacrificing style. Command in confidence.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(4177,1091,'Men\'s \'Trench\' Boots (brown)','Designer: Sennda of Emrayur \r\r\n\r\r\nClassic military style and boardroom chic come together in the natural, rugged brown of our latest footwear. Crafted of genuine calfskins, reinforced around the foot and supple at the ankle, our classic military boot features Resothane inserts for breathability. Shok-Lite lining and a subtly stacked heel provide essential support, so you never have to worry when you\'re thinking on your feet.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(4178,1091,'Men\'s \'Trench\' Boots (gray)','Designer: Sennda of Emrayur \r\r\n\r\r\nClassic military style and boardroom chic come together in ghostly pale gray of our latest footwear. Crafted of genuine calfskins, reinforced around the foot and supple at the ankle, our classic military boot features Resothane inserts for breathability. Shok-Lite lining and a subtly stacked heel provide essential support, so you never have to worry when you\'re thinking on your feet.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(4179,1091,'Men\'s \'Trench\' Boots (tan)','Designer: Sennda of Emrayur \r\r\n\r\r\nClassic military style and boardroom chic come together in the dusty burnt tan of our latest footwear. Crafted of genuine calfskins, reinforced around the foot and supple at the ankle, our classic military boot features Resothane inserts for breathability. Shok-Lite lining and a subtly stacked heel provide essential support, so you never have to worry when you\'re thinking on your feet.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(4180,1089,'Men\'s \'Form\' Shirt (black)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our black \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4181,1089,'Men\'s \'Form\' Shirt (blue)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our blue \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4182,1089,'Men\'s \'Form\' Shirt (brown)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our brown \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4183,1089,'Men\'s \'Form\' Shirt (dark blue)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our dark blue \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4184,1089,'Men\'s \'Form\' Shirt (dark red)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our dark red \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4185,1089,'Men\'s \'Form\' Shirt (khaki)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our khaki \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4186,1089,'Men\'s \'Form\' Shirt (light gray)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our light gray  \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4187,1089,'Men\'s \'Form\' Shirt (olive)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our olive \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4188,1089,'Men\'s \'Form\' Shirt (dark camo)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our dark camo \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4189,1089,'Men\'s \'Form\' Shirt (desert camo)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our dark camo \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4190,1089,'Men\'s \'Form\' Shirt (white)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our white \'Function\' shirt keeps you cool with a pretreated weave of soft material that emphasizes a strong mind in a strong body. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4191,1089,'Men\'s \'Street\' Shirt (black)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar systems, the hardy traveler must sometimes bring his accoutrements back to basics. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this black tank top bears the clear, classic lines that distinguish it as a true fashion item.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4192,1089,'Men\'s \'Street\' Shirt (blue)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar systems, the hardy traveler must sometimes bring his accoutrements back to basics. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this blue tank top bears the clear, classic lines that distinguish it as a true fashion item.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4193,1089,'Men\'s \'Street\' Shirt (brown)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar systems, the hardy traveler must sometimes bring his accoutrements back to basics. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this brown tank top bears the clear, classic lines that distinguish it as a true fashion item.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4194,1089,'Men\'s \'Street\' Shirt (gray)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar systems, the hardy traveler must sometimes bring his accoutrements back to basics. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this gray tank top bears the clear, classic lines that distinguish it as a true fashion item.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4195,1089,'Men\'s \'Street\' Shirt (green)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar systems, the hardy traveler must sometimes bring his accoutrements back to basics. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this green tank top bears the clear, classic lines that distinguish it as a true fashion item.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4196,1089,'Men\'s \'Street\' Shirt (gray urban camo)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar systems, the hardy traveler must sometimes bring his accoutrements back to basics. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this grey urban camo tank top bears the clear, classic lines that distinguish it as a true fashion item.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4197,1089,'Men\'s \'Street\' Shirt (brown camo)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar systems, the hardy traveler must sometimes bring his accoutrements back to basics. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this brown camo tank top bears the clear, classic lines that distinguish it as a true fashion item.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4198,1089,'Men\'s \'Street\' Shirt (urban camo)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar systems, the hardy traveler must sometimes bring his accoutrements back to basics. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this black and white urban camo tank top bears the clear, classic lines that distinguish it as a true fashion item.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4199,1089,'Men\'s \'Street\' Shirt (green camo)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar systems, the hardy traveler must sometimes bring his accoutrements back to basics. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this green camo tank top bears the clear, classic lines that distinguish it as a true fashion item.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4200,1089,'Men\'s \'Street\' Shirt (white)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar systems, the hardy traveler must sometimes bring his accoutrements back to basics. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this white tank top bears the clear, classic lines that distinguish it as a true fashion item.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4201,1089,'Women\'s \'Function\' Shirt (black)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our black \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4202,1089,'Women\'s \'Function\' Shirt (blue)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our blue \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4203,1089,'Women\'s \'Function\' Shirt (brown)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our brown \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4204,1089,'Women\'s \'Function\' Shirt (cream)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our cream \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4205,1089,'Women\'s \'Function\' Shirt (dark blue)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our dark blue \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4206,1089,'Women\'s \'Function\' Shirt (dark red)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our dark red \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4207,1089,'Women\'s \'Function\' Shirt (gray)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our gray \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4208,1089,'Women\'s \'Function\' Shirt (green)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our green \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4209,1089,'Women\'s \'Function\' Shirt (khaki)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our khaki \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4210,1089,'Women\'s \'Function\' Shirt (olive)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our olive \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4211,1089,'Women\'s \'Function\' Shirt (orange)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our orange \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4212,1089,'Women\'s \'Function\' Shirt (dark camo)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our dark camo \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4213,1089,'Women\'s \'Function\' Shirt (desert camo)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our desert camo \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4214,1089,'Women\'s \'Function\' Shirt (red)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our red \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4215,1089,'Women\'s \'Function\' Shirt (white)','Designer: House of Ranai\r\r\n\r\r\nLook trendy, sharp and casual, all at once. Our white \'Function\' shirt keeps you cool with a pretreated weave of soft material that clings in the right places and breathes for your comfort. Designed to be suitable for any kind of circumstance, from formal meetings to more relaxed gatherings, this shirt will take you anywhere you want to go.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4216,1089,'Women\'s \'Avenue\' Shirt (black)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this black tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4217,1089,'Women\'s \'Avenue\' Shirt (black leather)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this black leather tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4218,1089,'Women\'s \'Avenue\' Shirt (blue)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this blue tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4219,1089,'Women\'s \'Avenue\' Shirt (brown)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this brown tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4220,1089,'Women\'s \'Avenue\' Shirt (gray)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this gray tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4221,1089,'Women\'s \'Avenue\' Shirt (green)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this green tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4222,1089,'Women\'s \'Avenue\' Shirt (orange)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this orange tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4223,1089,'Women\'s \'Avenue\' Shirt (gray camo)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this gray camo tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4224,1089,'Women\'s \'Avenue\' Shirt (orange camo)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this orange camo tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4225,1089,'Women\'s \'Avenue\' Shirt (red patterned)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this red patterned tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4226,1089,'Women\'s \'Avenue\' Shirt (camo)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this camo tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4227,1089,'Women\'s \'Avenue\' Shirt (lined brown)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this lined brown tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4228,1089,'Women\'s \'Avenue\' Shirt (purple mesh)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this purple mesh tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4229,1089,'Women\'s \'Avenue\' Shirt (black and dark red)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this black and dark red tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4230,1089,'Women\'s \'Avenue\' Shirt (pink camo)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this pink camo tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4231,1089,'Women\'s \'Avenue\' Shirt (red)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this red tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4232,1089,'Women\'s \'Avenue\' Shirt (white)','Designer: Sennda of Emrayur\r\r\n\r\r\nIn a world that spans countless settled solar system, a traveler may undergo any number of discomforts, worries and uncertainty. The basics, then, must be kept simple, reliable, and elegant in design. Made of a specially treated blend guaranteed to withstand an entire spectrum of potential uses, from relaxation to intense activity, this white tank top brings sturdy comfort wherever it is worn.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4233,1088,'Men\'s \'Esquire\' Coat (black)','Designer: House of Ranai\r\r\n\r\r\nIn the world of boardroom politics, maintaining a commanding presence is essential. Lead from the front in our dual-layered resothane and spider-silk \"Esquire\" coat. The bold, clean lines of our latest design in a professional, uncompromising black offer you that sleek, tailored, and uncompromising impression; embossable molded-leather sleeves allow you to display your corporate rank for all to see. The contrasting yoke broadens the shoulders for a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4234,1088,'Men\'s \'Esquire\' Coat (green/gold)','Designer: House of Ranai\r\r\n\r\r\nIn the world of boardroom politics, maintaining a commanding presence is essential. Lead from the front in our dual-layered resothane and spider-silk \"Esquire\" coat. The bold, clean lines of our latest design in green and black offer you that sleek, tailored, and uncompromising impression; embossable molded-leather sleeves and regal, golden lines on all edges allow you to display your corporate rank for all to see. The contrasting yoke, with its eminently august green, broadens the shoulders for a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4235,1088,'Men\'s \'Esquire\' Coat (matte graphite)','Designer: House of Ranai\r\r\n\r\r\nIn the world of boardroom politics, maintaining a commanding presence is essential. Lead from the front in our dual-layered resothane and spider-silk \"Esquire\" coat. The bold, clean lines of our latest design in an dark graphite gray offer you that sleek, tailored, and uncompromising impression; embossable molded-leather sleeves allow you to display your corporate rank for all to see. The contrasting yoke broadens the shoulders for a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4236,1088,'Men\'s \'Esquire\' Coat (matte gray)','Designer: House of Ranai\r\r\n\r\r\nIn the world of boardroom politics, maintaining a commanding presence is essential. Lead from the front in our dual-layered resothane and spider-silk \"Esquire\" coat. The bold, clean lines of our latest design in an unblemished pale gray offer you that sleek, tailored, and uncompromising impression; embossable molded-leather sleeves allow you to display your corporate rank for all to see. The contrasting yoke broadens the shoulders for a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4237,1088,'Men\'s \'Esquire\' Coat (matte green)','Designer: House of Ranai\r\r\n\r\r\nIn the world of boardroom politics, maintaining a commanding presence is essential. Lead from the front in our dual-layered resothane and spider-silk \"Esquire\" coat. The bold, clean lines of our latest design in a natural matte green offer you that sleek, tailored, and uncompromising impression; embossable molded-leather sleeves allow you to display your corporate rank for all to see. The contrasting yoke broadens the shoulders for a military-sharp appearance that will guarantee their undivided attention.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4238,1088,'Men\'s \'Esquire\' Coat (red/gold)','Designer: House of Ranai\r\r\n\r\r\nIn the world of boardroom politics, maintaining a commanding presence is essential. Lead from the front in our dual-layered resothane and spider-silk \"Esquire\" coat. The bold, clean lines of our latest design in perfect starless black offer you that sleek, tailored, and uncompromising impression; embossable molded-leather sleeves and regal, golden lines on all edges allow you to display your corporate rank for all to see. The contrasting yoke, with its pure, uncompromising martial red, broadens the shoulders for a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4239,1088,'Men\'s \'Esquire\' Coat (silver)','Designer: House of Ranai\r\r\n\r\r\nIn the world of boardroom politics, maintaining a commanding presence is essential. Lead from the front in our dual-layered resothane and spider-silk \"Esquire\" coat. The bold, clean lines of our latest design offer you that sleek, tailored, and uncompromising impression; embossable molded-leather sleeves and lustrous cool lines on all edges  allow you to display your corporate rank for all to see. The contrasting yoke, with its steely grey silver, broadens the shoulders for a military-sharp appearance that will guarantee their undivided attention.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4240,1089,'Men\'s \'Sterling\' Dress Shirt (gold leather)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the detailed, rugged leather \"Sterling\" dress shirt is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. Gold thread highlights and gold chevrons finish the high-contrast look.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4241,1089,'Men\'s \'Sterling\' Dress Shirt (gray)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the professional, cool gray \"Sterling\" dress shirt is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. Silver thread highlights and sterling silver chevrons finish the high-contrast look.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4242,1089,'Men\'s \'Sterling\' Dress Shirt (red/black leather)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the detailed, rugged leather \"Sterling\" dress shirt is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. Red thread highlights and red chevrons - reportedly treated with traces of Morphite - finish the high-contrast look.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4243,1089,'Men\'s \'Sterling\' Dress Shirt (white/blue)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military blouses found in several modern navies, the crisply contrasted bone white and navy blue \"Sterling\" dress shirt is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our dark wool blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. Silver thread highlights and sterling silver chevrons finish the high-contrast look.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4244,1088,'Men\'s \'Field Marshal\' Coat (green)','Designer: Vallou Outerwear \r\r\n\r\r\nFor the discerning gentleman officer, our august green \"Field Marshal\" coat is an essential part of any commandant\'s wardrobe. Whether commanding troops in the field or inspecting facilities, command respect while remaining comfortable and secure. Our patented polycel and silk mix offers durability and softness, and we\'ve gone the extra length with a weather-fast Kruna-wool lining for added warmth.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4245,1088,'\'Silvershore\' Greatcoat','Designer: Vallou (Limited Collection)\r\r\n\r\r\nThe distinctive design of Vallou\'s officer coats is inspired by historical images of high-ranking military members from the heyday of the Garoun Empire, ancestors of the Gallente Federation. The most prestigious of these was the silver-lined leather coat worn by the Admiral of the Fleet, arguably the most important official in a kingdom so heavily reliant on maritime dominance.\r\r\n\r\r\nOne of the rarest and most sought-after items in Vallou\'s renowned Limited Collection, the Silvershore greatcoat is also one of the most expensive articles of clothing ever created. From the top-quality Caillian leather to the burnished platinum clasps, every aspect of this stately raiment has been carefully shaped to evoke the mystery, grandeur and peril of the unexplored.\r\r\n\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(4246,1136,'Minmatar Fuel Block','Frustrated with the inefficiencies involved in tracking multiple fuel types, Thukker logisticians pioneered the development of prepackaged fuel. In YC 111, after a successful trial period, they converted the Tribe\'s entire starbase network to use fuel blocks. Capsuleers were forced to wait for this innovation while CONCORD dithered over how to handle the transition period, but were finally granted clearance in YC113.\r\r\n\r\r\nThis is a block of fuel designed for Minmatar control towers. Forty blocks are sufficient to run a standard large tower for one hour, while medium and small towers require twenty and ten blocks respectively over the same period.',0,5,0,40,NULL,95.0000,1,1870,0),(4247,1136,'Amarr Fuel Block','Frustrated with the inefficiencies involved in tracking multiple fuel types, Thukker logisticians pioneered the development of prepackaged fuel. In YC 111, after a successful trial period, they converted the Tribe\'s entire starbase network to use fuel blocks. Capsuleers were forced to wait for this innovation while CONCORD dithered over how to handle the transition period, but were finally granted clearance in YC113.\r\r\n\r\r\nThis is a block of fuel designed for Amarr control towers. Forty blocks are sufficient to run a standard large tower for one hour, while medium and small towers require twenty and ten blocks respectively over the same period.',0,5,0,40,NULL,95.0000,1,1870,0),(4248,899,'Warp Disruption Field Generator II','The field generator projects a warp disruption sphere centered upon the ship for its entire duration. The field prevents any warping or jump drive activation within its area of effect.\r\n\r\nThe generator has several effects upon the parent ship whilst active. It increases its signature radius and agility whilst penalizing the velocity bonus of any afterburner or microwarpdrive modules. It also prevents any friendly remote effects from being rendered to the parent ship.\r\n\r\nThis module\'s effect can be modified with scripts.\r\n\r\nNote: can only be fitted on the Heavy Interdiction Cruisers.',0,50,1,1,NULL,4746166.0000,1,1085,0),(4249,132,'Warp Disruption Field Generator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(4250,650,'Small Tractor Beam II','By manipulating gravity fields, this module can pull cargo containers towards the ship.',50,50,0.8,1,NULL,2186176.0000,1,872,0),(4251,723,'Small Tractor Beam II Blueprint',' ',0,0.01,0,1,NULL,90000.0000,1,NULL,0),(4252,650,'Capital Tractor Beam II','By manipulating gravity fields, this module can pull cargo containers towards the ship.\r\r\n\r\r\nNote: this tractor beam can only be fitted on the Rorqual ORE Capital Ship',50,4000,0.8,1,NULL,56653041.0000,1,872,0),(4253,723,'Capital Tractor Beam II Blueprint',' ',0,0.01,0,1,NULL,400000000.0000,1,NULL,0),(4254,339,'Micro Auxiliary Power Core II','Supplements the main Power core providing more power',0,20,0,1,NULL,277678.0000,1,660,0),(4255,352,'Micro Auxiliary Power Core II Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,NULL,0),(4256,862,'Bomb Launcher II','A missile launcher bay module facilitating bomb preparation, and deployment.\r\r\n\r\r\nBomb Launchers can only be equipped by Stealth Bombers and each bomber can only equip one bomb launcher.',0,50,300,1,4,3616388.0000,1,1014,0),(4257,136,'Bomb Launcher II Blueprint',' ',0,0.01,0,1,NULL,19000000.0000,1,NULL,0),(4258,481,'Core Probe Launcher II','Launcher for <a href=showinfo:30013>Core Scanner Probes</a>, which are used to scan down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a> in space.\r\r\n\r\r\nNote: Only one probe launcher can be fitted per ship.\r\r\n\r\r\n5% bonus to strength of scan probes.',0,5,0.8,1,NULL,114738.0000,1,712,0),(4259,918,'Core Probe Launcher II Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,NULL,0),(4260,481,'Expanded Probe Launcher II','Launcher for <a href=showinfo:30013>Core Scanner Probes</a> and <a href=showinfo:30028>Combat Scanner Probes</a>.\r\r\n\r\r\n<a href=showinfo:30013>Core Scanner Probes</a> are used to scan down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a> in space.\r\r\n<a href=showinfo:30028>Combat Scanner Probes</a> are used to scan down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a>, starships, structures and drones.\r\r\n\r\r\nNote: Only one scan probe launcher can be fitted per ship.\r\r\n\r\r\n5% bonus to strength of scan probes.',0,5,8,1,NULL,114738.0000,1,712,0),(4261,918,'Expanded Probe Launcher II Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,NULL,0),(4262,316,'Armored Warfare Link - Damage Control II','Reduces the capacitor need of the fleet\'s personal and targeted armor repair systems.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,605261.0000,1,1634,0),(4263,532,'Armored Warfare Link - Damage Control II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4264,316,'Armored Warfare Link - Passive Defense II','Grants a bonus to the fleet\'s armor resistances.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,605261.0000,1,1634,0),(4265,532,'Armored Warfare Link - Passive Defense II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4266,316,'Armored Warfare Link - Rapid Repair II','Increases the speed of the fleet\'s personal and targeted armor repair systems.\r\r\nWill not affect Capital-sized personal repair modules.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,605261.0000,1,1634,0),(4267,532,'Armored Warfare Link - Rapid Repair II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4268,316,'Information Warfare Link - Electronic Superiority II','Boosts the strength of the fleet\'s electronic warfare modules.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,605261.0000,1,1635,0),(4269,532,'Information Warfare Link - Electronic Superiority II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4270,316,'Information Warfare Link - Recon Operation II','Increases range of modules requiring Electronic Warfare, Sensor Linking, Target Painting or Weapon Disruption for all ships in the fleet.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,605261.0000,1,1635,0),(4271,532,'Information Warfare Link - Recon Operation II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4272,316,'Information Warfare Link - Sensor Integrity II','Boosts sensor strengths and lock ranges for all of the fleet\'s ships.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,576589.0000,1,1635,0),(4273,532,'Information Warfare Link - Sensor Integrity II Blueprint',' ',0,0.01,0,1,NULL,1476280.0000,1,NULL,0),(4274,316,'Mining Foreman Link - Harvester Capacitor Efficiency II','Decreases the capacitor need of mining lasers, gas harvesters and ice harvesters.\r\r\n\r\r\nForeman Links are dedicated mining operation systems designed to assist foremen in coordinating their operations. \r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNote: The Fleet bonus only works if you are the assigned fleet booster.',0,60,0,1,NULL,605261.0000,1,1638,0),(4275,532,'Mining Foreman Link - Harvester Capacitor Efficiency II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4276,316,'Mining Foreman Link - Laser Optimization II','Decreases mining laser, gas harvester and ice harvester duration.\r\r\n\r\r\nForeman Links are dedicated mining operation systems designed to assist foremen in coordinating their operations.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNote: The Fleet bonus only works if you are the assigned fleet booster.',0,60,0,1,NULL,605261.0000,1,1638,0),(4277,532,'Mining Foreman Link - Laser Optimization II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4278,316,'Mining Foreman Link - Mining Laser Field Enhancement II','Increases the range of the fleet\'s mining lasers, gas harvesters, ice harvesters and survey scanners.\r\r\n\r\r\nForeman Links are dedicated mining operation systems designed to assist foremen in coordinating their operations.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNote: The Fleet bonus only works if you are the assigned fleet booster.',0,60,0,1,NULL,605261.0000,1,1638,0),(4279,532,'Mining Foreman Link - Mining Laser Field Enhancement II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4280,316,'Siege Warfare Link - Active Shielding II','Increases the speed of the fleet\'s shield boosters and decreases the duration of shield transporters. Will not affect Capital-sized personal shield boosters.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,605261.0000,1,1636,0),(4281,532,'Siege Warfare Link - Active Shielding II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4282,316,'Siege Warfare Link - Shield Efficiency II','Reduces the capacitor need of the fleet\'s shield boosters and shield transporters.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,605261.0000,1,1636,0),(4283,532,'Siege Warfare Link - Shield Efficiency II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4284,316,'Siege Warfare Link - Shield Harmonizing II','Boosts all shield resistances for the fleet\'s ships.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,605261.0000,1,1636,0),(4285,532,'Siege Warfare Link - Shield Harmonizing II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4286,316,'Skirmish Warfare Link - Evasive Maneuvers II','Lowers the signature radius of ships in the fleet.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,576589.0000,1,1637,0),(4287,532,'Skirmish Warfare Link - Evasive Maneuvers II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4288,316,'Skirmish Warfare Link - Interdiction Maneuvers II','Boosts the range of the fleet\'s propulsion jamming modules, except for Warp Disruption Field Generators.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,605261.0000,1,1637,0),(4289,532,'Skirmish Warfare Link - Interdiction Maneuvers II Blueprint',' ',0,0.01,0,1,NULL,1476280.0000,1,NULL,0),(4290,316,'Skirmish Warfare Link - Rapid Deployment II','Increases the speed of the fleet\'s afterburner and microwarpdrive modules.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,605261.0000,1,1637,0),(4291,532,'Skirmish Warfare Link - Rapid Deployment II Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,NULL,0),(4292,515,'Siege Module II','An electronic interface designed to augment and enhance a dreadnought\'s siege warfare abilities. Through a series of electromagnetic polarity field shifts, the siege module diverts energy from the ship\'s propulsion and warp systems to lend additional power to its offensive and defensive capabilities.\r\r\n\r\r\nThis results in a tremendous increase in damage, as well as a greatly increased rate of defensive self-sustenance. Due to the ionic field created by the siege module, remote effects like warp scrambling et al. will not affect the ship while in siege mode.\r\r\n\r\r\nThis also means that friendly remote effects will not work while in siege mode either. In addition, the lack of power to locomotion systems means that neither standard propulsion nor warp travel are available to the ship nor are you allowed to dock until out of siege mode.\r\r\n\r\r\nNote: A siege module requires Strontium clathrates to run and operate effectively. Only one siege module can be fitted to a dreadnought class ship. The amount of shield boosting gained from the Siege Module is subject to a stacking penalty when used with other similar modules that affect the same attribute on the ship.',1,4000,0,1,NULL,74338508.0000,1,801,0),(4293,516,'Siege Module II Blueprint',' ',0,0.01,0,1,NULL,522349680.0000,1,NULL,0),(4294,515,'Triage Module II','An electronic interface designed to augment and enhance a carrier\'s defenses and logistical abilities. Through a series of electromagnetic polarity field shifts, the triage module diverts energy from the ship\'s propulsion and warp systems to lend additional power to its defensive and logistical capabilities.\r\r\n\r\r\nThis results in a great increase in the carrier\'s ability to provide aid to members of its fleet, as well as a greatly increased rate of defensive self-sustenance. Due to the ionic flux created by the triage module, remote effects like warp scrambling et al. will not affect the ship while in triage mode.\r\r\n\r\r\nThis also means that friendly remote effects will not work while in triage mode either. The flux only disrupts incoming effects, however, meaning the carrier can still provide aid to its cohorts. Sensor strength and targeting capabilities are also significantly boosted. In addition, the lack of power to locomotion systems means that neither standard propulsion nor warp travel are available to the ship, nor is the carrier able to dock until out of triage mode. Finally, any drones or fighters currently in space will be abandoned when the module is activated.\r\r\n\r\r\nNote: A triage module requires Strontium Clathrates to run and operate effectively. Only one triage module can be run at any given time, so fitting more than one has no practical use. The remote repair module bonuses are only applied to capital sized modules. The amount of shield boosting gained from the Triage Module is subject to a stacking penalty when used with other similar modules that affect the same attribute on the ship.\r\r\n\r\r\nThis module can only be fit on Carriers.',1,4000,0,1,NULL,74502348.0000,1,801,0),(4295,516,'Triage Module II Blueprint',' ',0,0.01,0,1,NULL,522349680.0000,1,NULL,0),(4296,585,'Medium Remote Hull Repairer II','This module uses nano-assemblers to repair damage done to the hull of the Target ship.',20,10,0,1,NULL,429564.0000,1,1061,0),(4298,870,'Medium Remote Hull Repairer II Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,NULL,0),(4299,585,'Small Remote Hull Repairer II','This module uses nano-assemblers to repair damage done to the hull of the Target ship.',20,5,0,1,NULL,179504.0000,1,1060,0),(4300,870,'Small Remote Hull Repairer II Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,NULL,0),(4301,474,'Outgrowth Rogue Drone Hive Pass Key','This is a pass key handed out by Jeremy Tacs.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(4302,1201,'Oracle','In YC 113 Empress Jamyl Sarum I challenged <a href=showinfo:30//500003>Amarr</a> ship manufacturers to build a new battlecruiser that would break the stalemate of the Empyrean War. Deviating from the doctrine of brute-force and heavy armor, the engineers at <a href=showinfo:2//1000066>Viziam</a> took inspiration from <a href=showinfo:30//500001>Caldari</a> history.\r\r\n<br>During the Gallente-Caldari War, the Caldari developed light, maneuverable ships to counter the slow ships of the <a href=showinfo:30//500004>Gallente Federation</a>. This philosophy, along with a cutting-edge powertrain and ultra-light alloy armor plating, led to the Oracle.\r\r\n<br>The Empire immediately ordered the ship into production. The Empress personally congratulated Viziam Chief Researcher <a href=showinfo:1383//3014474>Parud Vakirokiki</a>, calling the ship \"a work of Divine Grace for the Empire, and retribution to our enemies.\"',14760000,234000,500,1,4,90222792.0000,1,470,0),(4303,1141,'Research Abstract: Project Tesseract','<b>Paper:</b> Project Tesseract - An Investigation into the Causes of the Seyllin Incident and the properties of A0 Blue stars and Isogen-5.<br>\r\r\n<b>Lead Researcher:</b> Rhavas<br>\r\r\n<b>Contributors:</b> Mark726, Dr Amira, Julianus Soter, Morwen Lagann, Darth Skorpius, The Antiquarian<br>\r\r\n<b>Summary:</b> In YC 111, one of the deadliest events in recent memory, the <a href=evebrowser:http://wiki.eveonline.com/en/wiki/Year_YC111_March>Seyllin Incident</a>, extinguished nearly 500 million souls as the system\'s A0-class blue sun poured radioactive energy along a magnetic field anomaly and directly into the depths of the first planet in the system, <a href=showinfo:30889//40318018>Seyllin I</a>. \r\r\n\r\r\nThe energy released by this event was so great that it may have triggered the opening of the wormhole network in addition to simultaneously decimating eight other planets which orbited similar A0 Blue stars. A chief aim of this project is to understand the causes and mechanics driving such incredible destruction. \r\r\n\r\r\nThis project has compiled all the known data on the subject, including multiple expeditions to  shattered planet  systems (located across both New Eden and wormhole space). We expect to uncover significant details about the mechanics of wormhole initiation as well as the role and power of Isogen-5, which is implicated in the events of that day.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system (beacon designation - <b>AJS1: Antiquus</b>).<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4304,1141,'Research Abstract: Project Theseus','<b>Paper:</b> Project Theseus<br>\r\r\n<b>Lead Researcher:</b> Valerie Valate<br>\r\r\n<b>Contributors:</b> Aedeal, Horatius Caul, Calen Davrissus, Kathryn Dougans, Myyona, Katy Moore, Gosakumori Noh<br>\r\r\n<b>Summary:</b> The Labyrinth deadspace complex in <a href=showinfo:5//30004124>Aphi</a> is one of the major Takmahl relic sites found in the <a href=showinfo:4//20000603>Araz constellation</a>. Project Theseus set out to map the Labyrinth, perform a survey of the site, identify any Takmahl artifacts present, and to aid in future projects investigating Takmahl culture in Araz. \r\r\n\r\r\nTeams of ships entered the Labyrinth to combat the  Minotaur  guardians within and explore the site. The result of those efforts was a three-dimensional map which reveals much about the shape of the Labyrinth, in addition to containing useful information about the types and quantities of Takmahl artifacts to be found there.  \r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4305,489,'Oracle Blueprint',' ',0,0.01,0,1,NULL,625000000.0000,1,589,0),(4306,1201,'Naga','The Naga was designed in YC 109 by <a href=showinfo:2//1000043>Corporate Police Force</a> as an anti-<a href=showinfo:30//500010>Guristas</a> ship, sacrificing the usual robust <a href=showinfo:2//1000035>Caldari Navy</a> standards in favor of supporting battleship-class weaponry. It was rejected by <a href=showinfo:2//1000005>Hyasyoda</a> management for being overspecialized.\r\r\n<br>The Naga design remained in the Hyasyoda archives, forgotten (save for a cameo in the Gallente holo-series <i>CPF Blue</i>). In YC 113 the Caldari Navy entertained contracts for a new tier of gunboat battlecruiser. Hyasyoda quickly submitted and won with the Naga, underbidding both <a href=showinfo:2//1000010>Kaalakiota</a> and <a href=showinfo:2//1000019>Ishukone</a>.\r\r\n<br>The Naga is effective in any campaign where fast, mobile firepower is required.',15000000,252000,575,1,1,87101986.0000,1,471,0),(4307,489,'Naga Blueprint',' ',0,0.01,0,1,NULL,615000000.0000,1,590,0),(4308,1201,'Talos','The Talos began in YC 110 as a R&D concept by <a href=showinfo:30//500014>ORE</a>. Conceived as a patrol craft for mining operations in lawless space, the Talos would have been abandoned completely were it not adopted by the Black Eagles, a black-ops branch of the <a href=showinfo:30//500004>Gallente</a> government. The Black Eagles stripped the Talos of non-essential systems and bolted on battleship-class weapons, creating a quick-strike craft ideal for guerilla action. \r\r\n<br>The Talos remained a military secret until YC 113, when it was introduced into wider circulation as a third tier battlecruiser. Today the Talos is manufactured by <a href=showinfo:2//1000109>Duvolle Labs</a>, who modified the original ORE designs to bring it in line with Gallente standards.',15552000,270000,600,1,8,92158294.0000,1,472,0),(4309,489,'Talos Blueprint',' ',0,0.01,0,1,NULL,650000000.0000,1,591,0),(4310,1201,'Tornado','In YC 113 <a href=showinfo:2//1000054>Republic Security Services</a> learned the <a href=showinfo:30//500003>Amarr Empire</a> was building a new battlecruiser capable of supporting battleship-class weapons. Determined to not lose their technological edge to their adversaries, <a href=showinfo:2//1000051>Republic Fleet</a> commissioned <a href=showinfo:2//1000057>Boundless Creation</a> to construct a gunboat to match.<br><br>What they designed was the Tornado. Developed in record time and total secrecy, the Tornado is a testament to Minmatar engineering. Modeled loosely off of flying-wing designs of ancient planetary bombers, the Tornado supports multiple large projectile turrets, dealing massive damage while maintaining a small signature radius.',15228000,216000,535,1,2,85689342.0000,1,473,0),(4311,489,'Tornado Blueprint',' ',0,0.01,0,1,NULL,592000000.0000,1,592,0),(4312,1136,'Gallente Fuel Block','Frustrated with the inefficiencies involved in tracking multiple fuel types, Thukker logisticians pioneered the development of prepackaged fuel. In YC 111, after a successful trial period, they converted the Tribe\'s entire starbase network to use fuel blocks. Capsuleers were forced to wait for this innovation while CONCORD dithered over how to handle the transition period, but were finally granted clearance in YC113.\r\r\n\r\r\nThis is a block of fuel designed for Gallente control towers. Forty blocks are sufficient to run a standard large tower for one hour, while medium and small towers require twenty and ten blocks respectively over the same period.',0,5,0,40,NULL,95.0000,1,1870,0),(4313,1137,'Gallente Fuel Block Blueprint',' ',0,0.01,0,1,8,10000000.0000,1,1920,0),(4314,1137,'Caldari Fuel Block Blueprint',' ',0,0.01,0,1,1,10000000.0000,1,1920,0),(4315,1137,'Amarr Fuel Block Blueprint',' ',0,0.01,0,1,4,10000000.0000,1,1920,0),(4316,1137,'Minmatar Fuel Block Blueprint',' ',0,0.01,0,1,2,10000000.0000,1,1920,0),(4318,1025,'InterBus Customs Office','Orbital Customs Offices are the primary points of contact between planetary and interplanetary economies. These facilities, resembling massive hangars in space, provide high-volume, high-frequency cargo transport services between a planet\'s surface and orbit.\r\r\n\r\r\n<i>Excerpt from the Amarr Prime Customs Agency regulations, section 17, subsection 4, paragraph 8:\r\r\n\r\r\nThe following items may only be imported or exported with the express prior approval of the Imperial Underscrivener for Commercial Affairs:\r\r\n\r\r\nNarcotic substances; handheld firearms; slaver hounds (except as personal property); Mindflood; live insects; ungulates; Class 1 refrigerants and aerosols; forced laborers/personal slaves (or other sapient livestock); animal germ-plasm; biomass of human origin; xenobiotics; walnuts.</i>',5000000000,100000000,35000,1,4,0.0000,0,NULL,0),(4319,226,'Protest Monument','This was once a memorial to the winners of a riddle contest sponsored by late entrepreneur Ruevo Aram. After standing proud for half a decade, it was destroyed in late YC113 by capsuleers who were staging a mass uprising against an intolerable status quo of intergalactic affairs. Today, the ruins of this once-great work of art stand as a testament to the fact that change is the universe\'s only constant.',0,0,0,1,NULL,0.0000,0,NULL,0),(4320,1141,'Research Abstract: Project Theta','<b>Paper:</b> Project Theta<br>\r\r\n<b>Lead Researcher:</b> Norman Vales<br>\r\r\n<b>Contributors:</b> Authochthonian, Chevalleis<br>\r\r\n<b>Summary:</b> The present goal of Project Theta is to produce laboratory equipment for use in attempting safe communications with rogue drones. Project Theta aims to achieve this goal by repurposing and reverse engineering available rogue drone technology to create a communications subnet intended to interface with the more advanced rogue drone networks.\r\r\n\r\r\nThe three-unit communications system includes an override of the present comms systems, designed as a protective measure. It has also been designed to provide on-the-fly encoding and decoding. Future testing will be necessary to determine if the system will work as required.\r\r\n\r\r\nBased on the <a href=showinfo:23678>Aether Hive Link</a> the network remains experimental, and will be part of an isolated communications system. Recent lab tests have indicated a bandwidth of at least ten times that which is available to typical businesses.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4321,1141,'Research Abstract: Project Blueprint','<b>Paper:</b> Project Blueprint<br>\r\r\n<b>Lead Researchers:</b> Adainy Gwanwyn, Emily Dallocort<br>\r\r\n<b>Contributors:</b> Mark726<br>\r\r\n<b>Summary:</b> The premise of Project Blueprint is to acquire photographic samples (along with standard documentation) of Sleeper constructs to determine their similarity, if any, to those produced in known space. Currently, researchers are in the initial phases of gathering samples of New Eden\'s structures to compare to the Sleeper constructs once wormhole excursions begin.\r\r\n\r\r\nThe purpose behind gathering this information is manifold:<br>\r\r\n   1. To investigate if Sleeper constructs hold any sort of cultural significance to the Sleepers themselves;<br>\r\r\n   2. To investigate if Sleepers build their constructs to establish permanent homes or temporary sites<br>\r\r\n   3. To assist in determining the relationship between Sleepers and the Talocan.\r\r\n\r\r\nUltimately, information gathered from Project Blueprint could be used to assist other Project teams (ideally, those under the <a href=evebrowser:http://wiki.eveonline.com/en/wiki/Arek%27Jaalan:_Sleeper_History>Sleeper History division</a>), and to help further the efforts of those in the Arek\'Jaalan initiative.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>\r\r\n',1,0.1,0,1,4,0.0000,1,NULL,0),(4322,1141,'Research Abstract: Project Catapult','<b>Paper:</b> Project Catapult, A Study of the Sansha Wormhole Generator Method<br>\r\r\n<b>Lead Researcher:</b> Rhavas<br>\r\r\n<b>Contributors:</b> Grideris, Mark726, Morwen Lagann, Razz Skyshatter, Tuoro<br>\r\r\n<b>Summary:</b> New Eden is under siege by Sansha Kuvakei and his Nation. Entire systems are attacked and disabled, but he reserves his most massive, propagandist attacks for the Slaves and Citizens, who come in <a href=showinfo:3628>Nation</a>-class supercapitals to destroy the capsuleer fleets. The hallmarks of these invasions are multiple wormholes under the direct control of Sansha\'s Nation. While the battle between the capsuleer community and Kuvakei lies outside the scope of the Arek\'Jaalan project, wormhole generation and stabilization technology represents a potentially critical link to understanding both current wormholes and the transportation capabilities and technologies of the ancient races.\r\r\n\r\r\nBy analyzing information captured by our sensors, probes and contacts, we hope to gather sufficient information to reverse engineer and recreate this technology. Three goals are indicated for this purpose: \r\r\n\r\r\n   1. Create new methods of point-to-point interstellar travel, either by enabling greater distances or a broader range of jump-capable vessels.<br>\r\r\n   2. Provide deeper insights to the basic functional physics of wormholes to help drive the efforts of <a href=showinfo:4333>Project Slipstream</a><br>\r\r\n   3. Provide potential insights into whether Sansha\'s Nation wormhole generators were created by the Nation, captured from the Jove, or adapted from the technology of ancient races (if so, those findings will be used to further inform <a href=evebrowser:http://wiki.eveonline.com/en/wiki/Project_Gateway>Project Gateway</a> and <a href=evebrowser:http://wiki.eveonline.com/en/wiki/Project_Rift>Project Rift</a>).\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4323,1141,'Research Abstract: Project Common Ground','<b>Paper</b>: Project Common Ground<br>\r\r\n<b>Lead Researcher</b>: Unit XS365BT<br>\r\r\n<b>Contributors</b>: None.<br>  \r\r\n<b>Summary:</b> This paper is a theoretical study on a possible history of the Talocan and Sleeper species, and their potential links to the rogue drone and capsuleer communities.\r\r\n\r\r\nIt theorizes that the Sleeper species was originally the Talocan equivalent of the capsuleer and that a war occurred between the Talocan and their creations, culminating in the release of an AI virus by the Talocan in an attempt to survive the conflict. This AI virus ravaged the Sleeper species, but not before they transmitted a large quantity of data to a secure storage device they had sent far from their own region of space. This data, when uncovered, gave rise to the rogue drone species.\r\r\n\r\r\nThis paper was created to serve as a theoretical basis for future projects.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>\r\r\n',1,0.1,0,1,4,0.0000,1,NULL,0),(4324,1141,'Research Abstract: Project Huntress Green (1 of 3)','<b>Paper:</b> Project Huntress Green - The Nature of Life in Anoikis<br>\r\r\n<b>Lead Researcher:</b> Gaia Ma\'chello<br>\r\r\n<b>Contributors:</b> James Arget, Tas Caern and Vincent Athena<br>\r\r\n<b>Summary:</b> Examination of biological samples obtained from planets in Anoikis has shown that life there is closely related to that found in known sectors of space. Both use DNA as the genetic material, and both use the same 26 amino acids for building proteins. In addition, the genetic code (that is, which combinations of three nucleotides code for which amino acid) is the same for both humans and life in Anoikis. As the genetic code is arbitrary, the chance of this happening by accident is one in ten to the 26th power. We are forced to conclude that life in Anoikis and human life sprang from the same source.\r\r\n\r\r\nFurther investigation into how this could have come to be is the topic of another paper: <a href=showinfo:4336>The Origin of Life in Anoikis.</a>\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4325,1141,'Research Abstract: Project Algintal','<b>Paper</b>: Project Algintal - Investigation of the Algintal Rogue Drone Hive<br>\r\r\n<b>Lead Researcher</b>: Myyona<br>\r\r\n<b>Contributors</b>: Natelia<br>\r\r\n<b>Summary</b>: Rogue drones have been spreading all over New Eden for the last 80 years or so and represent a constant threat to space travel across the cluster. The rogue drone hive found at the Skeleton Comet complex within the <a href=showinfo:5//30002681>Deltole</a> system appears to have assimilated ancient technologies left behind by the Yan Jung nation, resulting in the development of a new strain of drones, potentially more powerful than their standard counterparts. \r\r\n\r\r\nTwo reports on these events were gathered to determine the extent to which the drones were affected by assimilating the Yan Jung technology, and to establish what level of threat this could pose. The findings showed that the new strain of drones possess significantly enhanced communication systems and cognitive abilities as compared with their predecessors. However, through the examination process it was also discovered that apparently, nearly all of the new drone strains had been destroyed by the original rogue drone hive, likely due to self-regulatory mechanisms within the hive. Consequently, we conclude that any remaining drones pose little to no threat. \r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4326,1141,'Research Abstract: Project Enigma','<b>Paper:</b> Project Enigma - The Jovian Empires<br>\r\r\n<b>Lead Researcher:</b> Myyona<br>\r\r\n<b>Contributors:</b> None<br>\r\r\n<b>Summary:</b> The Jovian society was the first to recover after the closure of the EVE Gate, an event that caused a near-complete extinction of all human settlements in New Eden. Having existed for thousands of years since then, the Jovian Empire experienced peaks and falls long before any of the other currently existing empires even managed to establish themselves as spacefaring nations. \r\r\n\r\r\nBeing keen seekers of knowledge, the Jovians possess great insight on past events, though they do not share it freely and easily with outsiders. This paper looks into the documentation available on the history of the Jovian Empires in an attempt to better understand the Jove mentality and the current state of the Jovian society. Evidence gathered for the paper suggests that the recent lack of communication from Jovian officials, as well as their seeming inability to stop the fatal Jovian Disease, may signal that the current Jovian Empire is in decline.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4327,1141,'Research Abstract: Project Trinity','<b>Paper:</b> Project Trinity<br>\r\r\n<b>Lead Researcher:</b> Julianus Soter<br>\r\r\n<b>Contributors:</b> General Stargazer, Moira. Corporation<br>\r\r\n<b>Summary:</b> Operation Trinity was the in-field reconnaissance operation to gather experimental evidence to prove or deny the Trinity Hypothesis, part of Project Trinity. Conducted inside Class 4 space, the operation utilized military and scientific vessels to investigate Trinary Hub facilities in order to determine whether they held any similarity to the <a href=showinfo:11066>Trinary Data</a> discovered on an abandoned Helios in Class 6 space, suspected to have once belonged to missing astrophysicist Lianda Burreau, the first capsuleer to discover the unknown regions. \r\r\n\r\r\nA trinary hub was investigated and the Sleeper databanks located at the structure were hacked. Data analyzers were applied to all artifacts and signals captured from the facility were compared with a Jovian Trinary Data fragment acquired from Admiral Ouria\'s Eidolon battleship. Correlations were collected and indicate possible relationships between Jovian and Sleeper data structures. Additional conclusions may be possible with assistance from Eifyr & Co.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4328,1141,'Research Abstract: Project Infernal Spade','<b>Paper:</b> Project Infernal Spade - Analysis of the Ancient Talocan Temple and Sun Reader<br>\r\r\n<b>Lead Researcher:</b> Myyona<br>\r\r\n<b>Contributors:</b> None<br>\r\r\n<b>Summary:</b> The appearance of Talocan ruins in w-space has put a renewed focus on this civilization. Very little was known about the Talocan before their ruins appeared in w-space besides that they once had a presence in the <a href=showinfo:4//20000024>Okkelen constellation</a>, an area now claimed by the Caldari State. Despite being overrun by rogue drones, the Devil\'s Dig Site deadspace complex in the <a href=showinfo:5//30000171>Otitoh</a> system held archaeologists\' interest for some time, mostly due to its housing some of the only Talocan relic remnants still available.  \r\r\n\r\r\nThis paper is aimed at investigating the Devil\'s Dig Site and finding out what secrets it holds. It has become clear that the rogue drones inhabiting this site are formidable foes and, clearly surpassing most other rogue drone hives in power. Two ancient Talocan structures have also been discovered; an ancient temple and a mysterious black monolith identified as a  Sun Reader.\' Due to the hostility of the drones, a thorough investigation of these structures has not been possible yet and is still in the planning phase. \r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4329,1141,'Research Abstract: Project Astrosurvey','<b>Paper:</b> Astrosurvey<br>\r\r\n<b>Lead Researcher:</b> Pr. Gehen Sealbreaker<br>\r\r\n<b>Contributors:</b> Sealbreaker Labs, Vincent Athena<br>\r\r\n<b>Summary:</b> The homogeneity of the asteroids located in Anoikis is improbable, and ores extracted there have been thrown in refineries using old refining processes with no proper study. Considering current survey scanners only compare asteroid properties to a known ores database, their current classification may be wrong and not reflect their full potential.\r\r\n\r\r\nThree possibilities other than an improbable homogeneity can explain this:<br>\r\r\n   1. Ores in Anoikis are plain. Specific conditions in New Eden contributed to variants\' formation.<br>\r\r\n   2. Specific ores existed in Anoikis. Their supply was depleted by intensive exploitation from previous occupants.<br>\r\r\n   3. There are specific ore variants in Anoikis. Tolerance of survey scanners made us unaware of this. (Hypothesis studied)\r\r\n\r\r\nWhen it comes to crystal formation, stellar macroscopic effects are a main factor. Cosmic phenomenon must be considered, and samples from their systems studied.\r\r\n\r\r\nThe operation had 3 steps so far:<br>\r\r\n   1. Establishment of a scientific base camp in Anoikis.<br>\r\r\n   2. Harvesting and initial study of resources.<br>\r\r\n   3. Study of the collected samples using laboratories in Empire stations. (Ongoing)<br>\r\r\n\r\r\nCurrent results are inconclusive, but there is still much to do. So far, no collected ore matches the molecular structure of any known ore variant, common or rare (Luminous Kernite, Banidine, Polygypsum, etc).\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4330,1141,'Research Abstract: Project Omicron','<b>Paper:</b> Project Omicron<br>\r\r\n<b>Lead Researcher:</b> Authochthonian<br>\r\r\n<b>Contributors:</b> Authochthonian, Chevalleis, Grideris<br>\r\r\n<b>Summary:</b> Project Omicron is an attempt to establish two-way communications with the rogue drones. The purpose of this attempt is to find common ground as a prelude to full diplomatic negotiations and to find out as much information as possible on their origins, purpose and needs. Additionally, Omicron aims to investigate possible connections between rogue drones and sleeper drones by communicating directly with rogue drone hives where possible. Much of this project relates to others, such as <a href=showinfo:4320>Project Theta</a>, which seeks to provide the hardware to make such communication possible. \r\r\n\r\r\nTwo-way communications with rogue drones have been proven possible (see the Algintal Incident) and we are constantly refining our communication protocols and encryption/decryption techniques to improve our communication abilities. We predict, based on current evidence, that full communication with rogue drones may be possible around late YC 113 to early YC 114. \r\r\n\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4331,1141,'Research Abstract: Project Omega','<b>Paper:</b> Project Omega<br>\r\r\n<b>Lead Researcher:</b> Chevalleis<br>\r\r\n<b>Contributors:</b> Authochthonian, Chevalleis<br>\r\r\n<b>Summary:</b> Project Omega is an attempt to investigate the nature of rogue drone hives and their structures. Omega seeks to uncover anything that can be learned about their hierarchy and society by recording how the various rogue drone types interact with one another and other hives. Omega also studies the software of the rogue drones, analyzing their intelligence and their psychology in an effort to identify the programming code responsible for their behavior. \r\r\n\r\r\nResearch into existing types of hives found  naturally occurring  has been carried out and a comparative psychology study is also underway. These examinations should provide deeper insights into the nature of rogue drones and their hives.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4332,1141,'Research Abstract: Project Rho','<b>Paper:</b> Project Rho<br>\r\r\n<b>Lead Researcher:</b> Authochthonian<br>\r\r\n<b>Contributors:</b> Authochthonian, Chevalleis<br>\r\r\n<b>Summary:</b> Project Rho is an attempt to gather information on all types of rogue drone hardware, from the smallest to the largest drone types known to exist, and to compile this information into a comprehensive database for ease of access when comparing rogue drone technology to sleeper drone technology by other divisions of Arek\'Jaalan.  Detailed analysis of every rogue drone will be carried out and compared to empire equivalents.\r\r\n\r\r\nWhen completed, this project should enable us to identify any technological links between rogue drones and sleeper drones.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4333,1141,'Research Abstract: Project Slipstream','<b>Paper:</b> Project Slipstream - Wormhole Physics for Capsuleers<br>\r\r\n<b>Lead Researcher:</b> Helen Ohmiras<br>\r\r\n<b>Contributors:</b> Rhavas, Pat Irvam<br>\r\r\n<b>Summary:</b> Artificial wormhole induction processes are used in warp drives and jump drives across New Eden. Despite the prevalence of this technology, natural wormholes are still a mystery to many. A pilot with a firm grasp of wormhole mechanics can make more effective decisions when unforeseen and unpredicted events occur in the future.\r\r\n\r\r\nProject Slipstream is an attempt to educate the wider capsuleer community on basic wormhole physics. We will focus on clearing up misconceptions regarding the difference between natural wormholes and artificial wormholes. The nature of wormholes present in the uncharted regions will also be determined. These findings will then be used as a starting point for further clarification of the physics behind the technology used to create artificial wormholes, as well as other wormhole induction drive technologies.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4334,1141,'Arek\'Jaalan: Site One Contributions Listing','<b>Special Acknowledgement:</b> This site is named after the capsuleer known as \"The Antiquarian\" whose generous contributions played a large part in making this base in Eram a reality. \r\r\n\r\r\n</b>Dedication:</b> Arek\'Jaalan Site One is dedicated to the capsuleers who helped found the project, and ensure its continued stability and success. \r\r\n\r\r\nA full listing of donations is available <a href=evebrowser:http://wiki.eveonline.com/en/wiki/Arek%27Jaalan:_Site_One>here</a>. \r\r\n\r\r\nThe following individuals and corporations contributed to the construction of this site. Without their donations, Arek\'Jaalan Site One would not have been possible. \r\r\n\r\r\n</b>Corporations:</b>\r\r\nApplied Industrial Technologies\r\r\nFedMart\r\r\nKitzless\r\r\nNepenthe Inc.\r\r\nRed Rock Mining Company\r\r\nUnit Commune\r\r\nYahoo Inc\r\r\n\r\r\n</b>Individuals:</b>\r\r\nAdainy Gwanwyn\r\r\nAeb Raven\r\r\nAidan Brooder\r\r\nAkrasjel Lanate\r\r\nAlexa Wilkot\r\r\nAlextrasa Zurman\r\r\nAlpac T\'Zarri\r\r\nAngrypunch\r\r\nAquila Shadow\r\r\nArklan1\r\r\nBorascus\r\r\nBrick Royl\r\r\nCargo2000\r\r\nCold Vodka\r\r\nCunane Jeran\r\r\nDarkcoro Matari\r\r\nDravidshky\r\r\nDutchGunner\r\r\nEkserevnitis\r\r\nEri Vin\'Taur\r\r\nFaith Comet\r\r\nFaulx\r\r\nfLitSer\r\r\nGeneral Stargazer\r\r\nGouzu Kho\r\r\nGran Man\r\r\nHannah Viktor\r\r\nHector Von Hammerstorm\r\r\nHordi LaGeorge\r\r\nIwata Accuspray\r\r\nJack bubu\r\r\nJacques DuVey\r\r\nJames Gheris\r\r\nJara Blackwind\r\r\nJikane Ronuken\r\r\nJulianus Soter\r\r\nKais Malleus\r\r\nLancashirian\r\r\nLeopold Caine\r\r\nMai Satiri\r\r\nMark726\r\r\nMorwen Lagann\r\r\nMyrhial Arkenath\r\r\nMyyona\r\r\nNaraish Adarn\r\r\nNormal Vales\r\r\nPhaedra Aurilen\r\r\nPlanetary Genocide\r\r\nQansh\r\r\nRazz Skyshatter\r\r\nRees Noturana\r\r\nRhavas\r\r\nScatter Gun\r\r\nShin\'rohtak\r\r\nSteve Ronuken\r\r\nStone Cold Assassin\r\r\nTan Tau\r\r\nTaqai\r\r\nTarryn Nightstorm\r\r\nTerra Dedlow\r\r\nThe Antiquarian\r\r\nThomas Ownz\r\r\nTumbles Goodness\r\r\nTundradog\r\r\nUtremi Fasolasi\r\r\nVariden\r\r\n\r\r\n<b>ISK Donations:</b>\r\r\n\r\r\nThe following indviduals donated ISK towards the construction of Site One. Excess ISK left over after construction, will be used to fund archivist work. \r\r\n\r\r\n1,100,000,000 - Adhocracy Incorporated\r\r\n1,000,000,000 - House of Sebtin\r\r\n500,000,000 - Alpac T\'Zarri\r\r\n500,000,000 - skaunk (on behalf of Caustic Confluence corporation)\r\r\n300,000,000 - Salpun\r\r\n200,000,000 - Gauss Jannon\r\r\n100,000,000 - Gallente Independent Progressive Alternative\r\r\n50,000,000 - Ethan Revenant\r\r\n40,000,000 - Molocath Vynneve\r\r\n25,000,000 - Rae Seddon\r\r\n15,000,000 - Invader Squee\r\r\n10,000,000 - Windsong Woodhaven\r\r\n10,000,000 - Iwata Accuspray\r\r\n5,000,000 - Jethra Daystar\r\r\n1,000,000 - ElQuirko\r\r\n1,000,000 - Squid Tentacle\r\r\n1,000,000 - Lady mifa\r\r\n2,000,000 - jimmy 15',1,0.1,0,1,4,0.0000,1,NULL,0),(4335,1141,'Research Abstract: Project Compass','<b>Paper:</b> Project Compass<br>\r\r\n<b>Lead Researcher:</b> Mark726<br>\r\r\n<b>Contributors:</b> Rhavas<br>\r\r\n<b>Summary:</b> Project Compass represents an attempt to experimentally verify the spatial relationship between wormhole space and New Eden. The project is primarily aimed at identifying stellar objects   both in New Eden and in wormhole space   through spectroscopic analysis, and by using the properties of parallax and triangulation to determine the location of wormhole space in relation to New Eden. The Lead Researcher surveyed a random sample of wormhole systems and was able to identify a star cluster identifiable in both New Eden and wormhole space. Through mathematical extrapolation and analysis, the location of wormhole space was determined.\r\r\n\r\r\nProject Compass draws no final conclusions at this stage, as researchers are awaiting potential changes to capsule sensor technology that may yield new data.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4336,1141,'Research Abstract: Project Huntress Green (2 of 3)','<b>Paper:</b> Huntress Green - The Origin of Life in Anoikis<br>\r\r\n<b>Lead Researcher:</b> Gaia Ma\'chello <br>\r\r\n<b>Contributors:</b> James Arget, Tas Caern and Vincent Athena<br>\r\r\n<b>Summary:</b> Previous work has indicated that life in Anoikis and human life had the same origin. This brings up the question of how life originally came to planets in Anoikis.\r\r\n\r\r\nThe  molecular clock  method was used to estimate how long ago life in Anoikis and life in known space had a common ancestor. In the molecular clock method random changes to segments of  junk  DNA are examined and compared between organisms. Changes in these segments occur randomly, accumulate over time, and are not selected for by evolution. By seeing how different a given segment of junk DNA is between two organisms, an estimate can be made as to how long ago they had a common ancestor. \r\r\n\r\r\nFor this case, microorganisms that live in known space and those that live in Anoikis were compared. \r\r\n\r\r\nIt was found that life in Anoikis split from life in known space during the dark ages, the time period between the closure of the eve gate and the rebirth of civilization. Apparently, during this time, some space-faring civilization survived, or arose much faster than has been assumed. This civilization appears to have moved to Anoikis and made use of the planets.\r\r\n\r\r\nSome organisms were found that had a common ancestor with life in known space about a year ago. This is likely contamination from recent capsuleer activity in Anoikis.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4337,1141,'Research Abstract: Project Huntress Green (3 of 3)','<b>Paper:</b> Huntress Green - Possible disease organisms in Anoikis<br>\r\r\n<b>Lead Researcher:</b> Gaia Ma\'chello<br>\r\r\n<b>Contributors:</b> James Arget, Tas Caern and Vincent Athena<br>\r\r\n<b>Summary:</b> Examination of multiple biological samples obtained from planets in the unknown regions has found several organisms that could cause diseases in humans. The most interesting one is a certain fungus found on several temperate worlds.\r\r\n\r\r\nThis fungus appears able to colonize almost any surface or other organism. As it digests another organism, some proteins from that organism are displayed on the surface of the fungal strands. This allows the fungus to evade the immune system of many infected hosts.\r\r\n\r\r\nSome bacteria were also found that appear to be somewhat infectious. They do not appear to be too virulent, but some of the chemicals they produce are of particular interest. These chemicals have neurological effects that alter the behavior of the host, helping spread the bacteria.\r\r\n\r\r\n<i>This abstract relates to research undertaken by the <a href=evebrowser: http://wiki.eveonline.com/en/wiki/Arek%27Jaalan>Arek\'Jaalan Project.</a></i>\r\r\n\r\r\n<i>Authorized for capsuleer dissemination under the CONCORD Freedom of Distribution Act (Alpha-One-Five), YC 113.11.4</i>\r\r\n\r\r\n<i>Further copies of this document can be obtained through the Arek\'Jaalan administrative site, located in the <a href=showinfo:5//30003413>Eram</a> system.<i>',1,0.1,0,1,4,0.0000,1,NULL,0),(4338,1141,'Arek\'Jaalan: Mission Statement','The Arek\'Jaalan Project was founded to act as a cross-organizational research body and common ground for capsuleers to share information about the Sleeper civilization and related matters. The goals of the project are, relative to similar bodies, both simple to understand and quite humble. Put simply, our aim is to research, document and educate.\r\r\n\r\r\n<b>Research:</b> We aim to posit and debate theories, study known facts and uncover new ones, and use every other method available to deepen our understanding of the Sleepers and related subjects.\r\r\n\r\r\n<b>Document:</b> Through extensive use of open networks, and with the help of key staff, we aim to document all of the information shared between project members, from everyday communication to large-scale research projects.\r\r\n\r\r\n<b>Educate:</b> Using our body of contributors and their documented research as a foundation, we aim to educate other capsuleers about our work, and to encourage wider capsuleer interest in scientific matters by presenting information openly and accessibly.\r\r\n\r\r\nIn its initial phase, the project aims to build a  foundational  body of documented research, at which point a larger focus will begin to be placed on the goal of education.\r\r\n\r\r\nIt should be emphasized that Arek\'Jaalan does not aim to produce new technologies, and in particular that we take an active stance against any further weaponization of Sleeper or other technologies. We aim for something more benign and progressive.\r\r\n\r\r\nIt should be similarly noted that much of our work lies in centralizing and documenting scattered, yet publicly available, information. In the absence of these hard facts, we turn to educated theory. Although there is always the risk of information being used for immoral ends, it should be remembered what the majority of our work at the Arek\'Jaalan project actually amounts to, and that our own stance is to be firmly against such actions.\r\r\n\r\r\nOverwhelmingly, the current focus of interest in capsuleer research is applied science, particularly weaponization. The work we do is intended to help humanity, and science as a whole, not just the capsuleer military-industrial cycle. Arek\'Jaalan stands apart from the destructive mainstream; as an alternative way for capsuleers to use their unique capabilities. ',1,0.1,0,1,4,0.0000,1,NULL,0),(4345,77,'Gistum B-Type Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(4346,77,'Gistum A-Type Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(4347,77,'Pithum A-Type Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(4348,77,'Pithum B-Type Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(4349,77,'Pithum C-Type Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(4354,819,'Sansha Tenebrus','<font color=yellow>Subject:</font> Sansha Tenebrus<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Veteran-level crew. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> The Tenebrus is a specialized defensive vessel intended for swift and vicious first response action. Employing only those True Slaves most receptive to the hive-mind and therefore best able to coordinate amongst themselves, these ships are considered among the most valuable members of the Nation\'s military force.<br>\r\r\n<i>Analyst Kamal Shan, <a href=showinfo:2//1000081>Ministry of Assessment</a>.</i><br><i>Authorized for capsuleer dissemination.</i>  ',2112000,21120,235,1,4,0.0000,0,NULL,0),(4355,819,'Dark Blood Keeper','<font color=yellow>Subject:</font> Dark Blood Keeper<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Veteran-level crew. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> The Dark Blood Keeper is a defensive vessel designed to protect the human farm\'s living produce. Crewed by a hand-picked selection of expert technicians who are also zealous believers in the Blood Raider cause, this ship is without a doubt the most dangerous opponent in the vicinity. <br>\r\r\n<i>Analyst Kepur, <a href=showinfo:2//1000081>Ministry of Assessment</a>.</i><br><i>Authorized for capsuleer dissemination.</i>  \r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(4356,819,'Shadow Serpentis Warden','<font color=yellow>Subject:</font> Dark Blood Alpha<br>\r\r\n<font color=yellow>Military Specifications:</font> Frigate-class vessel. Veteran-level crew. <br>\r\r\n<font color=yellow>Additional Intelligence:</font> The Shadow Serpentis Warden is one of the most versatile frigate designs ever to be iterated on by any independent organization. Triple-reinforced armor, an augmented plasma ventilation system and extremely strict crew specifications have been identified as three primary reasons for why no Serpentis live cargo facility can ever be found without one.<br>\r\r\n<i>Analyst Batuan, <a href=showinfo:2//1000137>DED</a>.</i><br><i>Authorized for capsuleer dissemination.</i>  ',2650000,26500,235,1,8,0.0000,0,NULL,0),(4357,319,'Amarr Drone Mine','This is an Amarr drone mine.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(4358,283,'Exotic Dancers, Male','Exotic dancing is considered an art form, even though not everyone might agree. Exposing the flesh in public places may be perfectly acceptable within the Federation, but in the Amarr Empire it\'s considered a grave sin and a sign of serious deviancy.',50,1,0,1,NULL,0.0000,1,23,0),(4359,707,'QA Jump Bridge','This structure does not exist.',250000,1,30000,1,NULL,100000000.0000,1,NULL,0),(4360,353,'QA ECCM','This module does not exist.',0,1,0,1,NULL,127920.0000,1,NULL,0),(4361,365,'QA Fuel Control Tower','This structure does not exist.',200000000,1,1000000,1,1,400000000.0000,1,NULL,0),(4363,28,'Miasmos Quafe Ultra Edition','The Miasmos Quafe Ultra Edition was commissioned by the Quafe Corporation as a specialized vessel for the distribution of Quafe throughout the New Eden cluster.\r\r\n\r\r\nTo this end, the ship has been made more agile, given a faster warp engine and fitted with an upgraded cargohold that can carry vast amounts of sweet, sweet Quafe. Additionally, the controls have been simplified so that new pilots can be trained quickly and efficiently, allowing for optimal transport labor wages.\r\r\n\r\r\nA later addition under the new \"Miasmos\" moniker included a small number of sealed vats, but Quafe has demanded that those be accessed solely by corporate representatives, and not by crew nor capsuleer.',11250000,265000,5250,1,8,789952.0000,1,1614,0),(4364,108,'Miasmos Quafe Ultra Edition Blueprint',' ',0,0.01,0,1,NULL,4287500.0000,1,NULL,0),(4365,1089,'Men\'s \'Quafe\' T-shirt YC 114','Stand out in a crowd with your comfortable new Quafe Commemorative Casual Wear, designed exclusively for attendees of the YC 114 Impetus Annual Holoreel Convention.\r\r\n\r\r\nNote: While occasionally worn by holoreel stars, Quafe Commemorative Casual Wear is not guaranteed to net you a role in any kind of visual production, at least not one that involves any dialogue.\r\r\n\r\r\n',0.5,0.1,0,1,4,0.0000,1,1398,0),(4366,1089,'Women\'s \'Quafe\' T-shirt YC 114','Stand out in a crowd with your comfortable new Quafe Commemorative Casual Wear, designed exclusively for attendees of the YC 114 Impetus Annual Holoreel Convention.\r\r\n\r\r\nNote: While occasionally worn by holoreel stars, Quafe Commemorative Casual Wear is not guaranteed to net you a role in any kind of visual production, at least not one that involves any dialogue.\r\r\n\r\r\n',0.5,0.1,0,1,4,0.0000,1,1406,0),(4367,1089,'Men\'s \'Sterling\' Dress Shirt (white)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military clothing found in several modern navies, this sharply contrasted bone white and dusty gray \"Sterling\" dress shirt is a perfect way to begin your travels in New Eden. \r\r\n\r\r\nIt is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our material blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. \r\r\n\r\r\nDark thread highlights combine with a magnificent chevron design, unique to this particular item, to finish the high-contrast look.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(4368,1089,'Women\'s \'Sterling\' Dress Blouse (white)','Designer: Sennda of Emrayur\r\r\n\r\r\nModeled after the Class B military clothing found in several modern navies, this sharply contrasted bone white and dusty gray \"Sterling\" dress blouse is a perfect way to begin your travels in New Eden. \r\r\n\r\r\nIt is designed to cope with the realities of daily service while maintaining the image of an orderly fighting force. Our material blends are specially treated to resist staining, even tough grease and oil stains common on modern starships. \r\r\n\r\r\nDark thread highlights combine with a magnificent chevron design, unique to this particular item, to finish the high-contrast look.\r\r\n\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(4369,786,'Small Targeting Amplifier I','This ship modification is designed to increase the max targeting range, at the expense of agility and max velocity.',200,5,0,1,NULL,0.0000,0,NULL,0),(4370,787,'Small Targeting Amplifier I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(4371,353,'QA Remote Armor Repair System - 5 Players','This module does not exist.',20,1,0,1,NULL,257464.0000,1,NULL,0),(4372,353,'QA Shield Transporter - 5 Players','This module does not exist.',0,1,0,1,NULL,139968.0000,1,NULL,0),(4373,353,'QA Damage Module','This module does not exist.',0,1,0,1,NULL,0.0000,1,NULL,0),(4374,353,'QA Multiship Module - 10 Players','This module does not exist.',0,1,0,1,NULL,0.0000,1,NULL,0),(4375,353,'QA Multiship Module - 20 Players','This module does not exist.',0,1,0,1,NULL,0.0000,1,NULL,0),(4376,353,'QA Multiship Module - 40 Players','This module does not exist.',0,1,0,1,NULL,0.0000,1,NULL,0),(4377,353,'QA Multiship Module - 5 Players','This module does not exist.',0,1,0,1,NULL,0.0000,1,NULL,0),(4380,353,'QA Immunity Module','This type does not exist.',10000,1,0,1,NULL,362408.0000,1,NULL,0),(4383,1189,'Large Micro Jump Drive','The Micro Jump Drive is a module that spools up, then jumps the ship forward 100km in the direction it is facing. Upon arrival, the ship maintains its direction and velocity. Warp scramblers can be used to disrupt the module. Spool up time is reduced by the skill <a href=showinfo:4385>Micro Jump Drive Operation</a>.\r\r\n\r\r\nThe Micro Jump Drive was developed by Duvolle Laboratories Advanced Manifold Theory Unit. The drive was conceived by the late Avagher Xarasier, the genius behind several ground-breaking innovations of that era.\r\r\n',0,10,0,1,NULL,1340852.0000,1,1650,0),(4384,1191,'Large Micro Jump Drive Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,1697,0),(4385,275,'Micro Jump Drive Operation','Skill at using Micro Jump Drives. 5% reduction in activation time per skill level.',0,0.01,0,1,NULL,4500000.0000,1,374,0),(4386,1149,'Mobile Large Jump Disruptor I','A Large deployable self powered unit that prevents micro jumping into its area of effect.',0,585,0,1,NULL,12563756.0000,0,405,0),(4387,371,'Mobile Large Jump Disruptor I Blueprint',' ',0,0.01,0,1,NULL,119764480.0000,1,NULL,0),(4388,28,'Miasmos Quafe Ultramarine Edition','The Miasmos (originally Iteron Mark IV) Quafe Ultramarine Edition was commissioned by the Quafe Corporation as a vessel for highly focused distribution of Quafe to a demanding clientele in the New Eden cluster.\r\r\n\r\r\nTo this end, the ship has been made more agile, given a faster warp engine and fitted with an upgraded cargohold that can carry vast amounts of Quafe. In addition, its controls have been simplified so that new pilots can more easily meet the strict delivery conditions of prospective buyers.  A number of sealed vats were added after the ship was rebranded as the Miasmos, but Quafe has demanded that those be accessed solely by corporate representatives, and not by crew nor capsuleer.\r\r\n\r\r\nWhile the Quafe Corporation has firmly denied making any alterations to its lucrative formula, and insists that the Miasmos Quafe Ultramarine Edition does not have special dispensation to carry a supercaffeinated version of the famous drink, it is notable that this model has been fitted with extra security mechanisms to prevent any and all crew from sampling its cargo. \r\r\n\r\r\nWhile there are persistent rumors of storage crew personnel tasting the cargo and subsequently staying awake for days on end, grinding their teeth and yelling at each other, these have never been conclusively proven, although the Quafe Corporation does reportedly undertake all medical costs for any crewmember serving more than 72 consecutive hours onboard the Miasmos Quafe Ultramarine Edition. ',11250000,265000,5250,1,8,789952.0000,1,1614,0),(4389,108,'Miasmos Quafe Ultramarine Edition Blueprint',' ',0,0.01,0,1,NULL,4287500.0000,1,NULL,0),(4390,314,'Pax Ammaria','This book has a <a href=\"http://wiki.eveonline.com/en/wiki/Pax_Ammaria_(Chronicle)\">history</a>.',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(4391,1156,'Large Ancillary Shield Booster','Provides a quick boost in shield strength. The module takes Cap Booster charges and will start consuming the ship\'s capacitor upon the charges running out. Deactivating the module while it has no cap boosters loaded starts reloading, if there are cap boosters available in cargo hold.\r\r\n\r\r\nNote: Can use Cap Booster 150 and 200 as fuel. Reloading time is 60 seconds. Prototype Inferno Module.\r\r\n',0,25,42,1,NULL,161888.0000,1,611,0),(4392,1157,'Large Ancillary Shield Booster Blueprint',' ',0,0.01,0,1,NULL,1458560.0000,1,1552,0),(4393,645,'Drone Damage Amplifier I','The Drone Damage Amplifier projects a multi-node quantum entanglement onto the ship\'s drone communications net, creating a bridged processor between ship and drones that allows for better real-time trajectory projections.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',1,5,0,1,NULL,74348.0000,1,938,0),(4394,1152,'Drone Damage Amplifier I Blueprint',' ',0,0.01,0,1,NULL,499200.0000,1,939,0),(4395,781,'Medium Processor Overclocking Unit I','This ship modification is designed to increase a ship\'s CPU.\r\r\n\r\r\nPenalty: - 5% Shield Recharge Rate Bonus.\r\r\n',200,5,0,1,NULL,0.0000,1,1223,0),(4396,787,'Medium Processor Overclocking Unit I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1253,0),(4397,781,'Large Processor Overclocking Unit I','This ship modification is designed to increase a ship\'s CPU.\r\r\n\r\r\nPenalty: - 5% Shield Recharge Rate Bonus.\r\r\n',200,5,0,1,NULL,0.0000,1,1224,0),(4398,787,'Large Processor Overclocking Unit I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1254,0),(4399,781,'Medium Processor Overclocking Unit II','This ship modification is designed to increase a ship\'s CPU.\r\r\n\r\r\nPenalty: - 10% Shield Recharge Rate Bonus.',200,5,0,1,NULL,0.0000,1,1223,0),(4400,787,'Medium Processor Overclocking Unit II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(4401,781,'Large Processor Overclocking Unit II','This ship modification is designed to increase a ship\'s CPU.\r\r\n\r\r\nPenalty: - 10% Shield Recharge Rate Bonus.',200,5,0,1,NULL,0.0000,1,1224,0),(4402,787,'Large Processor Overclocking Unit II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(4403,1150,'Reactive Armor Hardener','The Reactive Armor Hardener possesses an advanced nano membrane that reacts to armor layer damage by shifting between resistances over time. This makes it able to align its defenses against whichever incoming damage types are prevalent.\r\r\n\r\r\nThe module spreads 60% resistance over the four damage types, starting at 15% in each.\r\r\n\r\r\nOnly one of this module type can be fitted at a time. Prototype Inferno Module.\r\r\n',1,25,0,1,NULL,225690.0000,1,1416,0),(4404,1151,'Reactive Armor Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(4405,645,'Drone Damage Amplifier II','The Drone Damage Amplifier projects a multi-node quantum entanglement onto the ship\'s drone communications net, creating a bridged processor between ship and drones that allows for better real-time trajectory projections.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,449587.0000,1,938,0),(4406,1152,'Drone Damage Amplifier II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(4407,1153,'Shield Booster Fuel Allocation Script','This script can be loaded into a specialized shield booster module to exchange capacitor use on activation with a charge from the cargo hold.\r\r\n',1,1,0,1,NULL,22432.0000,0,NULL,0),(4408,912,'Shield Booster Fuel Allocation Script Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,NULL,0),(4409,1154,'Target Spectrum Breaker','Copies the active sweeps of all targeting sensors and reflects them onto other targeters, giving their computers the impression that the ship being locked is in two places at once. The more target locks active or being attempted against the ship, the more conflicting input can be sent to each computer, thus increasing the chances that the locks will fail.\r\r\n\r\r\nNote: Will affect all targeting computers, including those of friendly vessels, of vessels immune to electronic warfare, and of the host ship itself. Can be fitted to Battleship, Black Ops and Marauder class ships.\r\r\n',0,5,0,1,NULL,95528.0000,1,1426,0),(4410,1155,'Target Spectrum Breaker Blueprint',' ',0,0.01,0,1,NULL,296960.0000,1,NULL,0),(4411,272,'Target Breaker Amplification','Improves the continuous reflection of active target spectrum breakers, resulting in much improved defenses against all those who wish to target any vessel in the vicinity.\r\n\r\nReduces duration time and capacitor need of Target Spectrum Breakers by 5% per level.',0,0.01,0,1,NULL,600000.0000,1,367,0),(4421,43,'F-a10 Buffer Capacitor Regenerator','Increases the capacitor recharge rate.',1,5,0,1,1,828.0000,0,NULL,0),(4423,43,'Industrial Capacitor Recharger','Increases the capacitor recharge rate.',1,5,0,1,2,828.0000,0,NULL,0),(4425,43,'AGM Capacitor Charge Array','Increases the capacitor recharge rate.',1,5,0,1,4,828.0000,0,NULL,0),(4427,43,'Secondary Parallel Link-Capacitor','Increases the capacitor recharge rate.',1,5,0,1,8,828.0000,0,NULL,0),(4431,43,'F-b10 Nominal Capacitor Regenerator','Increases the capacitor recharge rate.',1,5,0,1,1,1040.0000,0,NULL,0),(4433,43,'Barton Reactor Capacitor Recharger I','Increases the capacitor recharge rate.',1,5,0,1,2,1040.0000,0,NULL,0),(4435,43,'Eutectic Compact Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,4,1040.0000,1,665,0),(4437,43,'Fixed Parallel Link-Capacitor I','Increases the capacitor recharge rate.',1,5,0,1,8,1040.0000,0,NULL,0),(4471,71,'5W Infectious Power System Malfunction','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,1,8956.0000,1,689,0),(4473,71,'Small Rudimentary Energy Destabilizer I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,2,8956.0000,1,689,0),(4475,71,'Small Unstable Power Fluctuator I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,4,8956.0000,1,689,0),(4477,71,'Small \'Gremlin\' Power Core Disruptor I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,8,8956.0000,1,689,0),(4529,62,'Small I-a Polarized Armor Regenerator','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,1,9996.0000,1,1049,0),(4531,62,'Small Inefficient Armor Repair Unit','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,2,9996.0000,1,1049,0),(4533,62,'Small \'Accommodation\' Vestment Reconstructer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,4,9996.0000,1,1049,0),(4535,62,'Small Automated Carapace Restoration','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,8,9996.0000,1,1049,0),(4569,62,'Medium I-a Polarized Armor Regenerator','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,1,19916.0000,1,1050,0),(4571,62,'Medium Inefficient Armor Repair Unit','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,2,19916.0000,1,1050,0),(4573,62,'Medium \'Accommodation\' Vestment Reconstructer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,4,19916.0000,1,1050,0),(4575,62,'Medium Automated Carapace Restoration','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,8,19916.0000,1,1050,0),(4579,62,'Medium Nano Armor Repair Unit I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,2,49728.0000,1,NULL,0),(4609,62,'Large I-a Polarized Armor Regenerator','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,1,39996.0000,1,1051,0),(4611,62,'Large Inefficient Armor Repair Unit','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,2,39996.0000,1,1051,0),(4613,62,'Large \'Accommodation\' Vestment Reconstructer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(4615,62,'Large Automated Carapace Restoration','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,8,39996.0000,1,1051,0),(4621,62,'Large \'Reprieve\' Vestment Reconstructer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,94620.0000,1,NULL,0),(4745,61,'Micro F-4a Ld-Sulfate Capacitor Charge Unit','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,2.5,0,1,1,1936.0000,1,702,0),(4747,61,'Micro Ld-Acid Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,2.5,0,1,2,1936.0000,1,702,0),(4749,61,'Micro Peroxide Capacitor Power Cell','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,2.5,0,1,4,1936.0000,1,702,0),(4751,61,'Micro Ohm Capacitor Reserve I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,2.5,0,1,8,1936.0000,1,702,0),(4785,61,'Small F-4a Ld-Sulfate Capacitor Charge Unit','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,5,0,1,1,5000.0000,1,703,0),(4787,61,'Small Ld-Acid Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,5,0,1,2,5000.0000,1,703,0),(4789,61,'Small Peroxide Capacitor Power Cell','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,5,0,1,4,5000.0000,1,703,0),(4791,61,'Small Ohm Capacitor Reserve I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,5,0,1,8,5000.0000,1,703,0),(4829,76,'Medium F-RX Prototype Capacitor Boost','Provides a quick injection of power into the capacitor.',0,10,32,1,1,4920.0000,1,700,0),(4831,76,'Medium Brief Capacitor Overcharge I','Provides a quick injection of power into the capacitor.',0,10,32,1,2,4920.0000,1,700,0),(4833,76,'Medium Electrochemical Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,10,32,1,4,4920.0000,1,700,0),(4835,76,'Medium Tapered Capacitor Infusion I','Provides a quick injection of power into the capacitor.',0,10,32,1,8,4920.0000,1,700,0),(4869,61,'Large F-4a Ld-Sulfate Capacitor Charge Unit','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,15,0,1,1,31220.0000,1,705,0),(4871,61,'Large Ld-Acid Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,15,0,1,2,31220.0000,1,705,0),(4873,61,'Large Peroxide Capacitor Power Cell','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,15,0,1,4,31220.0000,1,705,0),(4875,61,'Large Ohm Capacitor Reserve I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,15,0,1,8,31220.0000,1,705,0),(4909,61,'X-Large F-4a Ld-Sulfate Capacitor Charge Unit','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,20,0,1,1,78120.0000,0,NULL,0),(4911,61,'X-Large Ld-Acid Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,20,0,1,2,78120.0000,0,NULL,0),(4913,61,'X-Large Peroxide Capacitor Power Cell','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,20,0,1,4,78120.0000,0,NULL,0),(4915,61,'X-Large Ohm Capacitor Reserve I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,20,0,1,8,78120.0000,0,NULL,0),(4955,76,'Micro F-RX Prototype Capacitor Boost','Provides a quick injection of power into the capacitor.',0,2.5,8,1,1,2234.0000,1,698,0),(4957,76,'Micro Brief Capacitor Overcharge I','Provides a quick injection of power into the capacitor.',0,2.5,8,1,2,2234.0000,1,698,0),(4959,76,'Micro Electrochemical Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,2.5,8,1,4,2234.0000,1,698,0),(4961,76,'Micro Tapered Capacitor Infusion I','Provides a quick injection of power into the capacitor.',0,2.5,8,1,8,2234.0000,1,698,0),(5007,76,'Small F-RX Prototype Capacitor Boost','Provides a quick injection of power into the capacitor.',0,5,12,1,1,3472.0000,1,699,0),(5009,76,'Small Brief Capacitor Overcharge I','Provides a quick injection of power into the capacitor.',0,5,12,1,2,3472.0000,1,699,0),(5011,76,'Small Electrochemical Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,5,12,1,4,3472.0000,1,699,0),(5013,76,'Small Tapered Capacitor Infusion I','Provides a quick injection of power into the capacitor.',0,5,12,1,8,3472.0000,1,699,0),(5017,76,'Small Perishable Capacitor Overcharge II','Provides a quick injection of power into the capacitor.',0,5,8,1,2,195308.0000,0,NULL,0),(5047,76,'Heavy F-RX Prototype Capacitor Boost','Provides a quick injection of power into the capacitor.',0,20,128,1,1,195308.0000,1,701,0),(5049,76,'Heavy Brief Capacitor Overcharge I','Provides a quick injection of power into the capacitor.',0,20,128,1,2,195308.0000,1,701,0),(5051,76,'Heavy Electrochemical Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,20,128,1,4,195308.0000,1,701,0),(5053,76,'Heavy Tapered Capacitor Infusion I','Provides a quick injection of power into the capacitor.',0,20,128,1,8,195308.0000,1,701,0),(5087,67,'Small Partial E95a Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,1,9840.0000,1,695,0),(5089,67,'Small Murky Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,2,9840.0000,1,695,0),(5091,67,'Small \'Regard\' Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,4,9840.0000,1,695,0),(5093,67,'Small Asymmetric Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,8,9840.0000,1,695,0),(5135,68,'E5 Prototype Energy Vampire','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,1,10816.0000,1,692,0),(5137,68,'Small \'Knave\' Energy Drain','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,2,10816.0000,1,692,0),(5139,68,'Small Diminishing Power System Drain I','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,4,10816.0000,1,692,0),(5141,68,'Small \'Ghoul\' Energy Siphon I','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,8,10816.0000,1,692,0),(5175,53,'Gatling Modal Laser I','Rapid fire multi-barreled energy weapon that delivers a steady stream of damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,1,1000.0000,1,570,0),(5177,53,'Gatling Afocal Maser I','Rapid fire multi-barreled energy weapon that delivers a steady stream of damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,2,1000.0000,1,570,0),(5179,53,'Gatling Modulated Energy Beam I','Rapid fire multi-barreled energy weapon that delivers a steady stream of damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,1000.0000,1,570,0),(5181,53,'Gatling Anode Particle Stream I','Rapid fire multi-barreled energy weapon that delivers a steady stream of damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,8,1000.0000,1,570,0),(5215,53,'Dual Modal Pulse Laser I','This light pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. Good skirmish weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,1,1976.0000,1,570,0),(5217,53,'Dual Afocal Pulse Maser I','This light pulse energy weapon uses two separate maser focusing systems to reduce the cool down period between shots. Good skirmish weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,2,1976.0000,1,570,0),(5219,53,'Dual Modulated Pulse Energy Beam I','This light pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. Good skirmish weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,1976.0000,1,570,0),(5221,53,'Dual Anode Pulse Particle Stream I','This light pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. Good skirmish weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,8,1976.0000,1,570,0),(5231,54,'EP-R Argon Ion Basic Excavation Pulse','Common, low technology mining laser. Works well for extracting common ore, but not useful for much else.',0,5,0,1,1,0.0000,0,NULL,0),(5233,54,'Single Diode Basic Mining Laser','Common, low technology mining laser. Works well for extracting common ore, but not useful for much else.',0,5,0,1,2,0.0000,1,1039,0),(5235,54,'Xenon Basic Drilling Beam','Common, low technology mining laser. Works well for extracting common ore, but not useful for much else.',0,5,0,1,4,0.0000,0,NULL,0),(5237,54,'Rubin Basic Particle Bore Stream','Common, low technology mining laser. Works well for extracting common ore, but not useful for much else.',0,5,0,1,8,0.0000,0,NULL,0),(5239,54,'EP-S Gaussian Scoped Mining Laser','Basic mining laser. Extracts common ore quickly, but has difficulty with the more rare types.',0,5,0,1,1,1580.0000,1,1039,0),(5241,54,'Dual Diode Mining Laser I','Basic mining laser. Extracts common ore quickly, but has difficulty with the more rare types.',0,5,0,1,2,1580.0000,0,NULL,0),(5243,54,'XeCl Drilling Beam I','Basic mining laser. Extracts common ore quickly, but has difficulty with the more rare types.',0,5,0,1,4,1580.0000,0,NULL,0),(5245,54,'Particle Bore Compact Mining Laser','Basic mining laser. Extracts common ore quickly, but has difficulty with the more rare types.',0,5,0,1,8,1580.0000,1,1039,0),(5279,290,'F-23 Reciprocal Remote Sensor Booster','Can only be activated on targets to increase their scan resolutions and boost their targeting range.  This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,1,9664.0000,1,673,0),(5280,290,'Connected Remote Sensor Booster','Can only be activated on targets to increase their scan resolutions and boost their targeting range.  This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,2,9664.0000,1,673,0),(5281,290,'Coadjunct Linked Remote Sensor Booster','Can only be activated on targets to increase their scan resolutions and boost their targeting range.  This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,4,9664.0000,1,673,0),(5282,290,'Linked Remote Sensor Booster','Can only be activated on targets to increase their scan resolutions and boost their targeting range.  This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,8,9664.0000,1,673,0),(5299,208,'Low Frequency Sensor Suppressor I','Reduces the range and speed of a targeted ship\'s sensors. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,1,13948.0000,1,679,0),(5300,208,'Indirect Scanning Dampening Unit I','Reduces the range and speed of a targeted ship\'s sensors. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,2,13948.0000,1,679,0),(5301,208,'Kapteyn Sensor Array Inhibitor I','Reduces the range and speed of a targeted ship\'s sensors. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,4,13948.0000,1,679,0),(5302,208,'Phased Muon Sensor Disruptor I','Reduces the range and speed of a targeted ship\'s sensors. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,8,13948.0000,1,679,0),(5319,291,'F-392 Baker Nunn Tracking Disruptor I','Disrupts the turret range and tracking speed of the target ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,1,14828.0000,1,680,0),(5320,291,'Balmer Series Tracking Disruptor I','Disrupts the turret range and tracking speed of the target ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,2,14828.0000,1,680,0),(5321,291,'\'Abandon\' Tracking Disruptor I','Disrupts the turret range and tracking speed of the target ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,4,14828.0000,1,680,0),(5322,291,'DDO Photometry Tracking Disruptor I','Disrupts the turret range and tracking speed of the target ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,8,14828.0000,1,680,0),(5339,209,'F-293 Nutation Remote Tracking Computer','Establishes a fire control link with another ship, thereby boosting the turret range and tracking speed of that ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,1,9964.0000,1,708,0),(5340,209,'Phase Switching Remote Tracking Computer','Establishes a fire control link with another ship, thereby boosting the turret range and tracking speed of that ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,2,9964.0000,1,708,0),(5341,209,'\'Prayer\' Remote Tracking Computer','Establishes a fire control link with another ship, thereby boosting the turret range and tracking speed of that ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,4,9964.0000,1,708,0),(5342,209,'Alfven Surface Remote Tracking Computer','Establishes a fire control link with another ship, thereby boosting the turret range and tracking speed of that ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,8,9964.0000,1,708,0),(5359,80,'1Z-3 Subversive ECM Eruption','Emits random electronic bursts intended to disrupt target locks on any ship with lower sensor strengths than the ECM burst jamming strength. Given the unstable nature of the bursts and the amount of internal shielding needed to ensure they do not affect their own point of origin, only battleship-class vessels can use this module to its fullest extent. \r\r\n\r\r\n\r\r\nNote: Only one module of this type can be activated at the same time.',5000,5,0,1,1,16732.0000,1,678,0),(5361,80,'\'Deluge\' ECM Burst I','Emits random electronic bursts which have a chance of momentarily disrupting target locks on ships within range.\r\r\n\r\r\nGiven the unstable nature of the bursts and the amount of internal shielding needed to ensure they do not affect their own point of origin, only battleship-class vessels can use this module to its fullest extent. \r\r\n\r\r\nNote: Only one module of this type can be activated at the same time.',5000,5,0,1,2,16732.0000,1,678,0),(5363,80,'\'Rash\' ECM Emission I','Emits random electronic bursts intended to disrupt target locks on any ship with lower sensor strengths than the ECM burst jamming strength. Given the unstable nature of the bursts and the amount of internal shielding needed to ensure they do not affect their own point of origin, only battleship-class vessels can use this module to its fullest extent. \r\r\n\r\r\nNote: Only one module of this type can be activated at the same time.',5000,5,0,1,4,16732.0000,1,678,0),(5365,80,'\'Cetus\' ECM Shockwave I','Emits random electronic bursts intended to disrupt target locks on any ship with lower sensor strengths than the ECM burst jamming strength. Given the unstable nature of the bursts and the amount of internal shielding needed to ensure they do not affect their own point of origin, only battleship-class vessels can use this module to its fullest extent. \r\r\n\r\r\nNote: Only one module of this type can be activated at the same time.',5000,5,0,1,8,16732.0000,1,678,0),(5399,52,'J5 Prototype Warp Disruptor I','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,1,19628.0000,1,1935,0),(5401,52,'Fleeting Warp Disruptor I','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,2,19628.0000,1,1935,0),(5403,52,'Faint Warp Disruptor I','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,4,19628.0000,1,1935,0),(5405,52,'Initiated Warp Disruptor I','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,8,19628.0000,1,1935,0),(5439,52,'J5b Phased Prototype Warp Scrambler I','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,1,19628.0000,1,1936,0),(5441,52,'Fleeting Progressive Warp Scrambler I','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,2,19628.0000,1,1936,0),(5443,52,'Faint Epsilon Warp Scrambler I','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,4,19628.0000,1,1936,0),(5445,52,'Initiated Harmonic Warp Scrambler I','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,8,19628.0000,1,1936,0),(5479,765,'Marked Modified SS Expanded Cargo','Increases cargo hold capacity.',50,5,0,1,1,320.0000,0,NULL,0),(5481,765,'Partial Hull Conversion Expanded Cargo','Increases cargo hold capacity.',50,5,0,1,2,320.0000,0,NULL,0),(5483,765,'Alpha Hull Mod Expanded Cargo','Increases cargo hold capacity.',50,5,0,1,4,320.0000,0,NULL,0),(5485,765,'Type-E Altered SS Expanded Cargo','Increases cargo hold capacity.',50,5,0,1,8,320.0000,0,NULL,0),(5487,765,'Mark I Modified SS Expanded Cargo','Increases cargo hold capacity.',50,5,0,1,1,512.0000,0,NULL,0),(5489,765,'Local Hull Conversion Expanded Cargo I','Increases cargo hold capacity.',50,5,0,1,2,512.0000,0,NULL,0),(5491,765,'Beta Hull Mod Expanded Cargo','Increases cargo hold capacity.',50,5,0,1,4,512.0000,0,NULL,0),(5493,765,'Type-D Restrained Expanded Cargo','Increases cargo hold capacity.',50,5,0,1,8,512.0000,1,1197,0),(5519,762,'Marked Modified SS Inertial Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,1,1024.0000,0,NULL,0),(5521,762,'Partial Hull Conversion Inertial Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,2,1024.0000,0,NULL,0),(5523,762,'Alpha Hull Mod Inertial Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,4,1024.0000,0,NULL,0),(5525,762,'Type-E Altered SS Inertial Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,8,1024.0000,0,NULL,0),(5527,762,'Mark I Modified SS Inertial Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,1,40960.0000,0,NULL,0),(5529,762,'Local Hull Conversion Inertial Stabilizers I','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,2,40960.0000,0,NULL,0),(5531,762,'Beta Hull Mod Inertial Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,4,40960.0000,0,NULL,0),(5533,762,'Type-D Restrained Inertial Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,8,40960.0000,1,1086,0),(5559,763,'Partial Hull Conversion Nanofiber Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,2,512.0000,0,NULL,0),(5561,763,'Local Hull Conversion Nanofiber Structure I','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,2,512.0000,0,NULL,0),(5591,763,'Alpha Hull Mod Nanofiber Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,4,512.0000,0,NULL,0),(5593,763,'Type-E Altered SS Nanofiber Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,8,512.0000,0,NULL,0),(5595,763,'Marked Modified SS Nanofiber Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,1,512.0000,0,NULL,0),(5597,763,'Beta Hull Mod Nanofiber Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,4,512.0000,0,NULL,0),(5599,763,'Type-D Restrained Nanofiber Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,8,512.0000,1,1196,0),(5601,763,'Mark I Modified SS Nanofiber Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,1,512.0000,0,NULL,0),(5611,764,'Partial Hull Conversion Overdrive Injector','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,2,8192.0000,0,NULL,0),(5613,764,'Alpha Hull Mod Overdrive Injector','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,4,8192.0000,0,NULL,0),(5615,764,'Type-E Altered SS Overdrive Injector','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,8,8192.0000,0,NULL,0),(5617,764,'Marked Modified SS Overdrive Injector','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,1,8192.0000,0,NULL,0),(5627,764,'Local Hull Conversion Overdrive Injector I','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,2,512.0000,0,NULL,0),(5629,764,'Beta Hull Mod Overdrive Injector','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,4,512.0000,0,NULL,0),(5631,764,'Type-D Restrained Overdrive Injector','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,8,512.0000,1,1087,0),(5633,764,'Mark I Modified SS Overdrive Injector','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,1,512.0000,0,NULL,0),(5643,78,'Local Hull Conversion Reinforced Bulkheads I','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,2,512.0000,0,NULL,0),(5645,78,'Beta Hull Mod Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,4,512.0000,0,NULL,0),(5647,78,'Type-D Restrained Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,8,512.0000,1,1195,0),(5649,78,'Mark I Compact Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,1,512.0000,1,1195,0),(5675,78,'Partial Hull Conversion Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,2,22528.0000,0,NULL,0),(5677,78,'Alpha Hull Mod Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,4,22528.0000,0,NULL,0),(5679,78,'Type-E Altered SS Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,8,22528.0000,0,NULL,0),(5681,78,'Marked Modified SS Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,1,22528.0000,0,NULL,0),(5683,63,'Medium Inefficient Hull Repair Unit','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,10,0,1,2,389520.0000,1,1054,0),(5693,63,'Small Inefficient Hull Repair Unit','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,5,0,1,2,9680.0000,1,1053,0),(5697,63,'Large Inefficient Hull Repair Unit','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,50,0,1,2,389520.0000,1,1055,0),(5719,63,'Medium \'Hope\' Hull Reconstructor I','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,10,0,1,4,389520.0000,1,1054,0),(5721,63,'Medium Automated Structural Restoration','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,10,0,1,8,389520.0000,1,1054,0),(5723,63,'Medium I-b Polarized Structural Regenerator','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,10,0,1,1,389520.0000,1,1054,0),(5743,63,'Small \'Hope\' Hull Reconstructor I','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,5,0,1,4,9680.0000,1,1053,0),(5745,63,'Small Automated Structural Restoration','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,5,0,1,8,9680.0000,1,1053,0),(5747,63,'Small I-b Polarized Structural Regenerator','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,5,0,1,1,9680.0000,1,1053,0),(5755,63,'Large \'Hope\' Hull Reconstructor I','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,50,0,1,4,389520.0000,1,1055,0),(5757,63,'Large Automated Structural Restoration','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,50,0,1,8,389520.0000,1,1055,0),(5759,63,'Large I-b Polarized Structural Regenerator','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,50,0,1,1,389520.0000,1,1055,0),(5829,60,'GLFF Containment Field','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,2,740.0000,1,615,0),(5831,60,'Interior Force Field Array','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,4,740.0000,1,615,0),(5833,60,'Systematic Damage Control','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,8,740.0000,1,615,0),(5835,60,'F84 Local Damage System','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,1,740.0000,1,615,0),(5837,60,'Pseudoelectron Containment Field I','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,2,2244.0000,1,615,0),(5839,60,'Internal Force Field Array I','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,4,2244.0000,1,615,0),(5841,60,'Emergency Damage Control I','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,8,2244.0000,1,615,0),(5843,60,'F85 Peripheral Damage System I','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,1,2244.0000,1,615,0),(5845,205,'Heat Exhaust System','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,2,4672.0000,1,647,0),(5846,205,'Thermal Exhaust System I','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,2,7360.0000,1,647,0),(5849,205,'Extruded Heat Sink I','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,4,7360.0000,1,647,0),(5854,205,'Stamped Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,4,4672.0000,1,647,0),(5855,205,'\'Boreas\' Coolant System','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,8,4672.0000,1,647,0),(5856,205,'C3S Convection Thermal Radiator','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,1,4672.0000,1,647,0),(5857,205,'\'Skadi\' Coolant System I','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,8,7360.0000,1,647,0),(5858,205,'C4S Coiled Circuit Thermal Radiator','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,1,7360.0000,1,647,0),(5865,82,'Indirect Target Acquisition I','Uses advanced gravitational and visual targeting to identify threats. Allows target lock without alerting the ship to a possible threat.',2000,5,0,1,2,934.0000,1,672,0),(5867,82,'Passive Targeting Array I','Uses advanced gravitational and visual targeting to identify threats. Allows target lock without alerting the ship to a possible threat.',2000,5,0,1,4,934.0000,1,672,0),(5869,82,'Suppressed Targeting System I','Uses advanced gravitational and visual targeting to identify threats. Allows target lock without alerting the ship to a possible threat.',2000,5,0,1,8,934.0000,1,672,0),(5871,82,'41F Veiled Targeting Unit','Uses advanced gravitational and visual targeting to identify threats. Allows target lock without alerting the ship to a possible threat.',2000,5,0,1,1,934.0000,1,672,0),(5913,59,'Hydraulic Stabilization Actuator','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,4796.0000,1,646,0),(5915,59,'Lateral Gyrostabilizer','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,4796.0000,1,646,0),(5917,59,'Stabilized Weapon Mounts','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,4796.0000,1,646,0),(5919,59,'F-M2 Weapon Inertial Suspensor','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,4796.0000,1,646,0),(5929,59,'Pneumatic Stabilization Actuator I','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,12096.0000,1,646,0),(5931,59,'Cross-Lateral Gyrostabilizer I','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,12096.0000,1,646,0),(5933,59,'Counterbalanced Weapon Mounts I','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,12096.0000,1,646,0),(5935,59,'F-M3 Munition Inertial Suspensor','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,12096.0000,1,646,0),(5945,46,'500MN Cold-Gas Enduring Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,2,790940.0000,1,131,0),(5955,46,'100MN Monopropellant Enduring Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,2,161280.0000,1,542,0),(5971,46,'5MN Cold-Gas Enduring Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,37748.0000,1,131,0),(5973,46,'5MN Y-T8 Compact Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,8,37748.0000,1,131,0),(5975,46,'50MN Cold-Gas Enduring Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,1,37748.0000,1,131,0),(6001,46,'1MN Y-S8 Compact Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,3952.0000,1,542,0),(6003,46,'1MN Monopropellant Enduring Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,8,3952.0000,1,542,0),(6005,46,'10MN Monopropellant Enduring Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,1,3952.0000,1,542,0),(6041,96,'Hostile Target Acquisition I','Targets any hostile ship within range on activation. Grants a +2 bonus to max targets when online.',30,5,0,1,2,1392.0000,1,670,0),(6043,96,'\'Recusant\' Hostile Targeting Array I','Targets any hostile ship within range on activation. Grants a +2 bonus to max targets when online.',30,5,0,1,4,1392.0000,1,670,0),(6045,96,'Responsive Auto-Targeting System I','Targets any hostile ship within range on activation. Grants a +2 bonus to max targets when online.',30,5,0,1,8,1392.0000,1,670,0),(6047,96,'Automated Targeting Unit I','Targets any hostile ship within range on activation. Grants a +2 bonus to max targets when online.',30,5,0,1,1,1392.0000,1,670,0),(6073,61,'Medium Ld-Acid Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,10,0,1,2,12244.0000,1,704,0),(6083,61,'Medium Peroxide Capacitor Power Cell','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,10,0,1,4,12244.0000,1,704,0),(6097,61,'Medium Ohm Capacitor Reserve I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,10,0,1,8,12244.0000,1,704,0),(6111,61,'Medium F-4a Ld-Sulfate Capacitor Charge Unit','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,10,0,1,1,12244.0000,1,704,0),(6129,47,'Surface Cargo Scanner I','Scans the cargo hold of another ship.',0,5,0,1,2,730.0000,0,NULL,0),(6131,47,'Type-E Enduring Cargo Scanner','Scans the cargo hold of another ship.',0,5,0,1,4,730.0000,1,711,0),(6133,47,'Interior Type-E Cargo Identifier','Scans the cargo hold of another ship.',0,5,0,1,8,730.0000,0,NULL,0),(6135,47,'PL-0 Scoped Cargo Scanner','Scans the cargo hold of another ship.',0,5,0,1,1,730.0000,1,711,0),(6157,212,'Supplemental Scanning CPU I','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,2,2460.0000,1,671,0),(6158,212,'Prototype Sensor Booster','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,4,2460.0000,1,671,0),(6159,212,'Alumel-Wired Sensor Augmentation','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,8,2460.0000,1,671,0),(6160,212,'F-90 Positional Sensor Subroutines','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,1,2460.0000,1,671,0),(6173,213,'Optical Tracking Computer I','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,2,1420.0000,1,706,0),(6174,213,'Monopulse Tracking Mechanism I','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,4,1420.0000,1,706,0),(6175,213,'\'Orion\' Tracking CPU I','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,8,1420.0000,1,706,0),(6176,213,'F-12 Nonlinear Tracking Processor','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,1,1420.0000,1,706,0),(6193,203,'Emergency Magnetometric Scanners','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,2350.0000,1,723,0),(6194,203,'Emergency Multi-Frequency Scanners','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,14702.0000,1,724,0),(6195,203,'Reserve Gravimetric Scanners','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,4398.0000,1,720,0),(6199,203,'Reserve Ladar Scanners','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,2350.0000,1,721,0),(6202,203,'Emergency RADAR Scanners','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,2350.0000,1,722,0),(6203,203,'Reserve Magnetometric Scanners','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,2350.0000,1,723,0),(6207,203,'Reserve Multi-Frequency Scanners','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,20,0,1,2,14702.0000,1,724,0),(6212,203,'Reserve RADAR Scanners','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,2350.0000,1,722,0),(6216,203,'Emergency Ladar Scanners','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,2350.0000,1,721,0),(6217,203,'Emergency Gravimetric Scanners','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,4398.0000,1,720,0),(6218,203,'Protected Gravimetric Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,4398.0000,1,720,0),(6222,203,'Protected Ladar Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,2350.0000,1,721,0),(6225,203,'Sealed RADAR Backup Cluster','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,2350.0000,1,722,0),(6226,203,'Protected Magnetometric Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,2350.0000,1,723,0),(6230,203,'Protected Multi-Frequency Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,20,0,1,4,14702.0000,1,724,0),(6234,203,'Protected RADAR Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,2350.0000,1,722,0),(6238,203,'Sealed Magnetometric Backup Cluster','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,2350.0000,1,723,0),(6239,203,'Sealed Multi-Frequency Backup Cluster','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,14702.0000,1,724,0),(6241,203,'Sealed Ladar Backup Cluster','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,2350.0000,1,721,0),(6242,203,'Sealed Gravimetric Backup Cluster','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,4398.0000,1,720,0),(6243,203,'Surrogate Gravimetric Reserve Array I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,4398.0000,1,720,0),(6244,203,'F-43 Repetitive Gravimetric Backup Sensors','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,4398.0000,1,720,0),(6251,203,'Surrogate Ladar Reserve Array I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,2350.0000,1,721,0),(6252,203,'F-43 Repetitive Ladar Backup Sensors','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,2350.0000,1,721,0),(6257,203,'Surplus RADAR Reserve Array','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,2350.0000,1,722,0),(6258,203,'F-42 Reiterative RADAR Backup Sensors','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,2350.0000,1,722,0),(6259,203,'Surrogate Magnetometric Reserve Array I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,2350.0000,1,723,0),(6260,203,'F-43 Repetitive Magnetometric Backup Sensors','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,2350.0000,1,723,0),(6267,203,'Surrogate Multi-Frequency Reserve Array I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,20,0,1,8,14702.0000,1,724,0),(6268,203,'F-43 Repetitive Multi-Frequency Backup Sensors','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,20,0,1,1,14702.0000,1,724,0),(6275,203,'Surrogate RADAR Reserve Array I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,2350.0000,1,722,0),(6276,203,'F-43 Repetitive RADAR Backup Sensors','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,2350.0000,1,722,0),(6283,203,'Surplus Magnetometric Reserve Array','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,2350.0000,1,723,0),(6284,203,'F-42 Reiterative Magnetometric Backup Sensors','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,2350.0000,1,723,0),(6285,203,'Surplus Multi-Frequency Reserve Array','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,14702.0000,1,724,0),(6286,203,'F-42 Reiterative Multi-Frequency Backup Sensors','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,14702.0000,1,724,0),(6289,203,'Surplus Ladar Reserve Array','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,2350.0000,1,721,0),(6290,203,'F-42 Reiterative Ladar Backup Sensors','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,2350.0000,1,721,0),(6291,203,'Surplus Gravimetric Reserve Array','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,4398.0000,1,720,0),(6292,203,'F-42 Reiterative Gravimetric Backup Sensors','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,4398.0000,1,720,0),(6293,210,'Wavelength Signal Enhancer I','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,4812.0000,1,669,0),(6294,210,'\'Mendicant\' Signal Booster I','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,4812.0000,1,669,0),(6295,210,'Type-D Attenuation Signal Augmentation','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,4812.0000,1,669,0),(6296,210,'F-89 Synchronized Signal Amplifier','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,4812.0000,1,669,0),(6309,210,'Amplitude Signal Enhancer','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,1264.0000,1,669,0),(6310,210,'\'Acolyth\' Signal Booster','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,1264.0000,1,669,0),(6311,210,'Type-E Discriminative Signal Augmentation','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,1264.0000,1,669,0),(6312,210,'F-90 Positional Signal Amplifier','Augments the maximum target acquisition range. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,1264.0000,1,669,0),(6321,211,'Beam Parallax Tracking Program','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',10,5,0,1,2,2796.0000,1,707,0),(6322,211,'Beta-Nought Tracking Mode','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',10,5,0,1,4,2796.0000,1,707,0),(6323,211,'Azimuth Descalloping Tracking Enhancer','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',10,5,0,1,8,2796.0000,1,707,0),(6324,211,'F-AQ Delay-Line Scan Tracking Subroutines','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',10,5,0,1,1,2796.0000,1,707,0),(6325,211,'Fourier Transform Tracking Program','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,2,7132.0000,1,707,0),(6326,211,'Sigma-Nought Tracking Mode I','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,4,7132.0000,1,707,0),(6327,211,'Auto-Gain Control Tracking Enhancer I','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,8,7132.0000,1,707,0),(6328,211,'F-aQ Phase Code Tracking Subroutines','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,1,7132.0000,1,707,0),(6437,40,'Small C5-L Emergency Shield Overload I','Expends energy to provide a quick boost in shield strength.',0,5,0,1,1,4554.0000,1,609,0),(6439,40,'Small Neutron Saturation Injector I','Expends energy to provide a quick boost in shield strength.',0,5,0,1,2,4554.0000,1,609,0),(6441,40,'Small Clarity Ward Booster I','Expends energy to provide a quick boost in shield strength.',0,5,0,1,4,4554.0000,1,609,0),(6443,40,'Small Converse Deflection Catalyzer','Expends energy to provide a quick boost in shield strength.',0,5,0,1,8,4554.0000,1,609,0),(6485,39,'M51 Iterative Shield Regenerator','Improves the recharge rate of the shield.',0,5,1,1,1,4108.0000,1,126,0),(6487,39,'Supplemental Screen Generator I','Improves the recharge rate of the shield.',0,5,1,1,2,4108.0000,1,126,0),(6489,39,'\'Benefactor\' Ward Reconstructor','Improves the recharge rate of the shield.',0,5,1,1,4,4108.0000,1,126,0),(6491,39,'Passive Barrier Compensator I','Improves the recharge rate of the shield.',0,5,1,1,8,4108.0000,1,126,0),(6525,48,'Ta3 Perfunctory Vessel Probe','Scans the target ship and provides a tactical analysis of its capabilities. The further it goes beyond scan range, the more inaccurate its results will be.',0,5,0,1,1,976.0000,0,NULL,0),(6527,48,'Ta3 Compact Ship Scanner','Scans the target ship and provides a tactical analysis of its capabilities. The further it goes beyond scan range, the more inaccurate its results will be.',0,5,0,1,2,976.0000,1,713,0),(6529,48,'Speculative Ship Identifier I','Scans the target ship and provides a tactical analysis of its capabilities. The further it goes beyond scan range, the more inaccurate its results will be.',0,5,0,1,4,976.0000,0,NULL,0),(6531,48,'Practical Type-E Ship Probe','Scans the target ship and provides a tactical analysis of its capabilities. The further it goes beyond scan range, the more inaccurate its results will be.',0,5,0,1,8,976.0000,0,NULL,0),(6567,49,'ML-3 Amphilotite Mining Probe','Scans the composition of asteroids, ice and gas clouds.',0,5,0,1,1,1000.0000,0,NULL,0),(6569,49,'ML-3 Scoped Survey Scanner','Scans the composition of asteroids, ice and gas clouds.',0,5,0,1,2,1000.0000,1,714,0),(6571,49,'Rock-Scanning Sensor Array I','Scans the composition of asteroids, ice and gas clouds.',0,5,0,1,4,1000.0000,0,NULL,0),(6573,49,'\'Dactyl\' Type-E Asteroid Analyzer','Scans the composition of asteroids, ice and gas clouds.',0,5,0,1,8,1000.0000,0,NULL,0),(6631,53,'Dual Modal Light Laser I','This light beam laser uses two separate laser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,1,3472.0000,1,567,0),(6633,53,'Dual Afocal Light Maser I','This light beam energy weapon uses two separate maser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,2,3472.0000,1,567,0),(6635,53,'Dual Modulated Light Energy Beam I','This light beam laser uses two separate laser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,3472.0000,1,567,0),(6637,53,'Dual Anode Light Particle Stream I','This light beam laser uses two separate laser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,8,3472.0000,1,567,0),(6671,53,'Small Focused Modal Pulse Laser I','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,1,5984.0000,1,570,0),(6673,53,'Small Focused Afocal Pulse Maser I','A high-powered pulse energy weapon. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,2,5984.0000,1,570,0),(6675,53,'Small Focused Modulated Pulse Energy Beam I','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,5984.0000,1,570,0),(6677,53,'Small Focused Anode Pulse Particle Stream I','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,8,5984.0000,1,570,0),(6715,53,'Small Focused Modal Laser I','A high-powered beam laser. Good for medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,1,7484.0000,1,567,0),(6717,53,'Small Focused Afocal Maser I','A high-powered beam energy weapon. Good for medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,2,7484.0000,1,567,0),(6719,53,'Small Focused Modulated Energy Beam I','A high-powered beam laser. Good for medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,7484.0000,1,567,0),(6721,53,'Small Focused Anode Particle Stream I','A high-powered beam laser. Good for medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,8,7484.0000,1,567,0),(6757,53,'Quad Modal Light Laser I','Uses four light laser focusing systems. Low powered, but makes up for it with a fast firing rate. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,1,10000.0000,1,568,0),(6759,53,'Quad Afocal Light Maser I','Uses four light maser focusing systems. Low powered, but makes up for it with a fast firing rate. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,2,10000.0000,1,568,0),(6761,53,'Quad Modulated Light Energy Beam I','Uses four light laser focusing systems. Low powered, but makes up for it with a fast firing rate. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,10000.0000,1,568,0),(6763,53,'Quad Anode Light Particle Stream I','Uses four light laser focusing systems. Low powered, but makes up for it with a fast firing rate. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,8,10000.0000,1,568,0),(6805,53,'Focused Modal Pulse Laser I','A high-energy, concentrated laser designed for short to medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,1,25888.0000,1,572,0),(6807,53,'Focused Afocal Pulse Maser I','A high-powered, concentrated energy weapon designed for short to medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,2,25888.0000,1,572,0),(6809,53,'Focused Modulated Pulse Energy Beam I','A high-energy, concentrated laser designed for short to medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,25888.0000,1,572,0),(6811,53,'Focused Anode Pulse Particle Stream I','A high-energy, concentrated laser designed for short to medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,8,25888.0000,1,572,0),(6859,53,'Focused Modal Medium Laser I','A high-energy, concentrated laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,1,44740.0000,1,568,0),(6861,53,'Focused Afocal Medium Maser I','A high-powered, concentrated energy weapon designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,2,44740.0000,1,568,0),(6863,53,'Focused Modulated Medium Energy Beam I','A high-energy, concentrated laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,44740.0000,1,568,0),(6865,53,'Focused Anode Medium Particle Stream I','A high-energy, concentrated laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,8,44740.0000,1,568,0),(6919,53,'Heavy Modal Pulse Laser I','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,1,59676.0000,1,572,0),(6921,53,'Heavy Afocal Pulse Maser I','A heavy energy weapon designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,2,59676.0000,1,572,0),(6923,53,'Heavy Modulated Pulse Energy Beam I','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,59676.0000,1,572,0),(6925,53,'Heavy Anode Pulse Particle Stream I','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,8,59676.0000,1,572,0),(6959,53,'Heavy Modal Laser I','A high-energy heavy laser designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,1,74980.0000,1,568,0),(6961,53,'Heavy Afocal Maser I','A high-powered heavy energy weapon designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,2,74980.0000,1,568,0),(6963,53,'Heavy Modulated Energy Beam I','A high-energy heavy laser designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,74980.0000,1,568,0),(6965,53,'Heavy Anode Particle Stream I','A high-energy heavy laser designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,8,74980.0000,1,568,0),(6999,53,'Dual Heavy Modal Pulse Laser I','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,1,98972.0000,1,573,0),(7001,53,'Dual Heavy Afocal Pulse Maser I','This heavy pulse energy weapon uses two separate maser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,2,98972.0000,1,573,0),(7003,53,'Dual Heavy Modulated Pulse Energy Beam I','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,98972.0000,1,573,0),(7005,53,'Dual Heavy Anode Pulse Particle Stream I','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,8,98972.0000,1,573,0),(7043,53,'Dual Modal Heavy Laser I','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,1,298716.0000,1,569,0),(7045,53,'Dual Afocal Heavy Maser I','This heavy beam energy weapon uses two separate maser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,2,298716.0000,1,569,0),(7047,53,'Dual Modulated Heavy Energy Beam I','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,298716.0000,1,569,0),(7049,53,'Dual Anode Heavy Particle Stream I','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,8,298716.0000,1,569,0),(7083,53,'Mega Modal Pulse Laser I','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,1,448700.0000,1,573,0),(7085,53,'Mega Afocal Pulse Maser I','A super-heavy pulse energy weapon designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,2,448700.0000,1,573,0),(7087,53,'Mega Modulated Pulse Energy Beam I','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,448700.0000,1,573,0),(7089,53,'Mega Anode Pulse Particle Stream I','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,8,448700.0000,1,573,0),(7123,53,'Mega Modal Laser I','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,1,595840.0000,1,569,0),(7125,53,'Mega Afocal Maser I','A super-heavy beam energy weapon designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,2,595840.0000,1,569,0),(7127,53,'Mega Modulated Energy Beam I','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,595840.0000,1,569,0),(7131,53,'Mega Anode Particle Stream I','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,8,595840.0000,1,569,0),(7167,53,'Tachyon Modal Laser I','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,1,744812.0000,1,569,0),(7169,53,'Tachyon Afocal Maser I','An ultra-heavy beam energy weapon designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,2,744812.0000,1,569,0),(7171,53,'Tachyon Modulated Energy Beam I','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,744812.0000,1,569,0),(7173,53,'Tachyon Anode Particle Stream I','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,8,744812.0000,1,569,0),(7217,289,'Spot Pulsing ECCM I','ECCM Projectors utilize a sophisticated system of electronics to fortify the sensor strengths of an allied ship allowing it to overcome jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,7040.0000,1,686,0),(7218,289,'Piercing ECCM Emitter I','ECCM Projectors utilize a sophisticated system of electronics to fortify the sensor strengths of an allied ship allowing it to overcome jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,7040.0000,1,686,0),(7219,289,'Scattering ECCM Projector I','ECCM Projectors utilize a sophisticated system of electronics to fortify the sensor strengths of an allied ship allowing it to overcome jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,7040.0000,1,686,0),(7220,289,'Phased Muon ECCM Caster I','ECCM Projectors utilize a sophisticated system of electronics to fortify the sensor strengths of an allied ship allowing it to overcome jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,7040.0000,1,686,0),(7247,74,'75mm Prototype Gauss Gun','A small multi-barreled railgun for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,1,1000.0000,1,564,0),(7249,74,'75mm \'Scout\' Accelerator Cannon','A small multi-barreled railgun for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,2,1000.0000,1,564,0),(7251,74,'75mm Carbide Railgun I','A small multi-barreled railgun for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,4,1000.0000,1,564,0),(7253,74,'75mm Compressed Coil Gun I','A small multi-barreled railgun for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,8,1000.0000,1,564,0),(7287,74,'150mm Prototype Gauss Gun','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,1,7496.0000,1,564,0),(7289,74,'150mm \'Scout\' Accelerator Cannon','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,2,7496.0000,1,564,0),(7291,74,'150mm Carbide Railgun I','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,4,7496.0000,1,564,0),(7293,74,'150mm Compressed Coil Gun I','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,8,7496.0000,1,564,0),(7327,74,'Dual 150mm Prototype Gauss Gun','This cruiser-sized weapon is a double-barreled version of the frigate class 150mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2,1,1,10000.0000,1,565,0),(7329,74,'Dual 150mm \'Scout\' Accelerator Cannon','This cruiser-sized weapon is a double-barreled version of the frigate class 150mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2,1,2,10000.0000,1,565,0),(7331,74,'Dual 150mm Carbide Railgun I','This cruiser-sized weapon is a double-barreled version of the frigate class 150mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2,1,4,10000.0000,1,565,0),(7333,74,'Dual 150mm Compressed Coil Gun I','This cruiser-sized weapon is a double-barreled version of the frigate class 150mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2,1,8,10000.0000,1,565,0),(7367,74,'250mm Prototype Gauss Gun','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,0.5,1,1,74980.0000,1,565,0),(7369,74,'250mm \'Scout\' Accelerator Cannon','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,0.5,1,2,74980.0000,1,565,0),(7371,74,'250mm Carbide Railgun I','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,0.5,1,4,74980.0000,1,565,0),(7373,74,'250mm Compressed Coil Gun I','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,0.5,1,8,74980.0000,1,565,0),(7407,74,'Dual 250mm Prototype Gauss Gun','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,1,98972.0000,1,566,0),(7409,74,'Dual 250mm \'Scout\' Accelerator Cannon','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,2,98972.0000,1,566,0),(7411,74,'Dual 250mm Carbide Railgun I','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,4,98972.0000,1,566,0),(7413,74,'Dual 250mm Compressed Coil Gun I','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,8,98972.0000,1,566,0),(7447,74,'425mm Prototype Gauss Gun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,1,744812.0000,1,566,0),(7449,74,'425mm \'Scout\' Accelerator Cannon','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,2,744812.0000,1,566,0),(7451,74,'425mm Carbide Railgun I','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,4,744812.0000,1,566,0),(7453,74,'425mm Compressed Coil Gun I','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,8,744812.0000,1,566,0),(7487,74,'Modal Light Electron Particle Accelerator I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,1,1976.0000,1,561,0),(7489,74,'Limited Light Electron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,2,1976.0000,1,561,0),(7491,74,'Regulated Light Electron Phase Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,4,1976.0000,1,561,0),(7493,74,'Anode Light Electron Particle Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,8,1976.0000,1,561,0),(7535,74,'Modal Light Ion Particle Accelerator I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.3,1,1,4484.0000,1,561,0),(7537,74,'Limited Light Ion Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.3,1,2,4484.0000,1,561,0),(7539,74,'Regulated Light Ion Phase Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.3,1,4,4484.0000,1,561,0),(7541,74,'Anode Light Ion Particle Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.3,1,8,4484.0000,1,561,0),(7579,74,'Modal Light Neutron Particle Accelerator I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,1,5996.0000,1,561,0),(7581,74,'Limited Light Neutron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,2,5996.0000,1,561,0),(7583,74,'Regulated Light Neutron Phase Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,4,5996.0000,1,561,0),(7585,74,'Anode Light Neutron Particle Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,8,5996.0000,1,561,0),(7619,74,'Modal Electron Particle Accelerator I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2.5,1,1,25888.0000,1,562,0),(7621,74,'Limited Electron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2.5,1,2,25888.0000,1,562,0),(7623,74,'Regulated Electron Phase Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2.5,1,4,25888.0000,1,562,0),(7625,74,'Anode Electron Particle Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2.5,1,8,25888.0000,1,562,0),(7663,74,'Modal Ion Particle Accelerator I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1.5,1,1,44740.0000,1,562,0),(7665,74,'Limited Ion Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1.5,1,2,44740.0000,1,562,0),(7667,74,'Regulated Ion Phase Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1.5,1,4,44740.0000,1,562,0),(7669,74,'Anode Ion Particle Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1.5,1,8,44740.0000,1,562,0),(7703,74,'Modal Neutron Particle Accelerator I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,1,59676.0000,1,562,0),(7705,74,'Limited Neutron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,2,59676.0000,1,562,0),(7707,74,'Regulated Neutron Phase Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,4,59676.0000,1,562,0),(7709,74,'Anode Neutron Particle Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,8,59676.0000,1,562,0),(7743,74,'Modal Mega Electron Particle Accelerator I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,5,1,1,298716.0000,1,563,0),(7745,74,'Limited Electron Blaster Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,5,1,2,298716.0000,1,563,0),(7747,74,'Regulated Mega Electron Phase Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,5,1,4,298716.0000,1,563,0),(7749,74,'Anode Mega Electron Particle Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,5,1,8,298716.0000,1,563,0),(7783,74,'Modal Mega Neutron Particle Accelerator I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,1,595840.0000,1,563,0),(7785,74,'Limited Mega Neutron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,2,595840.0000,1,563,0),(7787,74,'Regulated Mega Neutron Phase Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,20,2,1,4,595840.0000,1,563,0),(7789,74,'Anode Mega Neutron Particle Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,8,595840.0000,1,563,0),(7827,74,'Modal Mega Ion Particle Accelerator I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,3,1,1,448700.0000,1,563,0),(7829,74,'Limited Mega Ion Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,3,1,2,448700.0000,1,563,0),(7831,74,'Regulated Mega Ion Phase Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,3,1,4,448700.0000,1,563,0),(7833,74,'Anode Mega Ion Particle Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,3,1,8,448700.0000,1,563,0),(7867,202,'Supplemental Ladar ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,452.0000,1,726,0),(7869,202,'Supplemental Gravimetric ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,1216.0000,1,725,0),(7870,202,'Supplemental Omni ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,2656.0000,1,728,0),(7887,202,'Supplemental Radar ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,1216.0000,1,729,0),(7889,202,'Supplemental Magnetometric ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,448.0000,1,727,0),(7892,202,'Prototype ECCM Radar Sensor Cluster','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,1216.0000,1,729,0),(7893,202,'Prototype ECCM Ladar Sensor Cluster','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,452.0000,1,726,0),(7895,202,'Prototype ECCM Gravimetric Sensor Cluster','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,1216.0000,1,725,0),(7896,202,'Prototype ECCM Omni Sensor Cluster','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,2656.0000,1,728,0),(7914,202,'Prototype ECCM Magnetometric Sensor Cluster','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,448.0000,1,727,0),(7917,202,'Alumel Radar ECCM Sensor Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,1216.0000,1,729,0),(7918,202,'Alumel Ladar ECCM Sensor Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,452.0000,1,726,0),(7922,202,'Alumel Gravimetric ECCM Sensor Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,1216.0000,1,725,0),(7926,202,'Alumel Omni ECCM Sensor Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,2656.0000,1,728,0),(7937,202,'Alumel Magnetometric ECCM Sensor Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,448.0000,1,727,0),(7948,202,'Gravimetric Positional ECCM Sensor System I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,1216.0000,1,725,0),(7964,202,'Radar Positional ECCM Sensor System I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,1216.0000,1,729,0),(7965,202,'Omni Positional ECCM Sensor System I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,2656.0000,1,728,0),(7966,202,'Ladar Positional ECCM Sensor System I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,452.0000,1,726,0),(7970,202,'Magnetometric Positional ECCM Sensor System I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,448.0000,1,727,0),(7993,509,'Experimental TE-2100 Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.72,1,2,3000.0000,0,NULL,0),(7997,510,'XR-3200 Heavy Missile Bay','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,1.05,1,2,14996.0000,1,642,0),(8001,508,'Experimental ZW-4100 Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,1.8,1,2,20580.0000,1,644,0),(8007,511,'Experimental SV-2000 Rapid Light Missile Launcher','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.285,1,2,4224.0000,1,641,0),(8023,511,'Upgraded \'Malkuth\' Rapid Light Missile Launcher','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.285,1,4,4224.0000,1,641,0),(8025,511,'Limited \'Limos\' Rapid Light Missile Launcher','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.285,1,8,4224.0000,1,641,0),(8027,511,'Prototype \'Arbalest\' Rapid Light Missile Launcher','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.285,1,1,4224.0000,1,641,0),(8089,509,'Arbalest Compact Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.6,1,4,3000.0000,1,640,0),(8091,509,'TE-2100 Ample Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.',0,5,0.72,1,8,3000.0000,1,640,0),(8093,509,'Prototype \'Arbalest\' Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.72,1,1,3000.0000,0,NULL,0),(8101,510,'\'Malkuth\' Heavy Missile Launcher I','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,0.96,1,4,14996.0000,1,642,0),(8103,510,'Advanced \'Limos\' Heavy Missile Bay I','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,0.99,1,8,14996.0000,1,642,0),(8105,510,'\'Arbalest\' Heavy Missile Launcher','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,1.08,1,1,14996.0000,1,642,0),(8113,508,'Upgraded \'Malkuth\' Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,1.6,1,4,20580.0000,1,644,0),(8115,508,'Limited \'Limos\' Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,1.7,1,8,20580.0000,1,644,0),(8117,508,'Prototype \'Arbalest\' Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,1.8,1,1,20580.0000,1,644,0),(8131,768,'Local Power Plant Manager: Capacitor Flux I','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,2,2080.0000,0,NULL,0),(8133,768,'Mark I Compact Capacitor Flux Coil','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,4,2080.0000,1,666,0),(8135,768,'Type-D Restrained Capacitor Flux Coil','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,8,2080.0000,1,666,0),(8137,768,'Mark I Generator Refitting: Capacitor Flux','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,1,2080.0000,0,NULL,0),(8163,768,'Partial Power Plant Manager: Capacitor Flux','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,2,828.0000,0,NULL,0),(8165,768,'Alpha Reactor Control: Capacitor Flux','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,4,828.0000,0,NULL,0),(8167,768,'Type-E Power Core Modification: Capacitor Flux','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,8,828.0000,0,NULL,0),(8169,768,'Marked Generator Refitting: Capacitor Flux','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,1,828.0000,0,NULL,0),(8171,767,'Local Power Plant Manager: Capacity Power Relay I','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,2,1996.0000,0,NULL,0),(8173,767,'Beta Reactor Control: Capacitor Power Relay I','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,4,1996.0000,0,NULL,0),(8175,767,'Type-D Restrained Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,8,1996.0000,1,667,0),(8177,767,'Mark I Compact Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,1,1996.0000,1,667,0),(8203,767,'Partial Power Plant Manager: Capacity Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,2,2112.0000,0,NULL,0),(8205,767,'Alpha Reactor Control: Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,4,2112.0000,0,NULL,0),(8207,767,'Type-E Power Core Modification: Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,8,2112.0000,0,NULL,0),(8209,767,'Marked Generator Refitting: Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,1,2112.0000,0,NULL,0),(8211,766,'Partial Power Plant Manager: Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,2,1904.0000,0,NULL,0),(8213,766,'Alpha Reactor Control: Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,4,1904.0000,0,NULL,0),(8215,766,'Type-E Power Core Modification: Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,8,1904.0000,0,NULL,0),(8217,766,'Marked Generator Refitting: Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,1,1904.0000,0,NULL,0),(8219,766,'Local Power Plant Manager: Diagnostic System I','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,2,4704.0000,0,NULL,0),(8221,766,'Beta Reactor Control: Diagnostic System I','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,4,4704.0000,0,NULL,0),(8223,766,'Type-D Power Core Modification: Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,8,4704.0000,0,NULL,0),(8225,766,'Mark I Compact Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,1,4704.0000,1,658,0),(8251,769,'Partial Power Plant Manager: Reaction Control','Boosts power core output.',20,5,0,1,2,1968.0000,0,NULL,0),(8253,769,'Alpha Reactor Control: Reaction Control','Boosts power core output.',20,5,0,1,4,1968.0000,0,NULL,0),(8255,766,'Type-E Power Core Modification: Reaction Control','Boosts power core output.',20,5,0,1,8,1968.0000,0,NULL,0),(8257,769,'Marked Generator Refitting: Reaction Control','Boosts power core output.',20,5,0,1,1,1968.0000,0,NULL,0),(8259,769,'Local Power Plant Manager: Reaction Control I','Boosts power core output.',20,5,0,1,2,4960.0000,0,NULL,0),(8261,769,'Beta Reactor Control: Reaction Control I','Boosts power core output.',20,5,0,1,4,4960.0000,0,NULL,0),(8263,769,'Mark I Compact Reactor Control Unit','Boosts power core output.',20,5,0,1,8,4960.0000,1,659,0),(8265,769,'Mark I Generator Refitting: Reaction Control','Boosts power core output.',20,5,0,1,1,4960.0000,0,NULL,0),(8291,770,'Local Power Plant Manager: Reaction Shield Flux I','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,2,2080.0000,1,687,0),(8293,770,'Beta Reactor Control: Shield Flux I','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,4,2080.0000,1,687,0),(8295,770,'Type-D Power Core Modification: Shield Flux','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,8,2080.0000,1,687,0),(8297,770,'Mark I Generator Refitting: Shield Flux','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,1,2080.0000,1,687,0),(8323,770,'Partial Power Plant Manager: Shield Flux','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,2,816.0000,1,687,0),(8325,770,'Alpha Reactor Shield Flux','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,4,816.0000,1,687,0),(8327,770,'Type-E Power Core Modification: Shield Flux','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,8,816.0000,1,687,0),(8329,770,'Marked Generator Refitting: Shield Flux','Increases shield recharge rate while lowering the maximum shield capacity.',20,5,0,1,1,816.0000,1,687,0),(8331,57,'Local Power Plant Manager: Reaction Shield Power Relay I','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,2,2012.0000,1,688,0),(8333,57,'Beta Reactor Control: Shield Power Relay I','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,4,2012.0000,1,688,0),(8335,57,'Type-D Power Core Modification: Shield Power Relay','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,8,2012.0000,1,688,0),(8337,57,'Mark I Generator Refitting: Shield Power Relay','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,1,2012.0000,1,688,0),(8339,57,'Partial Power Plant Manager: Shield Power Relay','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,2,2096.0000,1,688,0),(8341,57,'Alpha Reactor Shield Power Relay','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,4,2096.0000,1,688,0),(8343,57,'Type-E Power Core Modification: Shield Power Relay','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,8,2096.0000,1,688,0),(8345,57,'Marked Generator Refitting: Shield Power Relay','Diverts power from the capacitors to the shields, thereby increasing the shield recharge rate.',20,5,0,1,1,2096.0000,1,688,0),(8387,38,'Micro Subordinate Screen Stabilizer I','Increases the maximum strength of the shield.',0,2.5,0,1,2,1920.0000,0,NULL,0),(8397,38,'Medium Subordinate Screen Stabilizer I','Increases the maximum strength of the shield.',0,10,0,1,2,15882.0000,0,NULL,0),(8401,38,'Small Subordinate Screen Stabilizer I','Increases the maximum strength of the shield.',0,5,0,1,2,3918.0000,0,NULL,0),(8409,38,'Large Subordinate Screen Stabilizer I','Increases the maximum strength of the shield.',0,20,0,1,2,79946.0000,0,NULL,0),(8419,38,'Large Azeotropic Restrained Shield Extender','Increases the maximum strength of the shield.',0,20,0,1,4,79946.0000,1,608,0),(8427,38,'Small Azeotropic Restrained Shield Extender','Increases the maximum strength of the shield.',0,5,0,1,4,3918.0000,1,605,0),(8433,38,'Medium Azeotropic Restrained Shield Extender','Increases the maximum strength of the shield.',0,10,0,1,4,15882.0000,1,606,0),(8437,38,'Micro Azeotropic Ward Salubrity I','Increases the maximum strength of the shield.',0,2.5,0,1,4,1920.0000,0,NULL,0),(8465,38,'Micro Supplemental Barrier Emitter I','Increases the maximum strength of the shield.',0,2.5,0,1,8,1920.0000,0,NULL,0),(8477,38,'Medium Supplemental Barrier Emitter I','Increases the maximum strength of the shield.',0,10,0,1,8,15882.0000,0,NULL,0),(8481,38,'Small Supplemental Barrier Emitter I','Increases the maximum strength of the shield.',0,5,0,1,8,3918.0000,0,NULL,0),(8489,38,'Large Supplemental Barrier Emitter I','Increases the maximum strength of the shield.',0,20,0,1,8,79946.0000,0,NULL,0),(8505,38,'Micro F-S9 Regolith Shield Induction','Increases the maximum strength of the shield.',0,2.5,0,1,1,1920.0000,0,NULL,0),(8517,38,'Medium F-S9 Regolith Compact Shield Extender','Increases the maximum strength of the shield.',0,10,0,1,1,15882.0000,1,606,0),(8521,38,'Small F-S9 Regolith Compact Shield Extender','Increases the maximum strength of the shield.',0,5,0,1,1,3918.0000,1,605,0),(8529,38,'Large F-S9 Regolith Compact Shield Extender','Increases the maximum strength of the shield.',0,20,0,1,1,79946.0000,1,608,0),(8531,41,'Small Murky Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,2,56698.0000,1,603,0),(8533,41,'Small \'Atonement\' Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,4,56698.0000,1,603,0),(8535,41,'Small Asymmetric Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,8,56698.0000,1,603,0),(8537,41,'Small S95a Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,1,56698.0000,1,603,0),(8579,41,'Medium Murky Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,2,12288.0000,1,602,0),(8581,41,'Medium \'Atonement\' Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,4,12288.0000,1,602,0),(8583,41,'Medium Asymmetric Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,8,12288.0000,1,602,0),(8585,41,'Medium S95a Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,1,12288.0000,1,602,0),(8627,41,'Micro Murky Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,2.5,0,1,2,14528.0000,1,604,0),(8629,41,'Micro \'Atonement\' Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,2.5,0,1,4,14528.0000,1,604,0),(8631,41,'Micro Asymmetric Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,2.5,0,1,8,14528.0000,1,604,0),(8633,41,'Micro S95a Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,2.5,0,1,1,14528.0000,1,604,0),(8635,41,'Large Murky Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,25,0,1,2,575820.0000,1,601,0),(8637,41,'Large \'Atonement\' Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,25,0,1,4,575820.0000,1,601,0),(8639,41,'Large Asymmetric Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,25,0,1,8,575820.0000,1,601,0),(8641,41,'Large S95a Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,25,0,1,1,575820.0000,1,601,0),(8683,41,'X-Large Murky Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,50,0,1,2,575820.0000,0,NULL,0),(8685,41,'X-Large \'Atonement\' Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,50,0,1,4,575820.0000,0,NULL,0),(8687,41,'X-Large Asymmetric Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,50,0,1,8,575820.0000,0,NULL,0),(8689,41,'X-Large S95a Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,50,0,1,1,575820.0000,0,NULL,0),(8743,285,'Nanomechanical CPU Enhancer','Increases CPU output.',0,5,0,1,2,2656.0000,0,NULL,0),(8744,285,'Nanoelectrical Co-Processor','Increases CPU output.',0,5,0,1,4,2656.0000,0,NULL,0),(8745,285,'Photonic CPU Enhancer','Increases CPU output.',0,5,0,1,8,2656.0000,0,NULL,0),(8746,285,'Quantum Co-Processor','Increases CPU output.',0,5,0,1,1,2656.0000,0,NULL,0),(8747,285,'Nanomechanical CPU Enhancer I','Increases CPU output.',0,5,0,1,2,14996.0000,0,NULL,0),(8748,285,'Photonic Upgraded Co-Processor','Increases CPU output.',0,5,0,1,4,14996.0000,1,676,0),(8749,285,'Photonic CPU Enhancer I','Increases CPU output.',0,5,0,1,8,14996.0000,0,NULL,0),(8750,285,'Quantum Co-Processor I','Increases CPU output.',0,5,0,1,1,14996.0000,0,NULL,0),(8759,55,'125mm Light \'Scout\' Autocannon I','This multi-barrel autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.5,1,2,1000.0000,1,574,0),(8785,55,'125mm Light Carbine Repeating Cannon I','This multi-barrel autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.5,1,4,1000.0000,1,574,0),(8787,55,'125mm Light Gallium Machine Gun','This multi-barrel autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.5,1,8,1000.0000,1,574,0),(8789,55,'125mm Light Prototype Automatic Cannon','This multi-barrel autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.5,1,1,1000.0000,1,574,0),(8815,55,'150mm Light \'Scout\' Autocannon I','A simple but effective close combat autocannon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.4,1,2,1976.0000,1,574,0),(8817,55,'150mm Light Carbine Repeating Cannon I','A simple but effective close combat autocannon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.4,1,4,1976.0000,1,574,0),(8819,55,'150mm Light Gallium Machine Gun','A simple but effective close combat autocannon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.4,1,8,1976.0000,1,574,0),(8821,55,'150mm Light Prototype Automatic Cannon','A simple but effective close combat autocannon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.4,1,1,1976.0000,1,574,0),(8863,55,'200mm Light \'Scout\' Autocannon I','A powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.3,1,2,4484.0000,1,574,0),(8865,55,'200mm Light Carbine Repeating Cannon I','A powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.3,1,4,4484.0000,1,574,0),(8867,55,'200mm Light Gallium Machine Gun','A powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.3,1,8,4484.0000,1,574,0),(8869,55,'200mm Light Prototype Automatic Cannon','A powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.3,1,1,4484.0000,1,574,0),(8903,55,'250mm Light \'Scout\' Artillery I','This artillery is one of the most powerful weapons that can be mounted on a frigate. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.1,1,2,5996.0000,1,577,0);
INSERT INTO `invTypes` VALUES (8905,55,'250mm Light Carbine Howitzer I','This artillery is one of the most powerful weapons that can be mounted on a frigate. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.1,1,4,5996.0000,1,577,0),(8907,55,'250mm Light Gallium Cannon','This artillery is one of the most powerful weapons that can be mounted on a frigate. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.1,1,8,5996.0000,1,577,0),(8909,55,'250mm Light Prototype Siege Cannon','This artillery is one of the most powerful weapons that can be mounted on a frigate. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.1,1,1,5996.0000,1,577,0),(9071,55,'Dual 180mm \'Scout\' Autocannon I','This autocannon is a simple but effective close combat weapon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',12.5,10,2.5,1,2,10000.0000,1,575,0),(9073,55,'Dual 180mm Carbine Repeating Cannon I','This autocannon is a simple but effective close combat weapon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',12.5,10,2.5,1,4,10000.0000,1,575,0),(9091,55,'Dual 180mm Gallium Machine Gun','This autocannon is a simple but effective close combat weapon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',12.5,10,2.5,1,8,10000.0000,1,575,0),(9093,55,'Dual 180mm Prototype Automatic Cannon','This autocannon is a simple but effective close combat weapon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',12.5,10,2.5,1,1,10000.0000,1,575,0),(9127,55,'220mm Medium \'Scout\' Autocannon I','This autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,2,1,2,25888.0000,1,575,0),(9129,55,'220mm Medium Carbine Repeating Cannon I','This autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,2,1,4,25888.0000,1,575,0),(9131,55,'220mm Medium Gallium Machine Gun','This autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,2,1,8,25888.0000,1,575,0),(9133,55,'220mm Medium Prototype Automatic Cannon','This autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,2,1,1,25888.0000,1,575,0),(9135,55,'425mm Medium \'Scout\' Autocannon I','The 425mm is a behemoth that will inflict severe damage on most cruisers and frigates in short-range battles. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,1.5,1,2,44740.0000,1,575,0),(9137,55,'425mm Medium Carbine Repeating Cannon I','The 425mm is a behemoth that will inflict severe damage on most cruisers and frigates in short-range battles. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,1.5,1,4,44740.0000,1,575,0),(9139,55,'425mm Medium Gallium Machine Gun','The 425mm is a behemoth that will inflict severe damage on most cruisers and frigates in short-range battles. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,1.5,1,8,44740.0000,1,575,0),(9141,55,'425mm Medium Prototype Automatic Cannon','The 425mm is a behemoth that will inflict severe damage on most cruisers and frigates in short-range battles. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,1.5,1,1,44740.0000,1,575,0),(9207,55,'650mm Medium \'Scout\' Artillery I','A powerful long-range artillery. One of the most damaging weapons mountable on a cruiser. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',125,10,0.5,1,2,59676.0000,1,578,0),(9209,55,'650mm Medium Carbine Howitzer I','A powerful long-range artillery. One of the most damaging weapons mountable on a cruiser. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',125,10,0.5,1,4,59676.0000,1,578,0),(9211,55,'650mm Medium Gallium Cannon','A powerful long-range artillery. One of the most damaging weapons mountable on a cruiser. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',125,10,0.5,1,8,59676.0000,1,578,0),(9213,55,'650mm Medium Prototype Siege Cannon','A powerful long-range artillery. One of the most damaging weapons mountable on a cruiser. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',125,10,0.5,1,1,59676.0000,1,578,0),(9247,55,'Dual 425mm \'Scout\' Autocannon I','Combines the damage output of two 425mm intermediate-range autocannons. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',200,20,5,1,2,98972.0000,1,576,0),(9249,55,'Dual 425mm Carbine Repeating Cannon I','Combines the damage output of two 425mm intermediate-range autocannons. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',200,20,5,1,4,98972.0000,1,576,0),(9251,55,'Dual 425mm Gallium Machine Gun','Combines the damage output of two 425mm intermediate-range autocannons. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',200,20,5,1,8,98972.0000,1,576,0),(9253,55,'Dual 425mm Prototype Automatic Cannon','Combines the damage output of two 425mm intermediate-range autocannons. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',200,20,5,1,1,98972.0000,1,576,0),(9287,55,'Dual 650mm \'Scout\' Repeating Cannon I','Powerful, intermediate-range repeating autocannon with a decent rate of fire. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,4,1,2,298716.0000,1,576,0),(9289,55,'Dual 650mm Carbine Repeating Cannon I','Powerful, intermediate-range repeating autocannon with a decent rate of fire. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,4,1,4,298716.0000,1,576,0),(9291,55,'Dual 650mm Gallium Repeating Cannon','Powerful, intermediate-range repeating autocannon with a decent rate of fire. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,4,1,8,298716.0000,1,576,0),(9293,55,'Dual 650mm Prototype Automatic Cannon','Powerful, intermediate-range repeating autocannon with a decent rate of fire. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,4,1,1,298716.0000,1,576,0),(9327,55,'800mm Heavy \'Scout\' Repeating Cannon I','An autocannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,20,3,1,2,448700.0000,1,576,0),(9329,55,'800mm Heavy Carbine Repeating Cannon I','An autocannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,20,3,1,4,448700.0000,1,576,0),(9331,55,'800mm Heavy Gallium Repeating Cannon','An autocannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,20,3,1,8,448700.0000,1,576,0),(9333,55,'800mm Heavy Prototype Automatic Cannon','An autocannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,20,3,1,1,448700.0000,1,576,0),(9367,55,'1200mm Heavy \'Scout\' Artillery I','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,1,1,2,595840.0000,1,579,0),(9369,55,'1200mm Heavy Carbine Howitzer I','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,1,1,4,595840.0000,1,579,0),(9371,55,'1200mm Heavy Gallium Cannon','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,1,1,8,595840.0000,1,579,0),(9373,55,'1200mm Heavy Prototype Artillery','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,1,1,1,159872.0000,0,579,0),(9377,55,'1200mm Heavy Prototype Siege Cannon','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,1,1,1,595840.0000,1,579,0),(9411,55,'280mm \'Scout\' Artillery I','Rocket-assisted artillery projectiles designed for long-range combat. It is the most powerful projectile weapon able to be fitted onto frigates. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.05,1,2,7496.0000,1,577,0),(9413,55,'280mm Carbine Howitzer I','Rocket-assisted artillery projectiles designed for long-range combat. It is the most powerful projectile weapon able to be fitted onto frigates. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.05,1,4,7496.0000,1,577,0),(9415,55,'280mm Gallium Cannon','Rocket-assisted artillery projectiles designed for long-range combat. It is the most powerful projectile weapon able to be fitted onto frigates. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.05,1,8,7496.0000,1,577,0),(9417,55,'280mm Prototype Siege Cannon','Rocket-assisted artillery projectiles designed for long-range combat. It is the most powerful projectile weapon able to be fitted onto frigates. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.05,1,1,7496.0000,1,577,0),(9419,55,'720mm \'Probe\' Artillery I','Not supposed to be here...',50,10,0.25,1,2,9856.0000,0,NULL,0),(9421,55,'720mm Cordite Howitzer I','You don\'t see this...',50,10,0.25,1,4,9856.0000,0,NULL,0),(9451,55,'720mm \'Scout\' Artillery I','This rocket-assisted howitzer is designed for long-range bombardment. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',50,10,0.25,1,2,74980.0000,1,578,0),(9453,55,'720mm Carbine Howitzer I','This rocket-assisted howitzer is designed for long-range bombardment. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',50,10,0.25,1,4,74980.0000,1,578,0),(9455,55,'720mm Gallium Cannon','This rocket-assisted howitzer is designed for long-range bombardment. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',50,10,0.25,1,8,74980.0000,1,578,0),(9457,55,'720mm Prototype Siege Cannon','This rocket-assisted howitzer is designed for long-range bombardment. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',50,10,0.25,1,1,74980.0000,1,578,0),(9491,55,'1400mm \'Scout\' Artillery I','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,0.5,1,2,744812.0000,1,579,0),(9493,55,'1400mm Carbine Howitzer I','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,0.5,1,4,744812.0000,1,579,0),(9495,55,'1400mm Gallium Cannon','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,0.5,1,8,744812.0000,1,579,0),(9497,55,'1400mm Prototype Siege Cannon','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,0.5,1,1,744812.0000,1,579,0),(9518,201,'Initiated Ion Field ECM I','Projects a low intensity field of ionized particles to disrupt the effectiveness of enemy sensors. Very effective against Magnetometric based sensors.',0,5,0,1,8,4960.0000,1,715,0),(9519,201,'FZ-3 Subversive Spatial Destabilizer ECM','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',0,5,0,1,1,4960.0000,1,717,0),(9520,201,'\'Penumbra\' White Noise ECM','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',0,5,0,1,2,4960.0000,1,718,0),(9521,201,'Initiated Multispectral ECM I','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,8,14848.0000,1,719,0),(9522,201,'Faint Phase Inversion ECM I','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',0,5,0,1,4,4960.0000,1,716,0),(9556,295,'Upgraded Explosive Deflection Amplifier I','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,3968.0000,1,1690,0),(9562,295,'Supplemental EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,1920.0000,1,1691,0),(9566,295,'Supplemental Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,1920.0000,1,1688,0),(9568,295,'Upgraded Thermic Dissipation Amplifier I','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,3968.0000,1,1688,0),(9570,295,'Supplemental Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,1920.0000,1,1689,0),(9574,295,'Supplemental Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,1920.0000,1,1690,0),(9580,295,'Upgraded EM Ward Amplifier I','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,3968.0000,1,1691,0),(9582,295,'Upgraded Kinetic Deflection Amplifier I','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,3968.0000,1,1689,0),(9608,77,'Limited Kinetic Deflection Field I','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(9622,77,'Limited \'Anointed\' EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,4,45412.0000,1,1695,0),(9632,77,'Limited Adaptive Invulnerability Field I','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(9646,77,'Limited Explosive Deflection Field I','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(9660,77,'Limited Thermic Dissipation Field I','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,8,45412.0000,1,1692,0),(9668,72,'Large Rudimentary Concussion Bomb I','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,50,0,1,2,769744.0000,1,381,0),(9670,72,'Small Rudimentary Concussion Bomb I','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',10,5,0,1,2,18620.0000,1,382,0),(9678,72,'Large \'Vehemence\' Shockwave Charge','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,4,769744.0000,1,381,0),(9680,72,'Small \'Vehemence\' Shockwave Charge','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',10,5,0,1,4,19712.0000,1,382,0),(9702,72,'Micro Rudimentary Concussion Bomb I','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,2.5,0,1,2,8560.0000,1,380,0),(9706,72,'Micro \'Vehemence\' Shockwave Charge','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,2.5,0,1,4,8560.0000,1,380,0),(9728,72,'Medium Rudimentary Concussion Bomb I','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,10,0,1,2,769744.0000,1,383,0),(9734,72,'Medium \'Vehemence\' Shockwave Charge','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,10,0,1,4,769744.0000,1,383,0),(9744,72,'Small \'Notos\' Explosive Charge I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',10,5,0,1,8,18624.0000,1,382,0),(9750,72,'Micro \'Notos\' Explosive Charge I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,2.5,0,1,8,8560.0000,1,380,0),(9762,72,'Medium \'Notos\' Explosive Charge I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,10,0,1,8,769744.0000,1,383,0),(9772,72,'Large \'Notos\' Explosive Charge I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,50,0,1,8,769744.0000,1,381,0),(9784,72,'Small YF-12a Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',10,5,0,1,1,19452.0000,1,382,0),(9790,72,'Micro YF-12a Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,2.5,0,1,1,8560.0000,1,380,0),(9800,72,'Medium YF-12a Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,10,0,1,1,769744.0000,1,383,0),(9808,72,'Large YF-12a Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,50,0,1,1,769744.0000,1,381,0),(9826,280,'Carbon','Carbon is an abundant nonmetallic element that occurs in many inorganic and in all organic compounds.',4400,0.01,0,1,4,350.0000,1,20,0),(9828,1042,'Silicon','As one of the most common elements in the universe, it\'s no surprise that silicon has found its way into almost every aspect of manufacturing, resulting in a steady price and perpetual mining operations on most solid planets.',0,0.38,0,1,NULL,266.0000,1,1334,0),(9830,1034,'Rocket Fuel','The properties of this carefully refined liquid make it ideal for controlled combustion whether in or outside of atmospheric environments; its severe volatility requires special containers to resist most forms of impact, high temperatures, and electrical activity during storage and transportation.',0,1.5,0,1,NULL,505.0000,1,1335,0),(9832,1034,'Coolant','This specially blended fluid is ideal for transferring thermal energy away from sensitive machinery or computer components, rerouting it to heat sinks so it can be eliminated from the system.',0,1.5,0,1,NULL,1000.0000,1,1335,0),(9834,1040,'Guidance Systems','An electrical device used in targeting systems and tracking computers.',0,6,0,1,NULL,380.0000,1,1336,0),(9836,1034,'Consumer Electronics','Consumer electronics encompass a wide variety of individual goods, from entertainment media and personal computers to slave collars and children\'s toys. ',0,1.5,0,1,NULL,230.0000,1,1335,0),(9838,1034,'Superconductors','Required for highly advanced technologies too numerous to mention to function properly, these conduits are made from super-cooled materials that function as perfect conductors, having an effective electrical resistance of zero.',0,1.5,0,1,NULL,850.0000,1,1335,0),(9840,1034,'Transmitter','This electronic device generates and amplifies a carrier wave, modulates it with a meaningful signal derived from speech or other sources, and radiates the resulting signal from an antenna or some other form of transducer.',0,1.5,0,1,NULL,313.0000,1,1335,0),(9842,1034,'Miniature Electronics','Advances in molecular chemistry and nanite-reduced computer chips have made almost every form of miniature electronics possible, from the simple holovid viewer and missile tracking systems to wetware cybernetics and quantum entanglement communications.',0,1.5,0,1,NULL,400.0000,1,1335,0),(9844,280,'Small Arms','Personal weapons and armaments, used both for warfare and personal security.',2500,2,0,1,NULL,1260.0000,1,492,0),(9846,1040,'Planetary Vehicles','Tracked, wheeled and hover vehicles used within planetary atmosphere for personal and business use.',0,6,0,1,NULL,3730.0000,1,1336,0),(9848,1040,'Robotics','These pre-programmed or remote control mechanical tools are commonly used in mass production facilities, hazardous material handling, or dangerous front line military duties such as bomb disarming and disposal.',0,6,0,1,NULL,6500.0000,1,1336,0),(9850,280,'Spirits','Alcoholic beverages made by distilling a fermented mash of grains.',2500,0.2,0,1,NULL,455.0000,1,492,0),(9852,280,'Tobacco','Tubular rolls of tobacco designed for smoking. The tube consists of finely shredded tobacco enclosed in a paper wrapper and is generally outfitted with a filter tip at the end.',2500,0.2,0,1,NULL,48.0000,1,492,0),(9854,237,'Polaris Inspector Frigate','The Polaris Inspector frigate is an observation vehicle with a very resiliant superstructure.',1000000,20400,0,1,16,0.0000,0,NULL,0),(9856,15,'Amarr Class A Starport',' ',0,0,0,1,4,0.0000,0,NULL,0),(9857,15,'Amarr Class B Starport',' ',0,0,0,1,4,0.0000,0,NULL,0),(9858,237,'Polaris Centurion TEST','The Polaris Centurion is an elite class observer vehicle with a nearly impenatrable armor coating.',1000000,20400,0,1,16,0.0000,0,NULL,0),(9860,237,'Polaris Legatus Frigate','The Polaris Legatus frigate is one of the most powerful Polaris ships built, superior in both combat and maneuverability.',1000000,20400,1000000,1,16,0.0000,0,NULL,0),(9862,237,'Polaris Centurion Frigate','The Polaris Centurion frigate is an observation vehicle with a very resiliant superstructure.',1000000,20400,0,1,16,0.0000,0,NULL,0),(9867,15,'Heaven',' ',0,0,0,1,2,0.0000,0,NULL,0),(9868,15,'Concord Starbase',' ',0,0,0,1,8,0.0000,0,NULL,0),(9869,298,'Loiterer I',' ',100000,60,1200,10,NULL,10.0000,0,NULL,0),(9871,299,'Repair Drone',' ',0,50,1200,10,NULL,10.0000,0,NULL,0),(9873,15,'Dark Amarr Station O',' ',0,0,0,1,4,0.0000,0,NULL,0),(9875,226,'Minmatar Trade Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9876,226,'Fortified Amarr Commercial Station Ruins','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(9877,226,'Amarr Military Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9878,226,'Amarr Mining Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9879,226,'Amarr Research Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9880,226,'Amarr Trade Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9881,226,'Fortified Caldari Station Ruins - Huge & Sprawling','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(9882,226,'Caldari Station Ruins - Hook Shaped','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9883,226,'Fortified Caldari Station Ruins - Flat Hulk','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(9884,226,'Caldari Station Ruins - Industry Drill','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9885,226,'Gallente Station Ruins - Disc','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9886,226,'Gallente Station Ruins - Fathom','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9887,226,'Gallente Station Ruins - Ugly Industrial','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9888,226,'Gallente Station Ruins - Biodomes','Ruins of a Gallentean station.',0,0,0,1,NULL,0.0000,0,NULL,0),(9889,226,'Gallente Station Ruins - Factory','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9890,226,'Gallente Station Ruins - Military','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9891,226,'Gallente Station Ruins - Research','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9892,226,'Gallente Station Ruins - Commercial','Ruins of a Gallentean station.',0,0,0,1,NULL,0.0000,0,NULL,0),(9893,226,'Minmatar Commercial Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9894,226,'Minmatar Industry Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9895,226,'Minmatar Military Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9896,226,'Minmatar Mining Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9897,226,'Minmatar Research Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9898,226,'Minmatar General Station Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(9899,745,'Ocular Filter - Basic','This image processor implanted in the occipital lobe grants a bonus to a character\'s Perception.\r\r\n\r\r\n+3 Bonus to Perception',0,1,0,1,NULL,200000.0000,1,618,0),(9917,23,'Clone Grade Delta',' ',0,1,0,1,NULL,66500.0000,0,NULL,0),(9919,23,'Clone Grade Epsilon',' ',0,1,0,1,NULL,91000.0000,0,NULL,0),(9921,23,'Clone Grade Zeta',' ',0,1,0,1,NULL,126000.0000,0,NULL,0),(9923,23,'Clone Grade Eta',' ',0,1,0,1,NULL,175000.0000,0,NULL,0),(9925,23,'Clone Grade Theta',' ',0,1,0,1,NULL,234500.0000,0,NULL,0),(9927,23,'Clone Grade Iota',' ',0,1,0,1,NULL,329000.0000,0,NULL,0),(9929,23,'Clone Grade Kappa',' ',0,1,0,1,NULL,455000.0000,0,NULL,0),(9931,23,'Clone Grade Lambda',' ',0,1,0,1,NULL,651000.0000,0,NULL,0),(9933,23,'Clone Grade Mu',' ',0,1,0,1,NULL,938000.0000,0,NULL,0),(9935,23,'Clone Grade Nu',' ',0,1,0,1,NULL,1386000.0000,0,NULL,0),(9937,23,'Clone Grade Xi',' ',0,1,0,1,NULL,2093000.0000,0,NULL,0),(9939,23,'Clone Grade Omicron',' ',0,1,0,1,NULL,3290000.0000,0,NULL,0),(9941,745,'Memory Augmentation - Basic','This image processor implanted in the temporal lobe grants a bonus to a character\'s memory.\r\r\n\r\r\n+3 Bonus to Memory',0,1,0,1,NULL,200000.0000,1,619,0),(9942,745,'Neural Boost - Basic','A Data processing unit implanted in the Parietal lobe. Grants a bonus to Willpower.\r\r\n\r\r\n+3 Bonus to Willpower',0,1,0,1,NULL,200000.0000,1,620,0),(9943,745,'Cybernetic Subprocessor - Basic','This grafted subprocessor implanted in the frontal lobe grants a bonus to a character\'s Intelligence.\r\r\n\r\r\n+3 Bonus to Intelligence',0,1,0,1,NULL,200000.0000,1,621,0),(9944,302,'Magnetic Field Stabilizer I','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,27772.0000,1,648,0),(9945,139,'Magnetic Field Stabilizer I Blueprint',' ',0,0.01,0,1,NULL,249940.0000,1,343,0),(9947,303,'Standard Crash Booster','This booster quickens a pilot\'s reactions, pushing him into the delicate twitch territory inhabited by the best missile marksmen. Any missile he launches at his hapless victims will hit its mark with that much more precision, although the pilot may be too busy grinding his teeth to notice.',1,1,0,1,NULL,65536.0000,1,977,0),(9950,303,'Standard Blue Pill Booster','This booster relaxes a pilot\'s ability to control certain shield functions, among other things. It creates a temporary feeling of euphoria that counteracts the unpleasantness inherent in activating shield boosters, and permits the pilot to force the boosters to better performance without suffering undue pain.',1,1,0,1,NULL,65536.0000,1,977,0),(9955,257,'Polaris','Skill at operating Polaris ships.',0,0.01,0,1,NULL,800000000.0000,0,NULL,0),(9956,745,'Social Adaptation Chip - Basic','This image processor implanted in the parietal lobe grants a bonus to a character\'s Charisma.\r\r\n\r\r\n+3 Bonus to Charisma',0,1,0,1,NULL,200000.0000,1,622,0),(9957,742,'Eifyr and Co. \'Gunslinger\' Motion Prediction MR-703','An Eifyr and Co. gunnery hardwiring designed to enhance turret tracking.\r\r\n\r\r\n3% bonus to turret tracking speed.',0,1,0,1,NULL,200000.0000,1,1499,0),(9959,182,'Amarr Surveillance Officer','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',1810000,18100,275,1,4,0.0000,0,NULL,0),(9960,182,'Amarr Surveillance Sergeant Major','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11800000,118000,1750,1,4,0.0000,0,NULL,0),(9962,182,'Amarr Surveillance Sergeant','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',11500000,115000,1775,1,4,0.0000,0,NULL,0),(9965,182,'Caldari Police Vice Commissioner','This is a security vessel of the Caldari Police Force. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',10100000,101000,1050,1,1,0.0000,0,NULL,0),(9970,182,'Caldari Police 3rd Lieutenant','This is a security vessel of the Caldari Police Force. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',1650000,16500,190,1,1,0.0000,0,NULL,0),(9971,182,'Caldari Police 1st Lieutenant','This is a security vessel of the Caldari Police Force. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',9200000,92000,1200,1,1,0.0000,0,NULL,0),(9977,182,'Minmatar Security Officer 2nd Rank','This is a security vessel of the Minmatar Security Service. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',8900000,89000,1250,1,2,0.0000,0,NULL,0),(9978,182,'Minmatar Security Officer 1st Rank','This is a security vessel of the Minmatar Security Service. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',8000000,80000,825,1,2,0.0000,0,NULL,0),(9983,182,'Gallente Police Master Sergeant','This is a security vessel of the Gallente Federation Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11300000,113000,1935,1,8,0.0000,0,NULL,0),(9984,182,'Gallente Police Captain','This is a security vessel of the Gallente Federation Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11500000,115000,1735,1,8,0.0000,0,NULL,0),(9987,182,'Khanid Surveillance Officer','This is a security vessel of the Royal Khanid Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',80000,20400,200,1,4,0.0000,0,NULL,0),(9988,182,'Khanid Surveillance Sergeant','This is a security vessel of the Royal Khanid Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',11500000,115000,500,1,4,0.0000,0,NULL,0),(9989,182,'Minmatar Security Officer 3rd Rank','This is a security vessel of the Minmatar Security Service. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Significant',1200000,12000,80,1,2,0.0000,0,NULL,0),(9991,182,'Gallente Police Sergeant','This is a security vessel of the Gallente Federation Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',2040000,20400,160,1,8,0.0000,0,NULL,0),(9997,288,'Imperial Navy Sergeant Major','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Significant',2810000,28100,350,1,4,0.0000,0,NULL,0),(9998,288,'Imperial Navy Sergeant','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',1810000,18100,225,1,4,0.0000,0,NULL,0),(9999,288,'Imperial Navy Captain','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',2870000,28700,200,1,4,0.0000,0,NULL,0),(10000,288,'Imperial Navy Major','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',2860000,28600,275,1,4,0.0000,0,NULL,0),(10001,288,'Imperial Navy Colonel','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',12000000,120000,1150,1,4,0.0000,0,NULL,0),(10003,288,'Imperial Navy General','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11800000,118000,1775,1,4,0.0000,0,NULL,0),(10013,550,'Angel Hijacker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2112000,21120,100,1,2,0.0000,0,NULL,0),(10014,550,'Angel Outlaw','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',1740000,17400,220,1,2,0.0000,0,NULL,0),(10015,550,'Angel Nomad','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',1750000,17500,180,1,2,0.0000,0,NULL,0),(10016,550,'Angel Raider','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(10017,551,'Angel Depredator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',9900000,99000,1900,1,2,0.0000,0,NULL,0),(10018,551,'Angel Smasher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,1400,1,2,0.0000,0,NULL,0),(10019,550,'Angel Hunter','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1910000,19100,80,1,2,0.0000,0,NULL,0),(10025,567,'Sansha\'s Servant','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2112000,21120,100,1,4,0.0000,0,NULL,0),(10026,567,'Sansha\'s Scavenger','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2000000,20000,200,1,4,0.0000,0,NULL,0),(10027,567,'Sansha\'s Savage','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2000000,20000,200,1,4,0.0000,0,NULL,0),(10028,567,'Sansha\'s Plague','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2112000,21120,200,1,4,0.0000,0,NULL,0),(10030,566,'Sansha\'s Ravager','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',10010000,100100,200,1,4,0.0000,0,NULL,0),(10035,182,'CONCORD SWAT Officer','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',2040000,20400,300,1,NULL,0.0000,0,NULL,0),(10036,182,'CONCORD SWAT Captain','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',10100000,101000,900,1,NULL,0.0000,0,NULL,0),(10037,301,'DED Special Operation Officer','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',2040000,20400,300,1,NULL,0.0000,0,NULL,0),(10038,301,'DED Special Operation Captain','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',10100000,101000,900,1,NULL,0.0000,0,NULL,0),(10039,40,'Civilian Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,NULL,366.0000,1,609,0),(10040,120,'Civilian Shield Booster Blueprint',' ',0,0.01,0,1,NULL,3360.0000,1,1552,0),(10041,226,'Frozen Corpse','A human corpse.',200,2,0,1,NULL,0.0000,0,NULL,0),(10043,297,'Peddler','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',89000000,890000,2300,1,2,0.0000,0,NULL,0),(10044,297,'Column','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',102000000,1020000,3000,1,1,0.0000,0,NULL,0),(10045,297,'Vanguard','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3600,1,4,0.0000,0,NULL,0),(10046,288,'Caldari Navy Captain 2nd Rank','This is a security vessel of the Caldari Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Significant',2040000,20400,200,1,1,0.0000,0,NULL,0),(10047,288,'Caldari Navy Captain 1st Rank','This is a security vessel of the Caldari Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: High',1970000,19700,230,1,1,0.0000,0,NULL,0),(10048,288,'Caldari Navy Commodore','This is a security vessel of the Caldari Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',1650000,16500,170,1,1,0.0000,0,NULL,0),(10050,288,'Caldari Navy Vice Admiral','This is a security vessel of the Caldari Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',9200000,92000,450,1,1,0.0000,0,NULL,0),(10052,288,'Federation Navy Command Sergeant Major','This is a security vessel of the Gallente Federation Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',2950000,29500,100,1,8,0.0000,0,NULL,0),(10053,288,'Federation Navy Fleet Captain','This is a security vessel of the Gallente Federation Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',1620000,16200,160,1,8,0.0000,0,NULL,0),(10054,288,'Federation Navy Sergeant Major','This is a security vessel of the Gallente Federation Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: High',2300000,23000,200,1,8,0.0000,0,NULL,0),(10056,288,'Federation Navy Fleet Major','This is a security vessel of the Gallente Federation Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11600000,116000,520,1,8,0.0000,0,NULL,0),(10057,288,'Federation Navy Fleet Colonel','This is a security vessel of the Gallente Federation Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11200000,112000,350,1,8,0.0000,0,NULL,0),(10058,288,'Republic Fleet Private 3rd Rank','This is a security vessel of the Minmatar Republic Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',1740000,17400,145,1,2,0.0000,0,NULL,0),(10060,288,'Republic Fleet Captain','This is a security vessel of the Minmatar Republic Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',1980000,19800,80,1,2,0.0000,0,NULL,0),(10065,227,'Dark Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10066,227,'Dark Green Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10067,227,'Dust Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10068,227,'Ion Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10069,227,'Spark Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10071,305,'Toxic Comet','Comet',1e35,20,0,250,NULL,3068504.0000,0,NULL,0),(10073,305,'Gold Comet','Comet',1e35,20,0,250,NULL,3068504.0000,0,NULL,0),(10076,288,'Khanid Navy Sergeant','This is a security vessel of the Royal Khanid Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',1810000,18100,225,1,4,0.0000,0,NULL,0),(10077,288,'Republic Fleet Commander','This is a security vessel of the Minmatar Republic Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',9600000,96000,580,1,2,0.0000,0,NULL,0),(10078,288,'Republic Fleet High Captain','This is a security vessel of the Minmatar Republic Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',8500000,85000,390,1,2,0.0000,0,NULL,0),(10079,288,'Khanid Navy Sergeant Major','This is a security vessel of the Royal Khanid Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',2810000,28100,200,1,4,0.0000,0,NULL,0),(10080,288,'Khanid Navy Major','This is a security vessel of the Royal Khanid Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',2860000,28600,200,1,4,0.0000,0,NULL,0),(10082,288,'Khanid Navy Colonel','This is a security vessel of the Royal Khanid Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',12000000,120000,550,1,4,0.0000,0,NULL,0),(10083,288,'Khanid Navy General','This is a security vessel of the Royal Khanid Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(10084,288,'Ammatar Navy Sergeant','This is a security vessel of the Ammatar Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',1810000,18100,225,1,4,0.0000,0,NULL,0),(10085,288,'Ammatar Navy Sergeant Major','This is a security vessel of the Ammatar Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Significant',2810000,28100,300,1,4,0.0000,0,NULL,0),(10086,288,'Ammatar Navy Major','This is a security vessel of the Ammatar Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',2860000,28600,200,1,4,0.0000,0,NULL,0),(10089,288,'Ammatar Navy General','This is a security vessel of the Ammatar Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(10090,288,'Sarum Navy Sergeant','This is a security vessel of the Sarum Family. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',1810000,18100,225,1,4,0.0000,0,NULL,0),(10091,288,'Sarum Navy Major','This is a security vessel of the Sarum Family. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',2860000,28600,200,1,4,0.0000,0,NULL,0),(10092,288,'Sarum Navy Captain','This is a security vessel of the Sarum Family. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',1870000,18700,300,1,4,0.0000,0,NULL,0),(10095,288,'Sarum Navy General','This is a security vessel of the Sarum Family. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(10097,182,'Ammatar Surveillance Officer','This is a security vessel of the Ammatar Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',1810000,18100,200,1,4,0.0000,0,NULL,0),(10099,182,'Ammatar Surveillance Sergeant Major','This is a security vessel of the Ammatar Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11800000,118000,550,1,4,0.0000,0,NULL,0),(10100,182,'Ammatar Surveillance Sergeant','This is a security vessel of the Ammatar Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',11500000,115000,500,1,4,0.0000,0,NULL,0),(10102,182,'Sarum Surveillance Officer','This is a security vessel of the Sarum Family. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',1810000,18100,200,1,4,0.0000,0,NULL,0),(10104,182,'Sarum Surveillance Sergeant Major','This is a security vessel of the Sarum Family. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11800000,118000,550,1,4,0.0000,0,NULL,0),(10105,182,'Sarum Surveillance Sergeant','This is a security vessel of the Sarum Family. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',11500000,115000,500,1,4,0.0000,0,NULL,0),(10106,288,'Intaki Defense Sergeant Major','This is a security vessel of the Intaki Space Police. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: High',1850000,18500,80,1,8,0.0000,0,NULL,0),(10107,288,'Intaki Defense Command Sergeant Major','This is a security vessel of the Intaki Space Police. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',2300000,23000,100,1,8,0.0000,0,NULL,0),(10108,288,'Intaki Defense Fleet Captain','This is a security vessel of the Intaki Space Police. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',2950000,29500,160,1,8,0.0000,0,NULL,0),(10109,288,'Intaki Defense Fleet Colonel','This is a security vessel of the Intaki Space Police. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11500000,115000,520,1,8,0.0000,0,NULL,0),(10110,826,'Thukker Follower','This is a security vessel of the Thukker Mix. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',1580000,15800,145,1,2,0.0000,0,NULL,0),(10111,288,'Thukker Brute','This is a security vessel of the Thukker Mix. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Significant',1710000,17100,235,1,2,0.0000,0,NULL,0),(10112,288,'Thukker Warrior','This is a security vessel of the Thukker Mix. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: High',1740000,17400,130,1,2,0.0000,0,NULL,0),(10113,288,'Thukker Tribal Lord','This is a security vessel of the Thukker Mix. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',8000000,80000,365,1,8,0.0000,0,NULL,0),(10114,297,'Tradesman','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',89000000,890000,2000,1,2,0.0000,0,NULL,0),(10115,297,'Merchant','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',85000000,850000,2800,1,8,0.0000,0,NULL,0),(10116,297,'Trafficker','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,3500,1,8,0.0000,0,NULL,0),(10117,297,'Caravan','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',109000000,1090000,3000,1,8,0.0000,0,NULL,0),(10118,297,'Flotilla','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',110500000,1105000,4000,1,8,0.0000,0,NULL,0),(10119,226,'Outpost/Disc - Spiky & Pulsating','This construction dampens all damage inflicted to ships within range.',0,0,0,1,NULL,0.0000,0,NULL,0),(10120,226,'Rock - Infested by Rogue Drones','This block of rock and girders seems to be infested with independant artificial life.',0,0,0,1,NULL,0.0000,0,NULL,0),(10121,226,'Small Asteroid w/Drone-tech','This massive hulk of rock appears to be infested with rogue drones.',0,0,0,1,NULL,0.0000,0,NULL,0),(10122,226,'Multi-purpose Pad','A platform designed to launch missiles similar to sentry guns.',0,0,0,1,1,0.0000,0,NULL,0),(10123,226,'Pulsating Power Generator',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10124,226,'Beacon','With its blinking orange light, this beacon appears to be marking a point of interest, or perhaps a waypoint in a greater trail.',0,0,0,1,NULL,0.0000,0,NULL,0),(10125,288,'Mordu\'s Lieutenant 3rd Rank','This is a security vessel of the Mordu\'s Legion. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',2025000,20250,180,1,1,0.0000,0,NULL,0),(10126,288,'Mordu\'s Lieutenant 2nd Rank','This is a security vessel of the Mordu\'s Legion. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Significant',1940000,19400,145,1,1,0.0000,0,NULL,0),(10127,226,'Magnetic Double-Capped Bubble','This construction recharges the shields on ships within range.',0,0,0,1,NULL,0.0000,0,NULL,0),(10128,227,'Dark Gray Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10129,227,'Dark Gray Turbulent Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10130,227,'Electric Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10131,227,'Fire Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10132,227,'Plasma Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10133,288,'Mordu\'s Lieutenant','This is a security vessel of the Mordu\'s Legion. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',1650000,16500,90,1,1,0.0000,0,NULL,0),(10134,288,'Mordu\'s Captain','This is a security vessel of the Mordu\'s Legion. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',9200000,92000,450,1,1,0.0000,0,NULL,0),(10135,226,'Depleted Station Battery','This massive battery column was probably a part of a destroyed power plant. It still surges with energy.',0,0,0,1,NULL,0.0000,0,NULL,0),(10136,226,'Black Monolith','It\'s full of stars.',0,0,0,1,NULL,0.0000,0,NULL,0),(10137,226,'Rock Formation - Branched & Twisted','A huge branching rock formation.',0,0,0,1,NULL,0.0000,0,NULL,0),(10138,226,'Spaceshuttle Wreck','The mangled wreck floats motionless in space, surrounded with a field of scorched debris.',0,0,0,1,NULL,0.0000,0,NULL,0),(10139,226,'Circular Construction','This circular piece may have once been a part of something larger. Now it is derelict, spinning alone in the blackness of space.',0,0,0,1,NULL,0.0000,0,NULL,0),(10140,226,'Debris - Broken Engine Part 1','This massive hulk of debris seems to have once been a part of the outer hull of a battleship or station.',0,0,0,1,NULL,0.0000,0,NULL,0),(10141,226,'Debris - Broken Engine Part 2','This damaged hunk of machinery could once have been a part of a powerplant or relay station.',0,0,0,1,NULL,0.0000,0,NULL,0),(10142,226,'Debris - Power Conduit','This space debris appears to have served as an external power conduit system on a gigantic vessel.',0,0,0,1,NULL,0.0000,0,NULL,0),(10143,226,'Debris - Twisted Metal','This floating debris appears to have once been a part of an outer hull or armor, ripped apart by an explosion or asteroid impact.',0,0,0,1,NULL,0.0000,0,NULL,0),(10144,226,'Scanner Sentry - Rapid Pulse',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10151,303,'Improved Crash Booster','This booster quickens a pilot\'s reactions, pushing him into the delicate twitch territory inhabited by the best missile marksmen. Any missile he launches at his hapless victims will hit its mark with that much more precision, although the pilot may be too busy grinding his teeth to notice.',1,1,0,1,NULL,65536.0000,1,977,0),(10152,303,'Strong Crash Booster','This booster quickens a pilot\'s reactions, pushing him into the delicate twitch territory inhabited by the best missile marksmen. Any missile he launches at his hapless victims will hit its mark with that much more precision, although the pilot may be too busy grinding his teeth to notice.',1,1,0,1,NULL,65536.0000,1,977,0),(10155,303,'Improved Blue Pill Booster','This booster relaxes a pilot\'s ability to control certain shield functions, among other things. It creates a temporary feeling of euphoria that counteracts the unpleasantness inherent in activating shield boosters, and permits the pilot to force the boosters to better performance without suffering undue pain.',1,1,0,1,NULL,65536.0000,1,977,0),(10156,303,'Strong Blue Pill Booster','This booster relaxes a pilot\'s ability to control certain shield functions, among other things. It creates a temporary feeling of euphoria that counteracts the unpleasantness inherent in activating shield boosters, and permits the pilot to force the boosters to better performance without suffering undue pain.',1,1,0,1,NULL,65536.0000,1,977,0),(10164,303,'Standard Sooth Sayer Booster','This booster induces a trancelike state whereupon the pilot is able to sense the movement of faraway items without all the usual static flooding the senses. Being in a trance helps the pilot hit those moving items with better accuracy, although he has to be careful not to start hallucinating.',1,1,0,1,NULL,65536.0000,1,977,0),(10165,303,'Improved Sooth Sayer Booster','This booster induces a trancelike state whereupon the pilot is able to sense the movement of faraway items without all the usual static flooding the senses. Being in a trance helps the pilot hit those moving items with better accuracy, although he has to be careful not to start hallucinating.',1,1,0,1,NULL,65536.0000,1,977,0),(10166,303,'Strong Sooth Sayer Booster','This booster induces a trancelike state whereupon the pilot is able to sense the movement of faraway items without all the usual static flooding the senses. Being in a trance helps the pilot hit those moving items with better accuracy, although he has to be careful not to start hallucinating.',1,1,0,1,NULL,65536.0000,1,977,0),(10167,306,'Abandoned Container','The wrecked container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(10188,302,'Basic Magnetic Field Stabilizer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,9728.0000,1,648,0),(10190,302,'Magnetic Field Stabilizer II','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,294972.0000,1,648,0),(10191,139,'Magnetic Field Stabilizer II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(10204,742,'Zainou \'Deadeye\' Sharpshooter ST-903','A Zainou gunnery hardwiring designed to enhance optimal range.\r\r\n\r\r\n3% bonus to turret optimal range.',0,1,0,1,NULL,200000.0000,1,1501,0),(10208,745,'Memory Augmentation - Standard','This image processor implanted in the temporal lobe grants a bonus to a character\'s memory.\r\r\n\r\r\n+4 Bonus to Memory',0,1,0,1,NULL,400000.0000,1,619,0),(10209,745,'Memory Augmentation - Improved','This image processor implanted in the temporal lobe grants a bonus to a character\'s memory.\r\r\n\r\r\n+5 Bonus to Memory',0,1,0,1,NULL,800000.0000,1,619,0),(10210,745,'Memory Augmentation - Advanced','This image processor implanted in the temporal lobe grants a bonus to a character\'s memory.\r\r\n\r\r\n+6 Bonus to Memory',0,1,0,1,NULL,1600000.0000,1,NULL,0),(10211,745,'Memory Augmentation - Elite','This image processor implanted in the temporal lobe grants a bonus to a character\'s memory.\r\r\n\r\r\n+7 Bonus to Memory',0,1,0,1,NULL,3200000.0000,1,NULL,0),(10212,745,'Neural Boost - Standard','A Data processing unit implanted in the Parietal lobe. Grants a bonus to Willpower.\r\r\n\r\r\n+4 Bonus to Willpower',0,1,0,1,NULL,400000.0000,1,620,0),(10213,745,'Neural Boost - Improved','A Data processing unit implanted in the Parietal lobe. Grants a bonus to Willpower.\r\r\n\r\r\n+5 Bonus to Willpower',0,1,0,1,NULL,800000.0000,1,620,0),(10214,745,'Neural Boost - Advanced','A Data processing unit implanted in the Parietal lobe. Grants a bonus to Willpower.\r\r\n\r\r\n+6 Bonus to Willpower',0,1,0,1,NULL,1600000.0000,1,NULL,0),(10215,745,'Neural Boost - Elite','A Data processing unit implanted in the Parietal lobe. Grants a bonus to Willpower.\r\r\n\r\r\n+7 Bonus to Willpower',0,1,0,1,NULL,3200000.0000,1,NULL,0),(10216,745,'Ocular Filter - Standard','This image processor implanted in the occipital lobe grants a bonus to a character\'s Perception.\r\r\n\r\r\n+4 Bonus to Perception',0,1,0,1,NULL,400000.0000,1,618,0),(10217,745,'Ocular Filter - Improved','This image processor implanted in the occipital lobe grants a bonus to a character\'s Perception.\r\r\n\r\r\n+5 Bonus to Perception',0,1,0,1,NULL,800000.0000,1,618,0),(10218,745,'Ocular Filter - Advanced','This image processor implanted in the occipital lobe grants a bonus to a character\'s Perception.\r\r\n\r\r\n+6 Bonus to Perception',0,1,0,1,NULL,800000.0000,1,NULL,0),(10219,745,'Ocular Filter - Elite','This image processor implanted in the occipital lobe grants a bonus to a character\'s Perception.\r\r\n\r\r\n+7 Bonus to Perception',0,1,0,1,NULL,3200000.0000,1,NULL,0),(10221,745,'Cybernetic Subprocessor - Standard','This grafted subprocessor implanted in the frontal lobe grants a bonus to a character\'s Intelligence.\r\r\n\r\r\n+4 Bonus to Intelligence',0,1,0,1,NULL,400000.0000,1,621,0),(10222,745,'Cybernetic Subprocessor - Improved','This grafted subprocessor implanted in the frontal lobe grants a bonus to a character\'s Intelligence.\r\r\n\r\r\n+5 Bonus to Intelligence',0,1,0,1,NULL,800000.0000,1,621,0),(10223,745,'Cybernetic Subprocessor - Advanced','This grafted subprocessor implanted in the frontal lobe grants a bonus to a character\'s Intelligence.\r\r\n\r\r\n+6 Bonus to Intelligence',0,1,0,1,NULL,1600000.0000,1,NULL,0),(10224,745,'Cybernetic Subprocessor - Elite','This grafted subprocessor implanted in the frontal lobe grants a bonus to a character\'s Intelligence.\r\r\n\r\r\n+7 Bonus to Intelligence',0,1,0,1,NULL,3200000.0000,1,NULL,0),(10225,745,'Social Adaptation Chip - Standard','This image processor implanted in the parietal lobe grants a bonus to a character\'s Charisma.\r\r\n\r\r\n+4 Bonus to Charisma',0,1,0,1,NULL,400000.0000,1,622,0),(10226,745,'Social Adaptation Chip - Improved','This image processor implanted in the parietal lobe grants a bonus to a character\'s Charisma.\r\r\n\r\r\n+5 Bonus to Charisma',0,1,0,1,NULL,800000.0000,1,622,0),(10227,745,'Social Adaptation Chip - Advanced','This image processor implanted in the parietal lobe grants a bonus to a character\'s Charisma.\r\r\n\r\r\n+6 Bonus to Charisma',0,1,0,1,NULL,1600000.0000,1,NULL,0),(10228,749,'Zainou \'Gnome\' Shield Management SM-703','Improved skill at regulating shield capacity.\r\r\n\r\r\n3% bonus to shield capacity.',0,1,0,1,NULL,200000.0000,1,1481,0),(10231,306,'Flotsam','The enclosed flotsam drifts quietly in space, waiting patiently to be pried open by a hungry looter.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(10232,227,'Debris Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10233,227,'Meteor Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10234,226,'Gallente Outpost','A standard outpost of Gallentean design.',0,0,0,1,8,0.0000,0,NULL,0),(10235,226,'Amarr Refining Outpost',' ',0,0,0,1,4,0.0000,0,NULL,0),(10236,226,'Amarr Repair Outpost',' ',0,0,0,1,4,0.0000,0,NULL,0),(10237,226,'Amarr Tactical Outpost',' ',0,0,0,1,4,0.0000,0,NULL,0),(10238,226,'Caldari Refining Outpost',' ',0,0,0,1,1,0.0000,0,NULL,0),(10239,226,'Caldari Repair Outpost',' ',0,0,0,1,1,0.0000,0,NULL,0),(10240,226,'Caldari Tactical Outpost',' ',0,0,0,1,1,0.0000,0,NULL,0),(10241,226,'Minmatar Refining Outpost','A Minmatar refinery outpost.',0,0,0,1,2,0.0000,0,NULL,0),(10242,226,'Minmatar Repair Outpost',' ',0,0,0,1,2,0.0000,0,NULL,0),(10243,226,'Minmatar Tactical Outpost',' ',0,0,0,1,2,0.0000,0,NULL,0),(10244,1228,'Zainou \'Gypsy\' Signature Analysis SA-703','A neural interface upgrade that boosts the pilot\'s skill at operating targeting systems.\r\r\n\r\r\n3% bonus to ships scan resolution.',0,1,0,1,NULL,10752.0000,1,1765,0),(10246,101,'Mining Drone I','Mining Drone',0,5,0,1,NULL,23706.0000,1,158,0),(10247,177,'Mining Drone I Blueprint',' ',0,0.01,0,1,NULL,19986000.0000,1,358,0),(10248,101,'Mining Drone - Improved',' ',0,5,0,1,NULL,14986.0000,0,NULL,0),(10250,101,'Mining Drone II','Mining Drone',0,5,0,1,NULL,172080.0000,1,158,0),(10251,177,'Mining Drone II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(10252,101,'Mining Drone - Elite','Mining Drone',0,5,0,1,NULL,14986.0000,0,NULL,0),(10256,226,'Asteroid Mining Post',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10257,307,'Gallente Administrative Outpost Platform',' ',0,750000,7500000,1,NULL,29361875000.0000,1,1864,0),(10258,307,'Minmatar Service Outpost Platform',' ',0,750000,7500000,1,NULL,24693750000.0000,1,1864,0),(10260,307,'Amarr Factory Outpost Platform',' ',0,750000,7500000,1,NULL,27208125000.0000,1,1864,0),(10261,306,'Drifting Cask','The worn container drifts quietly in space, waiting patiently to be pried open by a hungry looter.',10000,1200,1400,1,NULL,0.0000,0,NULL,0),(10262,306,'Forsaken Stockpile','The reinforced container revolves silently in space, giving little hint to what hoard it may hide.',10000,10500,10000,1,NULL,0.0000,0,NULL,0),(10263,306,'Cache Container','The bolted container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,2750,2700,1,NULL,0.0000,0,NULL,0),(10264,257,'Concord','Skill at operating Concord.  ',0,0.01,0,1,NULL,300000000.0000,0,NULL,0),(10265,561,'Guristas Ascriber','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',9600000,96000,450,1,1,0.0000,0,NULL,0),(10266,562,'Guristas Wrecker','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(10267,226,'Coral Rock Formation','This mysterious rock formation seems to have once been a part of a larger asteroid made of several mineral types. After eons of drifting through space, the soft rock has crumbled away, leaving a skeleton of crystalized compounds.',0,0,0,1,NULL,0.0000,0,NULL,0),(10269,226,'Floating Stonehenge','An archaic reminder of the days of olde.',0,0,0,1,NULL,0.0000,0,NULL,0),(10270,226,'Low-Tech Solar Harvester','An archaic reminder of the days of olde.',0,0,0,1,NULL,0.0000,0,NULL,0),(10273,567,'Sansha\'s Minion','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2000000,20000,235,1,4,0.0000,0,NULL,0),(10274,566,'Sansha\'s Ravisher','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',10010000,100100,235,1,4,0.0000,0,NULL,0),(10275,557,'Blood Follower','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2810000,28100,120,1,4,0.0000,0,NULL,0),(10276,557,'Blood Herald','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2810000,28100,235,1,4,0.0000,0,NULL,0),(10277,557,'Blood Upholder','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2810000,28100,135,1,4,0.0000,0,NULL,0),(10278,557,'Blood Seeker','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2810000,28100,165,1,4,0.0000,0,NULL,0),(10279,557,'Blood Collector','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2810000,28100,315,1,4,0.0000,0,NULL,0),(10280,557,'Blood Reaver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2870000,28700,135,1,4,0.0000,0,NULL,0),(10281,555,'Blood Arch Reaver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',11500000,115000,465,1,4,0.0000,0,NULL,0),(10282,555,'Blood Arch Engraver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',12000000,120000,450,1,4,0.0000,0,NULL,0),(10283,572,'Serpentis Scout','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2250000,22500,125,1,8,0.0000,0,NULL,0),(10284,572,'Serpentis Watchman','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2950000,29500,175,1,8,0.0000,0,NULL,0),(10285,572,'Serpentis Guard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,60,1,8,0.0000,0,NULL,0),(10286,572,'Serpentis Defender','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,140,1,8,0.0000,0,NULL,0),(10287,571,'Serpentis Chief Patroller','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(10299,802,'Alvus Controller','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(10305,226,'Ghost Ship','The mangled wreck floats motionless in space, surrounded by a field of scorched debris, leaving no hint to its form of demise.',0,0,0,1,NULL,0.0000,0,NULL,0),(10629,507,'Rocket Launcher I','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.1875,1,NULL,3336.0000,1,639,0),(10630,136,'Rocket Launcher I Blueprint',' ',0,0.01,0,1,NULL,30000.0000,1,340,0),(10631,507,'Rocket Launcher II','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.25,1,NULL,54774.0000,1,639,0),(10632,136,'Rocket Launcher II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(10642,308,'Countermeasure Launcher I','A launcher for various missile countermeasures.',0,6,10,1,NULL,9792.0000,0,NULL,0),(10643,136,'Countermeasure Launcher I Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(10645,310,'Celestial Beacon','Fitted with a power flash-battery, this beacon sends out signals throughout the entire solar system.',1,1,0,1,NULL,0.0000,0,NULL,0),(10646,314,'Training Certificate','Turn this in at your starting school station to get a small reward.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(10648,336,'Sentinel Sentry Gun I','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,4,0.0000,0,NULL,0),(10649,287,'Training Drone','This weak but hostile training drone allows rookie-pilots to experience combat without too much risk. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(10650,288,'Ammatar Navy Captain','This is a security vessel of the Ammatar Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',2870000,28700,315,1,4,0.0000,0,NULL,0),(10651,288,'Caldari Navy Captain 3rd Rank','This is a security vessel of the Caldari Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',1800000,18000,150,1,1,0.0000,0,NULL,0),(10652,288,'Federation Navy First Sergeant','This is a security vessel of the Gallente Federation Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',2250000,22500,125,1,8,0.0000,0,NULL,0),(10653,288,'Intaki Defense First Sergeant','This is a security vessel of the Intaki Space Police. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',2450000,24500,120,1,8,0.0000,0,NULL,0),(10654,288,'Mordu\'s Lieutenant 1st Rank','This is a security vessel of the Mordu\'s Legion. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',1970000,19700,305,1,1,0.0000,0,NULL,0),(10655,288,'Mordu\'s Legion','This is a security vessel of the Mordu\'s Legion. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',10100000,101000,250,1,1,0.0000,0,NULL,0),(10656,288,'Sarum Navy Sergeant Major','This is a security vessel of the Sarum Family. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: High',2810000,28100,165,1,4,0.0000,0,NULL,0),(10657,288,'Thukker Tribalist','This is a security vessel of the Thukker Mix. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',1980000,27289,130,1,2,0.0000,0,NULL,0),(10658,288,'Thukker Tribal Priest','This is a security vessel of the Thukker Mix. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',8900000,89000,440,1,2,0.0000,0,NULL,0),(10660,182,'Caldari Police 2nd Lieutenant','This is a security vessel of the Caldari Police Force. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',10700000,107000,485,1,1,0.0000,0,NULL,0),(10663,288,'Republic Fleet Private 1st Rank','This is a security vessel of the Minmatar Republic Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: High',2000000,20000,175,1,2,0.0000,0,NULL,0),(10664,288,'Republic Fleet Private 2nd Rank','This is a security vessel of the Minmatar Republic Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Significant',1740000,17400,150,1,2,0.0000,0,NULL,0),(10665,336,'Sentinel Sentry Gun II','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,4,0.0000,0,NULL,0),(10666,336,'Sentinel Sentry Gun III','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,4,0.0000,0,NULL,0),(10667,336,'Sentinel Sentry Gun IV','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,4,0.0000,0,NULL,0),(10668,336,'Sentinel Sentry Gun V','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,4,0.0000,0,NULL,0),(10669,288,'Ammatar Navy Colonel','This is a security vessel of the Ammatar Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',12000000,120000,345,1,4,0.0000,0,NULL,0),(10670,288,'Khanid Navy Captain','This is a security vessel of the Royal Khanid Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',2870000,28700,315,1,4,0.0000,0,NULL,0),(10674,182,'Khanid Surveillance Sergeant Major','This is a security vessel of the Royal Khanid Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11800000,118000,450,1,4,0.0000,0,NULL,0),(10676,288,'Sarum Navy Colonel','This is a security vessel of the Sarum Family. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',12000000,120000,345,1,4,0.0000,0,NULL,0),(10677,288,'Intaki Defense Fleet Major','This is a security vessel of the Intaki Space Police. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',11600000,116000,320,1,8,0.0000,0,NULL,0),(10678,74,'125mm Railgun I','The 125mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,NULL,9958.0000,1,564,0),(10679,154,'125mm Railgun I Blueprint',' ',0,0.01,0,1,NULL,90000.0000,1,291,0),(10680,74,'125mm Railgun II','The 125mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Javelin, Spike.',500,5,0.2,1,NULL,223498.0000,1,564,0),(10681,154,'125mm Railgun II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(10688,74,'125mm \'Scout\' Accelerator Cannon','The 125mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,2,4484.0000,1,564,0),(10690,74,'125mm Carbide Railgun I','The 125mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,4,4484.0000,1,564,0),(10692,74,'125mm Compressed Coil Gun I','The 125mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,8,4484.0000,1,564,0),(10694,74,'125mm Prototype Gauss Gun','The 125mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,1,4484.0000,1,564,0),(10753,227,'Soft Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10754,227,'Wispy Orange Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10755,227,'Sulphuric Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10756,227,'Dust Streak',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10757,227,'Plasmic Gas Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10758,227,'Wispy Chlorine Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10759,227,'Micro Nebula',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10760,227,'Acidic Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10761,227,'Nebulaic Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10762,227,'Chlorine Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10763,227,'Gaseous Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10764,227,'Amber Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10765,227,'Green Gas Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10766,336,'Guardian Sentry Gun I','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,1,0.0000,0,NULL,0),(10767,336,'Guardian Sentry Gun II','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,1,0.0000,0,NULL,0),(10768,336,'Guardian Sentry Gun III','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,1,0.0000,0,NULL,0),(10769,336,'Guardian Sentry Gun IV','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,1,0.0000,0,NULL,0),(10770,336,'Guardian Sentry Gun V','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,1,0.0000,0,NULL,0),(10771,226,'Asteroid Colony - Factory','Massive construction girders stretch between the crumbled asteroids, giving a solid ground for a station or outpost.',0,0,0,1,NULL,0.0000,0,NULL,0),(10772,226,'Asteroid Colony - Refinery','Massive construction girders stretch between the crumbled asteroids, giving a solid ground for a station or outpost.',0,0,0,1,NULL,0.0000,0,NULL,0),(10773,226,'Asteroid Colony - Wedge Shape','Massive construction girders stretch between the crumbled asteroids, giving a solid ground for a station or outpost.',0,0,0,1,NULL,0.0000,0,NULL,0),(10774,226,'Asteroid Colony - High & Massive','Massive construction girders stretch between the crumbled asteroids, giving a solid ground for a station or outpost.',0,0,0,1,NULL,0.0000,0,NULL,0),(10775,226,'Asteroid Colony - Medium Size','Massive construction girders stretch between the crumbled asteroids, giving a solid ground for a station or outpost.',0,0,0,1,NULL,0.0000,0,NULL,0),(10778,226,'Asteroid Colony - High & Medium Size','Massive construction girders stretch between the crumbled asteroids, giving a solid ground for a station or outpost.',0,0,0,1,NULL,0.0000,0,NULL,0),(10779,226,'Asteroid Colony - Small Tower','Massive construction girders stretch between the crumbled asteroids, giving a solid ground for a station or outpost.',0,0,0,1,NULL,0.0000,0,NULL,0),(10780,226,'Asteroid Colony - Small & Flat','Massive construction girders stretch between the crumbled asteroids, giving a solid ground for a station or outpost.',0,0,0,1,NULL,0.0000,0,NULL,0),(10781,226,'Asteroid Colony - Flat Hulk','Massive construction girders stretch between the crumbled asteroids, giving a solid ground for a station or outpost.',0,0,0,1,NULL,0.0000,0,NULL,0),(10782,226,'Giant Snake-Shaped Asteroid','Fragments from an asteroid collision or a supernova, this rock formation decorates the starscape as a planetary mountain range.',0,0,0,1,NULL,0.0000,0,NULL,0),(10783,226,'Small Rock','Fragments from an asteroid collision or a supernova, this rock formation decorates the starscape as a planetary mountain range.',0,0,0,1,NULL,0.0000,0,NULL,0),(10784,226,'Small and Sharded Rock','Fragments from an asteroid collision or a supernova, this rock formation decorates the starscape as a planetary mountain range.',0,0,0,1,NULL,0.0000,0,NULL,0),(10785,226,'Sharded Rock','Fragments from an asteroid collision or a supernova, this rock formation decorates the starscape as a planetary mountain range.',0,0,0,1,NULL,0.0000,0,NULL,0),(10786,226,'Tiny Rock','Fragments from an asteroid collision or a supernova, this rock formation decorates the starscape as a planetary mountain range.',0,0,0,1,NULL,0.0000,0,NULL,0),(10787,226,'Snake Shaped Asteroid','Fragments from an asteroid collision or a supernova, this rock formation decorates the starscape as a planetary mountain range.',0,0,0,1,NULL,0.0000,0,NULL,0),(10788,226,'Gas/Storage Silo','This enormous metal silo bears many marks of meteor-hits, suggesting it\'s lingered here for a long time.',0,0,0,1,NULL,0.0000,0,NULL,0),(10795,15,'Jovian Construct',' ',0,0,0,1,16,0.0000,0,NULL,0),(10809,312,'Thick White',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10810,312,'Bllue faint',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10811,312,'Blue quarter',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10812,312,'White sharp hemisphere',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10813,312,'Brown hemisphere',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10814,312,'Faint hemisphere',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10815,312,'White Crescent',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10816,312,'Brown crescent',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10817,312,'Brown quarter',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10818,312,'Quarter shard',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10819,312,'Bitter edge',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10820,312,'Thin claw',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10821,312,'White solid',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10822,312,'White solid 2',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(10823,297,'Retailer','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(10824,297,'Chafferer','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(10825,297,'Trailer','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',102000000,1020000,3000,1,1,0.0000,0,NULL,0),(10826,297,'Hauler','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',102000000,1020000,3000,1,1,0.0000,0,NULL,0),(10827,297,'Trader','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3000,1,4,0.0000,0,NULL,0),(10828,297,'Courier','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(10829,297,'Purveyor','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(10830,297,'Carrier','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(10831,297,'Hawker','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',89000000,890000,3400,1,2,0.0000,0,NULL,0),(10832,297,'Huckster','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3800,1,2,0.0000,0,NULL,0),(10833,297,'Patronager','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3800,1,2,0.0000,0,NULL,0),(10834,297,'Chandler','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',105000000,1050000,3000,1,8,0.0000,0,NULL,0),(10836,40,'Medium Shield Booster I','Expends energy to provide a quick boost in shield strength.',0,10,0,1,NULL,40472.0000,1,610,0),(10837,120,'Medium Shield Booster I Blueprint',' ',0,0.01,0,1,NULL,364640.0000,1,1552,0),(10838,40,'Large Shield Booster I','Expends energy to provide a quick boost in shield strength.',0,25,0,1,NULL,161888.0000,1,611,0),(10839,120,'Large Shield Booster I Blueprint',' ',0,0.01,0,1,NULL,1458560.0000,1,1552,0),(10840,40,'X-Large Shield Booster I','Expends energy to provide a quick boost in shield strength.',0,50,0,1,NULL,883072.0000,1,612,0),(10841,120,'X-Large Shield Booster I Blueprint',' ',0,0.01,0,1,NULL,5854720.0000,1,1552,0),(10842,40,'X-Large Shield Booster II','Expends energy to provide a quick boost in shield strength.',0,50,0,1,NULL,1359284.0000,1,612,0),(10843,120,'X-Large Shield Booster II Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,NULL,0),(10850,40,'Medium Shield Booster II','Expends energy to provide a quick boost in shield strength.',0,10,0,1,NULL,176726.0000,1,610,0),(10851,120,'Medium Shield Booster II Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,NULL,0),(10858,40,'Large Shield Booster II','Expends energy to provide a quick boost in shield strength.',0,10,0,1,NULL,446196.0000,1,611,0),(10859,120,'Large Shield Booster II Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,NULL,0),(10866,40,'Medium Neutron Saturation Injector I','Expends energy to provide a quick boost in shield strength.',0,10,0,1,2,18216.0000,1,610,0),(10868,40,'Medium Clarity Ward Booster I','Expends energy to provide a quick boost in shield strength.',0,10,0,1,4,18216.0000,1,610,0),(10870,40,'Medium Converse Deflection Catalyzer','Expends energy to provide a quick boost in shield strength.',0,10,0,1,8,18216.0000,1,610,0),(10872,40,'Medium C5-L Emergency Shield Overload I','Expends energy to provide a quick boost in shield strength.',0,10,0,1,1,18216.0000,1,610,0),(10874,40,'Large Neutron Saturation Injector I','Expends energy to provide a quick boost in shield strength.',0,25,0,1,2,72864.0000,1,611,0),(10876,40,'Large Clarity Ward Booster I','Expends energy to provide a quick boost in shield strength.',0,25,0,1,4,72864.0000,1,611,0),(10878,40,'Large Converse Deflection Catalyzer','Expends energy to provide a quick boost in shield strength.',0,25,0,1,8,72864.0000,1,611,0),(10880,40,'Large C5-L Emergency Shield Overload I','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(10882,40,'X-Large Neutron Saturation Injector I','Expends energy to provide a quick boost in shield strength.',0,50,0,1,2,291456.0000,1,612,0),(10884,40,'X-Large Clarity Ward Booster I','Expends energy to provide a quick boost in shield strength.',0,50,0,1,4,291456.0000,1,612,0),(10886,40,'X-Large Converse Deflection Catalyzer','Expends energy to provide a quick boost in shield strength.',0,50,0,1,8,291456.0000,1,612,0),(10888,40,'X-Large C5-L Emergency Shield Overload I','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(10986,806,'Moth Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(10987,806,'Dragonfly Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(10988,806,'Termite Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(10989,806,'Scorpionfly Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(10990,806,'Arachula Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(10991,806,'Tarantula Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(10992,806,'Beelzebub Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(10993,806,'Mammon Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(10994,806,'Asmodeus Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(10995,806,'Belphegor Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(10998,315,'Warp Core Stabilizer I','When installed this unit attempts to compensate for fluctuations and disruptions of the ship\'s warp core.',0,5,0,1,NULL,11116.0000,1,1088,0),(10999,298,'Convoy Escort','Entity: The Condor is fast and agile. It has limited cargo space so it\'s not very suitable for trading or mining. It is best used as an assault vessel in a hit-and-run type of operations. Special Ability: 5% bonus to shield capacity and hybrid turret range per skill level.',1800000,18000,150,1,1,0.0000,0,NULL,0),(11000,298,'Convoy Protector','Entity: The Griffin is much used by the Caldari Navy as a support vessel in combat squadrons, using its impressive array of electronic gadgetry to disrupt the operation of target ships, making them easy prey for traditional combat vessels. Special Ability: 5% bonus to hybrid turret range and CPU output per skill level.',1940000,19400,160,1,1,0.0000,0,NULL,0),(11001,298,'Convoy Guard','Entity: The Kestrel is a heavy missile boat with a fairly large cargo space and one of the most sophisticated sensor arrays around. Interestingly enough, it has been used by both the Caldari Navy and several wealthy trade corporations as a cargo-hauling vessel. It is one of few trading vessels with good punching power, making it ideal for solo trade-runs in dangerous areas. Special Ability: 10% bonus to targeting range per skill level.',1970000,19700,305,1,1,0.0000,0,NULL,0),(11002,298,'Convoy Sentry','Entity: The Merlin is the most powerful all-out combat frigate of the Caldari. It is highly valued for its versatility in using both missiles and turrets, while its defenses are exceptionally strong for a Caldari vessel. Special Ability: 5% bonus to hybrid turret damage and hybrid turret range per skill level.',1650000,16500,130,1,1,0.0000,0,NULL,0),(11011,26,'Guardian-Vexor','The Vexor is a strong combat ship that is also geared to operate in a variety of other roles. The Vexor is especially useful for surveying in potentially hostile sectors as it can stay on duty for a very long time before having to return to base. Furthermore, it is well capable of defending itself against even concentrated attacks.\r\r\n',10910000,115000,480,1,8,5942126.0000,1,1699,0),(11012,106,'Guardian-Vexor Blueprint',' ',0,0.01,0,1,NULL,43775000.0000,1,NULL,0),(11013,314,'Drug Contact List','Contact list of people involved in drug manufacturing and distribution.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11014,316,'Command Processor I','This sophisticated battle AI allows a commander to more efficiently oversee the complex data streams of a fleet warfare link, thus allowing him to utilize multiple such systems.\r\r\n\r\r\nAllows operation of one extra Warfare Link.',0,5,0,1,NULL,246320.0000,1,1639,0),(11015,274,'Test','This is a test skill and should never appear in the live game',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11017,316,'Skirmish Warfare Link - Interdiction Maneuvers I','Boosts the range of the fleet\'s propulsion jamming modules, except for Warp Disruption Field Generators.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,225005.0000,1,1637,0),(11019,25,'Cockroach','The specially adapted rogue drone scanning technology integrated into this unique frigate-sized platform is reserved for the exclusive use of the elite Equipment Certification and Anomaly Investigations Division (ECAID) agents. The femtometer wavelength scan resolution allows the pilot to virtually dissect and analyze any object at a subatomic scale, divining all flaws and defects with an uncanny level of quality.\r\r\n\r\r\nFlying one of these amazing ships is also a great mark of achievement. Any ECAID agent worthy of such a command can be said to have reached the pinnacle of his career and is worthy of all capsuleer\'s deep respect.',1170000,100,999999999,1,8,220000.0000,0,NULL,0),(11021,550,'Angel Thug','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2600500,26005,120,1,2,0.0000,0,NULL,0),(11022,550,'Angel Ruffian','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',1766000,17660,120,1,2,0.0000,0,NULL,0),(11023,550,'Angel Ambusher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1910000,19100,120,1,2,0.0000,0,NULL,0),(11024,550,'Angel Impaler','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(11025,551,'Angel Predator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',9900000,99000,120,1,2,0.0000,0,NULL,0),(11026,551,'Angel Crusher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(11027,562,'Guristas Infiltrator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2025000,20250,235,1,1,0.0000,0,NULL,0),(11028,562,'Guristas Saboteur','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2040000,20400,235,1,1,0.0000,0,NULL,0),(11029,562,'Guristas Destructor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(11030,562,'Guristas Demolisher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(11031,561,'Guristas Murderer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(11032,567,'Sansha\'s Ravener','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2000000,20000,235,1,4,0.0000,0,NULL,0),(11033,567,'Sansha\'s Enslaver','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2112000,21120,235,1,4,0.0000,0,NULL,0),(11034,567,'Sansha\'s Slavehunter','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2112000,21120,235,1,4,0.0000,0,NULL,0),(11035,567,'Sansha\'s Butcher','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(11036,561,'Guristas Killer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',9200000,92000,235,1,1,0.0000,0,NULL,0),(11037,566,'Sansha\'s Beast','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11038,566,'Sansha\'s Juggernaut','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11039,557,'Blood Worshipper','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2820000,24398,235,1,4,0.0000,0,NULL,0),(11040,557,'Blood Raider','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2870000,28700,235,1,4,0.0000,0,NULL,0),(11041,557,'Blood Diviner','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2860000,28600,235,1,4,0.0000,0,NULL,0),(11042,557,'Blood Engraver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(11043,555,'Blood Arch Templar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(11044,555,'Blood Revenant','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(11045,572,'Serpentis Agent','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2250000,22500,235,1,8,0.0000,0,NULL,0),(11046,572,'Serpentis Patroller','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2950000,29500,235,1,8,0.0000,0,NULL,0),(11047,572,'Serpentis Safeguard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,235,1,8,0.0000,0,NULL,0),(11048,572,'Serpentis Protector','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(11049,571,'Serpentis Chief Scout','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',11300000,113000,235,1,8,0.0000,0,NULL,0),(11050,571,'Serpentis Chief Watchman','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11500000,115000,235,1,8,0.0000,0,NULL,0),(11052,316,'Information Warfare Link - Sensor Integrity I','Boosts sensor strengths and lock ranges for all of the fleet\'s ships.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,196333.0000,1,1635,0),(11066,314,'Trinary Data','This complicated stream of data seems to be in trinary language. It appears to be of Jovian origin.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11067,314,'Nugoeihuvi Data Chip','A data chip containing the ship logs of a Nugoeihuvi secret agent.',1,0.1,0,1,NULL,100.0000,1,NULL,0),(11068,314,'Special Delivery','This box may contain personal items or commodities intended only for the delivery\'s recipient.',1,0.1,0,1,NULL,100.0000,1,NULL,0),(11069,314,'Criminal Dog Tag','Identification tags such as these may prove valuable if handed to the proper organization.',1,0.1,0,1,NULL,0.0000,1,492,0),(11070,314,'Religious Artifact','This religious artifact is highly decorated. It looks old, and it feels heavier than such a small thing should.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11071,314,'Battery Cartridge','This battery cartridge carries a heavy charge of electric power, intended as a spare pool of energy in distress.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11072,306,'Data Storage','This reinforced container is outfitted with a capturing mechanism to pick up data from nearby sensor arrays.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(11074,724,'Talisman Alpha Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(11075,257,'Jove Industrial','Skill at operating Jovian industrial ships.',0,0.01,0,1,16,300000.0000,0,NULL,0),(11076,319,'Serpentis Stronghold','This gigantic station is one of the Serpentis military installations and a black jewel of the alliance between The Guardian Angels and The Serpentis Corporation. Even for its size, it has no commercial station services or docking bays to receive guests.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(11077,319,'Angel Battlestation','This gigantic suprastructure is one of the military installations of the Angel Cartel. Even for its size, it has no commercial station services or docking bay to receive guests.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(11078,257,'Jove Battleship','Skill at operating jove battleships.',0,0.01,0,1,16,4000000.0000,0,NULL,0),(11079,319,'Guristas War Installation','This gigantic suprastructure is one of the military installations of the Guristas pirate corporation. Even for its size it has no commercial station services or docking bays to receive guests.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(11080,319,'Sansha\'s Battletower','This gigantic war station is one of the military installations of Sansha\'s slumbering nation.  It is known to be able to hold a massive number of Sansha vessels, but strange whispers hint at darker things than mere warfare going on underneath its jagged exterior.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(11081,319,'Blood Raider Battlestation','This gigantic suprastructure is one of the military installations of the Blood Raiders pirate corporation. Even for its size, it has no commercial station services or docking bay to receive guests.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(11082,255,'Small Railgun Specialization','Specialist training in the operation of advanced small railguns. 2% bonus per skill level to the damage of small turrets requiring Small Railgun Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,1000000.0000,1,364,0),(11083,255,'Small Beam Laser Specialization','Specialist training in the operation of small Beam Lasers. 2% bonus per skill level to the damage of small turrets requiring Small Beam Laser Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,1000000.0000,1,364,0),(11084,255,'Small Autocannon Specialization','Specialist training in the operation of advanced small Autocannons. 2% bonus per skill level to the damage of small turrets requiring Small Autocannon Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,1000000.0000,1,364,0),(11101,302,'Linear Flux Stabilizer I','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,24994.0000,1,648,0),(11103,302,'Insulated Stabilizer Array I','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,24994.0000,1,648,0),(11105,302,'Magnetic Vortex Stabilizer I','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,24994.0000,1,648,0),(11107,302,'Gauss Field Balancer I','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,24994.0000,1,648,0),(11109,302,'Linear Flux Stabilizer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,2,9728.0000,1,648,0),(11111,302,'Insulated Stabilizer Array','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,4,9728.0000,1,648,0),(11113,302,'Magnetic Vortex Stabilizer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,8,9728.0000,1,648,0),(11115,302,'Gauss Field Balancer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,1,9728.0000,1,648,0),(11125,301,'CONCORD Police Commander','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',20000000,1080000,14000,1,NULL,0.0000,0,NULL,0),(11126,182,'CONCORD SWAT Commander','The Concord battleships were built by a joint effort of the empires, each empire investing it with their own special technologies. Although this makes them a bit mismatched, their performance leaves no doubt about their awesome power.',2000000,1080000,14000,1,NULL,0.0000,0,NULL,0),(11127,288,'DED Army Commander','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',2000000,1080000,14000,1,NULL,0.0000,0,NULL,0),(11128,301,'DED Special Operation Commander','This is a security vessel of CONCORD. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises.',20000000,1080000,14000,1,NULL,0.0000,0,NULL,0),(11129,31,'Gallente Shuttle','Gallente Shuttle',1600000,5000,10,1,8,5556.0000,1,395,0),(11130,111,'Gallente Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,417,0),(11132,31,'Minmatar Shuttle','Minmatar Shuttle',1600000,5000,10,1,2,5556.0000,1,394,0),(11133,111,'Minmatar Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,418,0),(11134,31,'Amarr Shuttle','Amarr Shuttle',1600000,5000,10,1,4,5556.0000,1,393,0),(11135,111,'Amarr Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,415,0),(11136,323,'Concord Billboard','Concord Billboards keep you updated, bringing you the latest news and bounty information.',100,1,1000,1,NULL,0.0000,0,NULL,0),(11137,288,'Imperial Navy Fleet Marshall','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Significant',20000000,1100000,600,1,4,0.0000,0,NULL,0),(11138,288,'Caldari Navy Fleet Admiral','This is a security vessel of the Caldari Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',21000000,1080000,665,1,1,0.0000,0,NULL,0),(11139,288,'Federation Navy Fleet General','This is a security vessel of the Gallente Federation Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Moderate',21000000,1140000,675,1,8,0.0000,0,NULL,0),(11140,288,'Republic Fleet High Commander','This is a security vessel of the Minmatar Republic Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Significant',17000000,850000,600,1,2,0.0000,0,NULL,0),(11167,319,'Fragmented Cathedral I','The elegant decorations on these broken ruins indicate that it may once have been a ceremonial temple of high importance.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(11168,319,'Fragmented Cathedral II','The elegant decorations on these broken ruins indicate that it may once have been a ceremonial temple of high importance.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(11169,319,'Fragmented Cathedral III','The elegant decorations on these broken ruins indicate that it may once have been a ceremonial temple of high importance.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(11170,319,'Fragmented Cathedral IV','The elegant decorations on these broken ruins indicate that it may once have been a ceremonial temple of high importance.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(11171,319,'Fragmented Cathedral V','The elegant decorations on these broken ruins indicate that it may once have been a ceremonial temple of high importance.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(11172,830,'Helios','Designed for commando and espionage operation, its main strength is the ability to travel unseen through enemy territory and to avoid unfavorable encounters.\r\r\n\r\r\nDeveloper: CreoDron \r\r\n\r\r\nThe Helios is CreoDron\'s answer to the Ishukone Buzzard. After the fall of Crielere, the once-cordial relations between the Gallente Federation and the Caldari state deteriorated rapidly and, for a while, it seemed as if war might be brewing. It was seen by certain high-ranking officers within the Gallente navy as being of vital importance to be able to match the Caldari\'s cloaking technology in an effort to maintain the balance of power.\r\r\n',1271000,23000,175,1,8,4517098.0000,1,423,0),(11173,105,'Helios Blueprint',' ',0,0.01,0,1,NULL,1800000.0000,1,428,0),(11174,893,'Keres','Electronic attack ships are mobile, resilient electronic warfare platforms. Although well suited to a variety of situations, they really come into their own in skirmish and fleet encounters, particularly against larger ships. For anyone wanting to decentralize their fleet\'s electronic countermeasure capabilities and make them immeasurably harder to counter, few things will serve better than a squadron or two of these little vessels.\r\r\n\r\r\nDeveloper: Duvolle Labs \r\r\n\r\r\nDuvolle Labs manufactures sturdy ships with a good mix of offensive and defensive capabilities. Since the company is one of New Eden\'s foremost manufacturers of particle blasters, its ships tend to favor turrets and thus have somewhat higher power output than normal.',1204500,23000,175,1,8,4425454.0000,1,1068,0),(11175,105,'Keres Blueprint',' ',0,0.01,0,1,NULL,1800000.0000,1,NULL,0),(11176,831,'Crow','Interceptors utilize a combination of advanced alloys and electronics to reduce their effective signature radius.  This, along with superior maneuverability and speed, makes them very hard to target and track, particularly for high caliber turrets. \r\r\n\r\r\nDeveloper: Kaalakiota\r\r\n\r\r\nAs befits one of the largest weapons manufacturers in the known world, Kaalakiota\'s ships are very combat focused. Favoring the traditional Caldari combat strategy, they are designed around a substantial number of weapons systems, especially missile launchers. However, they have rather weak armor and structure, relying more on shields for protection.\r\r\n \r\r\n',1065000,18000,98,1,1,3810244.0000,1,401,0),(11177,105,'Crow Blueprint',' ',0,0.01,0,1,NULL,287500.0000,1,411,0),(11178,831,'Raptor','Interceptors utilize a combination of advanced alloys and electronics to reduce their effective signature radius.  This, along with superior maneuverability and speed, makes them very hard to target and track, particularly for high caliber turrets. \r\r\n\r\r\nDeveloper: Lai Dai\r\r\n\r\r\nLai Dai ships favor a balanced mix of ship systems, making them very versatile but also less powerful when it comes to specific tactics.\r\r\n\r\r\n',1050000,18000,92,1,1,3810244.0000,1,401,0),(11179,105,'Raptor Blueprint',' ',0,0.01,0,1,NULL,287500.0000,1,411,0),(11182,830,'Cheetah','Designed for commando and espionage operation, its main strength is the ability to travel unseen through enemy territory and to avoid unfavorable encounters.\r\r\n\r\r\nDeveloper: Thukker Mix\r\r\n\r\r\nIt is unclear how Thukker Mix could master the intricacies of cloaking technology so quickly after the fall of Crielere. According to Professor Oggand Viftuin, head of R&D, the tribe managed to recruit some senior Caldari scientist that used to work on the Mirage Project at Crielere. Ishukone has denied this, claiming that the Thukkers aquired the technology from prototypes stolen by the Guristas.',1430000,17400,200,1,2,4508172.0000,1,424,0),(11183,105,'Cheetah Blueprint',' ',0,0.01,0,1,NULL,1725000.0000,1,429,0),(11184,831,'Crusader','Interceptors utilize a combination of advanced alloys and electronics to reduce their effective signature radius.  This, along with superior maneuverability and speed, makes them very hard to target and track, particularly for high caliber turrets. \r\r\n\r\r\nDeveloper: Carthum Conglomerate\r\r\n\r\r\nCarthum ships are the very embodiment of the Amarrian warfare philosophy. Possessing sturdy armor and advanced weapon systems, they provide a nice mix of offense and defense. On the other hand, their electronic and shield systems tend to be rather limited.    \r\r\n\r\r\n',1050000,28100,90,1,4,3821088.0000,1,400,0),(11185,105,'Crusader Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,410,0),(11186,831,'Malediction','Interceptors utilize a combination of advanced alloys and electronics to reduce their effective signature radius.  This, along with superior maneuverability and speed, makes them very hard to target and track, particularly for high caliber turrets.\r\r\n\r\r\nDeveloper: Khanid Innovations \r\r\n\r\r\nIn addition to robust electronics systems, the Khanid Kingdom\'s ships possess advanced armor alloys capable of withstanding a great deal of punishment. Generally eschewing the use of turrets, they tend to gear their vessels more towards close-range missile combat.\r\r\n\r\r\n',1140000,28100,98,1,4,3821088.0000,1,400,0),(11187,105,'Malediction Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,410,0),(11188,830,'Anathema','Designed for commando and espionage operation, its main strength is the ability to travel unseen through enemy territory and to avoid unfavorable encounters.\r\r\n\r\r\nDeveloper: Khanid Innovation\r\r\n\r\r\nKhanid Innovations was quick to take advantage of the disintegration of the Crielere Project. Through shrewd diplomatic and financial maneuvering they were able to acquire a working Buzzard prototype as well as several of the former top scientists of Project Mirage to work on adapting its innovations to Khanid ship technology.',1147000,28100,190,1,4,4455246.0000,1,421,0),(11189,105,'Anathema Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,425,0),(11190,893,'Sentinel','Electronic attack ships are mobile, resilient electronic warfare platforms. Although well suited to a variety of situations, they really come into their own in skirmish and fleet encounters, particularly against larger ships. For anyone wanting to decentralize their fleet\'s electronic countermeasure capabilities and make them immeasurably harder to counter, few things will serve better than a squadron or two of these little vessels.\r\r\n\r\r\nDeveloper: Viziam\r\r\n\r\r\nViziam ships are quite possibly the most durable ships money can buy. Their armor is second to none and that, combined with superior shields, makes them hard nuts to crack. Of course this does mean they are rather slow and possess somewhat more limited weapons and electronics options.',1223200,28100,165,1,4,4588728.0000,1,1066,0),(11191,105,'Sentinel Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,NULL,0),(11192,830,'Buzzard','Designed for commando and espionage operation, its main strength is the ability to travel unseen through enemy territory and to avoid unfavorable encounters.\r\r\n\r\r\nDeveloper: Ishukone \r\r\n\r\r\nThe Buzzard was developed according to the exacting specifications of Admiral Okaseilen Fukashi, head of the Caldari Navy Recon Division, and was the first production level ship specifically built to take full advantage of the cloaking breakthroughs achieved by Project Mirage at Crielere.',1270000,19400,190,1,1,4525366.0000,1,422,0),(11193,105,'Buzzard Blueprint',' ',0,0.01,0,1,NULL,1600000.0000,1,427,0),(11194,893,'Kitsune','Electronic attack ships are mobile, resilient electronic warfare platforms. Although well suited to a variety of situations, they really come into their own in skirmish and fleet encounters, particularly against larger ships. For anyone wanting to decentralize their fleet\'s electronic countermeasure capabilities and make them immeasurably harder to counter, few things will serve better than a squadron or two of these little vessels.\r\r\n\r\r\nDeveloper: Lai Dai\r\r\n\r\r\nLai Dai have always favored a balanced approach to their mix of on-board systems, leading to a line-up of versatile ships but providing very little in terms of tactical specialization.',1228700,19400,160,1,1,4533720.0000,1,1067,0),(11195,105,'Kitsune Blueprint',' ',0,0.01,0,1,NULL,1600000.0000,1,NULL,0),(11196,831,'Claw','Interceptors utilize a combination of advanced alloys and electronics to reduce their effective signature radius.  This, along with superior maneuverability and speed, makes them very hard to target and track, particularly for high caliber turrets. \r\r\n\r\r\nDeveloper: Boundless Creation\r\r\n\r\r\nThe Boundless Creation ships are based on the Brutor tribe\'s philosophy of warfare: simply fit as much firepower onto your ship as humanly possible. On the other hand, defense systems and \"cheap tricks\" like electronic warfare have never been a high priority.\r\r\n\r\r\n',1100000,17400,94,1,2,3836370.0000,1,403,0),(11197,105,'Claw Blueprint',' ',0,0.01,0,1,NULL,275000.0000,1,413,0),(11198,831,'Stiletto','Interceptors utilize a combination of advanced alloys and electronics to reduce their effective signature radius.  This, along with superior maneuverability and speed, makes them very hard to target and track, particularly for high caliber turrets. \r\r\n\r\r\nDeveloper: Core Complexion Inc.\r\r\n\r\r\nCore Complexion\'s ships are unusual in that they favor electronics and defense over the \"Lots of guns\" approach traditionally favored by the Minmatar.   \r\r\n\r\r\n',1010000,17400,92,1,2,3836370.0000,1,403,0),(11199,105,'Stiletto Blueprint',' ',0,0.01,0,1,NULL,275000.0000,1,413,0),(11200,831,'Taranis','Interceptors utilize a combination of advanced alloys and electronics to reduce their effective signature radius. This, along with superior maneuverability and speed, makes them very hard to target and track, particularly for high caliber turrets.\r\r\n\r\r\nDeveloper: Duvolle Labs\r\r\n\r\r\nDuvolle labs manufactures sturdy ships with a good mix of offensive and defensive capacities. Since the company is one of New Eden\'s foremost manufacturers of particle blasters, its ships tend to favor turrets and thus have somewhat higher power output than normal.\r\r\n\r\r\n',1060000,22500,92,1,8,3818404.0000,1,402,0),(11201,105,'Taranis Blueprint',' ',0,0.01,0,1,NULL,292500.0000,1,412,0),(11202,831,'Ares','Interceptors utilize a combination of advanced alloys and electronics to reduce their effective signature radius.  This, along with superior maneuverability and speed, makes them very hard to target and track, particularly for high caliber turrets. \r\r\n\r\r\nDeveloper: Roden Shipyards \r\r\n\r\r\nUnlike most Gallente ship manufacturers, Roden Shipyards tends to favor missiles over drones and their ships are generally faster than other Gallente ships in their class. They generally have a substantial amount of hull modification options but limited electronic systems.  \r\r\n\r\r\n',950000,22500,96,1,8,3818404.0000,1,402,0),(11203,105,'Ares Blueprint',' ',0,0.01,0,1,NULL,292500.0000,1,412,0),(11204,1216,'Advanced Energy Grid Upgrades','Advanced Skill at installing power upgrades e.g. capacitor battery and power diagnostic units. a further a further 2% reduction in energy grid upgrade CPU needs.',0,0.01,0,1,NULL,79000.0000,0,NULL,0),(11206,1209,'Advanced Shield Upgrades','Skill at installing shield upgrades e.g. shield extenders and shield rechargers. 2% reduction in shield upgrade power needs.',0,0.01,0,1,NULL,84000.0000,0,NULL,0),(11207,1216,'Advanced Weapon Upgrades','Reduces the powergrid needs of weapon turrets and launchers by 2% per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,500000.0000,1,368,0),(11208,272,'Advanced Sensor Upgrades','Advanced skill at installing sensor upgrades, e.g. signal amplifier and backup sensor array. further 2% reduction of sensor upgrade CPU needs per skill level.',0,0.01,0,1,NULL,100000.0000,0,NULL,0),(11209,226,'Barren Asteroid',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(11210,226,'Sheared Rock Formation',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(11215,326,'Basic Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,25,0,1,NULL,33354.0000,1,1684,0),(11216,163,'Basic Energized EM Membrane Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,1543,0),(11217,326,'Energized EM Membrane I','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,25,0,1,NULL,90452.0000,1,1684,0),(11218,163,'Energized EM Membrane I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1543,0),(11219,326,'Energized EM Membrane II','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,289752.0000,1,1684,0),(11220,163,'Energized EM Membrane II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11225,326,'Basic Energized Explosive Membrane','A enhanced version of the standard Reactive armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,25,0,1,NULL,33354.0000,1,1682,0),(11226,163,'Basic Energized Explosive Membrane Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,1543,0),(11227,326,'Energized Explosive Membrane I','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,25,0,1,NULL,90452.0000,1,1682,0),(11228,163,'Energized Explosive Membrane I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1543,0),(11229,326,'Energized Explosive Membrane II','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,292392.0000,1,1682,0),(11230,163,'Energized Explosive Membrane II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11235,326,'Basic Energized Armor Layering Membrane','An enhanced version of the standard layered armor plating. Uses advanced magnetic field generators to strengthen the integrity of the plating.',1,25,0,1,NULL,33354.0000,1,1687,0),(11236,163,'Basic Energized Armor Layering Membrane Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,1543,0),(11237,326,'Energized Armor Layering Membrane I','An enhanced version of the standard layered armor plating. Uses advanced magnetic field generators to strengthen the integrity of the plating.',1,25,0,1,NULL,90452.0000,1,1687,0),(11238,163,'Energized Armor Layering Membrane I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1543,0),(11239,326,'Energized Armor Layering Membrane II','An enhanced version of the standard layered armor plating. Uses advanced magnetic field generators to strengthen the integrity of the plating.',1,5,0,1,NULL,290412.0000,1,1687,0),(11240,163,'Energized Armor Layering Membrane II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11245,326,'Basic Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,25,0,1,NULL,33354.0000,1,1685,0),(11246,163,'Basic Energized Kinetic Membrane Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,1543,0),(11247,326,'Energized Kinetic Membrane I','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,25,0,1,NULL,90452.0000,1,1685,0),(11248,163,'Energized Kinetic Membrane I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1543,0),(11249,326,'Energized Kinetic Membrane II','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,291732.0000,1,1685,0),(11250,163,'Energized Kinetic Membrane II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11255,326,'Basic Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,25,0,1,NULL,33354.0000,1,1683,0),(11256,163,'Basic Energized Thermic Membrane Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,1543,0),(11257,326,'Energized Thermic Membrane I','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,25,0,1,NULL,90452.0000,1,1683,0),(11258,163,'Energized Thermic Membrane I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1543,0),(11259,326,'Energized Thermic Membrane II','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,289752.0000,1,1683,0),(11260,163,'Energized Thermic Membrane II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11265,326,'Basic Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,25,0,1,NULL,55500.0000,1,1686,0),(11266,163,'Basic Energized Adaptive Nano Membrane Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,1543,0),(11267,326,'Energized Adaptive Nano Membrane I','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,25,0,1,NULL,120202.0000,1,1686,0),(11268,163,'Energized Adaptive Nano Membrane I Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,1543,0),(11269,326,'Energized Adaptive Nano Membrane II','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,318182.0000,1,1686,0),(11270,163,'Energized Adaptive Nano Membrane II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11277,328,'Armor Thermic Hardener I','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,20,0,1,NULL,148846.0000,1,1678,0),(11278,348,'Armor Thermic Hardener I Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,1540,0),(11279,329,'1600mm Steel Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,4,832436.0000,1,1676,0),(11280,349,'1600mm Steel Plates I Blueprint',' ',0,0.01,0,1,4,7000000.0000,1,1541,0),(11283,87,'Cap Booster 150','Provides a quick injection of power into your capacitor. Good for tight situations!',1,6,100,10,NULL,26814.0000,1,139,0),(11284,169,'Cap Booster 150 Blueprint',' ',0,0.01,0,1,NULL,1750000.0000,1,339,0),(11285,87,'Cap Booster 200','Provides a quick injection of power into your capacitor. Good for tight situations!',1,8,100,10,NULL,38670.0000,1,139,0),(11286,169,'Cap Booster 200 Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,339,0),(11287,87,'Cap Booster 400','Provides a quick injection of power into your capacitor. Good for tight situations!',40,16,100,10,NULL,59864.0000,1,139,0),(11288,169,'Cap Booster 400 Blueprint',' ',0,0.01,0,1,NULL,3750000.0000,1,339,0),(11289,87,'Cap Booster 800','Provides a quick injection of power into your capacitor. Good for tight situations!',80,32,100,10,NULL,82684.0000,1,139,0),(11290,169,'Cap Booster 800 Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,339,0),(11291,329,'50mm Steel Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,11052.0000,0,NULL,0),(11292,349,'50mm Steel Plates I Blueprint',' ',0,0.01,0,1,4,100000.0000,0,1541,0),(11293,329,'100mm Steel Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,23886.0000,1,1672,0),(11294,349,'100mm Steel Plates I Blueprint',' ',0,0.01,0,1,4,200000.0000,1,1541,0),(11295,329,'200mm Steel Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,101624.0000,1,1673,0),(11296,349,'200mm Steel Plates I Blueprint',' ',0,0.01,0,1,4,800000.0000,1,1541,0),(11297,329,'400mm Steel Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,25,0,1,4,198230.0000,1,1674,0),(11298,349,'400mm Steel Plates I Blueprint',' ',0,0.01,0,1,4,1600000.0000,1,1541,0),(11299,329,'800mm Steel Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,50,0,1,4,466500.0000,1,1675,0),(11300,349,'800mm Steel Plates I Blueprint',' ',0,0.01,0,1,4,4000000.0000,1,1541,0),(11301,328,'Armor EM Hardener I','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,20,0,1,NULL,102562.0000,1,1681,0),(11302,348,'Armor EM Hardener I Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,1540,0),(11303,328,'Armor Explosive Hardener I','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,20,0,1,NULL,134576.0000,1,1680,0),(11304,348,'Armor Explosive Hardener I Blueprint',' ',0,0.01,0,1,NULL,3500000.0000,1,1540,0),(11305,328,'Armor Kinetic Hardener I','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,20,0,1,NULL,123380.0000,1,1679,0),(11306,348,'Armor Kinetic Hardener I Blueprint',' ',0,0.01,0,1,NULL,3000000.0000,1,1540,0),(11307,329,'400mm Reinforced Titanium Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,2,160000.0000,0,NULL,0),(11309,329,'400mm Rolled Tungsten Compact Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,160000.0000,1,1674,0),(11311,329,'400mm Crystalline Carbonide Restrained Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,8,160000.0000,1,1674,0),(11313,329,'400mm Reinforced Nanofiber Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,1,160000.0000,0,NULL,0),(11315,329,'800mm Reinforced Titanium Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,2,400000.0000,0,NULL,0),(11317,329,'800mm Rolled Tungsten Compact Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,4,400000.0000,1,1675,0),(11319,329,'800mm Crystalline Carbonide Restrained Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,8,400000.0000,1,1675,0),(11321,329,'800mm Reinforced Nanofiber Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,1,400000.0000,0,NULL,0),(11323,329,'1600mm Reinforced Titanium Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,2,700000.0000,0,NULL,0),(11325,329,'1600mm Rolled Tungsten Compact Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,4,700000.0000,1,1676,0),(11327,329,'1600mm Crystalline Carbonide Restrained Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,8,700000.0000,1,1676,0),(11329,329,'1600mm Reinforced Nanofiber Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,1,700000.0000,0,NULL,0),(11331,329,'50mm Reinforced Titanium Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,2,31242.0000,0,NULL,0),(11333,329,'50mm Reinforced Rolled Tungsten Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,31242.0000,0,NULL,0),(11335,329,'50mm Reinforced Crystalline Carbonide Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,8,31242.0000,0,NULL,0),(11337,329,'50mm Reinforced Nanofiber Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,1,31242.0000,0,NULL,0),(11339,329,'100mm Reinforced Titanium Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,2,20000.0000,0,NULL,0),(11341,329,'100mm Rolled Tungsten Compact Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,20000.0000,1,1672,0),(11343,329,'100mm Crystalline Carbonide Restrained Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,8,20000.0000,1,1672,0),(11345,329,'100mm Reinforced Nanofiber Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,1,20000.0000,0,NULL,0),(11347,329,'200mm Reinforced Titanium Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,2,80000.0000,0,NULL,0),(11349,329,'200mm Rolled Tungsten Compact Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,80000.0000,1,1673,0),(11351,329,'200mm Crystalline Carbonide Restrained Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,8,80000.0000,1,1673,0),(11353,329,'200mm Reinforced Nanofiber Plates I','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,1,80000.0000,0,NULL,0),(11355,325,'Small Remote Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,5528.0000,1,1059,0),(11356,350,'Small Remote Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,49960.0000,1,1539,0),(11357,325,'Medium Remote Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,13860.0000,1,1058,0),(11358,350,'Medium Remote Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,124700.0000,1,1539,0),(11359,325,'Large Remote Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,50,0,1,NULL,34716.0000,1,1057,0),(11360,350,'Large Remote Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,312440.0000,1,1539,0),(11365,324,'Vengeance','The Vengeance represents the latest in the Kingdom\'s ongoing mission to wed Amarr and Caldari tech, molding the two into new and exciting forms. Sporting a Caldari ship\'s launcher hardpoints as well as an Amarr ship\'s armor systems, this relentless slugger is perfect for when you need to get up close and personal.\r\r\n\r\r\nDeveloper: Khanid Innovation\r\r\n\r\r\nConstantly striving to combine the best of two worlds, Khanid Innovation have utilized their Caldari connections to such an extent that the Kingdom\'s ships now possess the most advanced missile systems outside Caldari space, as well as fairly robust electronics systems.',1163000,28600,210,1,4,5703622.0000,1,433,0),(11366,105,'Vengeance Blueprint',' ',0,0.01,0,1,NULL,2875000.0000,1,459,0),(11367,318,'map Landmark',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(11369,226,'Particle Acceleration Superstructure','Whatever purpose this structure once served, it is utterly useless now. Only a few bits of the array\'s hull survived the explosion that tore it apart.',0,0,0,1,NULL,0.0000,0,NULL,0),(11370,330,'Prototype Cloaking Device I','This prototype of an advanced cloaking mechanism was one of the last major technological breakthroughs to come out of Crielere Labs. Although it does work it is not really a finished product and has some serious drawbacks, most notably the fact that the module creates high sensor disruption while fitted and can not operate unless at minimum velocity.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,1172349.0000,1,675,0),(11371,324,'Wolf','Named after a mythical beast renowned for its voraciousness, the Wolf is one of the most potentially destructive frigates currently in existence.  While hardier than its brother the Jaguar it has less in the way of shield systems, and the capabilities of its onboard computer leave something to be desired.  Nevertheless, the mere sight of a locked and loaded Wolf should be enough to make most pilots turn tail and flee.\r\r\n\r\r\nDeveloper:  Boundless Creation\r\r\n\r\r\nBoundless Creation\'s ships are based on the Brutor tribe\'s philosophy of warfare: simply fit as much firepower onto your ship as possible.  Defense systems and electronics arrays therefore take a back seat to sheer annihilative potential.',1309000,27289,165,1,2,5763436.0000,1,436,0),(11372,105,'Wolf Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,463,0),(11373,324,'Blade','Core Complexions ships are unusual in that they favor electronics and defense over the typical \"Lots of guns\" approach traditionaly favored by the Minmatar   ',1200000,28600,130,1,2,3802370.0000,0,NULL,0),(11374,105,'Blade Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,0,NULL,0),(11375,324,'Erinye',' ',2810000,28100,165,1,8,3511872.0000,0,NULL,0),(11376,105,'Erinye Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,0,NULL,0),(11377,834,'Nemesis','Specifically engineered to fire torpedoes, stealth bombers represent the next generation in covert ops craft. The bombers are designed for sneak attacks on large vessels with powerful missile guidance technology enabling the torpedoes to strike faster and from a longer distance. \r\r\n\r\r\nDeveloper: Duvolle Laboratories\r\r\n\r\r\nDuvolle Labs manufactures sturdy ships with a good mix of offensive and defensive capabilities. Being the foremost manufacturer of particle blasters, its ships tend to favor turrets and thus have somewhat higher power output than normal.\r\r\n\r\r\n',1410000,28100,270,1,8,5434454.0000,1,423,0),(11378,105,'Nemesis Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,428,0),(11379,324,'Hawk','Following in the footsteps of Caldari vessels since time immemorial, the Hawk relies on tremendously powerful shield systems to see it through combat, blending launchers and turrets to provide for a powerful, well-rounded combat vessel.\r\r\n\r\r\nDeveloper:  Lai Dai\r\r\n\r\r\nLai Dai have always favored a balanced approach to their mix of on-board systems, leading to a line-up of versatile ships but providing very little in terms of tactical specialization.',1217000,16500,300,1,1,5680592.0000,1,434,0),(11380,105,'Hawk Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,461,0),(11381,324,'Harpy','Already possessing a reputation despite its limited initial circulation, the Harpy is a powerful railgun platform with long range capability and strong defensive systems.  Formidable both one-on-one and as a support ship, it was referred to as the \"little Moa\" by the pilots who participated in its safety and performance testing.\r\r\n\r\r\nDeveloper: Ishukone\r\r\n\r\r\nIshukone created the Harpy as a long-range support frigate for defense of Ishukone holdings as well as increased muscle and visibility in the constantly shifting game of cold war the Caldari megacorps\' police forces play amongst themselves.\r\r\n',1155000,16500,165,1,1,5727582.0000,1,434,0),(11382,105,'Harpy Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,461,0),(11383,324,'Gatherer',' ',5250000,28100,400,1,4,2757872.0000,0,NULL,0),(11384,105,'Gatherer Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,0,NULL,0),(11387,893,'Hyena','Electronic attack ships are mobile, resilient electronic warfare platforms. Although well suited to a variety of situations, they really come into their own in skirmish and fleet encounters, particularly against larger ships. For anyone wanting to decentralize their fleet\'s electronic countermeasure capabilities and make them immeasurably harder to counter, few things will serve better than a squadron or two of these little vessels.\r\r\n\r\r\nDeveloper: Core Complexion Inc.\r\r\n\r\r\nCore Complexion\'s ships are unusual in that they favor electronics and defense over the \"lots of guns\" approach traditionally favored by the Minmatar.',1191300,17400,150,1,2,4547534.0000,1,1069,0),(11388,105,'Hyena Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,NULL,0),(11389,324,'Kishar',' ',5125000,28100,450,1,8,2090612.0000,0,NULL,0),(11390,105,'Kishar Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,0,NULL,0),(11393,324,'Retribution','The Retribution is an homage to the glory days of the Empire, informed by classical Amarrian design philosophy: if it\'s strong, sturdy and packs a punch, it\'s ready for action.  What this powerhouse lacks in speed and maneuverability it more than makes up for with its wide range of firepower possibilities and superb defensive ability.\r\r\n\r\r\nDeveloper:  Carthum Conglomerate\r\r\n\r\r\nCarthum ships are the very embodiment of the Amarrian warfare philosophy. Possessing sturdy armor and advanced weapon system they provide a nice mix of offense and defense.',1171000,28600,135,1,4,5750612.0000,1,433,0),(11394,105,'Retribution Blueprint',' ',0,0.01,0,1,NULL,2875000.0000,1,459,0),(11395,1218,'Deep Core Mining','Skill at operating mining lasers requiring Deep Core Mining. 20% reduction per skill level in the chance of a damage cloud forming while mining Mercoxit. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,500000.0000,1,1323,0),(11396,468,'Mercoxit','Mercoxit is a very dense ore that must be mined using specialized deep core mining techniques. It contains massive amounts of the extraordinary morphite mineral but few other minerals of note.\r\r\n\r\r\nAvailable in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,40,0,100,NULL,9830400.0000,1,530,0),(11399,18,'Morphite','Morphite is a highly unorthodox mineral that can only be found in the hard-to-get Mercoxit ore. It is hard to use Morphite as a basic building material, but when it is joined with existing structures it can enhance the performance and durability manifold. This astounding quality makes this the material responsible for ushering in a new age in technology breakthroughs.\r\r\n\r\r\nMay be obtained by reprocessing the following ores:\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:11396>Mercoxit</a>, <a href=showinfo:17869>Magma Mercoxit</a>, <a href=showinfo:17870>Vitreous Mercoxit</a>',0,0.01,0,1,NULL,32768.0000,1,1857,0),(11400,324,'Jaguar','The Jaguar is a versatile ship capable of reaching speeds unmatched by any other assault-class vessel. While comparatively weak on the defensive front it sports great flexibility, allowing pilots considerable latitude in configuring their loadouts for whatever circumstances they find themselves in.\r\r\n\r\r\nDeveloper:  Thukker Mix\r\r\n\r\r\nBeing the brain-child of the nomadic Thukkers, it is no surprise the Jaguar is as fast as it is.  Initially conceived as a way for the tribe to pack some added punch to their organized detachments, they\'ve found it to be equally useful as messenger, scout and escort, and it is likely to become one of the most commonly-seen ships in the Thukkers\' stomping grounds.',1366000,27289,130,1,2,5716446.0000,1,436,0),(11401,105,'Jaguar Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,463,0),(11433,270,'High Energy Physics','Skill and knowledge of High Energy Physics and its use in the development of advanced technology. \r\r\n\r\r\nUsed primarily in the research of various energy system modules as well as smartbombs and laser based weaponry. \r\r\n\r\r\nAllows High Energy Physics research to be performed with the help of a research agent. 1% reduction in manufacturing time for all items requiring High Energy Physics per level.\r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints.',0,0.01,0,1,4,10000000.0000,1,375,0),(11441,270,'Plasma Physics','Skill and knowledge of Plasma physics and its use in the development of advanced technology. \r\r\n\r\r\nUsed primarily in the research of particle blaster weaponry as well as plasma based missiles and smartbombs. \r\r\n\r\r\nAllows Plasma Physics research to be performed with the help of a research agent. 1% reduction in manufacturing time for all items requiring Plasma Physics per level.\r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints.',0,0.01,0,1,4,10000000.0000,1,375,0),(11442,270,'Nanite Engineering','Skill and knowledge of Nanite Engineering and its use in the development of advanced technology. \r\r\n\r\r\nUsed primarily in the research of various armor and hull systems. \r\r\n\r\r\nAllows Nanite Engineering research to be performed with the help of a research agent. 1% reduction in manufacturing time for all items requiring Nanite Engineering per level.\r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints.',0,0.01,0,1,4,10000000.0000,1,375,0),(11443,270,'Hydromagnetic Physics','Skill and knowledge of Hydromagnetic Physics and its use in the development of advanced technology . \r\r\n\r\r\nUsed primarily in the research of shield system.\r\r\n\r\r\nAllows Hydromagnetic Physics research to be performed with the help of a research agent. \r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. 1% reduction in manufacturing time for all items requiring Hydromagnetic Physics per level.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11444,270,'Amarr Starship Engineering','Skill and knowledge of Amarr Starship Engineering. \r\r\n\r\r\nUsed Exclusively in the research of Amarr Ships of all Sizes.\r\r\n\r\r\nAllows Amarr Starship Engineering research to be performed with the help of a research agent. \r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. 1% reduction in manufacturing time for all items requiring Amarr Starship Engineering per level.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11445,270,'Minmatar Starship Engineering','Skill and knowledge of Minmatar Starship Engineering and its use in the development of advanced technology. \r\r\n\r\r\nUsed in the research of Minmatar Ships of all Sizes.\r\r\n\r\r\nAllows Minmatar Starship Engineering research to be performed with the help of a research agent. \r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. 1% reduction in manufacturing time for all items requiring Minmatar Starship Engineering per level.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11446,270,'Graviton Physics','Skill and knowledge of Graviton physics and its use in the development of advanced technology. \r\r\n\r\r\nUsed primarily in the research of Cloaking and other spatial distortion devices as well as Graviton based missiles and smartbombs. \r\r\n\r\r\nAllows Graviton Physics research to be performed with the help of a research agent. \r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. 1% reduction in manufacturing time for all items requiring Graviton Physics per level.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11447,270,'Laser Physics','Skill and knowledge of Laser Physics and its use in the development of advanced Technology. \r\r\n\r\r\nUsed primarily in the research of Laser weaponry as well as EM based missiles and smartbombs.\r\r\n\r\r\nAllows Laser Physics research to be performed with the help of a research agent. 1% reduction in manufacturing time for all items requiring Laser Physics per level.\r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11448,270,'Electromagnetic Physics','Skill and knowledge of Electromagnetic Physics and its use in the development of advanced technology. \r\r\n\r\r\nUsed primarily in the research of Railgun weaponry and various electronic systems.  \r\r\n\r\r\nAllows Electromagnetic Physics research to be performed with the help of a research agent. \r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. 1% reduction in manufacturing time for all items requiring Electromagnetic Physics per level.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11449,270,'Rocket Science','Skill and knowledge of Rocket Science and its use in the development of advanced technology. \r\r\n\r\r\nUsed primarily in the research of missiles and propulsion systems.  \r\r\n\r\r\nAllows Rocket Science research to be performed with the help of a research agent. 1% reduction in manufacturing time for all items requiring Rocket Science per level.\r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11450,270,'Gallente Starship Engineering','Skill and knowledge of Gallente Starship Engineering and its use in the development of advanced technology. \r\r\n\r\r\nUsed in the research of Gallente Ships of all Sizes.\r\r\n\r\r\nAllows Gallente Starship Engineering research to be performed with the help of a research agent. \r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. 1% reduction in manufacturing time for all items requiring Gallente Starship Engineering per level.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11451,270,'Nuclear Physics','Skill and knowledge of Nuclear physics and its use in the development of advanced technology.  \r\r\n\r\r\nUsed primarily in the research of Projectile weaponry as well as Nuclear missiles and smartbombs. \r\r\n\r\r\nAllows Nuclear Physics research to be performed with the help of a research agent. 1% reduction in manufacturing time for all items requiring Nuclear Physics per level.\r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11452,270,'Mechanical Engineering','Skill and knowledge of Mechanical Engineering and its use in the development of advanced technology. \r\r\n\r\r\nUsed in all Starship research as well as hull and armor repair systems.  \r\r\n\r\r\nAllows Mechanical Engineering research to be performed with the help of a research agent. 1% reduction in manufacturing time for all items requiring Mechanical Engineering per level.\r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11453,270,'Electronic Engineering','Skill and knowledge of Electronic Engineering and its use in the development of advanced technology. \r\r\n\r\r\nUsed in all Electronics and Drone research.  \r\r\n\r\r\nAllows Electronic Engineering research to be performed with the help of a research agent. \r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. 1% reduction in manufacturing time for all items requiring Electronic Engineering per level.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11454,270,'Caldari Starship Engineering','Skill and knowledge of Caldari Starship Engineering and its use in the development of advanced technology. \r\r\n\r\r\nUsed in the research of Caldari Ships of all Sizes.\r\r\n\r\r\nAllows Caldari Starship Engineering research to be performed with the help of a research agent. \r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. 1% reduction in manufacturing time for all items requiring Caldari Starship Engineering per level.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11455,270,'Quantum Physics','Skill and knowledge of Quantum Physics and its use in the development of advanced Technology. \r\r\n\r\r\nUsed primarily in the research of shield systems and Particle Blasters.  \r\r\n\r\r\nAllows Quantum Physics research to be performed through a research agent. 1% reduction in manufacturing time for all items requiring Quantum Physics per level.\r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11457,332,'R.Db - Viziam','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11458,332,'R.Db - Khanid Innovation','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11459,332,'R.Db - Carthum Conglomerate','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11460,332,'R.Db - Thukker Mix','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11461,332,'R.Db - Boundless Creations','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11462,332,'R.Db - Core Complexion','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11463,332,'R.Db - Ishukone','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11464,332,'R.Db - Kaalakiota','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11465,332,'R.Db - Roden Shipyards','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11466,332,'R.Db - CreoDron','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11467,332,'R.Db - Duvolle Labs','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11468,332,'Hacker Deck - Codex','A computer subsystem for hacking Amarr computer networks. Used in reverse engineering, blueprint copying as well as material and time efficiency blueprint research on reverse engineered blueprints',0,15,0,1,NULL,60288.0000,0,NULL,0),(11469,332,'Hacker Deck - Shaman','A computer subsystem for hacking Minmatar computer networks. Primarily used for industrial espionage and reverse engineering.',0,15,0,1,NULL,60288.0000,0,NULL,0),(11470,332,'Hacker Deck - Hermes','A computer subsystem for hacking Gallente computer networks. Used in reverse engineering, blueprint copying as well as material and time efficiency blueprint research on reverse engineered blueprints',0,15,0,1,NULL,60288.0000,0,NULL,0),(11471,332,'Hacker Deck - LXD-27','A computer subsystem for hacking Caldari computer networks. Used in reverse engineering, blueprint copying as well as material and time efficiency blueprint research on reverse engineered blueprints',0,15,0,1,NULL,60288.0000,0,NULL,0),(11472,332,'Hyper Net Uplink','A unregistered uplink to the corporate network',0,15,0,1,NULL,132480.0000,0,NULL,0),(11473,332,'Terran Molecular Sequencer','A System used for duplication',0,100,0,1,NULL,55698706.0000,0,NULL,0),(11474,332,'R.A.M.- Industrial Tech','Robotic assembly modules designed for Industrial Class Ship Manufacturing',0,15,0,1,NULL,40696.0000,0,NULL,0),(11475,332,'R.A.M.- Armor/Hull Tech','Robotic assembly modules designed for Armor and Hull Tech Manufacturing',0,0.04,0,100,NULL,40696.0000,1,1908,0),(11476,332,'R.A.M.- Ammunition Tech','Robotic assembly modules designed for Missile and Ammo Manufacturing',0,0.04,0,100,NULL,40696.0000,1,1908,0),(11477,332,'R.A.M.- Platform Tech','Robotic assembly modules designed for Deployable platform  Manufacturing',0,15,0,1,NULL,40696.0000,0,NULL,0),(11478,332,'R.A.M.- Starship Tech','Robotic assembly modules designed for Ship Manufacturing',0,0.04,0,100,NULL,40696.0000,1,1908,0),(11479,332,'R.A.M.- Cruiser Tech','Robotic assembly modules designed for Cruiser Class Ship Manufacturing',0,15,0,1,NULL,52470.0000,0,NULL,0),(11480,332,'R.A.M.- Battleship Tech','Robotic assembly modules designed for Battleship Class Ship Manufacturing',0,15,0,1,NULL,76044.0000,0,NULL,0),(11481,332,'R.A.M.- Robotics','Robotic assembly modules designed for Drone Manufacturing',0,0.04,0,100,NULL,40696.0000,1,1908,0),(11482,332,'R.A.M.- Energy Tech','Robotic assembly modules designed for Energy System Manufacturing',0,0.04,0,100,NULL,40696.0000,1,1908,0),(11483,332,'R.A.M.- Electronics','Robotic assembly modules designed for Electronics and Sensor Manufacturing',0,0.04,0,100,NULL,40696.0000,1,1908,0),(11484,332,'R.A.M.- Shield Tech','Robotic assembly modules designed for Shield system Manufacturing',0,0.04,0,100,NULL,40696.0000,1,1908,0),(11485,332,'R.A.M.- Cybernetics','Robotic assembly modules designed for Implant Manufacturing',0,0.04,0,100,NULL,40696.0000,1,1908,0),(11486,332,'R.A.M.- Weapon Tech','Robotic assembly modules  designed for Turret and Launcher Manufacturing',0,0.04,0,100,NULL,40696.0000,1,1908,0),(11487,270,'Astronautic Engineering','Skill and knowledge of Astronautics and its use in the development of advanced technology. This skill has no practical application for capsuleers, and proficiency in its use conveys little more than bragging rights. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,10000000.0000,1,375,0),(11488,340,'Huge Secure Container','This Huge container is fitted with a password-protected security lock.\r\r\n\r\r\nNote: the container must be anchored to enable password functionality. Anchoring containers is only possible in solar systems with a security status of 0.7 or lower.',3000000,1500,1950,1,NULL,67500.0000,1,1651,0),(11489,340,'Giant Secure Container','This Giant container is fitted with a password-protected security lock.\r\r\n\r\r\nNote: the container must be anchored to enable password functionality. Anchoring containers is only possible in solar systems with a security status of 0.7 or lower.',6000000,3000,3900,1,NULL,152750.0000,1,1651,0),(11490,340,'Colossal Secure Container','This Colossal container is fitted with a password-protected security lock.\r\r\n\r\r\nNote: the container must be anchored to enable password functionality. Anchoring containers is only possible in solar systems with a security status of 0.7 or lower.',18000000,6000,11000,1,NULL,0.0000,0,NULL,0),(11491,333,'Datacore - Takmahl Tech 1',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(11492,333,'Datacore - Takmahl Tech 2',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(11493,333,'Datacore - Takmahl Tech 3',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(11496,333,'Datacore - Defensive Subsystems Engineering',' ',1,0.1,0,1,4,0.0000,1,1880,0),(11498,333,'Datacore - Sleeper Tech 3',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(11499,333,'Datacore - Sleeper Tech 4',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(11504,333,'Datacore - Yan Jung Tech 3',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(11506,333,'Datacore - Yan Jung Tech 5',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(11508,314,'Cross of the Sacred Throne Order','The Cross of the Sacred Throne Order was created during the Moral Reforms to reward those who display undying loyalty to the Emperor and eternal faith in God through exceptional service and sacrifice in the name of the Empire. There is no higher capsuleer honor in the Empire.<br><br>\r\r\n To serve, unshakably, is to reach greatness.  - The Scriptures, Amash Akura, 25:16\r\r\n ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11509,314,'Onyx Heart of Valor','Dating back to the Gallente-Caldari War, the Onyx Heart was created in memory of those brave souls that stayed behind on Caldari Prime to fight the Gallenteans when the rest of the population fled. Awarded only a few dozen times for the duration of the war, the Onyx Heart is only awarded when the well being of the State takes precedence over one\'s personal welfare.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11510,314,'Aidonis Honorary Fellow Medallion','The Aidonis Honorary Fellow Medallion is a companion prize to the Aidonis Peace Prize. Ten of these medallions are given out over the course of each year, each time to individuals who have made significant strides in promoting peace and fairness in intergalactic relations.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11511,314,'Liberty Tattoo of the Minmatar Nation','Created during the Minmatar Rebellion to honor those fighting the Amarrians. At first it was only awarded posthumously to those that died heroic deaths during the rebellion, today it is often given to those that show great sacrifice and dedication to the Republic.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11512,314,'Enlightened Soul Silver Shield','One of the oldest award around, the Silver Shield dates back to First Jovian Empire. Initially created to award inventors and discoverers it later evolved to include those responsible for gathering and storing great amounts of knowledge. Today it is awarded to those that show great service to the Jovian Empire, such as bridging the communication gap between the Jovians and the other races.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11513,332,'R.A.M.- Pharmaceuticals','Robotic assembly modules  designed for Booster Manufacturing',0,15,0,1,NULL,40696.0000,0,NULL,0),(11514,332,'R.A.M.- Hypernet Tech','Robotic assembly modules  designed for Hypernet Tool Manufacturing',0,15,0,1,NULL,40696.0000,0,NULL,0),(11515,182,'Amarr Surveillance General Major','This is a security vessel of the Imperial Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(11516,182,'Sarum Surveillance General Major','This is a security vessel of the Sarum Family. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(11517,182,'Ammatar Surveillance General Major','This is a security vessel of the Ammatar Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(11518,182,'Khanid Surveillance General Major','This is a security vessel of the Royal Khanid Navy. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(11519,182,'Gallente Police Major','This is a security vessel of the Gallente Federation Fleet. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',20000000,1080000,14000,1,8,0.0000,0,NULL,0),(11520,182,'Minmatar Security High Captain','This is a security vessel of the Minmatar Security Service. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',20000000,1080000,14000,1,2,0.0000,0,NULL,0),(11521,182,'Caldari Police Commissioner','This is a security vessel of the Caldari Police Force. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Deadly',20000000,1080000,14000,1,1,0.0000,0,NULL,0),(11528,314,'Jovian Delegates','This is a list of the Jovian science delegates assigned to the Crielere research facility. They handle all correspondence between the Jovians and the Gallente/Caldari:  Nida  Liko  Tarazin  Ulio  Fabor',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11529,270,'Molecular Engineering','Skill and knowledge of Molecular Engineering and its use in the development of advanced technology. \r\r\n\r\r\nUsed primarily in the research of various hull and propulsion\r\r\nsystems.  \r\r\n\r\r\nAllows Molecular Engineering research to be performed with the help of a research agent. 1% reduction in manufacturing time for all items requiring Molecular Engineering per level.\r\r\n\r\r\nNeeded for all research and manufacturing operations on related blueprints. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,10000000.0000,1,375,0),(11530,334,'Plasma Thruster','Propulsion Component used primarily in Minmatar ships as well as some propulsion tech. A component in various other technology as well.  ',1,1,0,1,2,7430.0000,1,1889,0),(11531,334,'Ion Thruster','Propulsion Component used primarily in Gallente ships. A component in various other technology as well.  ',1,1,0,1,8,7430.0000,1,1888,0),(11532,334,'Fusion Thruster','Propulsion Component used primarily in Amarr ships. A component in various other technology as well.  ',1,1,0,1,4,7430.0000,1,802,0),(11533,334,'Magpulse Thruster','Propulsion Component used primarily in Caldari ships. A component in various other technology as well.',1,1,0,1,1,7430.0000,1,803,0),(11534,334,'Gravimetric Sensor Cluster','Sensor Component used primarily in Caldari ships. A component in various other technology as well.  ',1,1,0,1,1,6040.0000,1,803,0),(11535,334,'Magnetometric Sensor Cluster','Sensor Component used primarily in Gallente ships. A component in various other technology as well.  ',1,1,0,1,8,6040.0000,1,1888,0),(11536,334,'Ladar Sensor Cluster','Sensor Component used primarily in Minmatar ships. A component in various other technology as well.    ',1,1,0,1,2,6040.0000,1,1889,0),(11537,334,'Radar Sensor Cluster','Sensor Component used primarily in Amarr ships. A component in various other technology as well.    ',1,1,0,1,4,6040.0000,1,802,0),(11538,334,'Nanomechanical Microprocessor','CPU Component used primarily in Minmatar ships. A component in various other technology as well.      ',1,1,0,1,2,12170.0000,1,1889,0),(11539,334,'Nanoelectrical Microprocessor','CPU Component used primarily in Amarr ships. A component in various other technology as well.   ',1,1,0,1,4,12170.0000,1,802,0),(11540,334,'Quantum Microprocessor','CPU Component used primarily in Caldari ships. A component in various other technology as well.    ',1,1,0,1,1,12170.0000,1,803,0),(11541,334,'Photon Microprocessor','CPU Component used primarily in Gallente ships. A component in various other technology as well.    ',1,1,0,1,8,12170.0000,1,1888,0),(11542,334,'Fernite Carbide Composite Armor Plate','Armor Component used primarily in Minmatar ships. A component in various other technology as well.    ',1,1,0,1,2,660.0000,1,1889,0),(11543,334,'Tungsten Carbide Armor Plate','Armor Component used primarily in Amarr ships. A component in various other technology as well.    ',1,1,0,1,4,660.0000,1,802,0),(11544,334,'Titanium Diborite Armor Plate','Armor Component used primarily in Caldari ships. A component in various other technology as well.    ',1,1,0,1,1,660.0000,1,803,0),(11545,334,'Crystalline Carbonide Armor Plate','Armor Component used primarily in Gallente ships. A component in various other technology as well.    ',1,1,0,1,8,660.0000,1,1888,0),(11546,335,'Mining Pollution Cloud','A toxic cloud which damages ships and shielding.  ',0,0,0,1,NULL,0.0000,0,NULL,0),(11547,334,'Fusion Reactor Unit','Power Core component used primarily in Gallente ships.  A component in various other technology as well.    ',1,1,0,1,8,24090.0000,1,1888,0),(11548,334,'Nuclear Reactor Unit','Power Core component used primarily in Minmatar ships. A component in various other technology as well.    ',1,1,0,1,2,24090.0000,1,1889,0),(11549,334,'Antimatter Reactor Unit','Power Core component used primarily in Amarr ships. A component in various other technology as well.    ',1,1,0,1,4,24090.0000,1,802,0),(11550,334,'Graviton Reactor Unit','Power Core component used primarily in Caldari ships. A component in various other technology as well.',1,1,0,1,1,24090.0000,1,803,0),(11551,334,'Electrolytic Capacitor Unit','Capacitor component used primarily in Minmatar ships. A component in various other technology as well.    ',1,1,0,1,2,10500.0000,1,1889,0),(11552,334,'Scalar Capacitor Unit','Capacitor component used primarily in Caldari ships. A component in various other technology as well.    ',1,1,0,1,1,10500.0000,1,803,0),(11553,334,'Oscillator Capacitor Unit','Capacitor component used primarily in Gallente ships. A component in various other technology as well.    ',1,1,0,1,8,10500.0000,1,1888,0),(11554,334,'Tesseract Capacitor Unit','Capacitor component used primarily in Amarr ships. A component in various other technology as well.  ',1,1,0,1,4,10500.0000,1,802,0),(11555,334,'Deflection Shield Emitter','Shield Component used primarily in Minmatar ships. A component in various other technology as well.    ',1,1,0,1,2,5900.0000,1,1889,0),(11556,334,'Pulse Shield Emitter','Shield Component used primarily in Gallente ships. A component in various other technology as well.   ',1,1,0,1,8,5900.0000,1,1888,0),(11557,334,'Linear Shield Emitter','Shield Component used primarily in Amarr ships. A component in various other technology as well.    ',1,1,0,1,4,5900.0000,1,802,0),(11558,334,'Sustained Shield Emitter','Shield Component used primarily in Caldari ships. A component in various other technology as well.    ',1,1,0,1,1,5900.0000,1,803,0),(11561,338,'Shield Boost Amplifier I','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,25,0,1,NULL,531040.0000,1,613,0),(11562,360,'Shield Boost Amplifier I Blueprint',' ',0,0.01,0,1,NULL,3500000.0000,1,1552,0),(11563,339,'Micro Auxiliary Power Core I','Supplements the main Power core providing more power',0,20,0,1,NULL,166790.0000,1,660,0),(11564,352,'Micro Auxiliary Power Core I Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1559,0),(11566,1209,'Thermic Shield Compensation','5% bonus to thermal resistance per level for Shield Amplifiers',0,0.01,0,1,NULL,120000.0000,1,1747,0),(11567,30,'Avatar','Casting his sight on his realm, the Lord witnessed\r\r\nThe cascade of evil, the torrents of war.\r\r\nBurning with wrath, He stepped \r\r\ndown from the Heavens\r\r\nTo judge the unworthy,\r\r\nTo redeem the pure.\r\r\n\r\r\n<i>-The Scriptures, Revelation Verses 2:12</i>\r\r\n\r\r\n',2278125000,155000000,11250,1,4,81352622518.0000,1,813,0),(11568,110,'Avatar Blueprint',' ',0,0.01,0,1,NULL,75000000000.0000,1,884,0),(11569,258,'Armored Warfare Specialist','Advanced proficiency at armored warfare. Boosts the effectiveness of armored warfare link modules by 20% per skill level.',0,0.01,0,1,NULL,400000.0000,1,370,0),(11572,258,'Skirmish Warfare Specialist','Advanced proficiency at skirmish warfare. Boosts the effectiveness of skirmish warfare link modules by 20% per skill level.',0,0.01,0,1,NULL,400000.0000,1,370,0),(11574,258,'Wing Command','Grants the Wing Commander the ability to pass on their bonuses to an additional Squadron per skill level, up to a maximum of 5 Squadrons. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,2000000.0000,1,370,0),(11577,330,'Improved Cloaking Device II','An Improved Cloaking device based on the Crielere Labs prototype. It performs better and allows for faster movement while cloaked.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,1442199.0000,1,675,0),(11578,330,'Covert Ops Cloaking Device II','A very specialized piece of technology, the covert ops cloak is designed for use in tandem with specific covert ops vessels. Although it could theoretically work on other ships, its spatial distortion field is so unstable that trying to compensate for its fluctuations will overwhelm non-specialized computing hardware. \r\r\n\r\r\nNote: This particular module is advanced enough that it allows a ship to warp while cloaked. However, fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,2232485.0000,1,675,0),(11579,272,'Cloaking','Skill at using Cloaking devices. 10% reduction in targeting delay after uncloaking per skill level.  \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,3500000.0000,1,367,0),(11580,336,'BH Sentry Gun','This is the BH Sentry Gun, it will kill you.',1000,1000,1000,1,4,0.0000,0,NULL,0),(11584,266,'Anchoring','Skill at Anchoring Deployables.',0,0.01,0,1,NULL,75000.0000,1,365,0),(11585,314,'Pax Amarria','Written by Heideran VII, the Amarr Emperor himself, Pax Amarria is the most remarkable book published in the last century. In it the Emperor writes about his hopes and dreams for peace throughout the galaxy; a vision that has propelled him into becoming the champion of improved interstellar relations. His relentless strive for these goals has brought unparalleled harmony in the relationship between the empires; his constant search for peaceful solutions to any problem having many times becalmed brewing storms of hostilities on the horizon. His determination and powers of persuasion have compelled his own people and others to sacrifice many things they thought sacred to ensure that tranquillity will prevail, now and forever.',1,0.1,0,1,NULL,3328.0000,1,492,0),(11586,314,'Signed Copy of Pax Amarria','Written by the Heideran VII, the Amarr Emperor himself, Pax Amarria is the most remarkable book published in the last century. In it the Emperor writes about his hopes and dreams for peace throughout the galaxy; a vision that has propelled him into becoming the champion of improved international relations. His relentless strive for these goals has brought unparalleled harmony in the relationship between the empires; his constant search for peaceful solutions to any problem having many times becalmed brewing storm.\r\r\n\r\r\nThis is a signed copy, with Heideran\'s signature at the front: \"Semper Pax. Heideran VII\".',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11587,314,'Temple Stone','This stone is from a sacred temple, valued both by the minmatar and the amarr.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11588,314,'Defunct Drone Sensor Module','These sensors are an old subsystem once used in drone prototypes.',1,0.1,0,1,NULL,0.0000,1,20,0),(11589,306,'Temple Stone Storage','This bolted storage container seems to have once been a part of a larger structure.',10000,2750,2700,1,NULL,0.0000,0,NULL,0),(11590,306,'Drone Sensor Storage','This high-tech container is a storage for old drone sensors.',10000,2750,2700,1,NULL,0.0000,0,NULL,0),(11593,818,'The Thief','This is the vessel carrying the thief which recently pulled off an audacious burglary at a nearby station.  A bounty has been put on his head and his ship identity revealed to all bounty hunters.  Bewarned however, the ship is armed and dangerous, do not attempt to intercept it unless you know what you are doing!  Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(11594,818,'The Ex-Employee','A disgruntled ex-employee who has been harrassing local customers. Threat level: pathetic',2250000,22500,75,1,2,0.0000,0,NULL,0),(11595,818,'Rogue Agent','This ship belongs to a Caldari civilian.',2250000,22500,75,1,2,0.0000,0,NULL,0),(11596,818,'Sangrel Minn','An infamous thief and all-round scoundrel, this pirate is a wanted man in every corner of the galaxy. CONCORD advises caution in dealing with this individual.  Threat level: Significant',2810000,28100,315,1,4,0.0000,0,NULL,0),(11597,817,'Kruul','This is the infamous leader of a small pirate raiding party which has been terrorizing various sectors throughout the known universe.  His most notable offenses include high-profile kidnappings.  His victims are either sold as slaves or for ransom.  Threat level: Extreme',9900000,99000,1900,1,2,0.0000,0,NULL,0),(11598,818,'Kruul\'s Henchman','This is a ship serving under Kruul, an infamous pirate and slave trader.   Threat level: Significant',1766000,17660,120,1,2,0.0000,0,NULL,0),(11600,818,'Pirate Drone','This is an unmanned pirate drone.  It appears to be controlled by an artificial intelligence system.  Caution is advised when approaching such vessels.  Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(11601,613,'Guristas Emissary','This is an emissary for the Guristas Pirates.  It is equipped with a powerfull array of weaponry, and should be approached with utmost caution. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(11602,314,'Gallente Federation Transaction And Salary Logs','These reports hold information on recent transaction and salary logs from a corporation within the Gallente Federation.  They are very sought after by pirates, who use the often sensitive information held within for various purposes.',1,1,0,1,NULL,0.0000,1,NULL,0),(11603,314,'Shiez Kuzaks Ship Database','This tiny, glassy data chip holds information from the database of a ship formerly in the possession of Shiez Kozak.  Information stored within here could be anything from the ship\'s logs.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11604,314,'Caldari State Transaction And Salary Logs','These reports hold information on recent transaction and salary logs from a corporation within the Caldari State.  They are very sought after by pirates, who use the often sensitive information held within for various purposes.',1,1,0,1,NULL,0.0000,1,NULL,0),(11606,314,'Amarr Empire Transaction And Salary Logs','These reports hold information on recent transaction and salary logs from a corporation within the Amarr Empire.  They are very sought after by pirates, who use the often sensitive information held within for various purposes.',1,1,0,1,NULL,0.0000,1,NULL,0),(11607,314,'Minmatar Republic Transaction And Salary Logs','These reports hold information on recent transaction and salary logs from a corporation within the Minmatar Republic.  They are very sought after by pirates, who use the often sensitive information held within for various purposes.',1,1,0,1,NULL,0.0000,1,NULL,0),(11608,314,'Ammatar Transaction and salary logs','These reports hold information on recent transaction and salary logs from an Ammatar corporation.  They are very sought after by pirates, who use the often sensitive information held within for various purposes.',1,1,0,1,NULL,0.0000,1,NULL,0),(11610,526,'Nugoeihuvi reports','These encoded reports may mean little to the untrained eye, but can prove valuable to the relevant institution.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11612,218,'Heat Sink I Blueprint',' ',0,0.01,0,1,NULL,249600.0000,1,343,0),(11613,342,'Warp Core Stabilizer I Blueprint',' ',0,0.01,0,1,NULL,99940.0000,1,332,0),(11614,343,'Tracking Disruptor I Blueprint',' ',0,0.01,0,1,NULL,298240.0000,1,1574,0),(11616,344,'Tracking Enhancer I Blueprint',' ',0,0.01,0,1,NULL,144000.0000,1,343,0),(11617,345,'Remote Tracking Computer I Blueprint',' ',0,0.01,0,1,NULL,299940.0000,1,343,0),(11619,346,'Co-Processor I Blueprint',' ',0,0.01,0,1,NULL,149960.0000,1,1584,0),(11620,223,'Sensor Booster I Blueprint',' ',0,0.01,0,1,NULL,98700.0000,1,1581,0),(11621,224,'Tracking Computer I Blueprint',' ',0,0.01,0,1,NULL,99000.0000,1,343,0),(11622,131,'ECCM - Gravimetric I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1575,0),(11623,131,'ECCM - Ladar I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1575,0),(11624,131,'ECCM - Magnetometric I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1575,0),(11625,131,'ECCM - Radar I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1575,0),(11626,131,'ECCM - Omni I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1575,0),(11628,130,'ECM - Ion Field Projector I Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,1567,0),(11629,130,'ECM - Multispectral Jammer I Blueprint',' ',0,0.01,0,1,NULL,296960.0000,1,1567,0),(11630,130,'ECM - Phase Inverter I Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,1567,0),(11631,130,'ECM - Spatial Destabilizer I Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,1567,0),(11632,130,'ECM - White Noise Generator I Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,1567,0),(11634,347,'Signal Amplifier I Blueprint',' ',0,0.01,0,1,NULL,118400.0000,1,1585,0),(11635,314,'Personal Information Data','This is a stack of data chips holding personal information about a station\'s general population.  Although information on wealthy or important citizens is rarely kept on these disks, they are still quite valuable for criminals.  Accessing this information without consent is illegal in most parts of the galaxy.',1,1,0,1,NULL,0.0000,1,NULL,0),(11636,705,'Minmatar Mercenary Warship','This is a mercenary warship of Minmatar origin.  The faction it belongs to is unknown.  Threat level: Deadly',11200000,112000,480,1,2,0.0000,0,NULL,0),(11639,683,'Minmatar Mercenary Fighter','This is a mercenary fighter ship of Minmatar origin.  Its faction allegiance is unknown.  Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(11640,315,'Warp Core Stabilizer II','When installed this unit attempts to compensate for fluctuations and disruptions of the ship\'s warp core.',0,5,0,1,NULL,235806.0000,1,1088,0),(11641,342,'Warp Core Stabilizer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11642,328,'Armor EM Hardener II','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,1025426.0000,1,1681,0),(11643,348,'Armor EM Hardener II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11644,328,'Armor Kinetic Hardener II','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,1046244.0000,1,1679,0),(11645,348,'Armor Kinetic Hardener II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11646,328,'Armor Explosive Hardener II','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,1057440.0000,1,1680,0),(11647,348,'Armor Explosive Hardener II Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,NULL,0),(11648,328,'Armor Thermic Hardener II','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,1071710.0000,1,1678,0),(11649,348,'Armor Thermic Hardener II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11650,817,'Zerim Kurzon','This is the charismatic leader of an Ammatar mercenary network, historically loyal to House Kor-Azor, but rumored to have ties to corporations outside of the Amarr Empire\'s influence.   Formerly a fighter pilot in the Amarr military, Zerim is no stranger to space combat.  But even though he has amassed wealth beyond most Ammatarian citizens wildest dreams, Zerim still uses his old Maller cruiser, which he has personally modded to make it a formidable ship of war.   Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11651,818,'Shark Kurzon','This is the second in command of a group of mercenaries, led by the infamous Zerim Kurzon.  Shark and Zerim share the same father, and have been close since childhood, forming a mercenary network within Ammatar and Amarr space which has historically been loyal to House Kor-Azor, but rumored to have ties with corporations outside of the influence of the Amarr Empire. Threat level: High',2870000,28700,235,1,4,0.0000,0,NULL,0),(11652,818,'Kurzon Mercenary','This is a fighter for the Kurzon Mercenary network.  The Kurzon Mercenary Network was founded by the charismatic ex-military fighter pilot Zerim Kurzon, who had ties with the House Kor-Azor of the Amarr Empire.  The Kurzon Mercenaries are a good blend of different races, and although officially loyal to the Amarr Empire, rumors have it that they also have ties elsewhere.  Threat level: Significant',2810000,28100,165,1,4,0.0000,0,NULL,0),(11653,332,'Hacker Deck - Alpha','A computer subsystem for hacking Jove computer networks. Used in reverse engineering, blueprint copying as well as material and time efficiency blueprint research on reverse engineered blueprints',0,15,0,1,NULL,194610.0000,0,NULL,0),(11654,314,'Korim Kor-Azor','This is a member of the House Kor-Azor, accused of being a traitor of the Empire by the Sarum.  He vehemently denies this accusation.',82,1,0,1,NULL,0.0000,1,NULL,0),(11655,817,'Shiez Kuzak','This is a mercenary leader, rumored to have clients within the Caldari State elite.  Little is known about his origins, other than he once worked for the Guristas pirates.  Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(11656,818,'Kuzak Mercenary Fighter','This is a mercenary fighter working for Shiez Kuzak, an infamous ex-pirate rumored to work for some of the Caldari State elite. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(11657,665,'Imperial Navy Detective','This is a detective working for the Imperial Navy.  These military operatives sometimes conduct operations inside pirate controlled territory.  Threat level: Deadly',10900000,109000,120,1,4,0.0000,0,NULL,0),(11658,665,'Ammatar Navy Detective','This is a detective working for the Ammatar Navy.  These military operatives sometimes conduct operations inside pirate controlled territory.  Threat level: Deadly',10900000,109000,120,1,4,0.0000,0,NULL,0),(11659,671,'Caldari Navy Detective','This is a detective working for the Caldari Navy.  These military operatives sometimes conduct operations inside pirate controlled territory.  Threat level: Deadly',10900000,109000,120,1,1,0.0000,0,NULL,0),(11660,705,'Republic Fleet Detective','This is a detective working for the Minmatar military.  These operatives sometimes conduct operations inside pirate controlled territory.  Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(11661,678,'Federation Navy Detective','This is a detective working for the Federation Navy.  These military operatives sometimes conduct operations inside pirate controlled territory.  Threat level: Deadly',12500000,116000,120,1,8,0.0000,0,NULL,0),(11662,665,'Imperial Navy Scout','This is a scout for the Imperial Navy.  It will attack anyone who engages it, but will normally not attack first. Threat level: High',1910000,19100,120,1,4,0.0000,0,NULL,0),(11663,665,'Ammatar Navy Scout','This is a scout for the Ammatar Navy.  It will attack anyone who engages it, but will normally not attack first. Threat level: High',1910000,19100,120,1,4,0.0000,0,NULL,0),(11664,671,'Caldari Navy Scout','This is a scout for the Caldari Navy.  It will attack anyone who engages it, but will normally not attack first. Threat level: High',1910000,19100,120,1,1,0.0000,0,NULL,0),(11665,683,'Minmatar Freedom Fighter','This is a freedom fighter working for an international organization, orginally founded by former Minmatar slaves, which has the sole goal of fighting oppression and slavery throughout the known universe.  The Amarr Empire consider them terrorists, and all the pirate factions despise them.  However normally they do not attack unless provoked, or believe you are harboring slaves.  They are well armed and dangerous, approach with caution.  Threat level: High',1910000,19100,120,1,2,0.0000,0,NULL,0),(11666,677,'Federation Navy Scout','This is a scout for the Federation Navy.  It will attack anyone who engages it, but will normally not attack first. Threat level: High',1910000,19100,120,1,8,0.0000,0,NULL,0),(11668,817,'Bounty Hunter Ikaruz','This is a bounty hunter.  These freelancers can be of any race and come from all walks of life, sometimes they have mercenaries aiding them, but they usually work solo.  Normally, unless sent to kill you, they will leave you alone.  Threat level: Deadly',11800000,118000,120,1,4,0.0000,0,NULL,0),(11669,817,'Bounty Hunter Obunga','This is a bounty hunter.  These freelancers can be of any race and come from all walks of life, sometimes they have mercenaries aiding them, but they usually work solo.  Normally, unless sent to kill you, they will leave you alone.  Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(11670,817,'Bounty Hunter Jason','This is a bounty hunter.  These freelancers can be of any race and come from all walks of life, sometimes they have mercenaries aiding them, but they usually work solo.  Normally, unless sent to kill you, they will leave you alone.  Threat level: Deadly',10900000,109000,120,1,8,0.0000,0,NULL,0),(11671,817,'Bounty Hunter Okochyn','This is a bounty hunter.  These freelancers can be of any race and come from all walks of life, sometimes they have mercenaries aiding them, but they usually work solo.  Normally, unless sent to kill you, they will leave you alone.  Threat level: Deadly',10900000,109000,120,1,1,0.0000,0,NULL,0),(11672,818,'Bounty Hunter Rookie','This is an inexperienced bounty hunter.  Bounty hunters are usually not aggressive unless you happen to be part of their contract.  Threat level: Medium',1910000,19100,80,1,2,0.0000,0,NULL,0),(11673,818,'Mercenary Fighter','This is a mercenary fighter.  Its faction alignment is unknown.  It may be aggressive, depending on its assignment.  Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(11675,817,'Karothas','This is a freedom fighter whos goal in life is to free as many slaves as possible from captivity.  Karothas is of Amarr origin, rumored to have been a loyal servant of the Amarr Empire before a change of heart caused him to join the Minmatar Freedom Fighters, which is an organization fighting against slavery everywhere within the galaxy.  He has a sizeable bounty on his head placed by the Amarr leadership who despise, and fear, him.  Threat level: Deadly',10900000,109000,120,1,4,0.0000,0,NULL,0),(11676,817,'Ibrahim','This is a freedom fighter whos goal in life is to free as many slaves as possible from captivity.  Ibrahim is part of the Minmatar Freedom Fighters, which is an organization fighting against slavery everywhere within the galaxy.   He is armed and extremely dangerous.  Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(11677,817,'Akori','Akori is a Caldari working for the Minmatar Freedom Fighters.  His goal in life is to fight oppression and slavery in all corners of the galaxy.  The Amarr consider him a terrorist and have placed a sizable bounty on his head.  Threat level: Deadly',10900000,109000,120,1,1,0.0000,0,NULL,0),(11678,226,'TEST Beacon','With it\'s blinking red light, this beacon appears to be marking a point of interest, or perhaps a waypoint in a greater trail.',0,0,0,1,NULL,0.0000,0,NULL,0),(11679,818,'Mercenary Rookie','This is a mercenary, who is obviously starting out in his profession.  Most mercenaries are not hostile unless they are on a specific mission to eliminate you, or view you as a threat.  Caution is advised when approaching such vessels however, as they are normally armed and dangerous.  Threat level: Moderate',1200000,17400,220,1,2,0.0000,0,NULL,0),(11680,306,'Forcefield Array','This beacon repels any object that comes near it.',10000,100,0,1,NULL,5000.0000,0,NULL,0),(11681,818,'Shazzyr','This is a pilot with a long history of criminal offenses.  Approach him with utmost caution.  Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(11683,817,'Shogon','This is a pilot with a long history of criminal offenses.  Approach him with utmost caution. Threat level: High',1645000,16450,110,1,8,0.0000,0,NULL,0),(11684,817,'Roland','This is a pilot with a long history of criminal offenses.  Approach him with utmost caution.  Threat level: Very high',1970000,19700,235,1,2,0.0000,0,NULL,0),(11685,818,'Durim','This is a pilot with a long history of criminal offenses.  Approach him with utmost caution.  Threat level: Very high',1970000,19700,235,1,8,0.0000,0,NULL,0),(11688,334,'Particle Accelerator Unit','Weapon Component used primarily in Blasters. A component in various other technology as well.  ',1,1,0,1,8,5400.0000,1,1888,0),(11689,334,'Laser Focusing Crystals','Weapon Component used primarily in Lasers. A component in various other technology as well.  ',1,1,0,1,4,5400.0000,1,802,0),(11690,334,'Superconductor Rails','Weapon Component used primarily in Railguns. A component in various other technology as well.  ',1,1,0,1,1,5400.0000,1,803,0),(11691,334,'Thermonuclear Trigger Unit','Weapon Component used primarily in Cannons. A component in various other technology as well.  ',1,1,0,1,2,5400.0000,1,1889,0),(11692,334,'Nuclear Pulse Generator','Weapon Component used primarily in Minmatar Missiles. A component in various other technology as well.  ',1,1,0,1,2,5820.0000,1,1889,0),(11693,334,'Graviton Pulse Generator','Weapon Component used primarily in Caldari Missiles. A component in various other technology as well.  ',1,1,0,1,1,5820.0000,1,803,0),(11694,334,'EM Pulse Generator','Weapon Component used primarily in Amarr Missiles. A component in various other technology as well.  ',1,1,0,1,4,5820.0000,1,802,0),(11695,334,'Plasma Pulse Generator','Weapon Component used primarily in Gallente Missiles. A component in various other technology as well.  ',1,1,0,1,8,5820.0000,1,1888,0),(11699,817,'Thanok Kuggar',' ',10900000,109000,1400,1,2,0.0000,0,NULL,0),(11701,283,'Thanok',' ',400,1,0,1,NULL,0.0000,1,NULL,0),(11702,314,'Transaction And Salary Logs','These reports hold information on recent transactions and salary logs of a corporation.  They are very sought after by pirates, who use the often sensitive information held within for various purposes.',1,1,0,1,NULL,0.0000,1,NULL,0),(11703,314,'Angel Cartel Plans',' ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(11704,817,'Shakyr Maruk','This is one of the most powerfull Druglords within the Angel Cartel.  This is not his most powerfull combat ship, but still very formidable and usually used during his infrequent travels through Minmatar space, as it gives him good speed and maneuverability, and is fitted with powerful defensive modules.',10900000,109000,120,1,2,0.0000,0,NULL,0),(11705,818,'Shakyr Personal Guard','This is one of Shakyrs personal guards.  He follows his master around wherever he goes.',1645000,16450,120,1,2,0.0000,0,NULL,0),(11707,314,'Strange Mechanical Device','A strange mechanical device, with a fading Gallente symbol painted on its side. ',2500,2,0,1,8,0.0000,1,NULL,0),(11708,817,'Alena Karyn','Alena is a smuggler by trade, but also a noteworthy pirate.  Long is the list of foolhardy bounty hunters which have fallen to her in combat. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(11709,283,'Comatose Alena Karyn','This is Alena Karyn, a notorious smuggler and pirate of Gallente origin.  She is currently in a comatose state, having hit her head on something when her ship was destroyed by a mercenary working for the Gallente Federation.',80,1,0,1,8,0.0000,1,NULL,0),(11710,705,'Minmatar Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',89000000,890000,2000,1,2,0.0000,0,NULL,0),(11711,668,'Amarr Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(11712,673,'Caldari Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(11713,668,'Ammatar Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(11714,927,'Gallente Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',110500000,1105000,4000,1,8,0.0000,0,NULL,0),(11716,604,'Blood Raider Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(11717,622,'Sanshas Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(11718,613,'Guristas Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(11719,595,'Angel Cartel Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',89000000,890000,2000,1,2,0.0000,0,NULL,0),(11720,631,'Serpentis Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',110500000,1105000,4000,1,8,0.0000,0,NULL,0),(11721,817,'Rogue Pirate Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(11722,817,'Rogue Pirate Escort','This is an escort ship employed by an unknown pirate faction.  Threat level: Deadly',10900000,109000,120,1,4,0.0000,0,NULL,0),(11723,314,'Design Documents','These complicated data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.',1,0.5,0,1,NULL,100.0000,1,NULL,0),(11724,355,'Glossy Compound','Precious mineral compounds can be reprocessed into multiple minerals.',0,1,0,1,NULL,32768.0000,1,1856,0),(11725,355,'Plush Compound','Precious mineral compounds can be reprocessed into multiple minerals.',0,1,0,1,NULL,32768.0000,1,1856,0),(11732,355,'Sheen Compound','Precious mineral compounds can be reprocessed into multiple minerals.',0,1,0,1,NULL,4096.0000,1,1856,0),(11733,355,'Motley Compound','Precious mineral compounds can be reprocessed into multiple minerals.',0,1,0,1,NULL,10240.0000,1,1856,0),(11734,355,'Opulent Compound','Precious mineral compounds can be reprocessed into multiple minerals.',0,1,0,1,NULL,65536.0000,1,1856,0),(11735,355,'Dark Compound','Precious mineral compounds can be reprocessed into multiple minerals.',0,1,0,1,NULL,8192.0000,1,1856,0),(11736,355,'Lustering Alloy','Precious alloys can be reprocessed into multiple minerals.',0,1,0,1,NULL,24576.0000,1,1856,0),(11737,355,'Precious Alloy','Precious alloys can be reprocessed into multiple minerals.',0,1,0,1,NULL,2048.0000,1,1856,0),(11738,355,'Lucent Compound','Precious mineral compounds can be reprocessed into multiple minerals.',0,1,0,1,NULL,6144.0000,1,1856,0),(11739,355,'Condensed Alloy','Precious alloys can be reprocessed into multiple minerals.',0,1,0,1,NULL,960.0000,1,1856,0),(11740,355,'Gleaming Alloy','Precious alloys can be reprocessed into multiple minerals.',0,1,0,1,NULL,3072.0000,1,1856,0),(11741,355,'Crystal Compound','Precious mineral compounds can be reprocessed into multiple minerals.',0,1,0,1,NULL,1536.0000,1,1856,0),(11742,283,'The Damsel','This is the damsel in distress.',60,0.1,0,1,NULL,0.0000,1,NULL,0),(11744,353,'QA Cloaking Device','This module does not exist.',0,1,0,1,NULL,475000.0000,0,NULL,0),(11745,683,'Republic Fleet Scout','This is a scout for the Minmatar Fleet.  It will attack anyone who engages it, but will normally not attack first. Threat level: High',1910000,19100,120,1,2,0.0000,0,NULL,0),(11746,332,'R.Db - Lai Dai','A searchable database of the corporations scientific research. Used in blueprint copying as well as material and time efficiency blueprint research',0,0.04,0,100,NULL,65184.0000,1,1907,0),(11747,346,'Co-Processor II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11750,131,'ECCM - Gravimetric II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11754,131,'ECCM - Ladar II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11758,131,'ECCM - Magnetometric II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11762,131,'ECCM - Omni II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11766,131,'ECCM - Radar II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11770,131,'ECCM Projector I Blueprint',' ',0,0.01,0,1,NULL,399680.0000,1,1577,0),(11771,131,'ECCM Projector II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11775,130,'ECM - Ion Field Projector II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11779,130,'ECM - Multispectral Jammer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11783,130,'ECM - Phase Inverter II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11787,130,'ECM - Spatial Destabilizer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11791,130,'ECM - White Noise Generator II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11795,218,'Heat Sink II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11798,223,'Remote Sensor Booster I Blueprint',' ',0,0.01,0,1,NULL,399680.0000,1,1580,0),(11799,223,'Remote Sensor Booster II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11803,223,'Remote Sensor Dampener I Blueprint',' ',0,0.01,0,1,NULL,499980.0000,1,1576,0),(11804,223,'Remote Sensor Dampener II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11808,223,'Sensor Booster II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11812,347,'Signal Amplifier II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11820,347,'Gravimetric Backup Array I Blueprint',' ',0,0.01,0,1,NULL,124940.0000,1,1583,0),(11821,347,'Gravimetric Backup Array II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11824,347,'Ladar Backup Array I Blueprint',' ',0,0.01,0,1,NULL,124940.0000,1,1583,0),(11825,347,'Ladar Backup Array II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11828,347,'Magnetometric Backup Array I Blueprint',' ',0,0.01,0,1,NULL,124940.0000,1,1583,0),(11829,347,'Magnetometric Backup Array II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11832,347,'Multi Sensor Backup Array I Blueprint',' ',0,0.01,0,1,NULL,689960.0000,1,1583,0),(11833,347,'Multi Sensor Backup Array II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11836,347,'RADAR Backup Array I Blueprint',' ',0,0.01,0,1,NULL,124940.0000,1,1583,0),(11837,347,'RADAR Backup Array II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(11840,224,'Tracking Computer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11844,343,'Tracking Disruptor II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11848,344,'Tracking Enhancer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11851,345,'Remote Tracking Computer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11855,281,'Protein Delicacies','Protein Delicacies are cheap and nutritious food products manufactured by one of the Caldari mega corporations, Sukuuvestaa. It comes in many flavors and tastes delicious. Despite its cheap price and abundance it is favored by many gourmet chefs in some of the finest restaurants around for its rich, earthy flavor and fragrance.',400,0.5,0,1,NULL,200.0000,1,492,0),(11856,314,'Foundation Stone',' ',10000,180,0,1,NULL,100.0000,1,NULL,0),(11857,356,'R.Db - Roden Shipyards Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11858,270,'Hypernet Science','Skill and knowledge of Hypernet Technology such as Hacking decks,  Codebreakers and Parasites. ',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(11859,356,'R.A.M.- Energy Tech Blueprint',' ',0,0.01,0,1,NULL,282640.0000,1,1918,0),(11860,356,'R.A.M.- Cybernetics Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,1918,0),(11861,356,'R.A.M.- Platform Tech Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11862,356,'Hacker Deck - LXD-27 Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11863,356,'Hacker Deck - Codex Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11864,356,'Hacker Deck - Hermes Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11865,356,'Hacker Deck - Shaman Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11866,356,'Hyper Net Uplink Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11867,356,'R.A.M.- Battleship Tech Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11868,356,'R.A.M.- Cruiser Tech Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11869,356,'R.A.M.- Industrial Tech Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11870,356,'R.A.M.- Electronics Blueprint',' ',0,0.01,0,1,NULL,282640.0000,1,1918,0),(11871,356,'Terran Molecular Sequencer Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11872,356,'R.A.M.- Ammunition Tech Blueprint',' ',0,0.01,0,1,NULL,364560.0000,1,1918,0),(11873,356,'R.A.M.- Armor/Hull Tech Blueprint',' ',0,0.01,0,1,NULL,364560.0000,1,1918,0),(11874,356,'R.A.M.- Hypernet Tech Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11876,356,'R.Db - Boundless Creations Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11877,356,'R.Db - Core Complexion Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11878,356,'R.Db - CreoDron Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11879,356,'R.Db - Duvolle Labs Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11880,356,'R.Db - Carthum Conglomerate Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11881,356,'R.Db - Kaalakiota Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11882,356,'R.Db - Khanid Innovation Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11883,356,'R.Db - Thukker Mix Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11884,356,'R.Db - Viziam Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11885,356,'R.Db - Ishukone Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11886,356,'R.Db - Lai Dai Blueprint',' ',0,0.01,0,1,NULL,586240.0000,1,1919,0),(11887,356,'R.A.M.- Robotics Blueprint',' ',0,0.01,0,1,NULL,282640.0000,1,1918,0),(11888,356,'R.A.M.- Pharmaceuticals Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11889,356,'R.A.M.- Shield Tech Blueprint',' ',0,0.01,0,1,NULL,282640.0000,1,1918,0),(11890,356,'R.A.M.- Starship Tech Blueprint',' ',0,0.01,0,1,NULL,282640.0000,1,1918,0),(11891,356,'R.A.M.- Weapon Tech Blueprint',' ',0,0.01,0,1,NULL,282640.0000,1,1918,0),(11892,356,'Hacker Deck - Alpha Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11894,551,'Angel Breaker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(11895,551,'Angel Defeater','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(11896,551,'Angel Marauder','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(11897,551,'Angel Liquidator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(11898,552,'Angel Commander','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(11899,552,'Angel General','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(11900,552,'Angel Warlord','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(11901,555,'Blood Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(11902,555,'Blood Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(11903,555,'Blood Arch Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(11904,555,'Blood Arch Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(11905,556,'Blood Archon','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(11906,556,'Blood Prophet','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(11907,556,'Blood Oracle','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(11908,556,'Blood Apostle','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(11909,566,'Sansha\'s Slaughterer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11910,566,'Sansha\'s Execrator','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11911,566,'Sansha\'s Mutilator','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11912,566,'Sansha\'s Torturer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11913,565,'Sansha\'s Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11914,565,'Sansha\'s Slave Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11915,565,'Sansha\'s Mutant Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11916,565,'Sansha\'s Savage Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(11917,571,'Serpentis Chief Guard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(11918,571,'Serpentis Chief Safeguard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(11919,571,'Serpentis Chief Defender','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(11920,571,'Serpentis Chief Protector','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(11921,570,'Serpentis Baron','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,1010000,480,1,8,0.0000,0,NULL,0),(11922,570,'Serpentis Commodore','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(11923,570,'Serpentis Port Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,1010000,480,1,8,0.0000,0,NULL,0),(11924,570,'Serpentis Rear Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(11927,552,'Angel War General','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(11928,561,'Guristas Annihilator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(11929,561,'Guristas Nullifier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(11930,561,'Guristas Mortifier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(11931,561,'Guristas Inferno','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(11932,560,'Guristas Eradicator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(11933,560,'Guristas Obliterator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',22000000,1080000,235,1,1,0.0000,0,NULL,0),(11934,560,'Guristas Dismantler','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(11935,560,'Guristas Extinguisher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(11936,27,'Apocalypse Imperial Issue','Designed by master starship engineers and constructed in the royal shipyards of the Emperor himself, the imperial issue of the dreaded Apocalypse battleship is held in awe throughout the Empire. Given only as an award to those who have demonstrated their fealty to the Emperor in a most exemplary way, it is considered a huge honor to command -- let alone own -- one of these majestic and powerful battleships.',99300000,495000,675,1,4,165728608.0000,1,1620,0),(11937,107,'Apocalypse Imperial Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11938,27,'Armageddon Imperial Issue','Designed and constructed by the most skilled starship engineers and architects of the Empire, the imperial issue of the mighty Armageddon class is an upgraded version of the most-used warship of the Amarr. Its heavy armaments and strong front are specially designed to crash into any battle like a juggernaut and deliver swift justice in the name of the Emperor.',97100000,486000,600,1,4,99307758.0000,1,1620,0),(11939,107,'Armageddon Imperial Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(11940,25,'Gold Magnate','This ship is a masterly designed frigate as well as an exquisite piece of art. The Magnate class has been the pet project of a small, elite group of royal ship engineers for over a decade. When the Gold Magnate was offered as a prize in the Amarr Championships in YC105,  the long years of expensive research were paid off with the deployment of this beautiful ship.',1072000,28100,135,1,4,30000.0000,1,1619,0),(11942,25,'Silver Magnate','This decoratively designed ship is a luxury in its own class. The Magnate frigate has been the pet project of a small, elite group of royal ship engineers for a decade. Over the long years of expensive research, the design process has gone through several stages, and each stage has set a new standard in frigate design. The Silver Magnate, offered as a reward in the Amarr Championships in YC105, is one of the most recent iterations in this line of masterworks. \r\r\n\r\r\n',1063000,28100,100,1,4,535544.0000,1,1619,0),(11944,314,'Synthetic Coffee','This stimulating aromatic drink, made out of dried, roasted and ground seeds, is a particular favorite among scientists and software engineers.',2500,0.2,0,1,NULL,0.0000,1,492,0),(11947,687,'Khanid Fighter','This is a fighter for the Khanid Kingdom. It is protecting the assets of the Khanid Kingdom and may attack anyone it perceives as a threat. Threat level: Moderate',1810000,18100,225,1,4,0.0000,0,NULL,0),(11948,689,'Khanid Officer','This is an officer for the Khanid Kingdom. He is protecting the assets of the Khanid Kingdom and may attack anyone he perceives as a threat or easy pickings. Threat level: Extreme',12250000,115000,465,1,4,0.0000,0,NULL,0),(11957,833,'Falcon','Force recon ships are the cruiser-class equivalent of covert ops frigates.  While not as resilient as combat recon ships, they are nonetheless able to do their job as reconaissance vessels very effectively, due in no small part to their ability to interface with covert ops cloaking devices and set up cynosural fields for incoming capital ships.\r\r\n\r\r\nDeveloper: Ishukone\r\r\n\r\r\nMost of the recent designs off their assembly line have provided for a combination that the Ishukone name is becoming known for: great long-range capabilities and shield systems unmatched anywhere else.\r\r\n\r\r\n',12230000,96000,315,1,1,49742824.0000,1,830,0),(11958,106,'Falcon Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,901,0),(11959,906,'Rook','Built to represent the last word in electronic warfare, combat recon ships have onboard facilities designed to maximize the effectiveness of electronic countermeasure modules of all kinds.  Filling a role next to their class counterpart, the heavy assault cruiser, combat recon ships are the state of the art when it comes to anti-support support.  They are also devastating adversaries in smaller skirmishes, possessing strong defensive capabilities in addition to their electronic superiority.\r\r\n\r\r\nDeveloper: Kaalakiota\r\r\n\r\r\nAs befits one of the largest weapons manufacturers in the known world, Kaalakiota\'s ships are very combat focused. Favoring the traditional Caldari combat strategy, they are designed around a substantial number of weapons systems, especially missile launchers. However, they have rather weak armor and structure, relying more on shields for protection.',12730000,96000,305,1,1,49765114.0000,1,830,0),(11960,106,'Rook Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,901,0),(11961,906,'Huginn','Built to represent the last word in electronic warfare, combat recon ships have onboard facilities designed to maximize the effectiveness of electronic countermeasure modules of all kinds.  Filling a role next to their class counterpart, the heavy assault cruiser, combat recon ships are the state of the art when it comes to anti-support support.  They are also devastating adversaries in smaller skirmishes, possessing strong defensive capabilities in addition to their electronic superiority.\r\r\n\r\r\nDeveloper:  Boundless Creation\r\r\n\r\r\nBoundless Creation\'s ships are based on the Brutor tribe\'s philosophy of warfare: simply fit as much firepower onto your ship as possible.  Defense systems and electronics arrays therefore tend to take a back seat to sheer annihilative potential.',11550000,85000,315,1,2,48057550.0000,1,836,0),(11962,106,'Huginn Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,903,0),(11963,833,'Rapier','Force recon ships are the cruiser-class equivalent of covert ops frigates.  While not as resilient as combat recon ships, they are nonetheless able to do their job as reconaissance vessels very effectively, due in no small part to their ability to interface with covert ops cloaking devices and set up cynosural fields for incoming capital ships.\r\r\n\r\r\nDeveloper: Core Complexion Inc.\r\r\n\r\r\nCore Complexion\'s ships are unusual in that they favor electronics and defense over the \"lots of guns\" approach traditionally favored by the Minmatar.   \r\r\n',11040000,85000,315,1,2,48035260.0000,1,836,0),(11964,106,'Rapier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,903,0),(11965,833,'Pilgrim','Force recon ships are the cruiser-class equivalent of covert ops frigates.  While not as resilient as combat recon ships, they are nonetheless able to do their job as reconaissance vessels very effectively, due in no small part to their ability to interface with covert ops cloaking devices and set up cynosural fields for incoming capital ships.\r\r\n\r\r\nDeveloper: Carthum Conglomerate\r\r\n\r\r\nCarthum ships are the very embodiment of the Amarrian warfare philosophy. Possessing sturdy armor and advanced weapon systems, they provide a nice mix of offense and defense. On the other hand, their electronic and shield systems tend to be rather limited.  \r\r\n\r\r\n',11370000,120000,315,1,4,48553106.0000,1,827,0),(11966,106,'Pilgrim Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,900,0),(11969,833,'Arazu','Force recon ships are the cruiser-class equivalent of covert ops frigates.  While not as resilient as combat recon ships, they are nonetheless able to do their job as reconaissance vessels very effectively, due in no small part to their ability to interface with covert ops cloaking devices and set up cynosural fields for incoming capital ships.\r\r\n\r\r\nDeveloper: Duvolle Labs\r\r\n\r\r\nDuvolle Labs manufactures sturdy ships with a good mix of offensive and defensive capabilities. Since the company is one of New Eden\'s foremost manufacturers of particle blasters, its ships tend to favor turrets and thus have somewhat higher power output than normal.',11650000,116000,315,1,8,48409102.0000,1,833,0),(11970,106,'Arazu Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,902,0),(11971,906,'Lachesis','Built to represent the last word in electronic warfare, combat recon ships have onboard facilities designed to maximize the effectiveness of electronic countermeasure modules of all kinds. Filling a role next to their class counterpart, the heavy assault cruiser, combat recon ships are the state of the art when it comes to anti-support support. They are also devastating adversaries in smaller skirmishes, possessing strong defensive capabilities in addition to their electronic superiority.\r\r\n\r\r\nDeveloper: Roden Shipyards\r\r\n\r\r\nUnlike most Gallente ship manufacturers, Roden Shipyards tend to favor missiles over drones and their ships generally possess stronger armor. Their electronics capacity, however, tends to be weaker than that of their competitors\'.',12070000,116000,320,1,8,48431392.0000,1,833,0),(11972,106,'Lachesis Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,902,0),(11978,832,'Scimitar','Built with special tracking support arrays, the Scimitar was designed in large part to assist heavy combat vessels in tracking fast-moving targets.  Relatively nimble for a support cruiser, it can often be found ducking between battleships, protecting its own back while lending the behemoths the support they need to take out their enemies.\r\r\n\r\r\nDeveloper: Core Complexion Inc.\r\r\n\r\r\nCore Complexions ships are unusual in that they favor electronics and defense over the \"Lots of guns\" approach traditionally favored by the Minmatar.  Being a support cruiser, the Scimitar therefore fits ideally into their design scheme.\r\r\n\r\r\n',12090000,89000,440,1,2,45808574.0000,1,441,0),(11979,106,'Scimitar Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,446,0),(11985,832,'Basilisk','Following in the time-honored Caldari spaceship design tradition, the Basilisk sports top-of-the-line on-board computer systems specially designed to facilitate shield transporting arrays, while sacrificing some of the structural strength commonly found in vessels of its class.\r\r\n\r\r\nDeveloper: Lai Dai\r\r\n\r\r\nLai Dai have always favored a balanced approach to their mix of on-board systems, leading to a line-up of versatile ships but providing very little in terms of tactical specialization.  With the Basilisk, their aim was to continue pushing forward the development of cutting-edge defense optimization systems while providing powerful support capability.\r\r\n\r\r\n',13130000,107000,485,1,1,46158956.0000,1,439,0),(11986,106,'Basilisk Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,444,0),(11987,832,'Guardian','The Guardian is the first vessel to feature Carthum Conglomerate\'s brand new capacitor flow maximization system, allowing for greater amounts of energy to be stored in the capacitor as well as providing increased facilities for transporting that energy to other ships.\r\r\n\r\r\nDeveloper: Carthum Conglomerate\r\r\n\r\r\nWhile featuring Carthum\'s trademark armor and hull strength, the Guardian, being a support ship, has limited room for armaments.  Its intended main function is to serve as an all-round support vessel, providing the raw energy for fleet compatriots to do what they need to do in order to achieve victory.\r\r\n\r\r\n',11980000,115000,465,1,4,45523896.0000,1,438,0),(11988,106,'Guardian Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,443,0),(11989,832,'Oneiros','Designed specifically as an armor augmenter, the Oneiros provides added defensive muscle to fighters on the front lines.  Additionally, its own formidable defenses make it a tough nut to crack.  Breaking through a formation supported by an Oneiros is no mean feat.\r\r\n\r\r\nDeveloper: Roden Shipyards\r\r\n\r\r\nDeciding that added defensive capabilities would serve to strengthen the overall effectiveness of Gallente ships, who traditionally have favored pure firepower over other aspects, Roden Shipyards came up with the Oneiros.  Intrigued, Gallente Navy officials are reportedly considering incorporating this powerful defender into their fleet formations.\r\r\n\r\r\n',13160000,113000,600,1,8,46060874.0000,1,440,0),(11990,106,'Oneiros Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,445,0),(11993,358,'Cerberus','No cruiser currently in existence can match the superiority of the Cerberus\'s onboard missile system. With a well-trained pilot jacked in, this fanged horror is capable of unleashing a hail of missiles to send even the most seasoned armor tankers running for cover. \r\r\n<br>Developer: Lai Dai \r\r\nMoving away from their traditionally balanced all-round designs, Lai Dai have created a very specialized - and dangerous - missile boat in the Cerberus. Many have speculated that due to recent friction between Caldari megacorporations, LD may be looking to beef up their own police force with these missile-spewing monstrosities.',12720000,92000,650,1,1,50094078.0000,1,450,0),(11994,106,'Cerberus Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,455,0),(11995,894,'Onyx','Effectively combining the trapping power of interdictors with the defensive capabilities of heavy assault cruisers, the heavy interdiction cruiser is an invaluable addition to any skirmish force, offensive or defensive. Heavy interdiction cruisers are the only ships able to use the warp disruption field generator, a module which creates a warp disruption field that moves with the origin ship wherever it goes.  \r\r\n\r\r\nDeveloper: Kaalakiota \r\r\n\r\r\nAs befits one of the largest weapons manufacturers in the known world, Kaalakiota\'s ships are very combat focused. Favoring the traditional Caldari combat strategy, they are designed around a substantial number of weapons systems, especially missile launchers. However, they have rather weak armor and structure, relying more on shields for protection.\r\r\n\r\r\n',15400000,92000,450,1,1,70269150.0000,1,1072,0),(11996,106,'Onyx Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(11999,358,'Vagabond','The fastest cruiser invented to date, this vessel is ideal for hit-and-run ops where both speed and firepower are required. Its on-board power core may not be strong enough to handle some of the larger weapons out there, but when it comes to guerilla work, the Vagabond can\'t be beat. \r\r\n<br>Developer: Thukker Mix \r\r\nImproving on the original Stabber design, Thukker Mix created the Vagabond as a cruiser-sized skirmish vessel equally suited to defending mobile installations and executing lightning strikes at their enemies. Honoring their tradition of building the fastest vessels to ply the space lanes, they count the Vagabond as one of their crowning achievements.',11590000,80000,460,1,2,47493644.0000,1,452,0),(12000,106,'Vagabond Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,457,0),(12003,358,'Zealot','The Zealot is built almost exclusively as a laser platform, designed to wreak as much havoc as its energy beams can be made to. As a vanguard vessel, its thick armor and dazzling destructive power make it capable of cutting through enemy fleets with striking ease. Zealots are currently being mass-produced by Viziam for the Imperial Navy. \r\r\n<br>Developer: Viziam \r\r\nFor their first production-ready starship design, Viziam opted to focus on their core proficiencies - heavy armor and highly optimized weaponry. The result is an extremely focused design that, when used correctly, can go toe-to-toe with any contemporary cruiser design.',12580000,118000,440,1,4,48704308.0000,1,449,0),(12004,106,'Zealot Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,454,0),(12005,358,'Ishtar','While not endowed with as much pure firepower as other ships of its category, the Ishtar is more than able to hold its own by virtue of its tremendous capacity for drones and its unique hard-coded drone-control subroutines. \r\r\n<br>Developer: CreoDron \r\r\nTouted as \"the Ishkur\'s big brother,\" the Ishtar design is the furthest CreoDron have ever gone towards creating a completely dedicated drone carrier. At various stages in its development process plans were made to strengthen the vessel in other areas, but ultimately the CreoDron engineers\' fascination with pushing the drone carrier envelope overrode all other concerns.',11100000,115000,560,1,8,48392154.0000,1,451,0),(12006,106,'Ishtar Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,456,0),(12011,358,'Eagle','Built on the shoulders of the sturdy Moa and improving on its durability and range, the Eagle is the next generation in Caldari gunboats. Able to fire accurately and do tremendous damage at ranges considered extreme by any cruiser pilot, this powerhouse will be the bane of anyone careless enough to think himself out of its range. \r\r\n<br>Developer: Ishukone \r\r\nCaldari starship design is showing a growing trend towards armaments effective at high ranges, and in this arena, as in others, Ishukone do not let themselves get left behind; the Eagle was intended by them as a counter to the fearsome long-range capabilities of Lai Dai\'s Cerberus ship.',11720000,101000,550,1,1,48893330.0000,1,450,0),(12012,106,'Eagle Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,455,0),(12013,894,'Broadsword','Effectively combining the trapping power of interdictors with the defensive capabilities of heavy assault cruisers, the heavy interdiction cruiser is an invaluable addition to any skirmish force, offensive or defensive. Heavy interdiction cruisers are the only ships able to use the warp disruption field generator, a module which creates a warp disruption field that moves with the origin ship wherever it goes.  \r\r\n\r\r\nDeveloper: Core Complexion Inc.\r\r\n\r\r\nCore Complexion\'s ships are unusual in that they favor electronics and defense over the  lots of guns  approach traditionally favored by the Minmatar.\r\r\n\r\r\n',15000000,96000,452,1,2,70132150.0000,1,1074,0),(12014,106,'Broadsword Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12015,358,'Muninn','Commissioned by the Republic Fleet to create a powerful assault vessel for the strengthening of the Matari tribes as well as a commercial platform for the Howitzers and other guns produced by the Fleet, Boundless Creation came up with the Muninn. Heavily armored, laden with turret hardpoints and sporting the latest in projectile optimization technology, this is the very definition of a gunboat. \r\r\n<br>Developer: Boundless Creation \r\r\nBoundless Creation\'s ships are based on the Brutor tribe\'s philosophy of warfare: simply fit as much firepower onto your ship as is humanly possible. The Muninn is far from being an exception.',11750000,96000,515,1,2,48756330.0000,1,452,0),(12016,106,'Muninn Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,457,0),(12017,894,'Devoter','Effectively combining the trapping power of interdictors with the defensive capabilities of heavy assault cruisers, the heavy interdiction cruiser is an invaluable addition to any skirmish force, offensive or defensive. Heavy interdiction cruisers are the only ships able to use the warp disruption field generator, a module which creates a warp disruption field that moves with the origin ship wherever it goes.  \r\r\n\r\r\nDeveloper: Viziam\r\r\n\r\r\nViziam ships are quite possibly the most durable ships money can buy. Their armor is second to none and that, combined with superior shields, makes them hard nuts to crack. Of course this does mean they are rather slow and possess somewhat more limited weapons and electronics options.\r\r\n\r\r\n',16200000,118000,375,1,4,69622394.0000,1,1071,0),(12018,106,'Devoter Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12019,358,'Sacrilege','Khanid\'s engineers have spent months perfecting the Sacrilege\'s on-board missile launcher optimization systems, making it a very effective assault missile platform. In addition, its supremely advanced capacitor systems make it one of the most dangerous ships in its class. \r\r\n<br>Developer: Khanid Innovation \r\r\nIn an effort to maintain the fragile peace with the old empire through force of deterrence, Khanid Innovation have taken the Maller blueprint and morphed it into a monster. State-of-the-art armor alloys, along with missile systems developed from the most advanced Caldari designs, mean the Sacrilege may be well on its way to becoming the Royal Khanid Navy\'s flagship cruiser.',11750000,118000,615,1,4,48246574.0000,1,449,0),(12020,106,'Sacrilege Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,454,0),(12021,894,'Phobos','Effectively combining the trapping power of interdictors with the defensive capabilities of heavy assault cruisers, the heavy interdiction cruiser is an invaluable addition to any skirmish force, offensive or defensive. Heavy interdiction cruisers are the only ships able to use the warp disruption field generator, a module which creates a warp disruption field that moves with the origin ship wherever it goes.  \r\r\n\r\r\nDeveloper: Roden Shipyards \r\r\n\r\r\nUnlike most Gallente ship manufacturers, Roden Shipyards tend to favor missiles over drones and their ships generally possess stronger armor. Their electronics capacity, however, tends to be weaker than ships from their competitors.\r\r\n',14000000,112000,400,1,8,69244372.0000,1,1073,0),(12022,106,'Phobos Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12023,358,'Deimos','Sharing more tactical elements with smaller vessels than with its size-class counterparts, the Deimos represents the final word in up-close-and-personal cruiser combat. Venture too close to this one, and swift death is your only guarantee. \r\r\n<br>Developer: Duvolle Labs \r\r\nRumor has it Duvolle was contracted by parties unknown to create the ultimate close-range blaster cruiser. In this their engineers and designers haven\'t failed; but the identity of the company\'s client remains to be discovered.',11460000,112000,415,1,8,47868552.0000,1,451,0),(12024,106,'Deimos Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,456,0),(12028,306,'Storage Bin','The enclosed storage bin drifts quietly in space, waiting patiently to be pried open by a hungry looter.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(12029,687,'Khanid Elite Fighter','This is a fighter for the Khanid Kingdom. It is protecting the assets of the Khanid Kindgom and may attack anyone it perceives as a threat.  Threat level: High',2870000,28700,315,1,4,0.0000,0,NULL,0),(12031,105,'Manticore Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,427,0),(12032,834,'Manticore','Specifically engineered to fire torpedoes, stealth bombers represent the next generation in covert ops craft. The bombers are designed for sneak attacks on large vessels with powerful missile guidance technology enabling the torpedoes to strike faster and from a longer distance. \r\r\n\r\r\nDeveloper: Lai Dai\r\r\n\r\r\nLai Dai have always favored a balanced approach to their mix of on-board systems, leading to a line-up of versatile ships. \r\r\n\r\r\n',1470000,28100,265,1,1,5485512.0000,1,422,0),(12034,834,'Hound','Specifically engineered to fire torpedoes, stealth bombers represent the next generation in covert ops craft. The bombers are designed for sneak attacks on large vessels with powerful missile guidance technology enabling the torpedoes to strike faster and from a longer distance. \r\r\n\r\r\nDeveloper: Boundless Creation\r\r\n\r\r\nBoundless Creation ships are based on the Brutor tribe\'s philosophy of warfare: simply fit as much firepower onto your ship as humanly possible. On the other hand, defense systems and \"cheap tricks\" like electronic warfare have never been a high priority.',1455000,28100,255,1,2,5381384.0000,1,424,0),(12035,105,'Hound Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,429,0),(12036,324,'Dagger',' ',2810000,28100,175,1,2,3685072.0000,0,NULL,0),(12037,105,'Dagger Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12038,834,'Purifier','Specifically engineered to fire torpedoes, stealth bombers represent the next generation in covert ops craft. The bombers are designed for sneak attacks on large vessels with powerful missile guidance technology enabling the torpedoes to strike faster and from a longer distance. \r\r\n\r\r\nDeveloper: Viziam\r\r\n\r\r\nViziam ships are quite possibly the most durable ships money can buy. Their armor is second to none and that, combined with superior shields, makes them hard nuts to crack. Of course this does mean they are rather slow and possess somewhat more limited weapons and electronics options.',1495000,28100,260,1,4,5342090.0000,1,421,0),(12041,105,'Purifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,425,0),(12042,324,'Ishkur','Specialized as a frigate-class drone carrier, the Ishkur carries less in the way of firepower than most other Gallente gunboats.  With a fully stocked complement of drones and a skilled pilot, however, no one should make the mistake of thinking this vessel easy prey.\r\r\n\r\r\nDeveloper:  CreoDron\r\r\n\r\r\nAs the largest drone developer and manufacturer in space, CreoDron has a vested interest in drone carriers.  While sacrificing relatively little in the way of defensive capability, the Ishkur can chew its way through surprisingly strong opponents - provided, of course, that the pilot uses top-of-the-line CreoDron drones.',1216000,29500,165,1,8,5730388.0000,1,435,0),(12043,105,'Ishkur Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,462,0),(12044,324,'Enyo','The single-fanged Enyo sports good firepower capability, a missile hardpoint and some extremely strong armor plating, making it one of the best support frigates out there.  Ideal for use as point ships to draw enemy fire from more vulnerable friendlies.\r\r\n\r\r\nDeveloper:  Roden Shipyards\r\r\n\r\r\nUnlike most Gallente ship manufacturers, Roden Shipyards tend to favor missiles over drones and their ships generally possess stronger armor.  Their electronics capacity, however, tends to be weaker than ships from their competitors.',1171000,29500,165,1,8,5579378.0000,1,435,0),(12045,105,'Enyo Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,462,0),(12046,668,'Ammatar Slave Trader','This is a slave trader working for the Ammatar.  Slave traders often have to fend off hostile ships, such as Minmatar Freedom Fighters or bounty hunters, and therefore come well equipped to deal with any such encounters.  Slave traders are also known to attack remote settlements throughout the galaxy to bolster their supply of slaves.  The Minmatar Republic has put a bounty on the head of any known slaver.  Threat level: Deadly',12000000,120000,345,1,4,0.0000,0,NULL,0),(12047,689,'Khanid Slave Trader','This is a slave trader working for the Khanid Kingdom.  Slave traders often have to fend off hostile ships, such as Minmatar Freedom Fighters or bounty hunters, and therefore come well equipped to deal with any such encounters.  Slave traders are also known to attack remote settlements throughout the galaxy to bolster their supply of slaves.  The Minmatar Republic has put a bounty on the head of any known slaver.  Threat level: Deadly',12000000,120000,550,1,4,0.0000,0,NULL,0),(12048,668,'Amarr Slave Trader','This is a slave trader working for the Amarr Empire.  Slave traders often have to fend off hostile ships, such as Minmatar Freedom Fighters or bounty hunters, and therefore come well equipped to deal with any such encounters.  Slave traders are also known to attack remote settlements throughout the galaxy to bolster their supply of slaves.  The Minmatar Republic has put a bounty on the head of any known slaver.  Threat level: Deadly',11800000,118000,1775,1,4,0.0000,0,NULL,0),(12049,283,'Slaver','Slavers thrive in the lawless areas of the galaxy, and in the Amarrian territories which view the slave business as a legal profession. Some slavers are notorious for their brutality and lack of morals, and will attack remote settlements without hesitation to capture innocent victims to be sold on the black market. The Minmatar Republic has been especially keen on setting bounties on all slave traders, as they bear a deep resentment and hatred towards slavery.',100,2,0,1,NULL,0.0000,1,23,0),(12052,46,'50MN Microwarpdrive I','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,25,0,1,4,192086.0000,1,131,0),(12053,126,'50MN Microwarpdrive I Blueprint',' ',0,0.01,0,1,4,1581880.0000,1,331,0),(12054,46,'500MN Microwarpdrive I','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,50,0,1,4,1076506.0000,1,131,0),(12055,126,'500MN Microwarpdrive I Blueprint',' ',0,0.01,0,1,4,7909400.0000,1,331,0),(12056,46,'10MN Afterburner I','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,25,0,1,4,35804.0000,1,542,0),(12057,126,'10MN Afterburner I Blueprint',' ',0,0.01,0,1,NULL,322560.0000,1,1525,0),(12058,46,'10MN Afterburner II','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,581162.0000,1,542,0),(12059,126,'10MN Afterburner II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12066,46,'100MN Afterburner I','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,50,0,1,4,189896.0000,1,542,0),(12067,126,'100MN Afterburner I Blueprint',' ',0,0.01,0,1,NULL,1612800.0000,1,1525,0),(12068,46,'100MN Afterburner II','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,976442.0000,1,542,0),(12069,126,'100MN Afterburner II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12076,46,'50MN Microwarpdrive II','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,1934240.0000,1,131,0),(12077,126,'50MN Microwarpdrive II Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(12084,46,'500MN Microwarpdrive II','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,4551556.0000,1,131,0),(12085,126,'500MN Microwarpdrive II Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(12092,257,'Interceptors','Skill for operation of Interceptors. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,1000000.0000,1,377,0),(12093,257,'Covert Ops','Covert operations frigates are designed for recon and espionage operation. Their main strength is the ability to travel unseen through enemy territory and to avoid unfavorable encounters  Much of their free space is sacrificed to house an advanced spatial field control system. This allows it to utilize very advanced forms of cloaking at greatly reduced CPU cost. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,4000000.0000,1,377,0),(12095,257,'Assault Frigates','Skill for operation of the Assault Frigates. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,4000000.0000,1,377,0),(12096,257,'Logistics','Skill for operation of Logistics cruisers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,28000000.0000,1,377,0),(12097,257,'Destroyers','Skill for the operation of Destroyers.',0,0.01,0,1,NULL,100000.0000,0,NULL,0),(12098,257,'Interdictors','Skill for operation of Interdictors.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,20000000.0000,1,377,0),(12099,257,'Battlecruisers','Skill at operating Battlecruisers. Can not be trained on Trial Accounts.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(12102,67,'Large Remote Capacitor Transmitter II','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,1157646.0000,1,697,0),(12103,147,'Large Remote Capacitor Transmitter II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12104,401,'Improved Cloaking Device II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12105,401,'Covert Ops Cloaking Device II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12108,54,'Deep Core Mining Laser I','A basic mining laser for deep core mining ore such as mercoxit. Very inefficient but does get the job done ... eventually',0,5,0,1,NULL,392328.0000,1,1039,0),(12109,134,'Deep Core Mining Laser I Blueprint',' ',0,0.01,0,1,NULL,3500000.0000,1,338,0),(12110,283,'Homeless','In most societies there are those who, for various reasons, live a life considered below the living standards of the normal citizen. These people are sometimes called tramps, beggars, drifters, vagabonds or homeless. They are especially common in the ultra-capitalistic Caldari State, but are also found elsewhere in most parts of the galaxy.',600,3,0,1,NULL,0.0000,1,23,0),(12179,270,'Research Project Management','Skill at overseeing agent research and development projects.  Allows the simultaneous use of 1 additional Research and Development agent per skill level.',0,0.01,0,1,NULL,40000000.0000,1,375,0),(12180,1218,'Arkonor Processing','Specialization in Arkonor reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Arkonor reprocessing yield per skill level.',0,0.01,0,1,NULL,375000.0000,1,1323,0),(12181,1218,'Bistot Processing','Specialization in Bistot reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Bistot reprocessing yield per skill level.',0,0.01,0,1,NULL,350000.0000,1,1323,0),(12182,1218,'Crokite Processing','Specialization in Crokite reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Crokite reprocessing yield per skill level.',0,0.01,0,1,NULL,325000.0000,1,1323,0),(12183,1218,'Dark Ochre Processing','Specialization in Dark Ochre reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Dark Ochre reprocessing yield per skill level.',0,0.01,0,1,NULL,275000.0000,1,1323,0),(12184,1218,'Gneiss Processing','Specialization in Gneiss reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Gneiss reprocessing yield per skill level.',0,0.01,0,1,NULL,250000.0000,1,1323,0),(12185,1218,'Hedbergite Processing','Specialization in Hedbergite reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Hedbergite reprocessing yield per skill level.',0,0.01,0,1,NULL,225000.0000,1,1323,0),(12186,1218,'Hemorphite Processing','Specialization in Hemorphite reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Hemorphite reprocessing yield per skill level.',0,0.01,0,1,NULL,200000.0000,1,1323,0),(12187,1218,'Jaspet Processing','Specialization in Jaspet reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Jaspet reprocessing yield per skill level.',0,0.01,0,1,NULL,175000.0000,1,1323,0),(12188,1218,'Kernite Processing','Specialization in Kernite reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Kernite reprocessing yield per skill level.',0,0.01,0,1,NULL,150000.0000,1,1323,0),(12189,1218,'Mercoxit Processing','Specialization in Mercoxit reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Mercoxit reprocessing yield per skill level.',0,0.01,0,1,NULL,400000.0000,1,1323,0),(12190,1218,'Omber Processing','Specialization in Omber reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Omber reprocessing yield per skill level.',0,0.01,0,1,NULL,125000.0000,1,1323,0),(12191,1218,'Plagioclase Processing','Specialization in Plagioclase reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Plagioclase reprocessing yield per skill level.',0,0.01,0,1,NULL,75000.0000,1,1323,0),(12192,1218,'Pyroxeres Processing','Specialization in Pyroxeres reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Pyroxeres reprocessing yield per skill level.',0,0.01,0,1,NULL,100000.0000,1,1323,0),(12193,1218,'Scordite Processing','Specialization in Scordite reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Scordite reprocessing yield per skill level.',0,0.01,0,1,NULL,50000.0000,1,1323,0),(12194,1218,'Spodumain Processing','Specialization in Spodumain reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Spodumain reprocessing yield per skill level.',0,0.01,0,1,NULL,300000.0000,1,1323,0),(12195,1218,'Veldspar Processing','Specialization in Veldspar reprocessing. Allows a skilled individual to utilize substandard refining facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Veldspar reprocessing yield per skill level.',0,0.01,0,1,NULL,25000.0000,1,1323,0),(12196,1218,'Scrapmetal Processing','Specialization in Scrapmetal reprocessing. Increases reprocessing returns for modules, ships and other reprocessable equipment (but not ore and ice).\r\r\n\r\r\n2% bonus to ship and module reprocessing yield per skill level.',0,0.01,0,1,NULL,300000.0000,1,1323,0),(12197,817,'Grecko','An infamouse thief and all-round scoundrel, this pirate is a wanted man in every corner of the galaxy.  Concord advises caution in dealing with this individual.  Threat level: Significant',11950000,118000,450,1,4,0.0000,0,NULL,0),(12198,361,'Mobile Small Warp Disruptor I','A small deployable self powered unit that prevents warping within its area of effect. ',0,65,0,1,NULL,1128190.0000,1,405,0),(12199,361,'Mobile Medium Warp Disruptor I','A Medium deployable self powered unit that prevents warping within its area of effect. ',0,195,0,1,NULL,4508396.0000,1,405,0),(12200,361,'Mobile Large Warp Disruptor I','A Large deployable self powered unit that prevents warping within its area of effect.',0,585,0,1,NULL,17990568.0000,1,405,0),(12201,255,'Small Artillery Specialization','Specialist training in the operation of advanced Small Artillery. 2% bonus per skill level to the damage of small turrets requiring Small Artillery Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,1000000.0000,1,364,0),(12202,255,'Medium Artillery Specialization','Specialist training in the operation of advanced Medium Artillery. 2% bonus per skill level to the damage of medium turrets requiring Medium Artillery Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,3000000.0000,1,364,0),(12203,255,'Large Artillery Specialization','Specialist training in the operation of advanced Large Artillery. 2% bonus per skill level to the damage of large turrets requiring Large Artillery Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,364,0),(12204,255,'Medium Beam Laser Specialization','Specialist training in the operation of advanced medium beam lasers. 2% bonus per skill level to the damage of medium turrets requiring Medium Beam Laser Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,3000000.0000,1,364,0),(12205,255,'Large Beam Laser Specialization','Specialist training in the operation of advanced large beam lasers. 2% Bonus per skill level to the damage of large turrets requiring Large Beam Laser Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,364,0),(12206,255,'Medium Railgun Specialization','Specialist training in the operation of advanced medium railguns. 2% bonus per skill level to the damage of medium turrets requiring Medium Railgun Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,3000000.0000,1,364,0),(12207,255,'Large Railgun Specialization','Specialist training in the operation of advanced large railguns. 2% bonus per skill level to the damage of large turrets requiring Large Railgun Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,364,0),(12208,255,'Medium Autocannon Specialization','Specialist training in the operation of advanced medium autocannons. 2% bonus per skill level to the damage of medium turrets requiring Medium Autocannon Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,3000000.0000,1,364,0),(12209,255,'Large Autocannon Specialization','Specialist training in the operation of advanced large autocannons. 2% Bonus per skill level to the damage of large turrets requiring Large Autocannon Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,364,0),(12210,255,'Small Blaster Specialization','Specialist training in the operation of advanced small blasters. 2% bonus per skill level to the damage of small turrets requiring Small Blaster Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,1000000.0000,1,364,0),(12211,255,'Medium Blaster Specialization','Specialist training in the operation of advanced medium blasters. 2% bonus per skill level to the damage of medium turrets requiring Medium Blaster Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,3000000.0000,1,364,0),(12212,255,'Large Blaster Specialization','Specialist training in the operation of advanced large blasters. 2% Bonus per skill level to the damage of large turrets requiring Large Blaster Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,364,0),(12213,255,'Small Pulse Laser Specialization','Specialist training in the operation of small pulse lasers. 2% bonus per skill level to the damage of small turrets requiring Small Pulse Laser Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,1000000.0000,1,364,0),(12214,255,'Medium Pulse Laser Specialization','Specialist training in the operation of advanced medium pulse lasers. 2% bonus per skill level to the damage of medium turrets requiring Medium Pulse Laser Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,3000000.0000,1,364,0),(12215,255,'Large Pulse Laser Specialization','Specialist training in the operation of advanced large pulse lasers. 2% bonus per skill level to the damage of large turrets requiring Large Pulse Laser Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,364,0),(12217,67,'Medium Remote Capacitor Transmitter I','Transfers capacitor energy to another ship.',1000,25,0,1,NULL,102806.0000,1,696,0),(12218,147,'Medium Remote Capacitor Transmitter I Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,1562,0),(12219,67,'Capital Remote Capacitor Transmitter I','Transfers capacitor energy to another ship.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',1000,4000,0,1,4,38325452.0000,1,910,0),(12220,147,'Capital Remote Capacitor Transmitter I Blueprint',' ',0,0.01,0,1,NULL,26773840.0000,1,1562,0),(12221,67,'Medium Remote Capacitor Transmitter II','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,684298.0000,1,696,0),(12222,147,'Medium Remote Capacitor Transmitter II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12223,67,'Capital Remote Capacitor Transmitter II','Transfers capacitor energy to another ship.\r\r\nNote: May only be fitted to capital class ships.',1000,1000,0,1,NULL,39206812.0000,0,NULL,0),(12224,147,'Capital Remote Capacitor Transmitter II Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12225,67,'Large Remote Capacitor Transmitter I','Transfers capacitor energy to another ship.',1000,50,0,1,NULL,248764.0000,1,697,0),(12226,147,'Large Remote Capacitor Transmitter I Blueprint',' ',0,0.01,0,1,NULL,788400.0000,1,1562,0),(12235,365,'Amarr Control Tower','The Amarr have always been fond of majestic and intimidating constructions. Their Control Towers do not deviate from that tradition and are truly big and powerful structures, intended more for preservation of territorial interests than commercial benefits.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Energy Sentry Optimal Range\r\r\n25% bonus to Energy Sentry Damage\r\r\n50% bonus to Silo Cargo Capacity',200000000,8000,140000,1,4,400000000.0000,1,478,0),(12236,365,'Gallente Control Tower','Gallente Control Towers are more pleasing to the eye than they are strong or powerful. They have above average electronic countermeasures, average CPU output, and decent power output compared to towers from the other races, but are quite lacking in sophisticated defenses.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Hybrid Sentry Damage\r\r\n100% bonus to Silo Cargo Capacity',200000000,8000,140000,1,8,400000000.0000,1,478,0),(12237,363,'Ship Maintenance Array','Mobile hangar and fitting structure. Used for ship storage and in-space fitting of modules contained in a ship\'s cargo bay.',100000000,8000,20000000,1,NULL,20000000.0000,1,484,0),(12238,311,'Reprocessing Array','An anchorable reprocessing array, able to take raw ores and process them into minerals. Has a lower reprocessing yield than fully upgraded outposts, but due to its mobile nature it is very valuable to frontier industrialists who operate light years away from the nearest permanent installation. This unit is sanctioned by CONCORD to be used in high-security space.',50000000,6000,200000,1,NULL,25000000.0000,1,482,0),(12239,1282,'Compression Array','This structure contains equipment needed to compress various ore and ice materials for easy transportation across the universe.\r\r\n\r\r\nThis array does not have a particular restriction on security level and may be anchored in Empire sovereign space.',50000000,6000,20000000,1,NULL,50000000.0000,1,1921,0),(12240,364,'Medium Storage Array','Mobile Storage',100000000,1150,8850,1,NULL,0.0000,0,NULL,0),(12241,266,'Sovereignty','Advanced corporation operation. +2000 corporation members allowed per level. \r\r\n\r\r\nNotice: the CEO must update his corporation through the corporation user interface before the skill takes effect. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,500000000.0000,1,365,0),(12242,15,'Station (Conquerable 1)',' ',0,1,0,1,8,0.0000,0,NULL,0),(12243,283,'Science Graduates','People that have recently graduated with a degree in science at an acknowledged university.',250,3,0,1,NULL,0.0000,1,23,0),(12244,817,'University Escort Ship','This is an escort ship for a major university.  These ships are usually well equipped, and are normally used for escorting personelle transports.  They can prove to be quite dangerous as they are designed to fend off pirates in low secure space. Threat level: Deadly',10100000,101000,900,1,NULL,0.0000,0,NULL,0),(12245,185,'Angel Fugitive','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2112000,21120,100,1,2,0.0000,0,NULL,0),(12246,185,'Blood Fugitive','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2810000,28100,120,1,4,0.0000,0,NULL,0),(12248,185,'Sansha\'s Fugitive','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2000000,20000,235,1,4,0.0000,0,NULL,0),(12249,185,'Serpentis Fugitive','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2450000,24500,60,1,8,0.0000,0,NULL,0),(12250,314,'Criminal DNA','Identification tags such as these may prove valuable if handed to the proper organization.',1,0.1,0,1,NULL,0.0000,1,752,0),(12251,817,'Sarrah','Being a part of the infamous pirate group going by the name of \"The Seven\", Sarrah is a threat not to be taken lightly.  These scoundrels have looted countless convoys in high security space, as well as being suspects for various high profile kidnappings throughout the galaxy.  Concord has placed a high bounty on their heads.  Threat level: Very high',10900000,109000,300,1,2,0.0000,0,NULL,0),(12252,817,'Schmidt','Being a part of the infamous pirate group going by the name of \"The Seven\", Schmidt is a threat not to be taken lightly.  These scoundrels have looted countless convoys in high security space, as well as being suspects for various high profile kidnappings throughout the galaxy.  Concord has placed a high bounty on their heads. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(12253,817,'Olufami','Being a part of the infamous pirate group going by the name of \"The Seven\", Olufami is a threat not to be taken lightly.  These scoundrels have looted countless convoys in high security space, as well as being suspects for various high profile kidnappings throughout the galaxy.  Concord has placed a high bounty on their heads. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(12254,817,'Test_NONE','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(12255,817,'Elena Gazky','Being a part of the infamous pirate group going by the name of \"The Seven\", Elena Gazky is a threat not to be taken lightly.  These scoundrels have looted countless convoys in high security space, as well as being suspects for various high profile kidnappings throughout the galaxy.  Concord has placed a high bounty on their heads. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(12256,816,'Zor','Little is known about \"Zor\", other than the fact he is part of an infamous pirate gang going by the nickname \"The Seven\".  Concord lists him as their second in command, and has placed a very high bounty on his head.  The Seven have allegedly taken part in numerous high profile kidnappings throughout the galaxy, as well as ambushing convoys and drug smuggling activity.  All of them go by aliases to hide their identity, and to date no knowledge exists about their origins. Threat level: Deadly',22000000,1080000,235,1,1,0.0000,0,NULL,0),(12257,68,'Medium Nosferatu I','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,25,0,1,NULL,315910.0000,1,693,0),(12258,148,'Medium Nosferatu I Blueprint',' ',0,0.01,0,1,NULL,1975200.0000,1,1564,0),(12259,68,'Medium Nosferatu II','Drains energy from the target ship and adds it to your own. This is a more powerful version designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,1316176.0000,1,693,0),(12260,148,'Medium Nosferatu II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(12261,68,'Heavy Nosferatu I','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,50,0,1,NULL,1663554.0000,1,694,0),(12262,148,'Heavy Nosferatu I Blueprint',' ',0,0.01,0,1,NULL,9876000.0000,1,1564,0),(12263,68,'Heavy Nosferatu II','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,3409836.0000,1,694,0),(12264,148,'Heavy Nosferatu II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(12265,71,'Medium Energy Neutralizer I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,173776.0000,1,690,0),(12266,151,'Medium Energy Neutralizer I Blueprint',' ',0,0.01,0,1,NULL,998400.0000,1,1565,0),(12267,71,'Medium Energy Neutralizer II','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,690876.0000,1,690,0),(12268,151,'Medium Energy Neutralizer II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(12269,71,'Heavy Energy Neutralizer I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,50,0,1,NULL,850636.0000,1,691,0),(12270,151,'Heavy Energy Neutralizer I Blueprint',' ',0,0.01,0,1,NULL,4996740.0000,1,1565,0),(12271,71,'Heavy Energy Neutralizer II','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,1628546.0000,1,691,0),(12272,151,'Heavy Energy Neutralizer II Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(12273,366,'Ancient Acceleration Gate','This is an ancient device that rumour says will hurtle those that come too close to faraway places.  Wary travelers stay away from them as some that have ventured too close have never been seen again.',100000,0,0,1,NULL,0.0000,0,NULL,0),(12274,367,'Ballistic Control System I','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,85006.0000,1,645,0),(12275,400,'Ballistic Control System I Blueprint',' ',0,0.01,0,1,NULL,499200.0000,1,343,0),(12292,10,'Smuggler route stargate','The old smuggling route gates were built by a coalition of Minmatar rebels and various pirate factions as a means to travel quickly and discreetly between the outer regions of space. They are favored by many to whom Empire Space is too high-profile and wish to keep a good distance from the vigilant fleet commanders of CONCORD.',100000000000,10000000,0,1,NULL,0.0000,0,NULL,0),(12293,368,'Basic Global Warp Disruptor','Disrupts warping over a large area.',1,0,0,1,NULL,0.0000,0,NULL,0),(12294,15,'Station (Conquerable 2)',' ',0,1,0,1,8,0.0000,0,NULL,0),(12295,15,'Station (Conquerable 3)',' ',0,1,0,1,8,0.0000,0,NULL,0),(12297,371,'Mobile Small Warp Disruptor I Blueprint',' ',0,0.01,0,1,NULL,7485280.0000,1,407,0),(12300,371,'Mobile Medium Warp Disruptor I Blueprint',' ',0,0.01,0,1,NULL,29941120.0000,1,407,0),(12301,371,'Mobile Large Warp Disruptor I Blueprint',' ',0,0.01,0,1,NULL,119764480.0000,1,407,0),(12302,314,'Test Dummies','These plastic dummies are used for the testing process of various products, including biopods, personal vehicles and gravimetric compressors.',1,2,0,1,NULL,100.0000,1,20,0),(12303,314,'Unassembled Energy Weapons','Energy weapon parts waiting to be assembled into fully functional equipment.',1,5,0,1,NULL,100.0000,1,NULL,0),(12304,370,'Angel Copper Tag','This copper tag carries the rank insignia equivalent of a private within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,1000.0000,1,740,0),(12305,273,'Drone Navigation','Skill at controlling drones at high speeds. 5% increase in drone max velocity per level.',0,0.01,0,1,NULL,100000.0000,1,366,0),(12306,369,'Angel Ship Log 137863054','This salvaged data from a destroyed Angel vessel reveals the following:\r\r\n\"I am continuing mission to raid the tradelines of the periphery. Seems like the gates have gone quiet for now, which should give me time to repair the damage the last conservative bleep did to my munitions hold. I only hope I\'ll get an order soon from commander Barnac to return home to our asteroid processing facility in Illinfrik. I miss the rusty crawlways despite their stink. Perhaps I\'ll have time to have some more fun with the slaves.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12339,369,'Angel Ship Log 165462566','This salvaged data from a destroyed Angel vessel reveals the following:\r\r\n\"We faced heavy onslaught from a group of mercenaries seemingly after our loot that we\'ve pillaged across the region. Rakner surprised one of them with a scrambler, allowing the rest of us to take them out after a few moments of intense fighting. According to our latest mission declaration, we are to get some reinforcements from our \'roid processing facility in Nedegulf. I hope they won\'t be as green as the last batch. That group of wannabe pirates ended up as floating stiffs at the first sign of trouble.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12340,369,'Angel Ship Log 109285473','This salvaged data from a destroyed Angel vessel reveals the following:\r\r\n\"My communication systems should be back online in a matter of days. The hit had disintegrated the sidejack powercables and shredded the delicate wiring inside the touplet. I\'ve managed to dig up some spare cables, but in the end I know I\'ll have to get new parts at our asteroid processing facility in Hardbako.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12341,369,'Angel Ship Log 174132231','This salvaged data from a destroyed Angel vessel reveals the following:\r\r\n\"I\'m jonesin\' for a juicy bottle of spiced wine. When I close my eyes to sleep, I see myriad frozen corpses drifting towards me. I think this job is getting to me. Just a friggin bottle of wine! That\'s all I ask. That\'s it, after this day\'s raiding duty, I\'ll head over to the Sin City complex in Lasleinur and get me some liquor. I\'ve heard they have a nice stash of juice there. They sure won\'t get to drink those heaps of barrels all on their own.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12342,369,'Angel Ship Log 141490454','This salvaged data from a destroyed Angel vessel reveals the following:\r\r\n\"Our plundering fleet is invincible! We\'ve taken down two convoys in the first hour of pillaging. I still have the explosion of their sundering ships burnt into my vision. Oh, how their burning corpses kindle my soul. We took a few of the survivors captive, including a saucy Brutor chick that I\'ll have to introduce to the boys at the \'roid processing facility in Altrinur. I hope I\'ll get my long overdue promotion at last.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12343,369,'Angel Ship Log 349584483','This salvaged data from a destroyed Angel vessel reveals the following:\r\r\n\"The explosive package that the boss told me to deliver to the Senate seems to have gone off in one of our cargo ships. The hold\'s contents are now drifting in the void, attracting scavengers of all sorts. To finish the mission, I will have to go to the installation in LN-56V and pick up a new device. The Senate\'s new order must be suppressed.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12344,74,'200mm Railgun I','The 200mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,NULL,129736.0000,1,565,0),(12345,154,'200mm Railgun I Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,290,0),(12346,74,'200mm Railgun II','The 200mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Javelin, Spike.',1000,10,1,1,NULL,417876.0000,1,565,0),(12347,154,'200mm Railgun II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12354,74,'350mm Railgun I','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,50,2,1,NULL,1395890.0000,1,566,0),(12355,154,'350mm Railgun I Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,289,0),(12356,74,'350mm Railgun II','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Javelin, Spike.',2000,20,2,1,NULL,2741034.0000,1,566,0),(12357,154,'350mm Railgun II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12365,1209,'EM Shield Compensation','5% bonus to EM resistance per level for Shield Amplifiers',0,0.01,0,1,NULL,120000.0000,1,1747,0),(12366,1209,'Kinetic Shield Compensation','5% bonus to kinetic resistance per level for Shield Amplifiers',0,0.01,0,1,NULL,120000.0000,1,1747,0),(12367,1209,'Explosive Shield Compensation','5% bonus to explosive resistance per level for Shield Amplifiers',0,0.01,0,1,NULL,120000.0000,1,1747,0),(12368,272,'Hypereuclidean Navigation','Skill at navigating while cloaked. 20% per level  bonus to cloaked velocity per skill level.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12369,369,'Angel Ship Log 303445882','This salvaged data from a destroyed Angel vessel reveals the following:\r\r\n\"Cannons! We need big friggin cannons! Not those micro autocannons they use for target practice. If only the wing commander would wake up from his stupidity and get us some real weaponry. I want one of heavy metal howitzers they keep at our Sin City complex in Aeditide. He says it\'s more economic this way. Which is another way of saying that he\'s the only one with a clone contract and doesn\'t give a damn whether we make it out alive or not.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12370,369,'Angel Ship Log 343873495','This salvaged data from a destroyed Angel vessel reveals the following:\r\r\n\"Toilet duty is more exciting than this. I\'ve seen graveyards with more life than this raiding party. These guys are totally devout of the gene of humor-appreciation. So what if I podded my wingman!? He had a clone contract back at our installation in RD-FWY. Why did nobody find that funny? I mean, he had it coming in that goofy ship of his. He\'d even spilt some quafe in his goo pod the day before, making the explosion all the more colorful. C\'mon, I just had to do it.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12371,369,'Angel Ship Log 523366291','This salvaged data from a destroyed Angel vessel reveals the following coded message:\r\r\n\"O4: core omega at HG8 delta. Caution. O7: spin kappa to NZPK-G. O1: trail iota with epsilon on B15. Proceed beta delta O3 and rearm. O2: return.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12372,369,'Angel Ship Log 583225679','This salvaged data from a destroyed Angel vessel reveals the following partly coded message:\r\r\n\"Orders: Take m98 and raid convoy at I-0,32. Continue to echo 5 and group up with K6 and G3 at the rendezvous point 832 parsecs from region border. Take loot and surviving ships to shipyard at 77S8-E. Pick up some spiced wine and rock whiskey and meet my fleet 125 parsecs from the Golgothan Fields.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12373,369,'Blood Raider Log 137393941','This salvaged data from a destroyed Blood Raider vessel reveals the following:\r\r\n\"We\'ve experienced heavy casualties since the Empire fleet attacked our outpost in the Outer Ring. We\'ve collected the blood from the wounded and drained the salvaged corpses of the enemy. According to the orders from the cathedral, we are to deliver the barrels to the outpost in the Ainsan system.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12374,369,'Blood Raider Log 118338758','This salvaged data from a destroyed Blood Raider vessel reveals the following communication log:\r\r\n\"Local > What more do you ask of me, Cardinal Sarikusa?\r\r\nOmir Sarikusa > I want you to meet up with three of my Blood Seekers at the outpost in Tegheon. Follow them on this blood quest to collect nine barrels of clone-blood, devoid of any impurities.\r\r\nLocal > Yes, Cardinal. What should I do with the blood from the Piri colony?\r\r\nOmir Sarikusa > Spill it! All I want is pure clone-blood. Anything else is contaminated. Is that clear?\r\r\nLocal > As you wish, Cardinal. I will do as you command.\r\r\nEnd of Transmission.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12375,369,'Blood Raider Log 114019732','This salvaged data from a destroyed Blood Raider vessel reveals the following:\r\r\n\"The Sani Sabik ritual is soon coming up and I fear I haven\'t reached the quota. I\'ve already deposited 600 liters to my storeroom in the outpost at Gasavak. If our raiding party can drain 80 more pilots in the coming week, we should be able to make it.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12376,267,'\'Logic\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,5000000.0000,0,NULL,0),(12377,369,'Blood Raider Log 189897223','This salvaged data from a destroyed Blood Raider vessel reveals the following:\r\r\n\"My prayers have not been answered. Perhaps I have fallen from grace since the incident back at the outpost in Huola. I may have to make up for it in some way. It\'s hard to do anything now after a few of the brothers were taken into custody by those heretic Concord officials. May the curse of the Sani Sabik fall on those wretched souls.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12378,369,'Blood Raider Log 167593883','This salvaged data from a destroyed Blood Raider vessel reveals the following:\r\r\n\"The directions that I was given were very vague. All I know is that I am supposed to go from our outpost in Jedandan, ferrying some drums of blood to another of our outposts in Miroona. I was told the location in Miroona was to be a very obvious one if I started to look from the sun, but it\'s hard to tell what they mean. I know they want the five liters in my own body. If this turns out to be another ambush, I have fitted my ship with a micro warpdrive fast enough to scoot out of range of their leeching lasers.\"\r\r\n',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12379,369,'Blood Raider Log 397001231','This salvaged data from a destroyed Blood Raider vessel reveals the following:\r\r\n\"These frequency crystals are all but burnt out. According to the raid bishop, there\'s plenty at the depot in the 8RQJ-2 system. If things slow down around here, I might find time to jet over there and pick up a few crystals and maybe get some real, warm sustenance in the way.\"\r\r\n ',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12380,369,'Blood Raider Log 335499422','This salvaged data from a destroyed Blood Raider vessel reveals the following:\r\r\n\"I snuck back in the cargo hold yesterday and ripped one of the canister lids off. I just had to taste it. According to the cardinal it\'s supposed to make you immortal. It tasted ok at first, but after  I swallowed a whole cupful my stomache rebelled and threw it all back up. I don\'t think anyone will notice my breakfast floating in there, and if they do, I\'ll be long gone to our Sota outpost.\"\r\r\n\r\r\n ',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12381,369,'Blood Raider Log 389314943','This salvaged data from a destroyed Blood Raider vessel reveals the following:\r\r\n\"The ship is breaking apart. I can hear the plating peeling away and the superstructure groans when I warp. I think somebody should do it a favor and just blast the damn thing, preferably without me inside it. A new ship would be waiting for me at the depot in Q-02UL, but I\'d have to buy some new modules since the old ones are way past their expiration date.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12382,369,'Blood Raider Log 534970023','This salvaged data from a destroyed Blood Raider vessel reveals the following coded message:\r\r\n\"Sarasomi al tokune ra\'popune. Kente ba\'al rapontes al pheton de\'skran o malen Sani Sabik. Dorurem tokun o batine sat dori am Z-XX2J. Meronam taru.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12383,267,'\'Presence\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,5000000.0000,0,NULL,0),(12384,369,'Blood Raider Log 518719843','This salvaged data from a destroyed Blood Raider vessel reveals the following code:\r\r\n\"Secret Base Sys: 0-NTIS\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12385,267,'\'Eidetic Memory\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,5000000.0000,0,NULL,0),(12386,267,'\'Focus\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,5000000.0000,0,NULL,0),(12387,267,'\'Clarity\'','This is part of a set of debunked CONCORD self-help books that used to be very popular among capsuleers until independent researchers proved conclusively that they were largely rubbish.',0,0.01,0,1,NULL,5000000.0000,0,NULL,0),(12388,667,'Imperial Navy Apocalypse','Only those in high favor with the Emperor can earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. These metallic monstrosities see to it that the word of the Emperor is carried out among the denizens of the Empire and beyond.  Threat level: Deadly',20500000,1150000,675,1,4,0.0000,0,NULL,0),(12389,706,'Republic Fleet Tempest','The Tempest battleship can become a real behemoth when fully equipped.\r\r\nThreat level: Deadly',19000000,850000,600,1,2,0.0000,0,NULL,0),(12390,680,'Federation Navy Megathron','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.\r\r\n  Threat level: Deadly',19000000,1140000,675,1,8,0.0000,0,NULL,0),(12391,674,'Caldari Navy Raven','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.  Threat level: Deadly',21000000,1040000,665,1,1,0.0000,0,NULL,0),(12392,691,'Khanid Mashtori','The Khanid Mashtori are an elite sect of bounty hunters which work exclusively for the Khanid royalty.  It is not uncommon for them to operate a battleship or lead a fleet of Khanid ships in times of war.   Threat level: Deadly',12000000,120000,550,1,4,0.0000,0,NULL,0),(12394,673,'Caldari Navy Blackbird','The Blackbird is a small high-tech cruiser newly employed by the Caldari Navy. What it lacks in armor strength it more than makes up with maneuverability and stealth. The Blackbird is not intended for head-on slugfests, but rather delicate tactical situations.  Threat level: Deadly',14000000,96000,305,1,1,0.0000,0,NULL,0),(12438,705,'Republic Fleet Stabber','The Stabber is the mainstay of the Minmatar fleet. It is light and extremely fast, yet surprisingly powerful, with a wide variety of weapons. It is one of few Minmatar vessels that have reached popularity outside Minmatar space.  Threat level: Deadly',10000000,80000,420,1,2,0.0000,0,NULL,0),(12439,668,'Imperial Navy Omen','The Omen is a good example of the sturdy and powerful cruisers of the Amarr, with super strong armor and defenses. It also mounts multiple turret hardpoints.  Threat level: Deadly',11950000,118000,450,1,4,0.0000,0,NULL,0),(12440,678,'Federation Navy Vexor','The Vexor is a strong combat ship that is also geared to operate in a variety of other roles. The Vexor is especially useful for surveying in potentially hostile sectors as it can stay on duty for a very long time before having to return to base. Furthermore, it is well capable of defending itself against even concentrated attacks.  Threat level: Deadly',13075000,115000,480,1,8,0.0000,0,NULL,0),(12441,256,'Missile Bombardment','Proficiency at long-range missile combat. 10% bonus to all missiles\' maximum flight time per level.',0,0.01,0,1,NULL,80000.0000,1,373,0),(12442,256,'Missile Projection','Skill at boosting missile bay trigger circuits and enhancing guided missiles\' ignition systems. 10% bonus to all missiles\' maximum velocity per level.',0,0.01,0,1,NULL,100000.0000,1,373,0),(12444,369,'Serpentis Ship Log 12682884','This salvaged data from a destroyed Serpentis vessel reveals the following:\r\r\n\"The two dealers that contacted me from Stacmon were both the regular low-life scum I\'m used to dealing with. They told me they\'d find me at outpost in Ainaille. These are no high-rollers and are dealing in a few hundreds of Nerve Sticks at most. I think I\'ve got some sticks on me, but joined with the stash I have in Slays, I should be able to facilitate their needs.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12445,369,'Serpentis Ship Log 187076356','This salvaged data from a destroyed Serpentis vessel reveals the following:\r\r\n\"One of the blue-pill packages is leaking in the hold. I checked the boxes before I left the depot in the Torvi system, so they seem to have been fractured sometime on my route through the region. I\'m afraid I may have an intruder onboard.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12446,369,'Serpentis Ship Log 144391348','This salvaged data from a destroyed Serpentis vessel reveals the following:\r\r\n\"This stuff is amazing. According to storage chief Plotola Auki, it only grows under very special circumstances. Every attempt to manufacture it in a lab has failed. It seems to grow well under the dim purple light on our outpost in Osmeden. It will be curious to know what effects this will have on the market.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12447,369,'Serpentis Ship Log 103298223','This salvaged data from a destroyed Serpentis vessel reveals the following:\r\r\n\"The DED has been making some inquiries into our operations in the Erme system. We\'re making inquires into how much the agents value their families\' well-being, though, so soon they should give up and divert their attention to more pressing business.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12448,369,'Serpentis Ship Log 166832001','This salvaged data from a destroyed Serpentis vessel reveals the following:\r\r\n\"I was told by the boss to pick up the delivery at the outpost in Laurvier. The region is clogged with cops as if the rival druglords aren\'t bad enough. I\'ll need at least a cruiser for a job like that.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12449,369,'Serpentis Ship Log 381038422','This salvaged data from a destroyed Serpentis vessel reveals the following:\r\r\n\"I need money fast. This courier job isn\'t paying off. A few of us gangmates are gonna hold-up the supply station in Covryn. According to our sources it shouldn\'t be defended by any guardian angels. At least not until they get their next big shipment, but we\'ll be long gone by then. The sweet thing is that we can probably sell the loot right back to Salvador Sarpati himself.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12450,369,'Serpentis Ship Log 303248612','This salvaged data from a destroyed Serpentis vessel reveals the following:\r\r\n\"The pleasant sound of credits loading into my account, what sweet symphony they make. So what if a few families die by the hand of my \'chemical remedies\'? This is a competitive world and I intend to win gold medal in the survival competition. Soon I\'ll make enough money, I can deposit all the isk from my account at the Serpentis supply depot in the Vaurent system, and start my own business in Foundation.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12451,369,'Serpentis Ship Log 378922371','This salvaged data from a destroyed Serpentis vessel reveals the following:\r\r\n\"Report: We\'ve got supply runs darting from our depot in Toustain, both ways. Three guys are camping in the Syndicate region and four guys in Placid. I\'ve got a small cabal of brothers running the deals between Solitude and Verge, everyone knowing what to do if the heat will rise.\"\r\r\n',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12452,369,'Serpentis Ship Log 534643764','This salvaged data from a destroyed Serpentis vessel reveals the following coded message:\r\r\n\"2 slops thr. Uhorn and D25sg. 50mg test=success. Rprt2 DC UTKS-5. Durand & Bilski=10-4 over log2 Placid.\"\r\r\n\r\r\n',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12453,369,'Serpentis Ship Log 501163556','This salvaged data from a destroyed Serpentis vessel reveals the following coded message:\r\r\n\"Waypnt.3 advance on Syndicate spinw. Echo cont. gate at Fountain. Pick up deliv. Ouelletta; Test results: 810551=Awful, Caimn23=Quality stuff, 25thH=Good.\"\r\r\n\r\r\n',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12454,369,'Guristas Ship Log 119373337','This salvaged data from a destroyed Guristas vessel reveals the following:\r\r\n\"The cooling coils didn\'t make it to HQ in Venal. This means we have to switch over to blasters before we pillage the Lonetrek target. I\'ve already invested in some short range weaponry at the depot in Kakki.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12455,369,'Guristas Ship Log 108634544','This salvaged data from a destroyed Guristas vessel reveals the following:\r\r\n\"Wow, I\'ve met Korako \'The Rabbit\' Kosakami himself! He was sailing his TL2+ Condor into the \'roid facility in Kusomonmon, with a small group of deserter sergeants from the Navy.  Man, wait \'til I tell the guys down at the fitting station.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12456,369,'Guristas Ship Log 125792289','This salvaged data from a destroyed Guristas vessel reveals the following:\r\r\n\"Three days in base was all I had and I\'d better use the short time well. I was speaking with Chief Scout Kaikka Peunato about our outposts in Venal, when he mentioned a hideout of ours that I wasn\'t familiar with. He told me that if I got into trouble, I could always go back to the Aikoro depot for repairs and rearming. It surprised me that I hadn\'t heard about it before, and I\'ll be sure to check it out, if not only to check his credibility.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12457,369,'Guristas Ship Log 175568934','This salvaged data from a destroyed Guristas vessel reveals the following:\r\r\n\"Our numbers rise as the number of navy pilots increases that discover the rewards of piracy versus the deprecatory pay of the state. New recruits are directed to the depot at Ekura, where they are put to the test.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12460,369,'Guristas Ship Log 180983465','This salvaged data from a destroyed Guristas vessel reveals the following part of a report:\r\r\n\"The last wave of intruders came as a surprise. They had three Merlins, a Kestrel missileboat and an osprey fitted with scramblers. Our forces had been weakened by the raid on the Hyasyoda compound, but we had the perimeter lined with backup ships that answered our call as the first two ships sundered. We took on the Merlins with our light crafts and let the reserves take out key targets; the Kestrel and the cruiser. Our three surviving ships headed over to the Mara outpost for repairs and rearming.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12461,369,'Guristas Ship Log 312887432','This salvaged data from a destroyed Guristas vessel reveals the following:\r\r\n\"Orders from Arjidsi Yimishoo: Deliver any loot and salvageable debris to the Obe outpost. Local hands of Guristas Production will then ship it to our commercial stations in the region.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12462,369,'Guristas Ship Log 398560763','This salvaged data from a destroyed Guristas vessel reveals the following:\r\r\n\"The missiles are on their way to the outpost in DT-TCD. Be sure to check their detonators and remove the wrappings so that the cruisers can have clear and hassle-free access when they arrive.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12463,369,'Guristas Ship Log 365764054','This salvaged data from a destroyed Guristas vessel reveals the following:\r\r\n\"Construction parts for the battlestation are being ferried and stored at the outpost in Oijanen. Station personnel training is under way in Venal HQ, estimated to be completed a day after construction completion. The blueprints are to be destroyed in the station incinerator as soon as it has been verified to operate successfully.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12464,816,'Mercenary Overlord','This is a mercenary battleship, usually deployed at the head of a fleet of ships, and harboring their leader.  Only the major factions or biggest corporations in Eve can afford to hire Overlords.  Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(12465,369,'Guristas Ship Log 534987422','This salvaged data from a destroyed Guristas vessel reveals the following:\r\r\n\"TOP SECRET - Destroy after processing\r\r\ntulip command XYZ:300312,321441,53131\r\r\nBOR <18966 au> under <839 au (w/o BOR)>\r\r\ndeadspace complex ZZZR-5.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12466,369,'Guristas Ship Log 573652885','This salvaged data from a destroyed Guristas vessel reveals the following:\r\r\n\"Report: The research plans have been delivered. Meet me at the prison facility in FHB-QA. Bring F&R.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12467,369,'Sansha Ship Log 104398459','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"Must perform better. Must follow masterplan. Must pick up fellow workers at Boranai outpost. Thus was I told, such will I act.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12468,369,'Sansha Ship Log 187342874','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"Sometimes my head hurts. Perhaps it\'s the Master\'s implants. I must be better at tolerating pain. Master wouldn\'t want me to feel pain. I must do what the Master wants. I feel compelled to go to the Hadonoo outpost. I am sure I\'m being directed there to increase my pain threshold. Then I could serve better.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12469,369,'Sansha Ship Log 148920447','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"Orders from Master Sansha: Attack anyone who enters the territory without Concord signiature. After destroying ten ships, return to Dabrid outpost and rearm.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12474,369,'Sansha Ship Log 136423760','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"Must follow the rules set by Master Sansha. Must find my fellow True Slaves at Agil outpost. We must work together to enforce Master\'s will.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12475,369,'Sansha Ship Log 112457832','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"Long live great Sansha! We will fight the evil empires that invade our rightful territory so that our perfect nation shall rise again from the waves of time. Mental Note: Recalibrate master implants at Nidebora outpost.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12476,369,'Sansha Ship Log 363587633','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"Blood Raiders invade our territory. Their pestilence is not welcome in the perfect eden of Sansha. The Power that Master Sansha has given us has enabled us great feats in the fight against the Raiders. An outpost has been built in X4-WLO, to ensure a firm foothold for the soldiers of Sansha in Blood Raider space.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12477,369,'Sansha Ship Log 309832812','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"Rumors have been spreading amongst Sansha\'s nation that The Master is not gone. Those would surely be good news, although we would carry out his orders until the end of days whether he be among us or in heaven. I shall have to check on these rumors at the outpost in C-VZAK.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12478,314,'Khumaak','The Khumaak (literally \"Hand of Maak\") is a replica of an ancient Amarrian relic used 125 years ago by a Minmatar slave to kill his master, thereby sparking a revolt on Arzad II (also known as Starkman Prime). This revolt, while precipitating the almost total annihilation of the Starkmanir Minmatar tribe, has in historical retrospect come to be credited as one of the seminal events in the larger Minmatar uprising. The weapon itself is a three-foot rod with a spiked solar disc on the top, the design of the original relic believed to date back to the pre-Reclaiming era of Amarrian prophet Dano Geinok. It isn\'t believed to have been intended as a weapon originally, but as a rod of command for high-ranking members of the Amarrian Conformist clergy.',2,0.3,0,1,NULL,10000.0000,1,492,0),(12479,369,'Sansha Ship Log 322301875','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"We shall rebuild. We shall serve. We shall carry out the word of the almighty Sansha. After the construction of the outpost in 9UY4-H, we shall go on. The world will be filled with wonders of construction, worthy of the kingdom of Master Sansha.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12480,369,'Sansha Ship Log 549327937','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"Implant error: Failed to initiate navigation subroutines for calibrated system node ZDYA-G. Possible cause: Neural tissue damage.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12481,369,'Sansha Ship Log 566930267','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"Sansha command I4-3G; Base E3-SDZ; reprocess biomass from old slave modules.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12484,273,'Amarr Drone Specialization','Specialization in the operation of advanced Amarr drones. 2% bonus per skill level to the damage of light, medium, heavy and sentry drones requiring Amarr Drone Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,366,0),(12485,273,'Minmatar Drone Specialization','Specialization in the operation of advanced Minmatar drones. 2% bonus per skill level to the damage of light, medium, heavy and sentry drones requiring Minmatar Drone Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,366,0),(12486,273,'Gallente Drone Specialization','Specialization in the operation of advanced Gallente drones. 2% bonus per skill level to the damage of light, medium, heavy and sentry drones requiring Gallente Drone Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,366,0),(12487,273,'Caldari Drone Specialization','Specialization in the operation of advanced Caldari drones. 2% bonus per skill level to the damage of light, medium, heavy and sentry drones requiring Caldari Drone Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,366,0),(12528,370,'Angel Silver Tag','This silver tag carries the rank insignia equivalent of a corporal within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,2250.0000,1,740,0),(12529,370,'Angel Brass Tag','This brass tag carries the rank insignia equivalent of a sergeant within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,4500.0000,1,740,0),(12530,370,'Angel Palladium Tag','This palladium tag carries the rank insignia equivalent of a lieutenant within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,6000.0000,1,740,0),(12531,370,'Angel Crystal Tag','This crystal tag carries the rank insignia equivalent of a captain within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,8250.0000,1,740,0),(12532,370,'Blood Bronze Tag','This bronze tag carries the rank insignia equivalent of a private within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,1000.0000,1,741,0),(12533,370,'Blood Silver Tag','This silver tag carries the rank insignia equivalent of a corporal within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,2250.0000,1,741,0),(12534,370,'Blood Upper-Tier Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,4500.0000,1,741,0),(12535,370,'Blood Platinum Tag','This platinum tag carries the rank insignia equivalent of a lieutenant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,6000.0000,1,741,0),(12536,370,'Blood Crystal Tag','This crystal tag carries the rank insignia equivalent of a captain within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,8250.0000,1,741,0),(12537,370,'Serpentis Bronze Tag','This bronze tag carries the rank insignia equivalent of a private within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,1000.0000,1,747,0),(12538,370,'Serpentis Silver Tag','This silver tag carries the rank insignia equivalent of a corporal within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,8250.0000,1,747,0),(12539,370,'Serpentis Gold Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,4500.0000,1,747,0),(12540,370,'Serpentis Platinum Tag','This platinum tag carries the rank insignia equivalent of a lieutenant within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,6000.0000,1,747,0),(12541,370,'Serpentis Crystal Tag','This crystal tag carries the rank insignia equivalent of a captain within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,8250.0000,1,747,0),(12542,370,'Guristas Bronze Tag','This bronze tag carries the rank insignia equivalent of a private within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,1000.0000,1,745,0),(12543,370,'Guristas Silver Tag','This silver tag carries the rank insignia equivalent of a corporal within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,2250.0000,1,745,0),(12544,370,'Guristas Gold Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,4500.0000,1,745,0),(12545,370,'Guristas Platinum Tag','This platinum tag carries the rank insignia equivalent of a lieutenant within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,6000.0000,1,745,0),(12546,370,'Guristas Crystal Tag','This crystal tag carries the rank insignia equivalent of a captain within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,8250.0000,1,745,0),(12547,370,'Sansha Bronze Tag','This bronze tag carries the rank insignia equivalent of a private within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,1000.0000,1,746,0),(12548,370,'Sansha Silver Tag','This silver tag carries the rank insignia equivalent of a corporal within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,2250.0000,1,746,0),(12549,370,'Sansha Gold Tag','This gold tag carries the rank insignia equivalent of a sergeant within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,4500.0000,1,746,0),(12550,370,'Sansha Platinum Tag','This platinum tag carries the rank insignia equivalent of a lieutenant within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,6000.0000,1,746,0),(12551,370,'Sansha Crystal Tag','This crystal tag carries the rank insignia equivalent of a captain within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,8250.0000,1,746,0),(12552,374,'Lux S','The Khanid Innovation Lux package is not really a laser crystal per say but rather a laser pumped graviton generator.  \r\r\n\r\r\nCan only be used by small tech level II+ Beam Lasers    ',1,1,0,4,NULL,32768.0000,0,NULL,0),(12553,726,'Lux S Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12554,306,'Munition Storage','This supply storage has apparently been left here drifting in space. Perhaps some military or pirate organization still uses it for storing goods.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(12555,306,'Charge Ammunition Storage','This supply storage has apparently been left here drifting in space. Perhaps some military or pirate organization still uses it for storing goods.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(12556,306,'Frequency Crystal Storage','This supply storage has apparently been left here drifting in space. Perhaps some military or pirate organization still uses it for storing goods.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(12557,374,'Gleam S','The Gleam overdrive crystal has tremendous damage capacity but needs substantially more energy than normal. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n75% reduced optimal range.\r\r\n25% increased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Beam Lasers.',1,1,0,4,NULL,45728.0000,1,868,0),(12558,726,'Gleam S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12559,374,'Aurora S','A Carthum Conglomerate small Beam Laser Crystal based on an upgraded version of the standard radio Crystal. Huge range and damage boost but far longer cooldown time. It is next to useless at close ranges. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n80% increased optimal range.\r\r\n75% reduced tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Beam Lasers.\r\r\n',1,1,0,4,NULL,45728.0000,1,868,0),(12560,726,'Aurora S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12561,375,'Blaze S','This frequency modulation crystal uses a modified microwave crystal coupled with a relatively low energy electron beam generator to alter the electric charge of molecules causing them to violently break apart. \r\r\n\r\r\nCan only be used by small tech level II Pulse Lasers      ',1,1,0,4,NULL,32768.0000,0,NULL,0),(12562,726,'Blaze S Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12563,375,'Scorch S','The Scorch is a UV crystal designed by Carthum Conglomerate. Utilizing AI microtrackers it gives a good boost to range but has fairly low damage potential, low tracking and is of limited use against heavily armored targets. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% decreased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Pulse Lasers. ',1,1,0,4,4,44198.0000,1,871,0),(12564,726,'Scorch S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12565,375,'Conflagration S','The Conflagration is a supercharged X-Ray crystal created by Carthum Conglomerate for the Imperial Navy. Has much greater damage potential than the standard version, but needs considerably more capacitor, has reduced effective range and negatively affects the weapon\'s tracking speed. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.\r\r\n30% reduced tracking speed.\r\r\n25% increased capacitor usage.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Pulse Lasers.',1,1,0,4,NULL,44198.0000,1,871,0),(12566,726,'Conflagration S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12597,369,'Angel Ship Log 516543793','This salvaged data from a destroyed Angel vessel reveals the following message:\r\r\n\"Bring the prisoners to the Prison Facility at J2-PZ6. The boys will make them a warm welcome. Be sure to have the biomass barrels ready on the hangar floor.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12598,369,'Blood Raider Log 533870654','This salvaged data from a destroyed Blood Raider vessel reveals the following strange message:\r\r\n\"Deal made. Bring the blood back to base at SKR-SP. Circle to deadspace location and bring her in on the seventh satellite. Turn the grinder on.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12599,369,'Serpentis Ship Log 598549355','This salvaged data from a destroyed Serpentis vessel reveals the following piece of a message:\r\r\n\"... up the shipyard in 7BX-6F just for kicks,  all the time thinking he was so funny. When the CEO heard about it, he had to explain the multi-million isk extra expenditure that went into the construction of the platform. I heard he was kicked soon af...\"\r\r\n\r\r\n',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12600,369,'Guristas Ship Log 524785540','This salvaged data from a destroyed Guristas vessel reveals the following:\r\r\n\"Bring the hostage into the prison facility at CS-ZGD, or your family will be disgraced. Don\'t let us down this time. You\'ve been walking the edge since the H-UCD1 incident.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12601,369,'Sansha Ship Log 500237688','This salvaged data from a destroyed Sansha vessel reveals the following:\r\r\n\"Return with the modules and scrapmetal from the Traumark Installation to outpost in EOT-XL. Destroy the trespassing vessels and leave no survivor. These are the orders from Master Sansha himself.\"',1,0.1,0,1,NULL,0.0000,0,NULL,0),(12602,306,'Missile Storage','This supply storage has apparently been left here drifting in space. Perhaps some military or pirate organization still uses it for storing goods.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(12604,48,'BH Ship Scanner','Scans the target ship and provides a tactical analysis of its capabilities. The further it goes beyond scan range, the more inaccurate its results will be.',0,5,0,1,NULL,1984.0000,0,NULL,0),(12608,372,'Hail S','Hail is an attempt to combine the penetration of titanium sabot with the versatility of a depleted uranium shell. It has tremendous damage potential, but should not be used at long ranges. Any pilot using this ammunition should be prepared to trade optimal range, falloff range, and tracking speed for a devastating amount of damage.\r\r\n\r\r\n25% reduced falloff.\r\r\n50% reduced optimal range.\r\r\n30% reduced tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Autocannons.',0.01,0.0025,0,5000,NULL,63368.0000,1,859,0),(12609,725,'Hail S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12610,377,'Desolation S','The Void Morphite blaster charge is Duvolle Labs\' answer to the recent advances in shield technology. Unlike most blaster charges, the Void\'s main power lies in the electromagnetic radiation generated by the plasmatized morphite.  \r\r\n\r\r\nCan only be used by small tech level II+ Blasters.          ',0.01,0.0025,0,5000,NULL,32768.0000,0,NULL,0),(12611,722,'Desolation S Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12612,377,'Void S','The Void Xenon charge is a high-powered blaster charge that delivers an extremely powerful blast of kinetic energy. However, it has several serious drawbacks, most notably the fact that it requires considerably more capacitor energy than any other blaster charge. It also needs to maintain a clean aim for a slightly longer time than normal.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced tracking speed.\r\r\n50% reduced falloff range.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Blasters.',0.01,0.0025,0,5000,NULL,47168.0000,1,862,0),(12613,722,'Void S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12614,377,'Null S','The Null is an improved version of the standard Thorium charge that possesses greatly improved molecular cohesion, resulting in superior range and reduced particle dissipation.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% decreased tracking speed.\r\r\n40% increased falloff range.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Blasters.',0.01,0.0025,0,5000,NULL,47168.0000,1,862,0),(12615,722,'Null S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12616,373,'Bolt S','The Bolt is actualy a modified Emp Artillery warhead Encased in a standard thungsten charge casing. This results in substantialy improved penetration as the emp shock disrupts the shield allowing the thungsten shrapnel to bypass it more effectively.\r\r\n\r\r\n        \r\r\nCan only be used by small tech level II+ Railguns      ',0.01,0.0025,0,5000,NULL,32768.0000,0,NULL,0),(12617,722,'Bolt S Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12618,373,'Spike S','The spike munition package is designed to deliver huge damage to targets at extreme distances. It consists of a superdense plutonium sabot mounted on a small rocket unit that provides a substantial boost to the sabots impact velocity.  However the charge is next to useless at close range.\r\r\n\r\r\n80% increased optimal range.\r\r\n75% reduced tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Railguns.',0.01,0.0025,0,5000,NULL,51518.0000,1,865,0),(12619,722,'Spike S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12620,373,'Javelin S','The Javelin charge consists of a cluster of Iridium Fletchets with a Graviton Pulse Detonator. This allows for much higher damage than can be achieved by a standard rail system. However, the inherent entropy of graviton pulses means that it is very hard to maintain accuracy at long range.\r\r\n\r\r\n75% reduced optimal range.\r\r\n25% increased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Railguns.',0.01,0.0025,0,5000,NULL,51518.0000,1,865,0),(12621,722,'Javelin S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12625,372,'Barrage S','An advanced version of the standard Nuclear ammo with a Morphite-enriched warhead and a smart tracking system.\r\r\n \r\r\n25% reduced tracking.\r\r\n40% increased falloff.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Autocannons.',0.01,0.0025,0,5000,2,63368.0000,1,859,0),(12626,725,'Barrage S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12627,372,'Storm S','The Storm is a mixed payload submunition system, designed as a versatile all-in-one solution for any combat scenario. Consisting of three different miniature warheads (EMP, Titanium And Plasma), it is incredibly hard to counter completely with standard defensive systems. The downside is of course that individually, the warheads are much weaker than normal and it\'s rather easy to counter at least part of the damage done.          \r\r\n\r\r\nCan only be used by small tech level II+ Autocannons.',0.01,0.0025,0,5000,NULL,0.0000,0,NULL,0),(12628,725,'Storm S Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12629,376,'Shock S','The Shock ionized plasma shell combines many of the benefits of EMP and Phased Plasma and will tear through most shields with relative ease.  However, they require substantially greater turret power to maintain the ammo\'s charge.    \r\r\n\r\r\nCan only be used by small Tech II+ Artillery Cannons.',0.01,0.0025,0,5000,NULL,32768.0000,0,NULL,0),(12630,725,'Shock S Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12631,376,'Quake S','A titanium sabot shell that delivers a shattering blow to the target. It is however nearly twice as bulky as standard ammunition.\r\r\n\r\r\n75% reduced optimal range.\r\r\n25% increased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Artillery Cannons.',0.01,0.0025,0,5000,NULL,138804.0000,1,856,0),(12632,725,'Quake S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12633,376,'Tremor S','An advanced long range shell designed for extended bombardment, the Tremor has great range but is nearly useless in close combat.\r\r\n\r\r\n80% increased optimal range.\r\r\n75% reduced tracking.\r\r\n\r\r\nNote: This ammunition can only be used by small tech level II Artillery Cannons.',0.01,0.0025,0,5000,NULL,138804.0000,1,856,0),(12634,725,'Tremor S Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12709,379,'Target Painter I','A targeting subsystem that projects an electronic \"Tag\" on the target thus making it easier to target and Hit. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized. ',0,5,0,1,NULL,51464.0000,1,757,0),(12710,504,'Target Painter I Blueprint',' ',0,0.01,0,1,NULL,298240.0000,1,1571,0),(12711,341,'Small Active Stealth System I','Scrambles the signature of a ship preventing tracking systems from identifing the ships shape and thus reducing their effectiveness. ',0,10,0,1,NULL,366.0000,0,NULL,0),(12712,120,'Small Active Stealth System I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12713,341,'Medium Active Stealth System I','Scrambles the signature of a ship preventing tracking systems from identifing the ships shape and thus reducing their effectiveness. ',0,20,0,1,NULL,366.0000,0,NULL,0),(12714,120,'Medium Active Stealth System I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12715,341,'Large Active Stealth System I','Scrambles the signature of a ship preventing tracking systems from identifing the ships shape and thus reducing their effectiveness. ',0,40,0,1,NULL,366.0000,0,NULL,0),(12716,120,'Large Active Stealth System I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12717,341,'Huge Active Stealth System I','Scrambles the signature of a ship preventing tracking systems from identifing the ships shape and thus reducing their effectiveness. ',0,80,0,1,NULL,366.0000,0,NULL,0),(12718,120,'Huge Active Stealth System I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12729,1202,'Crane','Developer: Kaalakiota\r\r\n\r\r\nBlockade runner transports are the fastest type of industrial available.  Utilizing sturdy but lightweight construction materials and sacrificing some cargo space, these haulers are able to reach speeds greater than those of a cruiser while withstanding heavy fire - factors which make them ideal for zipping through dangerous territories with valuable cargo.',11000000,195000,4300,1,1,25013560.0000,1,631,0),(12730,503,'Crane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,636,0),(12731,380,'Bustard','Developer: Lai Dai\r\r\n\r\r\nDeep space transports are designed with the depths of lawless space in mind.  Possessing defensive capabilities far in excess of standard industrial ships, they provide great protection for whatever cargo is being transported in their massive holds.  They are, however, some of the slowest ships to be found floating through space.',20000000,390000,5000,1,1,37786588.0000,1,631,0),(12732,503,'Bustard Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,636,0),(12733,1202,'Prorator','Developer: Viziam\r\r\n\r\r\nBlockade runner transports are the fastest type of industrial available.  Utilizing sturdy but lightweight construction materials and sacrificing some cargo space, these haulers are able to reach speeds greater than those of a cruiser while withstanding heavy fire - factors which make them ideal for zipping through dangerous territories with valuable cargo.',10750000,200000,2900,1,4,25184446.0000,1,630,0),(12734,503,'Prorator Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,635,0),(12735,1202,'Prowler','Developer: Core Complexion Inc.\r\r\n\r\r\nBlockade runner transports are the fastest type of industrial available.  Utilizing sturdy but lightweight construction materials and sacrificing some cargo space, these haulers are able to reach speeds greater than those of a cruiser while withstanding heavy fire - factors which make them ideal for zipping through dangerous territories with valuable cargo.',11200000,180000,3500,1,2,24948246.0000,1,633,0),(12736,503,'Prowler Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,638,0),(12743,1202,'Viator','Developer: Duvolle Labs\r\r\n\r\r\nBlockade runner transports are the fastest type of industrial available.  Utilizing sturdy but lightweight construction materials and sacrificing some cargo space, these haulers are able to reach speeds greater than those of a cruiser while withstanding heavy fire - factors which make them ideal for zipping through dangerous territories with valuable cargo.',10000000,190000,3600,1,8,24995868.0000,1,632,0),(12744,503,'Viator Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,637,0),(12745,380,'Occator','Developer: Roden Shipyards\r\r\n\r\r\nDeep space transports are designed with the depths of lawless space in mind.  Possessing defensive capabilities far in excess of standard industrial ships, they provide great protection for whatever cargo is being transported in their massive holds.  They are, however, some of the slowest ships to be found floating through space.\r\r\n',19000000,390000,3900,1,8,37509324.0000,1,632,0),(12746,503,'Occator Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,637,0),(12747,380,'Mastodon','Developer: Thukker Mix\r\r\n\r\r\nDeep space transports are designed with the depths of lawless space in mind.  Possessing defensive capabilities far in excess of standard industrial ships, they provide great protection for whatever cargo is being transported in their massive holds.  They are, however, some of the slowest ships to be found floating through space.\r\r\n\r\r\n',19200000,385000,4500,1,2,37986558.0000,1,633,0),(12748,503,'Mastodon Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,638,0),(12753,380,'Impel','Developer: Khanid Innovations\r\r\n\r\r\nDeep space transports are designed with the depths of lawless space in mind.  Possessing defensive capabilities far in excess of standard industrial ships, they provide great protection for whatever cargo is being transported in their massive holds.  They are, however, some of the slowest ships to be found floating through space.\r\r\n\r\r\nDeveloper: Khanid Innovations, Inc.\r\r\n\r\r\nIn addition to robust electronics systems, the Khanid Kingdom\'s ships possess advanced armor alloys capable of withstanding a great deal of punishment. \r\r\n\r\r\n',19500000,400000,3100,1,4,37739612.0000,1,630,0),(12754,503,'Impel Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,635,0),(12761,376,'Quake L','A titanium sabot shell that delivers a shattering blow to the target. It is however nearly twice as bulky as standard ammunition.\r\r\n\r\r\n75% reduced optimal range.\r\r\n25% increased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Artillery Cannons.',0.01,0.025,0,5000,NULL,1388040.0000,1,854,0),(12762,725,'Quake L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12763,376,'Shock L','The Shock ionized plasma shell combines many of the benefits of EMP and Phased Plasma and will tear through most shields with relative ease.  However, they require substantially greater turret power to maintain the ammo\'s charge.      \r\r\n\r\r\nCan only be used by large Tech II+ Artillery Cannons.',0.01,0.025,0,5000,NULL,32768.0000,0,NULL,0),(12764,725,'Shock L Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12765,376,'Tremor L','An advanced long range shell designed for extended bombardment, the Tremor has great range but is nearly useless in close combat.\r\r\n\r\r\n80% increased optimal range.\r\r\n75% reduced tracking.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Artillery Cannons.',0.01,0.025,0,5000,NULL,1388040.0000,1,854,0),(12766,725,'Tremor L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12767,376,'Quake M','A titanium sabot shell that delivers a shattering blow to the target. It is however nearly twice as bulky as standard ammunition.\r\r\n\r\r\n75% reduced optimal range.\r\r\n25% increased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Artillery Cannons.',0.01,0.0125,0,5000,NULL,555216.0000,1,855,0),(12768,725,'Quake M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12769,376,'Shock M','The Shock ionized plasma shell combines many of the benefits of EMP and Phased Plasma and will tear through most shields with relative ease.  However, they require substantially greater turret power to maintain the ammo\'s charge.      \r\r\n\r\r\nCan only be used by medium Tech II+ Artillery Cannons.',0.01,0.0125,0,5000,NULL,32768.0000,0,NULL,0),(12770,725,'Shock M Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12771,376,'Tremor M','An advanced long range shell designed for extended bombardment, the Tremor has great range but is nearly useless in close combat.\r\r\n\r\r\n80% increased optimal range.\r\r\n75% reduced tracking.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Artillery Cannons.',0.01,0.0125,0,5000,NULL,555216.0000,1,855,0),(12772,725,'Tremor M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12773,372,'Barrage M','An advanced version of the standard Nuclear ammo with a Morphite-enriched warhead and a smart tracking system. \r\r\n\r\r\n25% reduced tracking.\r\r\n40% increased falloff.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Autocannons. ',0.01,0.0125,0,5000,2,319008.0000,1,858,0),(12774,725,'Barrage M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12775,372,'Barrage L','An advanced version of the standard Nuclear ammo with a Morphite-enriched warhead and a smart tracking system. \r\r\n\r\r\n25% reduced tracking.\r\r\n40% increased falloff.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Autocannons.',0.01,0.025,0,5000,2,797520.0000,1,857,0),(12776,725,'Barrage L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12777,372,'Hail M','Hail is an attempt to combine the penetration of titanium sabot with the versatility of a depleted uranium shell. It has tremendous damage potential, but should not be used at long ranges. Any pilot using this ammunition should be prepared to trade optimal range, falloff range, and tracking speed for a devastating amount of damage.\r\r\n\r\r\n25% reduced falloff.\r\r\n50% reduced optimal range.\r\r\n30% reduced tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Autocannons.',0.01,0.0125,0,5000,NULL,319008.0000,1,858,0),(12778,725,'Hail M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12779,372,'Hail L','Hail is an attempt to combine the penetration of titanium sabot with the versatility of a depleted uranium shell. It has tremendous damage potential, but should not be used at long ranges. Any pilot using this ammunition should be prepared to trade optimal range, falloff range, and tracking speed for a devastating amount of damage.\r\r\n\r\r\n25% reduced falloff.\r\r\n50% reduced optimal range.\r\r\n30% reduced tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Autocannons.',0.01,0.025,0,5000,NULL,797520.0000,1,857,0),(12780,725,'Hail L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12781,372,'Storm M','The Storm is a mixed payload submunition system, designed as a versatile all-in-one solution for any combat scenario. Consisting of three different miniature warheads (EMP, Titanium And Plasma), it is incredibly hard to counter completely with standard defensive systems. The downside is of course that individually, the warheads are much weaker than normal and it\'s rather easy to counter at least part of the damage done.          \r\r\n\r\r\nCan only be used by medium tech level II+ Autocannons.   ',0.01,0.0125,0,5000,NULL,32768.0000,0,NULL,0),(12782,725,'Storm M Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12783,372,'Storm L','The Storm is a mixed payload submunition system, designed as a versatile all-in-one solution for any combat scenario. Consisting of three different miniature warheads (EMP, Titanium And Plasma), it is incredibly hard to counter completely with standard defensive systems. The downside is of course that individually, the warheads are much weaker than normal and it\'s rather easy to counter at least part of the damage done.          \r\r\n\r\r\nCan only be used by large tech level II+ Autocannons.   ',0.01,0.025,0,5000,NULL,32768.0000,0,NULL,0),(12784,725,'Storm L Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12785,377,'Null M','The Null is an improved version of the standard Thorium charge that possesses greatly improved molecular cohesion, resulting in superior range and reduced particle dissipation.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% decreased tracking speed.\r\r\n40% increased falloff range.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Blasters.',0.01,0.0125,0,5000,NULL,254208.0000,1,861,0),(12786,722,'Null M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12787,377,'Null L','The Null is an improved version of the standard Thorium charge that possesses greatly improved molecular cohesion, resulting in superior range and reduced particle dissipation.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% decreased tracking speed.\r\r\n40% increased falloff range.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Blasters.    ',0.01,0.025,0,5000,NULL,635520.0000,1,860,0),(12788,722,'Null L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12789,377,'Void M','The Void Xenon charge is a high-powered blaster charge that delivers an extremely powerful blast of kinetic energy. However, it has several serious drawbacks, most notably the fact that it requires considerably more capacitor energy than any other blaster charge. It also needs to maintain a clean aim for a slightly longer time than normal.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced tracking speed.\r\r\n50% reduced falloff range.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Blasters.',0.01,0.0125,0,5000,NULL,254208.0000,1,861,0),(12790,722,'Void M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12791,377,'Void L','The Void Xenon charge is a high-powered blaster charge that delivers an extremely powerful blast of kinetic energy. However, it has several serious drawbacks, most notably the fact that it requires considerably more capacitor energy than any other blaster charge. It also needs to maintain a clean aim for a slightly longer time than normal.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced tracking speed.\r\r\n50% reduced falloff range.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Blasters.',0.01,0.025,0,5000,NULL,635520.0000,1,860,0),(12792,722,'Void L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12793,377,'Desolation M','The Void Morphite blaster charge is Duvolle Labs\' answer to the recent advances in shield technology. Unlike most blaster charges, the Void\'s main power lies in the electromagnetic radiation generated by the plasmatized morphite. \r\r\n\r\r\nCan only be used by medium tech level II+ Blasters.',0.01,0.0125,0,5000,NULL,32768.0000,0,NULL,0),(12794,722,'Desolation M Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12795,377,'Desolation L','The Void Morphite blaster charge is Duvolle Labs\' answer to the recent advances in shield technology. Unlike most blaster charges, the Void\'s main power lies in the electromagnetic radiation generated by the plasmatized morphite. \r\r\n\r\r\nCan only be used by large tech level II+ Blasters.          ',0.01,0.025,0,5000,NULL,32768.0000,0,NULL,0),(12796,722,'Desolation L Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12797,373,'Bolt M','The Bolt is actualy a modified Emp Artillery warhead Encased in a standard thungsten charge casing. This results in substantialy improved penetration as the emp shock disrupts the shield allowing the thungsten scrapnel to bipass it more effectively.\r\r\n\r\r\n        \r\r\nCan only be used by Medium tech level II+ Railguns        ',0.01,0.0125,0,5000,NULL,32768.0000,0,NULL,0),(12798,722,'Bolt M Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12799,373,'Bolt L','The Bolt is actualy a modified Emp Artillery warhead Encased in a standard thungsten charge casing. This results in substantialy improved penetration as the emp shock disrupts the shield allowing the thungsten scrapnel to bipass it more effectively.\r\r\n\r\r\n        \r\r\nCan only be used by Large tech level II+ Railguns      ',0.01,0.025,0,5000,NULL,32768.0000,0,NULL,0),(12800,722,'Bolt L Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12801,373,'Javelin M','The Javelin charge consists of a cluster of Iridium Fletchets with a Graviton Pulse Detonator. This allows for much higher damage than can be achieved by a standard rail system. However, the inherent entropy of graviton pulses means that it is very hard to maintain accuracy at long range.\r\r\n\r\r\n75% reduced optimal range.\r\r\n25% increased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Railguns.',0.01,0.0125,0,5000,NULL,271608.0000,1,864,0),(12802,722,'Javelin M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12803,373,'Javelin L','The Javelin charge consists of a cluster of Iridium Fletchets with a Graviton Pulse Detonator. This allows for much higher damage than can be achieved by a standard rail system. However, the inherent entropy of graviton pulses means that it is very hard to maintain accuracy at long range.\r\r\n\r\r\n75% reduced optimal range.\r\r\n25% increased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Railguns.',0.01,0.025,0,5000,NULL,679020.0000,1,863,0),(12804,722,'Javelin L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12805,373,'Spike M','The spike munition package is designed to deliver huge damage to targets at extreme distances. It consists of a superdense plutonium sabot mounted on a small graviton booster unit that provides a substantial boost to the sabots impact velocity.  However, the charge is next to useless at close range.\r\r\n\r\r\n80% increased optimal range.\r\r\n75% reduced tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Railguns.',0.01,0.0125,0,5000,NULL,271608.0000,1,864,0),(12806,722,'Spike M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12807,373,'Spike L','The Spike munition package is designed to deliver huge damage to targets at extreme distances. It consists of a superdense plutonium sabot mounted on a small rocket unit that provides a substantial boost to the sabots impact velocity.  However, the charge is next to useless at close range.\r\r\n\r\r\n80% increased optimal range.\r\r\n75% reduced tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Railguns.',0.01,0.025,0,5000,NULL,679020.0000,1,863,0),(12808,722,'Spike L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12810,375,'Blaze M','This frequency modulation crystal uses a modified microwave crystal coupled with a relatively low energy electron beam generator to alter the electric charge of molecules causing them to violently break apart. \r\r\n\r\r\nCan only be used by medium tech level II Pulse Lasers      ',1,1,0,4,NULL,32768.0000,0,NULL,0),(12811,726,'Blaze M Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12812,375,'Blaze L','This frequency modulation crystal uses a modified microwave crystal coupled with a relatively low energy electron beam generator to alter the electric charge of molecules causing them to violently break apart. \r\r\n\r\r\nCan only be used by large tech level II Pulse Lasers      ',1,1,0,4,NULL,32768.0000,0,NULL,0),(12813,726,'Blaze L Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12814,375,'Conflagration M','The Conflagration is a supercharged X-Ray crystal created by Carthum Conglomerate for the Imperial Navy. Has much greater damage potential than the standard version, but needs considerably more capacitor, has reduced effective range and negatively affects the weapon\'s tracking speed. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.\r\r\n30% reduced tracking speed.\r\r\n25% increased capacitor usage.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Pulse Lasers. ',1,1,0,4,NULL,242328.0000,1,870,0),(12815,726,'Conflagration M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12816,375,'Conflagration L','The Conflagration is a supercharged X-Ray crystal created by Carthum Conglomerate for the Imperial Navy. Has much greater damage potential than the standard version, but needs considerably more capacitor, has reduced effective range and negatively affects the weapon\'s tracking speed. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.\r\r\n30% reduced tracking speed.\r\r\n25% increased capacitor usage.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Pulse Lasers.\r\r\n',1,1,0,4,NULL,605820.0000,1,869,0),(12817,726,'Conflagration L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12818,375,'Scorch M','The Scorch is a UV crystal designed by Carthum Conglomerate. Utilizing AI microtrackers, it gives a good boost to range but has fairly low damage potential and low tracking and is of limited use against heavily armored targets. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% decreased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Pulse Lasers.\r\r\n',1,1,0,4,4,242328.0000,1,870,0),(12819,726,'Scorch M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12820,375,'Scorch L','The Scorch is a UV crystal designed by Carthum Conglomerate. Utilizing AI microtrackers it gives a good boost to range but has fairly low damage potential, low tracking and is of limited use against heavily armored targets. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% decreased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Pulse Lasers.\r\r\n',1,1,0,4,4,605820.0000,1,869,0),(12821,726,'Scorch L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12822,374,'Aurora M','A Carthum Conglomerate medium Beam Laser Crystal based on an upgraded version of the standard radio Crystal. Huge range and damage boost but also uses way more capacitor power than normal and has a far longer cooldown time. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n80% increased optimal range.\r\r\n75% reduced tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Beam Lasers.',1,1,0,4,NULL,248448.0000,1,867,0),(12823,726,'Aurora M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12824,374,'Aurora L','A Carthum Conglomerate large Beam Laser Crystal based on an upgraded version of the standard radio Crystal. Huge range and damage boost but suffers from much reduced tracking and has a considerably longer cooldown than normal. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n80% increased optimal range.\r\r\n75% reduced tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Beam Lasers.',1,1,0,4,NULL,621120.0000,1,866,0),(12825,726,'Aurora L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12826,374,'Gleam M','The Gleam overdrive crystal has tremendous damage capacity but needs substantially more energy than normal. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n75% reduced optimal range.\r\r\n25% increased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by medium tech level II Beam Lasers.',1,1,0,4,NULL,248448.0000,1,867,0),(12827,726,'Gleam M Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12828,374,'Gleam L','The Gleam overdrive crystal has tremendous damage capacity but needs substantially more energy than normal. The delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n75% reduced optimal range.\r\r\n25% increased tracking speed.\r\r\n\r\r\nNote: This ammunition can only be used by large tech level II Beam Lasers.',1,1,0,4,NULL,621120.0000,1,866,0),(12829,726,'Gleam L Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(12830,374,'Lux M','A Carthum Conglomerate small Beam Laser Crystal based on an upgraded version of the standard radio Crystal. Huge range and damage boost but also uses way more capacitor power than normal and has a far longer cooldown time. \r\r\n\r\r\nCan only be used by medium tech level II+ Beam Lasers',1,1,0,4,NULL,32768.0000,0,NULL,0),(12831,726,'Lux M Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12832,374,'Lux L','A Carthum Conglomerate small Beam Laser Crystal based on an upgraded version of the standard radio Crystal. Huge range and damage boost but also uses way more capacitor power than normal and has a far longer cooldown time. \r\r\n\r\r\nCan only be used by large tech level II+ Beam Lasers',1,1,0,4,NULL,32768.0000,0,NULL,0),(12833,726,'Lux L Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(12834,274,'General Freight','Skill at the stowage and transportation of bulk goods\r\r\n5% Bonus per level to Ship Cargo Capacity',0,0.01,0,1,NULL,200000.0000,0,NULL,0),(12835,817,'Mercenary Commander','This is a mercenary commander.  These freelancers will do almost anything for the highest bidder. Threat level: Extreme',9200000,92000,450,1,1,0.0000,0,NULL,0),(12836,1040,'Transcranial Microcontrollers','The Transcranial Microcontroller was originally developed by the School of Applied Knowledge with funds from several humanitarian organizations to help catatonics regain consciousness and resume their lives, though in a limited capacity. The microcontroller, which can be used both in humans and machines, proved to be a great success and the Ishukone corporation stepped in and bought the rights to the chip several months ago. Since then, further studies by Ishukone technicians have revealed several additional ways the microcontroller can be used, such as control mechanisms in robots for industrial usage. Experts claim that the microchip does not offer higher efficiency in the robots compared to already established methods due to its reliance of a biomechanical host system. ',0,6,0,1,NULL,5800.0000,1,1336,0),(12847,382,'Ammo Shipping Crate',' ',10000,100,120,1,NULL,0.0000,0,NULL,0),(12850,382,'General Shipping Crate',' ',10000,100,120,1,NULL,0.0000,0,NULL,0),(12851,382,'Consumable Shipping Crate',' ',10000,100,120,1,NULL,0.0000,0,NULL,0),(12852,382,'Hazardous Material Shipping Crate',' ',10000,100,120,1,NULL,0.0000,0,NULL,0),(12853,382,'Raw Material Shipping Crate',' ',10000,100,120,1,NULL,0.0000,0,NULL,0),(12854,382,'Frigate Shipping Crate',' ',10000,100,120,1,NULL,0.0000,0,NULL,0),(12856,382,'Mineral Shipping Crate',' ',10000,100,120,1,NULL,0.0000,0,NULL,0),(12865,280,'Quafe Ultra','Quafe Ultra is the new energy drink from the Quafe Company, the largest manufacturer of soft drinks in the universe.  A delightful promuform-and-guarana mix with just a hint of mango and a dash of passion fruit, this party-in-a-can will give you all the energy you can handle and then some!\r\r\n\r\r\nNot recommended for children under 5 and people with high blood pressure, uncontrolled diabetes or epilepsy.  Quafe accepts no responsibility for injuries inflicted under the influence of Quafe Ultra.\r\r\n\r\r\nTrademark, Copyright and all rights reserved by The Quafe Company Ltd.\r\r\n',500,0.1,0,1,NULL,80.0000,1,492,0),(12867,333,'Datacore - Talocan Tech 1',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(12892,817,'Maryk Ogun','Maryk is a high ranking commander within a minmatar organization called the Freedom Fighters.  The Freedom Fighters are an influential organization within the Minmatar Republic, whos sole purpose is to eradicate slavery in all forms, the Amarrian Empire being their prime enemy.  Threat level: Deadly',11200000,112000,480,1,2,0.0000,0,NULL,0),(12989,319,'Rent-A-Dream Pleasure Gardens','This Gallentean pleasure resort sports various activities open for guests, including casinos, baths, escort booths and three domes of simulated tropical paradise for maximum bliss.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(12994,314,'Quafe Ultra Special Edition','Quafe Ultra is the new energy drink from the Quafe Company, the largest manufacturer of soft drinks in the universe. A delightful promuform-and-guarana mix with just a hint of mango and a dash of passion fruit, this party-in-a-can will give you all the energy you can handle and then some!\r\r\n\r\r\nQuafe Ultra special edition is spiked with a \"secret ingredient\" to make the experience more thrilling and exciting for all those who want more from life.\r\r\n\r\r\nNot recommended for children under 5 and people with high blood pressure, uncontrolled diabetes or epilepsy. Quafe accepts no responsibility for injuries inflicted under the influence of Quafe Ultra.\r\r\n\r\r\n',500,0.1,0,1,NULL,0.0000,1,492,0),(12995,314,'Ultra! Promotional holoreel','This holoreel is a promotional reel from Quafe Corp, produced to advertise QuafeUltra. The reel has been universally panned by critics for what is perceived by many as intensely lurid subject matter.  One scene that\'s caused an uproar among various fundamentalist factions involves two of the main characters, Amarr girl Nadira and Brutor male Okar, engaging in a bout of severely salty reparte  immediately followed by quite obviously-hinted-at sexual activity.  In another, the Gallente protagonist, a comely young female, enjoys a sultry dance with two other girls, culminating in a show of half-naked flesh that sent mothers everywhere lunging for their children\'s eyes.  Mentions and displays of Quafe Ultra during the reel\'s 89-minute running time number around 110, resulting in an average of 1.23 not-so-hidden advertisements per minute of the film\'s running time - another reason, critics say, to throw this reel into the jettison canister where it belongs. ',100,0.5,0,1,NULL,0.0000,1,492,0),(12996,817,'UDI Mercenary','This mysterious fightercraft is working with an unknown agenda. Threat level: Deadly',10900000,109000,1400,1,2,0.0000,0,NULL,0),(12999,668,'Ammatar Navy Augoror','The Auguror-class cruiser is one of the old warhorses of the Amarr Empire, having seen action in both the Jovian War and the Minmatar Rebellion. It is mainly used by the Amarrians for escort and scouting duties where frigates are deemed too weak. Like most Amarrian vessels, the Auguror depends first and foremost on its resilience and heavy armor to escape unscathed from unfriendly encounters.  Threat level: Deadly',12250000,115000,465,1,4,0.0000,0,NULL,0),(13000,401,'Prototype Cloaking Device I Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,430,0),(13001,68,'Small Nosferatu II','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,509462.0000,1,692,0),(13002,148,'Small Nosferatu II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(13003,71,'Small Energy Neutralizer II','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,302116.0000,1,689,0),(13004,151,'Small Energy Neutralizer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(13032,550,'Arch Angel Rogue','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(13033,550,'Arch Angel Thug','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(13034,319,'Power Generator','This generator provides power to nearby structures. It is fitted with a small shield module and appears to be coated with a thin layer of armored plates.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(13035,550,'Arch Angel Hijacker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(13036,550,'Arch Angel Outlaw','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(13037,557,'Elder Blood Upholder','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(13038,557,'Elder Blood Worshipper','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2860000,28600,235,1,4,0.0000,0,NULL,0),(13039,557,'Elder Blood Follower','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2870000,28700,235,1,4,0.0000,0,NULL,0),(13040,557,'Elder Blood Herald','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2870000,28700,135,1,4,0.0000,0,NULL,0),(13041,562,'Dire Guristas Invader','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(13042,562,'Dire Guristas Infiltrator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(13043,562,'Dire Guristas Imputor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(13044,562,'Dire Guristas Arrogator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(13045,567,'Sansha\'s Loyal Ravener','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(13046,567,'Sansha\'s Loyal Scavanger','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,200,1,4,0.0000,0,NULL,0),(13047,567,'Sansha\'s Loyal Minion','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2112000,21120,200,1,4,0.0000,0,NULL,0),(13048,567,'Sansha\'s Loyal Servant','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2112000,21120,235,1,4,0.0000,0,NULL,0),(13049,572,'Guardian Agent','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(13050,572,'Guardian Spy','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,140,1,8,0.0000,0,NULL,0),(13051,572,'Guardian Scout','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,235,1,8,0.0000,0,NULL,0),(13052,572,'Guardian Initiate','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,60,1,8,0.0000,0,NULL,0),(13067,314,'Smurgleblaster','A drink like having your brains smashed out by a slice of lemon wrapped round a large gold brick.',2500,0.2,0,1,NULL,0.0000,1,NULL,0),(13068,383,'Guristas Sentry Gun','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,1,0.0000,0,NULL,0),(13069,274,'Starship Freight','The skill at transporting contraband without getting caught. -10% chance of being caught transporting contraband. Base chance 60%.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(13070,274,'Mineral Freight','The skill at transporting contraband without getting caught. -10% chance of being caught transporting contraband. Base chance 60%.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(13071,274,'Munitions Freight','The skill at transporting contraband without getting caught. -10% chance of being caught transporting contraband. Base chance 60%.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(13072,274,'Drone Freight','The skill at transporting contraband without getting caught. -10% chance of being caught transporting contraband. Base chance 60%.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(13073,274,'Raw Material Freight','The skill at transporting contraband without getting caught. -10% chance of being caught transporting contraband. Base chance 60%.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(13074,274,'Consumable Freight','The skill at transporting contraband without getting caught. -10% chance of being caught transporting contraband. Base chance 60%.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(13075,274,'Hazardous Material Freight','The skill at transporting contraband without getting caught. -10% chance of being caught transporting contraband. Base chance 60%.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(13104,671,'Caldari Navy Officer','This is an officer for the Caldari Navy.  A common sight in Caldari raiding parties, these combat veterans are not to be taken lightly.  Threat level: Deadly',10900000,109000,120,1,1,0.0000,0,NULL,0),(13105,705,'Republic Fleet Officer','This is an officer for the Minmatar Fleet.  A common sight in Minmatar raiding parties, these combat veterans are not to be taken lightly.  Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(13106,319,'Scanner Post','This piece of equipment emanates waves from its built-in broadcasting beacon. It is fitted with a small shield module and appears to be coated with a thin layer of armored plates.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(13107,668,'Imperial Navy Officer','This is an officer for the Imperial Navy.  A common sight in Amarr raiding parties, these combat veterans are not to be taken lightly.  Threat level: Deadly',10900000,109000,120,1,4,0.0000,0,NULL,0),(13112,677,'Federation Navy Officer','This is an officer for the Federation Navy.  A common sight in Gallente raiding parties, these combat veterans are not to be taken lightly.  Threat level: Deadly',10900000,109000,120,1,8,0.0000,0,NULL,0),(13113,383,'Sansha Sentry Gun','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,4,0.0000,0,NULL,0),(13114,383,'Angel Sentry Gun','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,2,0.0000,0,NULL,0),(13115,383,'Serpentis Sentry Gun','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,8,0.0000,0,NULL,0),(13116,383,'Blood Raider Sentry Gun','Sentry guns are placed around important space facilities and will attack anyone threatening the place they\'ve been assigned to defend. Sentry guns are very powerful compared to their ease of purchase and deployment. ',1000,1000,1000,1,4,0.0000,0,NULL,0),(13119,648,'Mjolnir Javelin Rocket','A small rocket with an EMP warhead.\r\r\n\r\r\nA modified version of the Mjolnir rocket. It can reach higher velocity than the Mjolnir rocket at the expense of warhead size.',100,0.005,0,5000,NULL,45068.0000,1,928,0),(13163,818,'Mercenary Elite Fighter','This is an elite mercenary fighter.  Its faction alignment is unknown.  It may be aggressive, depending on its assignment.  Threat level: High',1650000,16500,90,1,1,0.0000,0,NULL,0),(13166,742,'Inherent Implants \'Lancer\' Gunnery RF-903','An Inherent Implants gunnery hardwiring designed to enhance turret rate of fire.\r\r\n\r\r\n3% bonus to all turret rate of fire.',0,1,0,1,NULL,200000.0000,1,1501,0),(13200,319,'Large EM Forcefield','An antimatter generator powered by tachyonic crystals, creating a perfect defensive circle of electro-magnetic radiance.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(13201,817,'Testgaur','This is a freedom fighter whos goal in life is to fight oppression and slavery in all corners of the galaxy.  Akori is a Caldari working for the Minmatar Freedom Fighters, which is an organization fighting against slavery everywhere within the galaxy.   The Amarr consider him a terrorist and have placed a sizable bounty on his head.  Threat level: Deadly',10900000,109000,120,1,1,0.0000,0,NULL,0),(13202,27,'Megathron Federate Issue','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.\r\r\n\r\r\nThe Federate Issue is a unique ship, commissioned by Gallentean president Foiritan as an honorary award given to those individuals whose outstanding achivements benefit the entire Federation.',105200000,486000,675,1,8,151356848.0000,1,1620,0),(13203,107,'Megathron Federate Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(13204,314,'Sacred Bricks','Bricks from the Tal-Romon Cathedral, dedicated to the famous saint said to have been clairvoyant. Every brick was blessed by an Apostle, even the mortar was mixed with holy water, ensuring the whole building reeked of divinity. Being in the vicinity of even one of these bricks brings you this much closer to God, so behave now.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(13205,314,'Heart Stone','These religious artifacts are highly decorated and carry an air of something ancient and beyond grasp.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(13206,314,'Defiled Relics','Sacred objects from the Tal-Romon Cathedral that have become tainted through touch with the elements. Though once proud pieces worthy of reverence and penance, they are now nothing more than debris cluttering space.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(13209,744,'Armored Warfare Mindlink','This advanced interface link drastically improves a commander\'s Armored Warfare ability by directly linking to the Structural Integrity Monitors of all ships in the fleet.\r\r\n\r\r\n25% increase to the command bonus of Armored Warfare Link modules.\r\r\n\r\r\nReplaces Armored Warfare skill bonus with fixed 15% armor HP bonus.',0,1,0,1,NULL,200000.0000,1,1505,0),(13210,314,'Cerebral Slice','A slice of the cerebral cortex, part of the outer layers of the brain, which controls for instance sensations, reasoning and memory.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(13211,314,'Epidermis Sliver','Sliver of the upper layer of the skin, the largest organ that provides insulation, sensation and temperature control among other things.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(13212,314,'Liver Bile','Alkaline fluid secreted by the liver and stored in the gall bladder, it aids digestion and hemoglobin breakdown.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(13213,314,'Blood Drop','Tiny drop of oxygen-rich blood, red and juicy.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(13214,314,'Bone Splinter','Tiny fragment of a bone, too small to be easily discernable as to what part of the body it belongs to. Razor-sharp.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(13215,314,'Complex Fullerene Shard','Fullerene is a molecule composed entirely of carbon. It is usually spherical in shape and can be harmful to living organisms. Basic Fullerene is used as superconductors and in the biotech industry. Complex Fullerene is an advanced version of basic fullerene that only the Jovians know how to produce. It is much harder than basic fullerene and is indestructible by all conventional methods used by the other races and thus useless in the current technological environment. The force involved in breaking it into shards must have been staggering. ',10,1,0,1,NULL,0.0000,1,NULL,0),(13216,741,'Zainou \'Gypsy\' CPU Management EE-603','A neural interface upgrade that boosts the pilot\'s skill at electronics.\r\r\n\r\r\n3% bonus to the CPU output.',0,1,0,1,NULL,200000.0000,1,1507,0),(13217,742,'Inherent Implants \'Lancer\' Large Energy Turret LE-1003','An Inherent Implants gunnery hardwiring designed to enhance skill with large energy turrets.\r\r\n\r\r\n3% bonus to large energy turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(13218,742,'Zainou \'Deadeye\' Large Hybrid Turret LH-1003','A Zainou gunnery hardwiring designed to enhance skill with large hybrid turrets.\r\r\n\r\r\n3% bonus to large hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(13219,742,'Eifyr and Co. \'Gunslinger\' Large Projectile Turret LP-1003','An Eifyr and Co. gunnery hardwiring designed to enhance skill with large projectile turrets.\r\r\n\r\r\n3% bonus to large projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(13220,742,'Inherent Implants \'Lancer\' Medium Energy Turret ME-803','An Inherent Implants gunnery hardwiring designed to enhance skill with medium energy turrets.\r\r\n\r\r\n3% bonus to medium energy turret damage.',0,1,0,1,NULL,200000.0000,1,1500,0),(13221,742,'Zainou \'Deadeye\' Medium Hybrid Turret MH-803','A Zainou gunnery hardwiring designed to enhance skill with medium hybrid turrets.\r\r\n\r\r\n3% bonus to medium hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1500,0),(13222,742,'Eifyr and Co. \'Gunslinger\' Medium Projectile Turret MP-803','An Eifyr and Co. gunnery hardwiring designed to enhance skill with medium projectile turrets.\r\r\n\r\r\n3% bonus to medium projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1500,0),(13223,742,'Inherent Implants \'Lancer\' Small Energy Turret SE-603','An Inherent Implants gunnery hardwiring designed to enhance skill with small energy turrets.\r\r\n\r\r\n3% bonus to small energy turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(13224,742,'Zainou \'Deadeye\' Small Hybrid Turret SH-603','A Zainou gunnery hardwiring designed to enhance skill with small hybrid turrets.\r\r\n\r\r\n3% bonus to small hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(13225,742,'Eifyr and Co. \'Gunslinger\' Small Projectile Turret SP-603','An Eifyr and Co. gunnery hardwiring designed to enhance skill with small projectile turrets.\r\r\n\r\r\n3% bonus to small projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(13226,746,'Zainou \'Snapshot\' Cruise Missiles CM-603','A neural interface upgrade that boosts the pilot\'s skill with cruise missiles.\r\r\n\r\r\n3% bonus to the damage of cruise missiles.',0,1,0,1,NULL,200000.0000,1,1493,0),(13227,746,'Zainou \'Snapshot\' Defender Missiles DM-803','A neural interface upgrade that boosts the pilot\'s skill with defender missiles.\r\r\n\r\r\n3% bonus to the velocity of defender missiles.',0,1,0,1,NULL,200000.0000,1,1495,0),(13228,746,'Zainou \'Snapshot\' FOF Explosion Radius FR-1003','A neural interface upgrade that boosts the pilot\'s skill with auto-target missiles.\r\r\n\r\r\n3% bonus to explosion radius of auto-target missiles.',0,1,0,1,NULL,200000.0000,1,1497,0),(13229,746,'Zainou \'Snapshot\' Heavy Missiles HM-703','A neural interface upgrade that boosts the pilot\'s skill with heavy missiles.\r\r\n\r\r\n3% bonus to heavy missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(13230,746,'Zainou \'Snapshot\' Rockets RD-903','A neural interface upgrade that boosts the pilot\'s skill with rockets.\r\r\n\r\r\n3% bonus to the damage of rockets.',0,1,0,1,NULL,200000.0000,1,1496,0),(13231,746,'Zainou \'Snapshot\' Torpedoes TD-603','A neural interface upgrade that boosts the pilot\'s skill with torpedoes.\r\r\n\r\r\n3% bonus to the damage of torpedoes.',0,1,0,1,NULL,200000.0000,1,1493,0),(13232,740,'Zainou \'Gypsy\' Electronic Warfare EW-903','A neural interface upgrade that boosts the pilot\'s skill at electronic warfare.\r\r\n\r\r\n3% reduction in ECM and ECM Burst module capacitor need.',0,1,0,1,NULL,200000.0000,1,1513,0),(13233,1228,'Zainou \'Gypsy\' Long Range Targeting LT-803','A neural interface upgrade that boosts the pilot\'s skill at long range targeting.\r\r\n\r\r\n3% bonus to max targeting range.',0,1,0,1,NULL,21504.0000,1,1766,0),(13234,740,'Zainou \'Gypsy\' Propulsion Jamming PJ-803','A neural interface upgrade that boosts the pilot\'s skill at propulsion jamming.\r\r\n\r\r\n3% reduction in capacitor need for modules requiring Propulsion Jamming skill.',0,1,0,1,NULL,200000.0000,1,1512,0),(13235,740,'Zainou \'Gypsy\' Sensor Linking SL-903','A neural interface upgrade that boosts the pilot\'s skill at sensor linking.\r\r\n\r\r\n3% reduction in capacitor need of modules requiring the Sensor Linking skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(13236,740,'Zainou \'Gypsy\' Weapon Disruption WD-903','A neural interface upgrade that boosts the pilot\'s skill at weapon disruption.\r\r\n\r\r\n3% reduction in capacitor need of modules requiring the Weapon Disruption skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(13237,747,'Eifyr and Co. \'Rogue\' Navigation NN-603','A Eifyr and Co hardwiring designed to enhance pilot navigation skill.\r\r\n\r\r\n3% bonus to ship velocity.',0,1,0,1,NULL,200000.0000,1,1489,0),(13238,747,'Eifyr and Co. \'Rogue\' Fuel Conservation FC-803','Improved control over afterburner energy consumption.\r\r\n\r\r\n3% reduction in afterburner capacitor needs.',0,1,0,1,NULL,200000.0000,1,1491,0),(13239,747,'Eifyr and Co. \'Rogue\' Afterburner AB-606','A neural interface upgrade that boosts the pilot\'s skill with afterburners.\r\r\n\r\r\n6% bonus to the duration of afterburners.',0,1,0,1,NULL,200000.0000,1,1489,0),(13240,747,'Eifyr and Co. \'Rogue\' Evasive Maneuvering EM-703','A neural interface upgrade designed to enhance pilot Maneuvering skill.\r\r\n\r\r\n3% bonus to ship agility.',0,1,0,1,NULL,200000.0000,1,1490,0),(13241,747,'Eifyr and Co. \'Rogue\' Warp Drive Operation WD-606','A neural interface upgrade that boosts the pilot\'s skill at warp drive operation.\r\r\n\r\r\n6% reduction in the capacitor need of warp drive.',0,1,0,1,NULL,200000.0000,1,1489,0),(13242,747,'Eifyr and Co. \'Rogue\' Warp Drive Speed WS-610','A neural interface upgrade that boosts the pilot\'s skill at warp navigation.\r\r\n\r\r\n10% bonus to ships warp speed.',0,1,0,1,NULL,200000.0000,1,1489,0),(13243,747,'Eifyr and Co. \'Rogue\' High Speed Maneuvering HS-903','Improves the performance of microwarpdrives.\r\r\n\r\r\n3% reduction in capacitor need of modules requiring High Speed Maneuvering.',0,1,0,1,NULL,200000.0000,1,1492,0),(13244,742,'Eifyr and Co. \'Gunslinger\' Surgical Strike SS-903','An Eifyr and Co. gunnery hardwiring designed to enhance skill with all turrets.\r\r\n\r\r\n3% bonus to all turret damages.',0,1,0,1,NULL,200000.0000,1,1501,0),(13245,742,'Zainou \'Deadeye\' Trajectory Analysis TA-703','A Zainou gunnery hardwiring designed to enhance falloff range.\r\r\n\r\r\n3% bonus to turret falloff.',0,1,0,1,NULL,200000.0000,1,1499,0),(13246,742,'Inherent Implants \'Lancer\' Controlled Bursts CB-703','An Inherent Implants gunnery hardwiring designed to enhance turret energy management.\r\r\n\r\r\n3% reduction in all turret capacitor need.',0,1,0,1,NULL,200000.0000,1,1499,0),(13247,746,'Zainou \'Deadeye\' Missile Bombardment MB-703','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n3% bonus to all missiles\' maximum flight time.',0,1,0,1,NULL,200000.0000,1,1494,0),(13248,746,'Zainou \'Deadeye\' Missile Projection MP-703','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n3% bonus to all missiles\' maximum velocity.',0,1,0,1,NULL,200000.0000,1,1494,0),(13249,746,'Zainou \'Deadeye\' Rapid Launch RL-1003','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n3% bonus to all missile launcher rate of fire.',0,1,0,1,NULL,200000.0000,1,1497,0),(13250,746,'Zainou \'Deadeye\' Target Navigation Prediction TN-903','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n3% decrease in factor of target\'s velocity for all missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(13251,741,'Inherent Implants \'Squire\' Energy Pulse Weapons EP-703','A neural interface upgrade that boosts the pilot\'s skill with energy pulse weapons.\r\r\n\r\r\n3% reduction in the cycle time of modules requiring the Energy Pulse Weapons skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(13252,742,'Zainou \'Gnome\' Weapon Upgrades WU-1003','A neural Interface upgrade that lowers turret CPU needs.\r\r\n\r\r\n3% reduction in the CPU required by turrets.',0,1,0,1,NULL,200000.0000,1,1502,0),(13253,749,'Zainou \'Gnome\' Shield Upgrades SU-603','A neural Interface upgrade that reduces the shield upgrade module power needs.\r\r\n\r\r\n3% reduction in power grid needs of modules requiring the Shield Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1480,0),(13254,741,'Zainou \'Gypsy\' Electronics Upgrades EU-603','A neural interface upgrade that boosts the pilot\'s skill with electronics upgrades.\r\r\n\r\r\n3% reduction in CPU need of modules requiring the Electronics Upgrade skill.',0,1,0,1,NULL,200000.0000,1,1507,0),(13255,741,'Inherent Implants \'Squire\' Energy Grid Upgrades EU-703','A neural interface upgrade that boosts the pilot\'s skill with energy grid upgrades.\r\r\n\r\r\n3% reduction in CPU need of modules requiring the Energy Grid Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(13256,738,'Inherent Implants \'Noble\' Hull Upgrades HG-1003','A neural Interface upgrade that boosts the pilot\'s skill at maintaining their ship\'s midlevel defenses.\r\r\n\r\r\n3% bonus to armor hit points.',0,1,0,1,NULL,200000.0000,1,1518,0),(13257,738,'Inherent Implants \'Noble\' Mechanic MC-803','A neural Interface upgrade that boosts the pilot\'s skill at maintaining the mechanical components and structural integrity of a spaceship.\r\r\n\r\r\n3% bonus to hull hp.',0,1,0,1,NULL,200000.0000,1,1516,0),(13258,738,'Inherent Implants \'Noble\' Repair Systems RS-603','A neural Interface upgrade that boosts the pilot\'s skill in operating armor/hull repair modules.\r\r\n\r\r\n3% reduction in repair systems duration.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,200000.0000,1,1514,0),(13259,741,'Inherent Implants \'Squire\' Capacitor Management EM-803','A neural interface upgrade that boosts the pilot\'s skill at energy management.\r\r\n\r\r\n3% bonus to ships capacitor capacity.',0,1,0,1,NULL,200000.0000,1,1509,0),(13260,741,'Inherent Implants \'Squire\' Capacitor Systems Operation EO-603','A neural interface upgrade that boosts the pilot\'s skill at energy systems operation.\r\r\n\r\r\n3% reduction in capacitor recharge time.',0,1,0,1,NULL,200000.0000,1,1507,0),(13261,741,'Inherent Implants \'Squire\' Power Grid Management EG-603','A neural interface upgrade that boosts the pilot\'s skill at engineering.\r\r\n\r\r\n3% bonus to the power grid output of your ship.',0,1,0,1,NULL,200000.0000,1,1507,0),(13262,749,'Zainou \'Gnome\' Shield Emission Systems SE-803','A neural Interface upgrade that reduces the capacitor need for shield emission system modules such as shield transfer array.\r\r\n\r\r\n3% reduction in capacitor need of modules requiring the Shield Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1482,0),(13263,749,'Zainou \'Gnome\' Shield Operation SP-903','A neural Interface upgrade that boosts the recharge rate of the shields of the pilots ship.\r\r\n\r\r\n3% boost to shield recharge rate.',0,1,0,1,NULL,200000.0000,1,1483,0),(13265,741,'Inherent Implants \'Squire\' Capacitor Emission Systems ES-703','A neural interface upgrade that boosts the pilot\'s skill with energy emission systems.\r\r\n\r\r\n3% reduction in capacitor need of modules requiring the Capacitor Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(13267,283,'Janitor','The janitor is the person who is in charge of keeping the premises of a building (as an apartment or office) clean, tends the heating system, and makes minor repairs.',100,3,0,1,NULL,0.0000,1,23,0),(13268,817,'Cathedral Carrier','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',12250000,113000,425,1,8,0.0000,0,NULL,0),(13278,1217,'Archaeology','Proficiency at identifying and analyzing ancient artifacts. Required skill for the use of Relic Analyzer modules.\r\r\n\r\r\nGives +10 Virus Coherence per level.  ',0,0.01,0,1,NULL,100000.0000,1,1110,0),(13279,1241,'Remote Sensing','The ability to gather and analyze remote sensing data from satellites in orbit around a planet and produce properly calibrated surveys.\r\r\n\r\r\nLevel 1: allows scans within 1 ly\r\r\nLevel 2: allows scans within 3 ly\r\r\nLevel 3: allows scans within 5 ly\r\r\nLevel 4: allows scans within 7 ly\r\r\nLevel 5: allows scans within 9 ly\r\r\n ',0,0.01,0,1,NULL,250000.0000,1,1823,0),(13283,745,'Limited Ocular Filter','This image processor implanted in the occipital lobe grants a bonus to a character\'s Perception.\r\r\n\r\r\n+1 Bonus to Perception',0,1,0,1,NULL,10000.0000,1,618,0),(13284,745,'Limited Memory Augmentation','This image processor implanted in the temporal lobe grants a bonus to a character\'s memory.\r\r\n\r\r\n+1 Bonus to Memory',0,1,0,1,NULL,10000.0000,1,619,0),(13285,745,'Limited Neural Boost','A Data processing unit implanted in the Parietal lobe. Grants a bonus to Willpower.\r\r\n\r\r\n+1 Bonus to Willpower',0,1,0,1,NULL,10000.0000,1,620,0),(13286,745,'Limited Social Adaptation Chip','This image processor implanted in the parietal lobe grants a bonus to a character\'s Charisma.\r\r\n\r\r\n+1 Bonus to Charisma',0,1,0,1,NULL,10000.0000,1,622,0),(13287,745,'Limited Cybernetic Subprocessor','This grafted subprocessor implanted in the frontal lobe grants a bonus to a character\'s Intelligence.\r\r\n\r\r\n+1 Bonus to Intelligence',0,1,0,1,NULL,10000.0000,1,621,0),(13288,314,'DNA Sample','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.',1,0.1,0,1,NULL,0.0000,1,752,0),(13320,506,'Cruise Missile Launcher I','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1,1,NULL,167472.0000,1,643,0),(13321,136,'Cruise Missile Launcher I Blueprint',' ',0,0.01,0,1,NULL,749970.0000,1,340,0),(13323,287,'Rogue Drone','This is an unmanned drone.  It appears to be controlled by an artificial intelligence system.  Caution is advised when approaching such vessels.  Threat level: Moderate',100000,60,40,1,NULL,0.0000,0,NULL,0),(13328,314,'Star Charts','A vast number of travel and trade routes are marked on these sheets, which are called Star Charts.  Although most veteran travelers have their travel routes stored in their ships computer, it\'s always handy to carry some hardcopies just in case.',1,0.1,0,1,NULL,100.0000,1,NULL,0),(13513,817,'Rogue Pirate','Rogue pirates belong to no formal faction, or atleast not officially.  Threat level: Deadly',10900000,109000,120,1,4,0.0000,0,NULL,0),(13514,816,'Rogue Pirate Leader','Rogue pirates belong to no faction, atleast officially.  This is a leader of a group of pirates.  Threat level: Deadly',8000000,80000,365,1,8,0.0000,0,NULL,0),(13515,789,'Domination Hijacker','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',2112000,21120,100,1,2,0.0000,0,NULL,0),(13516,789,'Domination Rogue','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',2250000,22500,75,1,2,0.0000,0,NULL,0),(13517,789,'Domination Outlaw','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1740000,17400,220,1,2,0.0000,0,NULL,0),(13518,789,'Domination Thug','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',2600500,26005,120,1,2,0.0000,0,NULL,0),(13519,789,'Domination Ambusher','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1910000,19100,120,1,2,0.0000,0,NULL,0),(13520,790,'Domination Depredator','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',9900000,99000,1900,1,2,0.0000,0,NULL,0),(13521,789,'Domination Hunter','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1910000,19100,80,1,2,0.0000,0,NULL,0),(13522,789,'Domination Impaler','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1645000,16450,120,1,2,0.0000,0,NULL,0),(13523,790,'Domination Crusher','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(13524,790,'Domination Smasher','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,1400,1,2,0.0000,0,NULL,0),(13525,789,'Domination Nomad','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1750000,17500,180,1,2,0.0000,0,NULL,0),(13526,790,'Domination Predator','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',9900000,99000,120,1,2,0.0000,0,NULL,0),(13527,789,'Domination Raider','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1645000,16450,110,1,2,0.0000,0,NULL,0),(13528,789,'Domination Ruffian','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1766000,17660,120,1,2,0.0000,0,NULL,0),(13529,790,'Domination Breaker','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(13530,790,'Domination Defeater','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(13531,790,'Domination Marauder','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(13532,790,'Domination Phalanx','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(13533,790,'Domination Liquidator','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(13534,790,'Domination Centurion','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(13535,848,'Domination Commander','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13536,553,'Mizuro Cybon','Cybon has an air of vulnerability about her petite body, but don\'t expect any mercy from the COO of the Dominations; she\'ll swat you like a fly without a moment\'s thought. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13537,848,'Domination General','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13538,553,'Hakim Stormare','Stormare is a scoundrel and a rogue of Intaki ancestry that roamed the world for years before entering the service of the Dominations, where his reputation for cruelty and avarice are well appreciated. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13539,848,'Domination War General','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13540,848,'Domination Saint','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13541,553,'Gotan Kreiss','Sly and tricky, Kreiss is the head of Internal Security and is feared almost as much within the Dominations as without. Almost. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13542,848,'Domination Nephilim','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13543,848,'Domination Warlord','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13544,553,'Tobias Kruzhor','Kruzhor, commonly known as Raze, is the right hand man of Trald Vukenda, leader of the Dominations. Indeed, many consider Raze to be the real leader, as he keeps enemies at bay and friends in check. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13545,792,'Dark Blood Reaver','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2870000,28700,135,1,4,0.0000,0,NULL,0),(13546,792,'Dark Blood Follower','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,120,1,4,0.0000,0,NULL,0),(13547,791,'Dark Blood Arch Engraver','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',12000000,120000,450,1,4,0.0000,0,NULL,0),(13548,791,'Dark Blood Arch Priest','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(13549,791,'Dark Blood Dark Priest','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(13550,791,'Dark Blood Arch Reaver','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11500000,115000,465,1,4,0.0000,0,NULL,0),(13551,791,'Dark Blood Arch Sage','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(13552,791,'Dark Blood Shadow Sage','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(13553,791,'Dark Blood Arch Templar','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(13554,792,'Dark Blood Diviner','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2860000,28600,235,1,4,0.0000,0,NULL,0),(13555,792,'Dark Blood Upholder','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,135,1,4,0.0000,0,NULL,0),(13556,849,'Dark Blood Prophet','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(13557,559,'Raysere Giant','Known as the Sick Giant, due to his pale complexion and sadistic streak, which makes him ideal for his role as head of Internal Security. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(13558,792,'Dark Blood Collector','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,315,1,4,0.0000,0,NULL,0),(13559,849,'Dark Blood Oracle','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',20500000,1100000,235,1,4,0.0000,0,NULL,0),(13560,849,'Dark Blood Archbishop','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',20500000,1100000,235,1,4,0.0000,0,NULL,0),(13561,559,'Ahremen Arkah','Arkah joined the Raiders as a young girl, working her way upwards. She now handles the day to day operation of the Covenant, a strong indication of her intelligence and determination. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(13562,849,'Dark Blood Apostle','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(13563,849,'Dark Blood Harbinger','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(13564,559,'Draclira Merlonne','Merlonne has spent much of her young life locked up in mental institutions. She is a certified sociopath, her sole loyalty focused on the Raiders, making her both willing and capable of attacking anyone perceived as a threat. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(13565,791,'Dark Blood Priest','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(13566,792,'Dark Blood Raider','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2870000,28700,235,1,4,0.0000,0,NULL,0),(13567,792,'Dark Blood Herald','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,235,1,4,0.0000,0,NULL,0),(13568,792,'Dark Blood Seeker','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,165,1,4,0.0000,0,NULL,0),(13569,791,'Dark Blood Revenant','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(13570,791,'Dark Blood Sage','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(13571,792,'Dark Blood Worshipper','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2820000,24398,235,1,4,0.0000,0,NULL,0),(13572,849,'Dark Blood Archon','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',20500000,1100000,235,1,4,0.0000,0,NULL,0),(13573,559,'Tairei Namazoth','Member of a minor royal family, Namazoth was outcast long ago when she killed her cousins over a trivial matter. Lived in exile for years before finally finding her kin in the Covenant. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(13574,792,'Dark Blood Engraver','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2860000,28600,235,1,4,0.0000,0,NULL,0),(13575,798,'Dread Guristas Killer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',9200000,92000,235,1,1,0.0000,0,NULL,0),(13576,800,'Dread Guristas Arrogator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1500100,15001,45,1,1,0.0000,0,NULL,0),(13577,798,'Dread Guristas Ascriber','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',9600000,96000,450,1,1,0.0000,0,NULL,0),(13578,850,'Dread Guristas Dismantler','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',21000000,1040000,235,1,1,0.0000,0,NULL,0),(13579,850,'Dread Guristas Eliminator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',21000000,1040000,235,1,1,0.0000,0,NULL,0),(13580,564,'Vepas Minimala','The only thing greater than Minimala\'s combat skills is his lust for glory. Vain and pompous, Minimala quit the Caldari Navy after being denied an admiral post. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(13581,800,'Dread Guristas Demolisher','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1650000,16500,235,1,1,0.0000,0,NULL,0),(13582,800,'Dread Guristas Despoiler','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',2040000,20400,100,1,1,0.0000,0,NULL,0),(13583,850,'Dread Guristas Obliterator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',22000000,1080000,235,1,1,0.0000,0,NULL,0),(13584,564,'Thon Eney','Formerly member of the Intaki Syndicate, Eney has quickly risen through the ranks in the Guristas organization. Which comes as no wonder, as she is brilliant, charismatic and utterly corrupt. Threat level: Deadly',22000000,1080000,235,1,1,0.0000,0,NULL,0),(13585,800,'Dread Guristas Destructor','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1970000,19700,235,1,1,0.0000,0,NULL,0),(13586,798,'Dread Guristas Inferno','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(13587,798,'Dread Guristas Abolisher','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(13588,850,'Dread Guristas Eradicator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',21000000,1040000,235,1,1,0.0000,0,NULL,0),(13589,564,'Kaikka Peunato','Peunato, an extremely competent pilot, was forced out of the Caldari Navy when he revealed he was gay. Since joining the Guristas, Peunato has been instrumental in expanding their power and influence. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(13590,800,'Dread Guristas Imputor','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1612000,16120,80,1,1,0.0000,0,NULL,0),(13591,798,'Dread Guristas Mortifier','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(13592,798,'Dread Guristas Eraser','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(13593,800,'Dread Guristas Infiltrator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',2025000,20250,235,1,1,0.0000,0,NULL,0),(13594,800,'Dread Guristas Invader','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',2025000,20250,65,1,1,0.0000,0,NULL,0),(13595,798,'Dread Guristas Nullifier','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(13596,798,'Dread Guristas Murderer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(13597,800,'Dread Guristas Plunderer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1970000,19700,125,1,1,0.0000,0,NULL,0),(13598,800,'Dread Guristas Saboteur','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',2040000,20400,235,1,1,0.0000,0,NULL,0),(13599,798,'Dread Guristas Annihilator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(13600,798,'Dread Guristas Silencer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10700000,107000,850,1,1,0.0000,0,NULL,0),(13601,850,'Dread Guristas Extinguisher','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(13602,850,'Dread Guristas Exterminator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(13603,564,'Estamel Tharchon','Bastard child of a prominent businessman, who ostracized her when she started displaying typical teenage rebellion symptoms. Driven on by her agenda to bring down the Caldari State, Tharchon wastes no opportunity for bringing mayhem upon the State. Threat level: Deadly',1080000,22000000,235,1,1,0.0000,0,NULL,0),(13604,800,'Dread Guristas Wrecker','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1650000,16500,130,1,1,0.0000,0,NULL,0),(13605,808,'True Sansha\'s Beast','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13606,851,'True Sansha\'s Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13609,569,'Brokara Ryver','A former slave of the Empire, Ryver is now a slave of the machines and seems to like it, by what little emotions she\'s still capable of showing. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13610,810,'True Sansha\'s Butcher','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,235,1,4,0.0000,0,NULL,0),(13611,808,'True Sansha\'s Slaughterer','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13612,810,'True Sansha\'s Enslaver','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,235,1,4,0.0000,0,NULL,0),(13613,808,'True Sansha\'s Juggernaut','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13614,851,'True Sansha\'s Slave Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13615,569,'Selynne Mardakar','Even for a Sansha Mardakar is cool and calculated, the epitome of Sansha\'s vision. Fiercely territorial, her enjoyment to fight is the only emotion she ever exhibits. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13616,810,'True Sansha\'s Manslayer','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,200,1,4,0.0000,0,NULL,0),(13617,810,'True Sansha\'s Minion','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,100,1,4,0.0000,0,NULL,0),(13618,808,'True Sansha\'s Torturer','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13619,808,'True Sansha\'s Hellhound','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13620,851,'True Sansha\'s Mutant Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13621,851,'True Sansha\'s Plague Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13622,569,'Vizan Ankonin','Skilled fighter often used by Sansha to take care of tricky situations. A superb tracker capable of locating and hunting down anyone, anywhere. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13623,810,'True Sansha\'s Plague','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,200,1,4,0.0000,0,NULL,0),(13624,808,'True Sansha\'s Ravager','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,200,1,4,0.0000,0,NULL,0),(13625,810,'True Sansha\'s Ravener','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2000000,20000,235,1,4,0.0000,0,NULL,0),(13626,808,'True Sansha\'s Ravisher','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13627,810,'True Sansha\'s Savage','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2000000,20000,200,1,4,0.0000,0,NULL,0),(13628,810,'True Sansha\'s Scavenger','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2000000,20000,200,1,4,0.0000,0,NULL,0),(13629,810,'True Sansha\'s Servant','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2000000,20000,235,1,4,0.0000,0,NULL,0),(13630,808,'True Sansha\'s Mutilator','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13631,808,'True Sansha\'s Fiend','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13632,810,'True Sansha\'s Slavehunter','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,235,1,4,0.0000,0,NULL,0),(13633,851,'True Sansha\'s Beast Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13634,851,'True Sansha\'s Savage Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13635,569,'Chelm Soran','Being autistic, Soran was an embarrassment to his Holder parents, but his unique mindset adapts well to Sansha\'s techniques. A formidable opponent with bold, relentless drive. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13636,808,'True Sansha\'s Execrator','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13637,812,'Shadow Serpentis Chief Watchman','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',11500000,115000,235,1,8,0.0000,0,NULL,0),(13638,812,'Shadow Serpentis Chief Patroller','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(13639,812,'Shadow Serpentis Chief Scout','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',11300000,113000,235,1,8,0.0000,0,NULL,0),(13640,814,'Shadow Serpentis Safeguard','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2300000,23000,235,1,8,0.0000,0,NULL,0),(13641,812,'Shadow Serpentis Chief Spy','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',11600000,116000,900,1,8,0.0000,0,NULL,0),(13642,814,'Shadow Serpentis Guard','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2300000,23000,60,1,8,0.0000,0,NULL,0),(13643,814,'Shadow Serpentis Spy','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2500000,25000,60,1,8,0.0000,0,NULL,0),(13644,814,'Shadow Serpentis Watchman','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2950000,29500,175,1,8,0.0000,0,NULL,0),(13645,814,'Shadow Serpentis Scout','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2250000,22500,125,1,8,0.0000,0,NULL,0),(13646,814,'Shadow Serpentis Agent','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2250000,22500,235,1,8,0.0000,0,NULL,0),(13647,814,'Shadow Serpentis Defender','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2650000,26500,140,1,8,0.0000,0,NULL,0),(13648,814,'Shadow Serpentis Patroller','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2950000,29500,235,1,8,0.0000,0,NULL,0),(13649,814,'Shadow Serpentis Initiate','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2450000,24500,60,1,8,0.0000,0,NULL,0),(13650,814,'Shadow Serpentis Protector','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2650000,26500,235,1,8,0.0000,0,NULL,0),(13651,812,'Shadow Serpentis Chief Protector','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(13652,852,'Shadow Serpentis Vice Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(13653,852,'Shadow Serpentis Rear Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(13654,574,'Cormack Vaaja','An old warhorse, Vaaja has a history of narcotic abuse. While prohibiting him from serving with the Caldari Navy, the more lenient Guardian Angels can truly appreciate his experience and battle fervor. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(13656,812,'Shadow Serpentis Chief Sentinel','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(13658,852,'Shadow Serpentis Commodore','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(13659,574,'Tuvan Orth','Orth may be an egotistical bastard, but he is easily the best fighter Serpentis possesses, which at least makes his intolerable arrogance somewhat excusable. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(13660,852,'Shadow Serpentis Baron','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',19000000,1010000,480,1,8,0.0000,0,NULL,0),(13661,574,'Brynn Jerdola','Jerdola is a former spy for the FIO, her job was to infiltrate the Guardian Angels. Having done so admirably, she was lured by the riches of criminal life and soon changed her allegiance. Threat level: Deadly',19000000,1010000,480,1,8,0.0000,0,NULL,0),(13663,812,'Shadow Serpentis Chief Safeguard','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(13664,812,'Shadow Serpentis Chief Guard','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(13665,852,'Shadow Serpentis Port Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',19000000,1010000,480,1,8,0.0000,0,NULL,0),(13666,852,'Shadow Serpentis Flotilla Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',19000000,1010000,480,1,8,0.0000,0,NULL,0),(13667,574,'Setele Schellan','Being obsessive-compulsive Schellan\'s paranoia has served her and the Guardian Angels well in their constant struggle against authorities and other pirate groups. Threat level: Deadly',19000000,1010000,480,1,8,0.0000,0,NULL,0),(13668,812,'Shadow Serpentis Chief Defender','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(13669,812,'Shadow Serpentis Chief Infantry','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(13670,817,'Korrani Salemo','Once a member of the elite ranks within the Mordu\'s Legion Command, Korrani was a popular role model for young and aspiring pilots within the mercenary organization.  Because of this it was even more surprising that such a talented and well known fighter pilot would be caught up in a murder trial ... of his own brother, who stood to inherit most of the real estate empire previously in possession of his Caldari grandfather.  Korranis tale, although sad, is currently used by mentors within the Mordus Legion to teach new recruits a valuable lesson on life.  But meanwhile, Korrani has made quite a name for himself within the underworld, choosing to live the life of a rogue freelancer rather than face trial in his nation of birth for murder.\r\r\n\r\r\nKorrani operates a powerfull Mordu ship fitted with top notch equipment, a worthy adversary for any decent fighter pilot.',10100000,101000,250,1,1,0.0000,0,NULL,0),(13671,817,'Zerak Cheryn','Zerak is an ex-military agent within the Gallente Navy turned rogue freelance mercenary.  A decent pilot, Zeraks main asset is his bounty hunter skills.  He has been frequently named as a suspect in various cases of kidnapping, usually within the Gallente Federation borders but is also known to operate in other regions of the galaxy.\r\r\n\r\r\nZerak operates a stolen Intaki vessel, and should be considered moderately dangerous to advanced pilots.',11600000,116000,320,1,8,0.0000,0,NULL,0),(13672,817,'Lynk','Lynk is a known freelance mercenary who is well connected within the criminal element outside of Concord patrolled space.  He operates a powerfull cruiser, and is not to be taken lightly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(13673,817,'Kuran \'Scarface\' Lonan','Kuran (Scarface) Lonan is a known freelance mercenary who is well connected within the criminal element outside of Concord patrolled space.  He operates a powerfull cruiser, and is not to be taken lightly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(13678,554,'Angel Carrier','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13679,554,'Angel Convoy','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13680,554,'Angel Trailer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13681,554,'Angel Hauler','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(13682,554,'Angel Bulker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(13683,554,'Angel Transporter','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(13684,554,'Angel Trucker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(13685,554,'Angel Courier','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(13686,554,'Angel Loader','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(13687,554,'Angel Ferrier','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1910000,19100,80,1,2,0.0000,0,NULL,0),(13688,554,'Angel Gatherer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(13689,554,'Angel Harvester','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1910000,19100,120,1,2,0.0000,0,NULL,0),(13690,558,'Blood Carrier','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(13691,558,'Blood Convoy','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(13692,558,'Blood Trailer','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(13693,558,'Blood Hauler','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(13694,558,'Blood Bulker','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(13695,558,'Blood Transporter','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(13696,558,'Blood Trucker','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(13697,558,'Blood Courier','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(13698,558,'Blood Loader','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(13699,558,'Blood Ferrier','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2870000,28700,135,1,4,0.0000,0,NULL,0),(13700,558,'Blood Gatherer','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2860000,28600,235,1,4,0.0000,0,NULL,0),(13701,558,'Blood Harvester','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2870000,28700,235,1,4,0.0000,0,NULL,0),(13702,573,'Serpentis Carrier','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(13703,573,'Serpentis Convoy','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,1010000,480,1,8,0.0000,0,NULL,0),(13704,573,'Serpentis Trailer','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(13705,573,'Serpentis Hauler','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,1010000,480,1,8,0.0000,0,NULL,0),(13706,573,'Serpentis Bulker','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(13707,573,'Serpentis Transporter','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(13708,573,'Serpentis Trucker','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(13709,573,'Serpentis Courier','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(13710,573,'Serpentis Loader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(13711,573,'Serpentis Ferrier','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,140,1,8,0.0000,0,NULL,0),(13712,573,'Serpentis Gatherer','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,235,1,8,0.0000,0,NULL,0),(13713,573,'Serpentis Harvester','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,60,1,8,0.0000,0,NULL,0),(13714,563,'Guristas Carrier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',1080000,22000000,235,1,1,0.0000,0,NULL,0),(13715,563,'Guristas Convoy','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(13716,563,'Guristas Trailer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',22000000,1080000,235,1,1,0.0000,0,NULL,0),(13717,563,'Guristas Hauler','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(13718,563,'Guristas Bulker','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(13719,563,'Guristas Transporter','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(13720,563,'Guristas Trucker','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(13721,563,'Guristas Courier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(13722,563,'Guristas Loader','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(13723,563,'Guristas Ferrier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(13724,563,'Guristas Gatherer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(13725,563,'Guristas Harvester','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(13726,568,'Sansha\'s Carrier','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13727,568,'Sansha\'s Convoy','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13728,568,'Sansha\'s Trailer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13729,568,'Sansha\'s Hauler','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13730,568,'Sansha\'s Bulker','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13731,568,'Sansha\'s Transporter','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13732,568,'Sansha\'s Trucker','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13733,568,'Sansha\'s Courier','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13734,568,'Sansha\'s Loader','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(13735,568,'Sansha\'s Ferrier','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,200,1,4,0.0000,0,NULL,0),(13736,568,'Sansha\'s Gatherer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2112000,21120,200,1,4,0.0000,0,NULL,0),(13737,568,'Sansha\'s Harvester','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2112000,21120,235,1,4,0.0000,0,NULL,0),(13771,817,'Drazin Jaruk','Drazin Jaruk is a old veteran of the underworld who is a longtime affiliate of the infamous pirate organization, the Angel Cartel.  He has countless contacts with various pirate organizations, and has been jailed dozens of times in the past.\r\r\n\r\r\nHe has recently been released from his last prison sentance, and therefore does not carry a bounty on his head and is not a legal target for assassination.',10900000,109000,120,1,2,0.0000,0,NULL,0),(13772,818,'Drezins Capsule','This is an escape capsule which is released upon the destruction of ones ship.',32000,1000,0,1,NULL,0.0000,0,NULL,0),(13773,55,'Domination 125mm Autocannon','This multi-barrel autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',750,5,0.5,1,2,1000.0000,1,574,0),(13774,55,'Domination 1200mm Artillery','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',750,20,1,1,2,595840.0000,1,579,0),(13775,55,'Domination 1400mm Howitzer Artillery','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1500,20,0.5,1,2,744812.0000,1,579,0),(13776,55,'Domination 150mm Autocannon','A simple but effective close combat autocannon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',20,5,0.4,1,2,1976.0000,1,574,0),(13777,55,'Domination 200mm Autocannon','A powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',15,5,0.3,1,2,4484.0000,1,574,0),(13778,55,'Domination 220mm Autocannon','This autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',12,10,2,1,2,25888.0000,1,575,0),(13779,55,'Domination 250mm Artillery','This artillery is one of the most powerful weapons that can be mounted on a frigate. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',150,5,0.1,1,2,5996.0000,1,577,0),(13780,397,'Equipment Assembly Array','A mobile assembly facility where modules, implants, deployables, structures and containers can be manufactured more efficiently than the rapid equipment assembly array but at a reduced speed.\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials',200000000,6250,1000000,1,NULL,60000000.0000,1,932,0),(13781,55,'Domination 280mm Howitzer Artillery','Rocket-assisted artillery projectiles designed for long-range combat. It is the most powerful projectile weapon able to be fitted onto frigates. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',5,5,0.05,1,2,7496.0000,1,577,0),(13782,55,'Domination 425mm Autocannon','The 425mm is a behemoth that will inflict severe damage on most cruisers and frigates in short-range battles. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',8,10,1.5,1,2,44740.0000,1,575,0),(13783,55,'Domination 650mm Artillery','A powerful long-range artillery. One of the most damaging weapons mountable on a cruiser. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',125,10,0.5,1,2,59676.0000,1,578,0),(13784,55,'Domination 720mm Howitzer Artillery','This rocket-assisted howitzer is designed for long-range bombardment. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',50,10,0.25,1,2,74980.0000,1,578,0),(13785,55,'Domination 800mm Repeating Cannon','An autocannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,20,3,1,2,448700.0000,1,576,0),(13786,55,'Domination Dual 180mm Autocannon','This autocannon is a simple but effective close combat weapon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',12.5,10,2.5,1,2,10000.0000,1,575,0),(13787,55,'Domination Dual 425mm Autocannon','Combines the damage output of two 425mm intermediate-range autocannons. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',200,20,5,1,2,98972.0000,1,576,0),(13788,55,'Domination Dual 650mm Repeating Cannon','Powerful, intermediate-range repeating autocannon with a decent rate of fire. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,4,1,2,298716.0000,1,576,0),(13791,53,'Dark Blood Dual Heavy Pulse Laser','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,98972.0000,1,573,0),(13793,53,'Dark Blood Dual Heavy Beam Laser','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,298716.0000,1,569,0),(13795,53,'Dark Blood Dual Light Beam Laser','This light beam laser uses two separate laser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,3472.0000,1,567,0),(13797,53,'Dark Blood Dual Light Pulse Laser','This light pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. Good skirmish weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,1976.0000,1,570,0),(13799,53,'Dark Blood Focused Medium Beam Laser','A high-energy, concentrated laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,44740.0000,1,568,0),(13801,53,'Dark Blood Focused Medium Pulse Laser','A high-energy, concentrated laser designed for short to medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,25888.0000,1,572,0),(13803,53,'Dark Blood Gatling Pulse Laser','Rapid fire multi-barreled energy weapon that delivers a steady stream of damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,1000.0000,1,570,0),(13805,53,'Dark Blood Heavy Beam Laser','A high-energy heavy laser designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,74980.0000,1,568,0),(13807,53,'Dark Blood Heavy Pulse Laser','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,59676.0000,1,572,0),(13809,53,'Dark Blood Small Focused Beam Laser','A high-powered beam laser. Good for medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,7484.0000,1,567,0),(13811,53,'Dark Blood Small Focused Pulse Laser','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,5984.0000,1,570,0),(13813,53,'Dark Blood Mega Beam Laser','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,595840.0000,1,569,0),(13815,53,'Dark Blood Mega Pulse Laser','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,448700.0000,1,573,0),(13817,53,'Dark Blood Tachyon Beam Laser','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,744812.0000,1,569,0),(13819,53,'Dark Blood Quad Beam Laser','Uses four light laser focusing systems. Low powered, but makes up for it with a fast firing rate. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,10000.0000,1,568,0),(13820,53,'True Sansha Dual Heavy Beam Laser','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,298716.0000,1,569,0),(13821,53,'True Sansha Dual Heavy Pulse Laser','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,98972.0000,1,573,0),(13822,53,'True Sansha Dual Light Beam Laser','This light beam laser uses two separate laser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,3472.0000,1,567,0),(13823,53,'True Sansha Dual Light Pulse Laser','This light pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. Good skirmish weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,1976.0000,1,570,0),(13824,53,'True Sansha Focused Medium Beam Laser','A high-energy, concentrated laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,44740.0000,1,568,0),(13825,53,'True Sansha Focused Medium Pulse Laser','A high-energy, concentrated laser designed for short to medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,25888.0000,1,572,0),(13826,53,'True Sansha Gatling Pulse Laser','Rapid fire multi-barreled energy weapon that delivers a steady stream of damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,1000.0000,1,570,0),(13827,53,'True Sansha Heavy Beam Laser','A high-energy heavy laser designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,74980.0000,1,568,0),(13828,53,'True Sansha Heavy Pulse Laser','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,59676.0000,1,572,0),(13829,53,'True Sansha Small Focused Beam Laser','A high-powered beam laser. Good for medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,7484.0000,1,567,0),(13830,53,'True Sansha Small Focused Pulse Laser','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,5984.0000,1,570,0),(13831,53,'True Sansha Mega Beam Laser','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,595840.0000,1,569,0),(13832,53,'True Sansha Mega Pulse Laser','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,448700.0000,1,573,0),(13833,53,'True Sansha Quad Beam Laser','Uses four light laser focusing systems. Low powered, but makes up for it with a fast firing rate. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,10000.0000,1,568,0),(13834,53,'True Sansha Tachyon Beam Laser','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,744812.0000,1,569,0),(13835,226,'Abandoned Drill - Ruined','This colossal drill once served a purpose in some forgotten outfit\'s mining operation. Its technology is long since outdated and it\'s actuators are beyond repair.',0,0,0,1,NULL,0.0000,0,NULL,0),(13836,226,'Walkway Debris','A fragment of a larger structure, this walkway\'s self-luminescent halls are silently running out of energy. What remains of the rest of the structure is unknown, only that it must have been subject to a cataclysmic force, powerful enough to rip apart nanoreinforced station steel.',0,0,0,1,NULL,0.0000,0,NULL,0),(13837,283,'Captives','Unfortunate captives.',80,1,0,1,NULL,0.0000,1,NULL,0),(13856,654,'Nova Javelin Heavy Assault Missile','A nuclear warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range. \r\r\n\r\r\nA modified version of the Nova Heavy Assault Missile. It can reach higher velocity than the Nova Heavy Assault Missile at the expense of warhead size.',625,0.015,0,5000,NULL,63488.0000,1,972,0),(13864,74,'Shadow Serpentis 125mm Railgun','The 125mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,1,4484.0000,1,564,0),(13865,74,'Dread Guristas 125mm Railgun','The 125mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,1,4484.0000,1,564,0),(13866,74,'Shadow Serpentis 150mm Railgun','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,1,7496.0000,1,564,0),(13867,74,'Dread Guristas 150mm Railgun','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,1,7496.0000,1,564,0),(13868,74,'Shadow Serpentis 200mm Railgun','The 200mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,NULL,100000.0000,1,565,0),(13870,74,'Dread Guristas 200mm Railgun','The 200mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,NULL,100000.0000,1,565,0),(13872,74,'Shadow Serpentis 250mm Railgun','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,0.5,1,1,74980.0000,1,565,0),(13873,74,'Dread Guristas 250mm Railgun','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,0.5,1,1,74980.0000,1,565,0),(13874,74,'Shadow Serpentis 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(13876,74,'Dread Guristas 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(13878,74,'Shadow Serpentis 425mm Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,1,744812.0000,1,566,0),(13879,74,'Dread Guristas 425mm Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,1,744812.0000,1,566,0),(13880,74,'Shadow Serpentis Dual 150mm Railgun','This cruiser-sized weapon is a double-barreled version of the frigate class 150mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2,1,1,10000.0000,1,565,0),(13881,74,'Dread Guristas Dual 150mm Railgun','This cruiser-sized weapon is a double-barreled version of the frigate class 150mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2,1,1,10000.0000,1,565,0),(13882,74,'Shadow Serpentis Dual 250mm Railgun','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,1,98972.0000,1,566,0),(13883,74,'Dread Guristas Dual 250mm Railgun','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,1,98972.0000,1,566,0),(13884,74,'Shadow Serpentis Heavy Electron Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2.5,1,4,25888.0000,1,562,0),(13885,74,'Shadow Serpentis Heavy Ion Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1.5,1,4,44740.0000,1,562,0),(13886,74,'Shadow Serpentis Light Electron Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,4,1976.0000,1,561,0),(13887,74,'Shadow Serpentis Light Ion Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.3,1,4,4484.0000,1,561,0),(13888,74,'Shadow Serpentis Light Neutron Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,4,5996.0000,1,561,0),(13889,74,'Shadow Serpentis Electron Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,5,1,4,298716.0000,1,563,0),(13890,74,'Shadow Serpentis Ion Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,3,1,4,448700.0000,1,563,0),(13891,74,'Shadow Serpentis Neutron Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,4,595840.0000,1,563,0),(13892,74,'Shadow Serpentis Heavy Neutron Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,4,59676.0000,1,562,0),(13893,74,'Dread Guristas 75mm Railgun','A small multi-barreled railgun for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid ammo types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,1,1000.0000,1,564,0),(13894,74,'Shadow Serpentis 75mm Railgun','A small multi-barreled railgun for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,1,1000.0000,1,564,0),(13895,818,'Darkonnen Veteran','This is a veteran fighter for the Darkonnen. It is protecting the assets of the Darkonnen and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(13896,817,'Darkonnen Gang Leader','This is a fighter for the Darkonnen. It is protecting the assets of the Darkonnen and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(13897,817,'Darkonnen Overlord','This is one of the highest ranking leaders within the Darkonnen organization. It is protecting the assets of the Darkonnen and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(13898,818,'Maru Raider','This is a fighter for Marus Rebels. It is protecting the assets of Marus Rebels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(13899,817,'Maru Raid Leader','This is a raid leader for Marus Rebels. It is protecting the assets of Marus Rebels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13900,817,'Maru Harbinger','This is a very important figure within the Marus Rebels. Harbingers of Doom they are also called, for good reason.  Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(13901,818,'Odamian Privateer','This is a fighter for the Odamian Renegades. It is protecting the assets of the Odamian Renegades and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(13902,817,'Odamian Veteran','This is a veteran fighter for the Odamian Renegades. It is protecting the assets of the Odamian Renegades and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11500000,115000,235,1,8,0.0000,0,NULL,0),(13903,817,'Odamian Master','This is a leader of the Odamian Renegades.  Odamian Masters are the second highest ranking members of their organization, exceeded only by the head honcho himself. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(13904,818,'Komni Smuggler','This is a smuggler for the Komni Corporation. It is protecting the assets of the Komni Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(13905,817,'Komni Assassin','This is a fighter for the Komni Corporation.  Komni Assassins are used to eliminate anyone who the Komni leaders percieve as a threat, and have been known to target high profile members of the Caldari State.  They are also sometimes used to protect the Komni smugglers while they are conducting risky operations. Threat level: Deadly',9200000,92000,235,1,1,0.0000,0,NULL,0),(13906,817,'Komni Honcho','This is a leader within the Komni Corporation.  Komni Honchos are the highest ranking members of the Komni Corporation within a certain area, answering only to the head honcho himself, Drako. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(13908,816,'Komni Envoy','This is a battleship class envoy for the Komni Corporation.  It is extremely well equipped and should only be engaged by the most experienced pilots out there.  Threat level: Deadly.',21000000,1040000,235,1,1,0.0000,0,NULL,0),(13909,816,'Darkonnen Envoy','This is a battleship class envoy for the Darkonnen organization.  It is extremely well equipped and should only be engaged by the most experienced pilots out there.  Threat level: Deadly.',20500000,1100000,235,1,4,0.0000,0,NULL,0),(13910,816,'Maru Envoy','This is a battleship class envoy for the Maru Rebels.  It is extremely well equipped and should only be engaged by the most experienced pilots out there.  Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(13911,816,'Odamian Envoy','This is a battleship class envoy for the Odamian Renegades.  It is extremely well equipped and should only be engaged by the most experienced pilots out there.  Threat level: Deadly.',19000000,1010000,480,1,8,0.0000,0,NULL,0),(13914,818,'Darkonnen Grunt','This is a fighter for the Darkonnen organization. It is protecting the assets of the Darkonnen and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2810000,28100,315,1,4,0.0000,0,NULL,0),(13915,818,'Maru Grunt','This is a fighter for the Maru Rebels. It is protecting the assets of the Maru Rebels and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',1750000,17500,180,1,2,0.0000,0,NULL,0),(13916,818,'Odamian Guard','This is a fighter for the Odamian Renegades. It is protecting the assets of the Odamian Renegades and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2950000,29500,235,1,8,0.0000,0,NULL,0),(13917,818,'Komni Grunt','This is a fighter for the Komni Corporation. It is protecting the assets of the Komni Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2040000,20400,235,1,1,0.0000,0,NULL,0),(13918,314,'Korranis DNA','Once a member of the elite ranks within the Mordu\'s Legion Command, Korrani was a popular role model for young and aspiring pilots within the mercenary organization. Because of this it was even more surprising that such a talented and well known fighter pilot would be caught up in a murder trial ... of his own brother, who stood to inherit most of the real estate empire previously in possession of his Caldari grandfather. Korranis tale, although sad, is currently used by mentors within the Mordus Legion to teach new recruits a valuable lesson on life. But meanwhile, Korrani has made quite a name for himself within the underworld, choosing to live the life of a rogue freelancer rather than face trial in his nation of birth for murder. Korrani operates a powerfull Mordu ship fitted with top notch equipment, a worthy adversary for any decent fighter pilot. ',1,0.1,0,1,NULL,0.0000,1,752,0),(13919,511,'Domination Rapid Light Missile Launcher','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.315,1,1,4224.0000,1,641,0),(13920,511,'Dread Guristas Rapid Light Missile Launcher','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.315,1,1,4224.0000,1,641,0),(13921,510,'Domination Heavy Missile Launcher','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,1.23,1,1,14996.0000,1,642,0),(13922,510,'Dread Guristas Heavy Missile Launcher','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,1.35,1,1,14996.0000,1,642,0),(13923,508,'Domination Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2,1,1,20580.0000,1,644,0),(13924,508,'Dread Guristas Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.3,1,1,20580.0000,1,644,0),(13925,509,'Domination Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.9,1,1,3000.0000,1,640,0),(13926,509,'Dread Guristas Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.9,1,1,3000.0000,1,640,0),(13927,506,'Domination Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.35,1,NULL,99996.0000,1,643,0),(13929,506,'Dread Guristas Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.5,1,NULL,99996.0000,1,643,0),(13931,507,'Domination Rocket Launcher','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.2531,1,NULL,3000.0000,1,639,0),(13933,507,'Dread Guristas Rocket Launcher','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.2813,1,NULL,3000.0000,1,639,0),(13935,367,'Domination Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,645,0),(13937,367,'Dread Guristas Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,645,0),(13939,59,'Domination Gyrostabilizer','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24320.0000,1,646,0),(13941,205,'Dark Blood Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,647,0),(13943,205,'True Sansha Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,647,0),(13945,302,'Shadow Serpentis Magnetic Field Stabilizer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24994.0000,1,648,0),(13947,40,'Dread Guristas Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(13948,40,'Domination Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(13949,40,'Dread Guristas Medium Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,1,18216.0000,1,610,0),(13950,40,'Domination Medium Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,1,18216.0000,1,610,0),(13951,40,'Dread Guristas Small Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,1,4554.0000,1,609,0),(13952,40,'Domination Small Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,1,4554.0000,1,609,0),(13953,40,'Dread Guristas X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(13954,40,'Domination X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(13955,62,'Domination Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(13956,62,'True Sansha Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(13957,62,'Dark Blood Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(13958,62,'Domination Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,4,19916.0000,1,1050,0),(13959,62,'True Sansha Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,4,19916.0000,1,1050,0),(13960,62,'Dark Blood Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,4,19916.0000,1,1050,0),(13962,62,'Domination Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,4,9996.0000,1,1049,0),(13963,62,'True Sansha Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,4,9996.0000,1,1049,0),(13964,62,'Dark Blood Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,4,9996.0000,1,1049,0),(13965,77,'Dread Guristas EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(13966,77,'Dread Guristas Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(13967,77,'Dread Guristas Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(13968,77,'Dread Guristas Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(13969,77,'Dread Guristas Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(13970,328,'True Sansha Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(13972,328,'Dark Blood Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(13974,328,'True Sansha Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(13976,328,'Dark Blood Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(13978,328,'True Sansha Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(13980,328,'Dark Blood Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(13982,328,'True Sansha Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(13984,328,'Dark Blood Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(13986,328,'Domination Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(13988,328,'Domination Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(13990,328,'Domination Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(13992,328,'Domination Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(13994,77,'Domination EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,4,45412.0000,1,1695,0),(13995,77,'Domination Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,8,45412.0000,1,1692,0),(13996,77,'Domination Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,1,45412.0000,1,1694,0),(13997,77,'Domination Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,2,5808.0000,1,1693,0),(13998,77,'Domination Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,1,63062.0000,1,1696,0),(13999,98,'Domination Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14001,98,'True Sansha Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14003,98,'Dark Blood Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14005,98,'Domination Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14007,98,'True Sansha Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14009,98,'Dark Blood Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14011,98,'Domination Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14013,98,'True Sansha Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14015,98,'Dark Blood Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14017,98,'Domination EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14019,98,'True Sansha EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14021,98,'Dark Blood EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14023,98,'Domination Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14025,98,'True Sansha Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14027,98,'Dark Blood Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14029,295,'Domination Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(14031,295,'Dread Guristas Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(14033,295,'Domination Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(14035,295,'Dread Guristas Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(14037,295,'Domination Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(14039,295,'Dread Guristas Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(14041,295,'Domination EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(14043,295,'Dread Guristas EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(14045,338,'Domination Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(14047,338,'Dread Guristas Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(14049,98,'Shadow Serpentis Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14051,98,'Shadow Serpentis Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14053,98,'Shadow Serpentis Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14055,98,'Shadow Serpentis EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14057,98,'Shadow Serpentis Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14059,328,'Shadow Serpentis Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(14061,328,'Shadow Serpentis Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(14063,328,'Shadow Serpentis Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(14065,328,'Shadow Serpentis Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(14067,62,'Shadow Serpentis Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14068,62,'Shadow Serpentis Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,4,19916.0000,1,1050,0),(14069,62,'Shadow Serpentis Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,4,9996.0000,1,1049,0),(14070,326,'Dark Blood Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14072,326,'True Sansha Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14074,326,'Shadow Serpentis Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14076,326,'Dark Blood Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(14078,326,'True Sansha Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(14080,326,'Shadow Serpentis Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(14082,326,'Dark Blood Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(14084,326,'True Sansha Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(14086,326,'Shadow Serpentis Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(14088,326,'Dark Blood Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14090,326,'True Sansha Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14092,326,'Shadow Serpentis Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14094,326,'Dark Blood Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14096,326,'True Sansha Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14098,326,'Shadow Serpentis Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14100,211,'Domination Tracking Enhancer','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,707,0),(14102,46,'Domination 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(14104,46,'Shadow Serpentis 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(14106,46,'Domination 10MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,32256.0000,1,542,0),(14108,46,'Shadow Serpentis 10MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,32256.0000,1,542,0),(14110,46,'Domination 1MN Afterburner','Gives a boosts to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,6450.0000,1,542,0),(14112,46,'Shadow Serpentis 1MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,6450.0000,1,542,0),(14114,46,'Domination 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(14116,46,'Shadow Serpentis 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(14118,46,'Domination 50MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,158188.0000,1,131,0),(14120,46,'Shadow Serpentis 50MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,158188.0000,1,131,0),(14122,46,'Domination 5MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,31636.0000,1,131,0),(14124,46,'Shadow Serpentis 5MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,31636.0000,1,131,0),(14126,764,'Domination Overdrive Injector','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,2,512.0000,1,1087,0),(14127,763,'Domination Nanofiber Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,2,512.0000,1,1196,0),(14128,769,'Dark Blood Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(14130,769,'True Sansha Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(14132,769,'Shadow Serpentis Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(14134,766,'Dark Blood Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(14136,766,'True Sansha Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(14138,766,'Shadow Serpentis Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(14140,43,'True Sansha Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,23750.0000,1,665,0),(14142,43,'Dark Blood Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,23750.0000,1,665,0),(14144,767,'Dark Blood Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(14146,767,'True Sansha Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(14148,68,'Dark Blood Small Nosferatu','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,39504.0000,1,692,0),(14150,68,'True Sansha Small Nosferatu','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,39504.0000,1,692,0),(14152,68,'Dark Blood Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(14154,68,'True Sansha Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(14156,68,'Dark Blood Medium Nosferatu','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,197520.0000,1,693,0),(14158,68,'True Sansha Medium Nosferatu','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,197520.0000,1,693,0),(14160,71,'Dark Blood Small Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,28160.0000,1,689,0),(14162,71,'True Sansha Small Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,28160.0000,1,689,0),(14164,71,'Dark Blood Medium Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,99840.0000,1,690,0),(14166,71,'True Sansha Medium Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,99840.0000,1,690,0),(14168,71,'Dark Blood Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(14170,71,'True Sansha Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(14172,76,'Dark Blood Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,70258.0000,1,701,0),(14174,76,'True Sansha Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,70258.0000,1,701,0),(14176,76,'Dark Blood Medium Capacitor Booster','Provides a quick injection of power into the capacitor.',0,10,32,1,NULL,28124.0000,1,700,0),(14178,76,'True Sansha Medium Capacitor Booster','Provides a quick injection of power into the capacitor.',0,10,32,1,NULL,28124.0000,1,700,0),(14180,76,'Dark Blood Micro Capacitor Booster','Provides a quick injection of power into the capacitor.',0,2.5,8,1,NULL,4500.0000,1,698,0),(14182,76,'True Sansha Micro Capacitor Booster','Provides a quick injection of power into the capacitor.',0,2.5,8,1,NULL,4500.0000,1,698,0),(14184,76,'Dark Blood Small Capacitor Booster','Provides a quick injection of power into the capacitor.',0,5,12,1,NULL,11250.0000,1,699,0),(14186,76,'True Sansha Small Capacitor Booster','Provides a quick injection of power into the capacitor.',0,5,12,1,NULL,11250.0000,1,699,0),(14188,72,'Dark Blood Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14190,72,'True Sansha Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14192,72,'Dark Blood Medium EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,10,0,1,NULL,39382.0000,1,383,0),(14194,72,'True Sansha Medium EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,10,0,1,NULL,39382.0000,1,383,0),(14196,72,'Dark Blood Micro EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,2.5,0,1,NULL,19988.0000,1,380,0),(14198,72,'True Sansha Micro EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,2.5,0,1,NULL,19988.0000,1,380,0),(14200,72,'Dark Blood Small EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',10,5,0,1,NULL,49734.0000,1,382,0),(14202,72,'True Sansha Small EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',10,5,0,1,NULL,49734.0000,1,382,0),(14204,72,'Dread Guristas Large Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14206,72,'Shadow Serpentis Large Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14208,72,'Domination Large Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14210,72,'Dread Guristas Medium Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,10,0,1,NULL,39382.0000,1,383,0),(14212,72,'Dread Guristas Micro Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,2.5,0,1,NULL,19988.0000,1,380,0),(14214,72,'Dread Guristas Small Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',10,5,0,1,NULL,49734.0000,1,382,0),(14218,72,'Shadow Serpentis Micro Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,2.5,0,1,NULL,19988.0000,1,380,0),(14220,72,'Shadow Serpentis Medium Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,10,0,1,NULL,39382.0000,1,383,0),(14222,72,'Domination Medium Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,10,0,1,NULL,39382.0000,1,383,0),(14224,72,'Domination Micro Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,2.5,0,1,NULL,19988.0000,1,380,0),(14226,72,'Domination Small Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',10,5,0,1,NULL,49734.0000,1,382,0),(14228,72,'Shadow Serpentis Small Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',10,5,0,1,NULL,57926.0000,1,382,0),(14230,285,'Dread Guristas Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,1,676,0),(14232,285,'Shadow Serpentis Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,1,676,0),(14234,330,'Dread Guristas Cloaking Device','This prototype of an advanced cloaking mechanism was one of the last major technological breakthroughs to come out of Crielere Labs. Although it does work it is not really a finished product and has some serious drawbacks, most notably the fact that the module creates high sensor disruption while fitted and can not operate unless at minimum velocity.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference..',0,100,0,1,NULL,738304.0000,1,675,0),(14236,212,'Shadow Serpentis Sensor Booster','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9870.0000,1,671,0),(14238,213,'Shadow Serpentis Tracking Computer','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9900.0000,1,706,0),(14240,209,'Shadow Serpentis Remote Tracking Computer','Establishes a fire control link with another ship, thereby boosting the turret range and tracking speed of that ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,29994.0000,1,708,0),(14242,52,'Dark Blood Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,1,1935,0),(14244,52,'Domination Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,1,1935,0),(14246,52,'Dread Guristas Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,1,1935,0),(14248,52,'True Sansha Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,1,1935,0),(14250,52,'Shadow Serpentis Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,1,1935,0),(14252,52,'Dark Blood Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,39424.0000,1,1936,0),(14254,52,'Domination Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,39424.0000,1,1936,0),(14256,52,'Dread Guristas Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,39424.0000,1,1936,0),(14258,52,'True Sansha Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,39424.0000,1,1936,0),(14260,52,'Shadow Serpentis Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,39424.0000,1,1936,0),(14262,65,'Dark Blood Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,22488.0000,1,683,0),(14264,65,'Domination Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,22488.0000,1,683,0),(14266,65,'Dread Guristas Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,22488.0000,1,683,0),(14268,65,'True Sansha Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,22488.0000,1,683,0),(14270,65,'Shadow Serpentis Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,22488.0000,1,683,0),(14272,74,'200mm Carbide Railgun I','The 200mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,NULL,100000.0000,1,565,0),(14274,74,'200mm \'Scout\' Accelerator Cannon','The 200mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,NULL,100000.0000,1,565,0),(14276,74,'200mm Compressed Coil Gun I','The 200mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,NULL,100000.0000,1,565,0),(14278,74,'200mm Prototype Gauss Gun','The 200mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,NULL,100000.0000,1,565,0),(14280,74,'350mm Carbide Railgun I','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(14282,74,'350mm \'Scout\' Accelerator Cannon','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(14284,74,'350mm Compressed Coil Gun I','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(14286,74,'350mm Prototype Gauss Gun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(14292,314,'Kruul\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis is a DNA sample taken from the hapless pirate marauder, Kruul.',1,0.1,0,1,NULL,0.0000,1,752,0),(14293,314,'X-Rated Holoreel','X-Rated Holo-Vid reels are a popular type of personal entertainment, especially in Gallente territories.  These type of Holoreels are strictly forbidden in the Amarr Empire and Khanid Kingdom.',100,0.5,0,1,NULL,0.0000,1,NULL,0),(14294,818,'Kruul\'s Capsule','This is an escape capsule which is released upon the destruction of ones ship.',32000,1000,0,1,NULL,0.0000,0,NULL,0),(14295,745,'Limited Ocular Filter - Beta','This image processor implanted in the occipital lobe grants a bonus to a character\'s Perception.  The beta version of the limited implants are a more advanced prototype, originally developed by the Caldari corporation Zero-G Research Firm as a cost effective alternative to the basic non-limited implants.\r\r\n\r\r\n+2 Bonus to Perception',0,1,0,1,NULL,0.0000,1,618,0),(14296,745,'Limited Neural Boost - Beta','A Data processing unit implanted in the Parietal lobe. Grants a bonus to Willpower. The beta version of the limited implants are a more advanced prototype, originally developed by the Caldari corporation Zero-G Research Firm as a cost effective alternative to the basic non-limited implants.\r\r\n\r\r\n+2 Bonus to Willpower',0,1,0,1,NULL,0.0000,1,620,0),(14297,745,'Limited Memory Augmentation - Beta','This image processor implanted in the temporal lobe grants a bonus to a character\'s memory.  The beta version of the limited implants are a more advanced prototype, originally developed by the Caldari corporation Zero-G Research Firm as a cost effective alternative to the basic non-limited implants.\r\r\n\r\r\n+2 Bonus to Memory',0,1,0,1,NULL,0.0000,1,619,0),(14298,745,'Limited Cybernetic Subprocessor - Beta','This grafted subprocessor implanted in the frontal lobe grants a bonus to a character\'s Intelligence. The beta version of the limited implants are a more advanced prototype, originally developed by the Caldari corporation Zero-G Research Firm as a cost effective alternative to the basic non-limited implants. \r\r\n\r\r\n+2 Bonus to Intelligence',0,1,0,1,NULL,0.0000,1,621,0),(14299,745,'Limited Social Adaptation Chip - Beta','This image processor implanted in the parietal lobe grants a bonus to a character\'s Charisma.  The beta version of the limited implants are a more advanced prototype, originally developed by the Caldari corporation Zero-G Research Firm as a cost effective alternative to the basic non-limited implants.\r\r\n\r\r\n+2 Bonus to Charisma',0,1,0,1,NULL,0.0000,1,622,0),(14343,404,'Silo','Used to store or provide resources.',100000000,4000,20000,1,NULL,15000000.0000,1,483,0),(14344,613,'Renegade Guristas Pirate','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(14345,595,'Renegade Angel Goon','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(14346,604,'Renegade Blood Raider','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(14347,631,'Renegade Serpentis Assassin','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(14348,622,'Renegade Sanshas Slaver','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(14349,668,'Sarum Maller','The Maller is the largest cruiser class used by the Amarrians. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches. In the Amarr Imperial Navy, the Maller is commonly used as the spearhead for large military operations.  Threat level: Deadly',12750000,118000,280,1,4,0.0000,0,NULL,0),(14350,816,'Commander Karzo Sarum','Only those in high favor with the Emperor can earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. These metallic monstrosities see to it that the word of the Emperor is carried out among the denizens of the Empire and beyond.  Threat level: Uber',19000000,1150000,675,1,4,0.0000,0,NULL,0),(14351,665,'Imperial Navy Soldier','The Imperial Navy Soldier class fighter ships are a common sight within the Amarr Imperial armada.  Threat level: Very high',1265000,18100,235,1,4,0.0000,0,NULL,0),(14352,665,'Ammatar Navy Soldier','The Ammatar Soldier class fighter ships are a common sight within the Ammatar armada.  Threat level: Very high',1265000,18100,235,1,4,0.0000,0,NULL,0),(14353,677,'Federation Navy Soldier','The Gallente Navy Soldier class fighter ships are a common sight within the Gallente Federation armada.  Threat level: Very high',2040000,20400,200,1,8,0.0000,0,NULL,0),(14354,683,'Republic Fleet Soldier','The Republic Fleet Soldier class fighter ships are a common sight within the Minmatar Republic armada. Threat level: Very high',1200000,12000,80,1,2,0.0000,0,NULL,0),(14355,671,'Caldari Navy Soldier','The Caldari Navy Soldier class fighter ships are a common sight within the Caldari State armada. Threat level: Very high',1680000,17400,90,1,1,0.0000,0,NULL,0),(14356,667,'Ammatar Navy Apocalypse','Only those in high favor with the Emperor can earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. These metallic monstrosities see to it that the word of the Emperor is carried out among the denizens of the Empire and beyond.  Threat level: Deadly',20500000,1150000,675,1,4,0.0000,0,NULL,0),(14358,314,'Zemnar','Zemnar is an uncommon type of antibiotic specifically used to combat rare bacterial infections. Originally discovered by the late Gallente biologist, Lameur Zemnar, the drug is now frequently kept in stock in the more wealthy quarters of the galaxy, in case of a bacterial outbreak.',5,0.2,0,1,NULL,100.0000,1,492,0),(14359,671,'Caldari Navy Condor','The Condor is fast and agile. It has limited cargo space so it\'s not very suitable for trading or mining. It is best used as an assault vessel in a hit-and-run type of operations.  It is sometimes used by the Caldari Navy and is generally considered an expendable low-cost craft.  Threat level: Moderate',1300000,18000,150,1,1,0.0000,0,NULL,0),(14360,683,'Republic Fleet Slasher','The Slasher is cheap, but versatile. It\'s been manufactured en masse, making it one of the most common vessels in Minmatar space. The Slasher is extremely fast, with decent armaments, and is popular amongst budding pirates and smugglers.  It is sometimes used by the Minmatar Fleet and is generally considered an expendable low-cost craft.  Threat level: Moderate',1000000,17400,120,1,2,0.0000,0,NULL,0),(14361,677,'Federation Navy Atron','The Atron is a hard nugget with an advanced power conduit system, but little space for cargo. Although the Atron is a good harvester when it comes to mining, its main ability is as a combat vessel.  It is sometimes used by the Federation Navy and is generally considered an expendable low-cost craft.  Threat level: Moderate',1200000,22500,125,1,8,0.0000,0,NULL,0),(14362,665,'Imperial Navy Executioner','The Executioner is another newly commissioned ship of the Amarr Imperial Navy. The Executioner was designed specially to counter the small, fast raider frigates of the Minmatar Republic; thus it is different from most Amarr ships in favoring speed over defenses. With the Executioner, the Amarrians have expanded their tactical capabilities on the battlefield.  It is sometimes used by the Imperial Navy and is generally considered an expendable low-cost craft.  Threat level: Moderate',1000000,28100,135,1,4,0.0000,0,NULL,0),(14363,665,'Ammatar Navy Executioner','The Executioner is another newly commissioned ship of the Amarr Imperial Navy. The Executioner was designed specially to counter the small, fast raider frigates of the Minmatar Republic; thus it is different from most Amarr ships in favoring speed over defenses. With the Executioner, the Amarrians have expanded their tactical capabilities on the battlefield.  It is sometimes used by the Ammatar Navy and is generally considered an expendable low-cost craft.  Threat level: Moderate',1000000,28100,135,1,4,0.0000,0,NULL,0),(14364,665,'Ammatar Navy Officer','This is an officer for the Ammatar Navy.  A common sight in Ammatar raiding parties, these combat veterans are not to be taken lightly.  Threat level: Deadly',10900000,109000,120,1,4,0.0000,0,NULL,0),(14375,74,'Tuvan\'s Modified Electron Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,5,1,NULL,600000.0000,1,563,0),(14377,74,'Cormack\'s Modified Electron Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,5,1,NULL,600000.0000,1,563,0),(14379,74,'Cormack\'s Modified Ion Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,3,1,NULL,900000.0000,1,563,0),(14381,74,'Tuvan\'s Modified Ion Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,3,1,NULL,900000.0000,1,563,0),(14383,74,'Tuvan\'s Modified Neutron Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1200000.0000,1,563,0),(14385,74,'Cormack\'s Modified Neutron Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',200,20,2,1,NULL,1200000.0000,1,563,0),(14387,74,'Brynn\'s Modified 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(14389,74,'Setele\'s Modified 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(14391,74,'Kaikka\'s Modified 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(14393,74,'Vepas\' Modified 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(14395,74,'Estamel\'s Modified 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,1,566,0),(14397,74,'Brynn\'s Modified 425mm Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,NULL,1500000.0000,1,566,0),(14399,74,'Setele\'s Modified 425mm Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,NULL,1500000.0000,1,566,0),(14401,74,'Kaikka\'s Modified 425mm Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,NULL,1500000.0000,1,566,0),(14403,74,'Vepas\' Modified 425mm Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,NULL,1500000.0000,1,566,0),(14405,74,'Estamel\'s Modified 425mm Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,NULL,1500000.0000,1,566,0),(14407,74,'Brynn\'s Modified Dual 250mm Railgun','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,NULL,200000.0000,1,566,0),(14409,74,'Setele\'s Modified Dual 250mm Railgun','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,NULL,200000.0000,1,566,0),(14411,74,'Kaikka\'s Modified Dual 250mm Railgun','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,NULL,200000.0000,1,566,0),(14413,74,'Vepas\' Modified Dual 250mm Railgun','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,NULL,200000.0000,1,566,0),(14415,74,'Estamel\'s Modified Dual 250mm Railgun','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1500,20,4,1,NULL,200000.0000,1,566,0),(14417,53,'Selynne\'s Modified Dual Heavy Beam Laser','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,600000.0000,1,569,0),(14419,53,'Chelm\'s Modified Dual Heavy Beam Laser','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,600000.0000,1,569,0),(14421,53,'Raysere\'s Modified Dual Heavy Beam Laser','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,600000.0000,1,569,0),(14423,53,'Draclira\'s Modified Dual Heavy Beam Laser','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,600000.0000,1,569,0),(14425,53,'Tairei\'s Modified Dual Heavy Pulse Laser','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,200000.0000,1,573,0),(14427,53,'Ahremen\'s Modified Dual Heavy Pulse Laser','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,200000.0000,1,573,0),(14429,53,'Brokara\'s Modified Dual Heavy Pulse Laser','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,200000.0000,1,573,0),(14431,53,'Vizan\'s Modified Dual Heavy Pulse Laser','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,200000.0000,1,573,0),(14433,53,'Selynne\'s Modified Mega Beam Laser','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1200000.0000,1,569,0),(14435,53,'Chelm\'s Modified Mega Beam Laser','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1200000.0000,1,569,0),(14437,53,'Raysere\'s Modified Mega Beam Laser','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1200000.0000,1,569,0),(14439,53,'Draclira\'s Modified Mega Beam Laser','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1200000.0000,1,569,0),(14441,53,'Tairei\'s Modified Mega Pulse Laser','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,900000.0000,1,573,0),(14443,53,'Ahremen\'s Modified Mega Pulse Laser','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,900000.0000,1,573,0),(14445,53,'Brokara\'s Modified Mega Pulse Laser','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,900000.0000,1,573,0),(14447,53,'Vizan\'s Modified Mega Pulse Laser','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,900000.0000,1,573,0),(14449,53,'Selynne\'s Modified Tachyon Beam Laser','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1500000.0000,1,569,0),(14451,53,'Chelm\'s Modified Tachyon Beam Laser','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1500000.0000,1,569,0),(14453,53,'Raysere\'s Modified Tachyon Beam Laser','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1500000.0000,1,569,0),(14455,53,'Draclira\'s Modified Tachyon Beam Laser','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1500000.0000,1,569,0),(14457,55,'Mizuro\'s Modified 800mm Repeating Cannon','A two-barreled, intermediate-range, powerful cannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,20,3,1,NULL,900000.0000,1,576,0),(14459,55,'Gotan\'s Modified 800mm Repeating Cannon','A two-barreled, intermediate-range, powerful cannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,20,3,1,NULL,900000.0000,1,576,0),(14461,55,'Hakim\'s Modified 1200mm Artillery Cannon','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',750,20,1,1,NULL,1200000.0000,1,579,0),(14463,55,'Tobias\' Modified 1200mm Artillery Cannon','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',750,20,1,1,NULL,1200000.0000,1,579,0),(14465,55,'Hakim\'s Modified 1400mm Howitzer Artillery','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1500,20,0.5,1,NULL,1500000.0000,1,579,0),(14467,55,'Tobias\' Modified 1400mm Howitzer Artillery','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1500,20,0.5,1,NULL,1500000.0000,1,579,0),(14469,55,'Mizuro\'s Modified Dual 425mm AutoCannon','Combines the damage output of two 425mm intermediate-range autocannons. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',200,20,5,1,NULL,200000.0000,1,576,0),(14471,55,'Gotan\'s Modified Dual 425mm AutoCannon','Combines the damage output of two 425mm intermediate-range autocannons.  \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',200,20,5,1,NULL,200000.0000,1,576,0),(14473,55,'Mizuro\'s Modified Dual 650mm Repeating Cannon','Powerful, intermediate-range repeating autocannon with a decent rate of fire. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,4,1,NULL,600000.0000,1,576,0),(14475,55,'Gotan\'s Modified Dual 650mm Repeating Cannon','Powerful, intermediate-range repeating autocannon with a decent rate of fire. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,4,1,NULL,600000.0000,1,576,0),(14477,226,'Ruined Neon Sign','This billboard seems to have been destroyed in some long forgotten skirmish.',0,0,0,1,NULL,0.0000,0,NULL,0),(14478,671,'Caldari Navy Griffin','The Griffin is much used by the Caldari Navy as a support vessel in combat squadrons, using its impressive array of electronic gadgetry to disrupt the operation of target ships, making them easy prey for traditional combat vessels. Threat level: Significant',1600000,19400,160,1,1,0.0000,0,NULL,0),(14479,665,'Imperial Navy Crucifer','The Crucifier was first designed as an explorer/scout, but the current version employs the electronic equipment originally intended for scientific studies for more offensive purposes. The Crucifier\'s electronic and computer systems take up a large portion of the internal space leaving limited room for cargo or traditional weaponry. Threat level: Significant',1525000,28100,165,1,4,0.0000,0,NULL,0),(14480,683,'Republic Fleet Vigil','The Vigil is an unusual Minmatar ship, serving both as a long range scout as well as an electronic warfare platform. It is fast and agile, allowing it to keep the distance needed to avoid enemy fire while making use of jammers or other electronic gadgets. Threat level: Significant',1125000,17400,150,1,2,0.0000,0,NULL,0),(14481,677,'Federation Navy Maulus','The Maulus is a high-tech vessel, specialized for electronic warfare. It is particularly valued amongst bounty hunters for the ship\'s optimization for warp scrambling technology, giving its targets no chance of escape.  Threat level: Moderate',1400000,23000,175,1,8,0.0000,0,NULL,0),(14482,665,'Ammatar Navy Inquisitor','The Inquisitor is another example of how the Amarr Imperial Navy has modeled their design to counter specific tactics employed by the other empires. The Inquisitor is a fairly standard Amarr ship in most respects, having good defenses and lacking mobility. It is more Caldari-like than most Amarr ships, however, since its arsenal mostly consists of missile bays. Threat level: Significant',1525000,28700,315,1,4,0.0000,0,NULL,0),(14483,314,'Drezins DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis is a DNA sample taken from the infamous pirate Drezin.',1,0.1,0,1,NULL,0.0000,1,752,0),(14484,46,'Mizuro\'s Modified 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(14486,46,'Hakim\'s Modified 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(14488,46,'Gotan\'s Modified 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(14490,46,'Tobias\' Modified 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(14492,46,'Mizuro\'s Modified 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(14494,46,'Hakim\'s Modified 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(14496,46,'Gotan\'s Modified 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(14498,46,'Tobias\' Modified 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(14500,46,'Brynn\'s Modified 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(14502,46,'Tuvan\'s Modified 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(14504,46,'Setele\'s Modified 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(14506,46,'Cormack\'s Modified 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(14508,46,'Brynn\'s Modified 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(14510,46,'Tuvan\'s Modified 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(14512,46,'Setele\'s Modified 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(14514,46,'Cormack\'s Modified 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(14516,506,'Mizuro\'s Modified Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.45,1,NULL,99996.0000,1,643,0),(14518,506,'Hakim\'s Modified Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.5,1,NULL,99996.0000,1,643,0),(14520,506,'Gotan\'s Modified Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.6,1,NULL,99996.0000,1,643,0),(14522,506,'Tobias\' Modified Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.65,1,NULL,99996.0000,1,643,0),(14524,508,'Mizuro\'s Modified Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.2,1,1,20580.0000,1,644,0),(14525,508,'Hakim\'s Modified Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.3,1,1,20580.0000,1,644,0),(14526,508,'Gotan\'s Modified Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.4,1,1,20580.0000,1,644,0),(14527,508,'Tobias\'s Modified Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.5,1,1,20580.0000,1,644,0),(14528,367,'Hakim\'s Modified Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,645,0),(14530,367,'Mizuro\'s Modified Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,645,0),(14532,367,'Gotan\'s Modified Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,645,0),(14534,367,'Tobias\' Modified Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,645,0),(14536,59,'Mizuro\'s Modified Gyrostabilizer','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24320.0000,1,646,0),(14538,59,'Hakim\'s Modified Gyrostabilizer','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24320.0000,1,646,0),(14540,59,'Gotan\'s Modified Gyrostabilizer','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24320.0000,1,646,0),(14542,59,'Tobias\' Modified Gyrostabilizer','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24320.0000,1,646,0),(14544,72,'Mizuro\'s Modified Large Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14546,72,'Hakim\'s Modified Large Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14548,72,'Gotan\'s Modified Large Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14550,72,'Tobias\' Modified Large Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14552,62,'Mizuro\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14554,62,'Gotan\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14556,98,'Mizuro\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14560,98,'Gotan\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14564,98,'Mizuro\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14568,98,'Gotan\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14572,98,'Mizuro\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14576,98,'Gotan\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14580,98,'Mizuro\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14584,98,'Gotan\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14588,98,'Mizuro\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14592,98,'Gotan\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14597,40,'Hakim\'s Modified Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(14599,40,'Tobias\' Modified Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(14601,40,'Hakim\'s Modified X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(14603,40,'Tobias\' Modified X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(14606,295,'Hakim\'s Modified Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(14610,295,'Tobias\' Modified Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(14614,295,'Hakim\'s Modified Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(14618,295,'Tobias\' Modified Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(14622,295,'Hakim\'s Modified Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(14626,295,'Tobias\' Modified Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(14630,295,'Hakim\'s Modified EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(14634,295,'Tobias\' Modified EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(14636,338,'Hakim\'s Modified Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(14638,338,'Tobias\' Modified Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(14640,211,'Mizuro\'s Modified Tracking Enhancer','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,707,0),(14642,211,'Hakim\'s Modified Tracking Enhancer','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,707,0),(14644,211,'Gotan\'s Modified Tracking Enhancer','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,707,0),(14646,211,'Tobias\' Modified Tracking Enhancer','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,707,0),(14648,65,'Mizuro\'s Modified Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,22488.0000,1,683,0),(14650,65,'Hakim\'s Modified Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,22488.0000,1,683,0),(14652,65,'Gotan\'s Modified Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,22488.0000,1,683,0),(14654,65,'Tobias\' Modified Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,22488.0000,1,683,0),(14656,52,'Mizuro\'s Modified Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,1,1935,0),(14658,52,'Hakim\'s Modified Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,1,1935,0),(14660,52,'Gotan\'s Modified Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,1,1935,0),(14662,52,'Tobias\' Modified Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,1,1935,0),(14664,52,'Mizuro\'s Modified Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,39424.0000,1,1936,0),(14666,52,'Hakim\'s Modified Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,39424.0000,1,1936,0),(14668,52,'Gotan\'s Modified Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,39424.0000,1,1936,0),(14670,52,'Tobias\' Modified Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,39424.0000,1,1936,0),(14672,506,'Kaikka\'s Modified Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.6,1,NULL,99996.0000,1,643,0),(14674,506,'Thon\'s Modified Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.65,1,NULL,99996.0000,1,643,0),(14676,506,'Vepas\' Modified Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.75,1,NULL,99996.0000,1,643,0),(14678,506,'Estamel\'s Modified Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.8,1,NULL,99996.0000,1,643,0),(14680,508,'Kaikka\'s Modified Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.4,1,1,20580.0000,1,644,0),(14681,508,'Thon\'s Modified Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.5,1,1,20580.0000,1,644,0),(14682,508,'Vepas\'s Modified Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.6,1,1,20580.0000,1,644,0),(14683,508,'Estamel\'s Modified Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.7,1,1,20580.0000,1,644,0),(14684,367,'Kaikka\'s Modified Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,645,0),(14686,367,'Thon\'s Modified Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,645,0),(14688,367,'Vepas\' Modified Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,645,0),(14690,367,'Estamel\'s Modified Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,645,0),(14692,72,'Kaikka\'s Modified Large Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14694,72,'Thon\'s Modified Large Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14696,72,'Vepas\' Modified Large Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14698,72,'Estamel\'s Modified Large Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14700,40,'Kaikka\'s Modified Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(14701,40,'Thon\'s Modified Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(14702,40,'Vepas\' Modified Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(14703,40,'Estamel\'s Modified Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(14704,40,'Kaikka\'s Modified X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(14705,40,'Thon\'s Modified X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(14706,40,'Vepas\' Modified X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(14707,40,'Estamel\'s Modified X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(14708,338,'Kaikka\'s Modified Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(14710,338,'Thon\'s Modified Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',0,5,0,1,NULL,350000.0000,1,613,0),(14712,338,'Vepas\' Modified Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(14714,338,'Estamel\'s Modified Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(14716,295,'Kaikka\'s Modified Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(14718,295,'Thon\'s Modified Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(14720,295,'Vepas\' Modified Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(14722,295,'Estamel\'s Modified Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(14724,295,'Kaikka\'s Modified Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(14726,295,'Thon\'s Modified Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(14728,295,'Vepas\' Modified Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(14730,295,'Estamel\'s Modified Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(14732,295,'Kaikka\'s Modified Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(14734,295,'Thon\'s Modified Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(14736,295,'Vepas\' Modified Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(14738,295,'Estamel\'s Modified Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(14740,295,'Kaikka\'s Modified EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(14742,295,'Thon\'s Modified EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(14744,295,'Vepas\' Modified EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(14746,295,'Estamel\'s Modified EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(14748,77,'Kaikka\'s Modified Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(14749,77,'Thon\'s Modified Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(14750,77,'Vepas\'s Modified Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(14751,77,'Estamel\'s Modified Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(14752,77,'Kaikka\'s Modified EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(14753,77,'Thon\'s Modified EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(14754,77,'Vepas\'s Modified EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(14755,77,'Estamel\'s Modified EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(14756,77,'Kaikka\'s Modified Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(14757,77,'Thon\'s Modified Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(14758,77,'Vepas\'s Modified Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(14759,77,'Estamel\'s Modified Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(14760,77,'Kaikka\'s Modified Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(14761,77,'Thon\'s Modified Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(14762,77,'Vepas\'s Modified Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(14763,77,'Estamel\'s Modified Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(14764,77,'Kaikka\'s Modified Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(14765,77,'Thon\'s Modified Adaptive Invulnerability Field','Boosts shield resistance against all damage types. <br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(14766,77,'Vepas\'s Modified Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(14767,77,'Estamel\'s Modified Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,1,1696,0),(14768,285,'Kaikka\'s Modified Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,1,676,0),(14770,285,'Thon\'s Modified Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,1,676,0),(14772,285,'Vepas\' Modified Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,1,676,0),(14774,285,'Estamel\'s Modified Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,1,676,0),(14776,330,'Kaikka\'s Modified Cloaking Device','This prototype of an advanced cloaking mechanism was one of the last major technological breakthroughs to come out of Crielere Labs. Although it does work it is not really a finished product and has some serious drawbacks, most notably the fact that the module creates high sensor disruption while fitted and can not operate unless at minimum velocity.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,475000.0000,1,675,0),(14778,330,'Thon\'s Modified Cloaking Device','This prototype of an advanced cloaking mechanism was one of the last major technological breakthroughs to come out of Crielere Labs. Although it does work it is not really a finished product and has some serious drawbacks, most notably the fact that the module creates high sensor disruption while fitted and can not operate unless at minimum velocity.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,475000.0000,1,675,0),(14780,330,'Vepas\' Modified Cloaking Device','This prototype of an advanced cloaking mechanism was one of the last major technological breakthroughs to come out of Crielere Labs. Although it does work it is not really a finished product and has some serious drawbacks, most notably the fact that the module creates high sensor disruption while fitted and can not operate unless at minimum velocity.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,475000.0000,1,675,0),(14782,330,'Estamel\'s Modified Cloaking Device','This prototype of an advanced cloaking mechanism was one of the last major technological breakthroughs to come out of Crielere Labs. Although it does work it is not really a finished product and has some serious drawbacks, most notably the fact that the module creates high sensor disruption while fitted and can not operate unless at minimum velocity.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,475000.0000,1,675,0),(14784,72,'Brokara\'s Modified Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14786,72,'Tairei\'s Modified Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14788,72,'Selynne\'s Modified Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14790,72,'Raysere\'s Modified Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14792,72,'Vizan\'s Modified Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14794,72,'Ahremen\'s Modified Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14796,72,'Chelm\'s Modified Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14798,72,'Draclira\'s Modified Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(14800,205,'Brokara\'s Modified Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,647,0),(14802,205,'Tairei\'s Modified Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,647,0),(14804,205,'Selynne\'s Modified Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,647,0),(14806,205,'Raysere\'s Modified Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,647,0),(14808,205,'Vizan\'s Modified Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,647,0),(14810,205,'Ahremen\'s Modified Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,647,0),(14812,205,'Chelm\'s Modified Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,647,0),(14814,205,'Draclira\'s Modified Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,647,0),(14816,68,'Brokara\'s Modified Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(14818,68,'Tairei\'s Modified Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(14820,68,'Selynne\'s Modified Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(14822,68,'Raysere\'s Modified Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(14824,68,'Vizan\'s Modified Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(14826,68,'Ahremen\'s Modified Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(14828,68,'Chelm\'s Modified Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(14830,68,'Draclira\'s Modified Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(14832,71,'Brokara\'s Modified Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(14834,71,'Tairei\'s Modified Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(14836,71,'Selynne\'s Modified Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(14838,71,'Raysere\'s Modified Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(14840,71,'Vizan\'s Modified Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(14842,71,'Ahremen\'s Modified Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(14844,71,'Chelm\'s Modified Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(14846,71,'Draclira\'s Modified Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(14848,62,'Brokara\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14849,62,'Tairei\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14850,62,'Selynne\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14851,62,'Raysere\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14852,62,'Vizan\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14853,62,'Ahremen\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14854,62,'Chelm\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14855,62,'Draclira\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(14856,98,'Brokara\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14858,98,'Tairei\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14860,98,'Selynne\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14862,98,'Raysere\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14864,98,'Vizan\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14866,98,'Ahremen\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14868,98,'Chelm\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14870,98,'Draclira\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(14872,98,'Brokara\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14874,98,'Tairei\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14876,98,'Selynne\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14878,98,'Raysere\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14880,98,'Vizan\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14882,98,'Ahremen\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14884,98,'Chelm\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14886,98,'Draclira\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(14888,98,'Brokara\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14890,98,'Tairei\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14892,98,'Selynne\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14894,98,'Raysere\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14896,98,'Vizan\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14898,98,'Ahremen\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14900,98,'Chelm\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14902,98,'Draclira\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(14904,98,'Brokara\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14906,98,'Tairei\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14908,98,'Selynne\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14910,98,'Raysere\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14912,98,'Vizan\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14914,98,'Ahremen\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14916,98,'Chelm\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14918,98,'Draclira\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(14920,98,'Brokara\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14922,98,'Tairei\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14924,98,'Selynne\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14926,98,'Raysere\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14928,98,'Vizan\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14930,98,'Ahremen\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14932,98,'Chelm\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14934,98,'Draclira\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(14936,326,'Brokara\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14938,326,'Tairei\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14940,326,'Selynne\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14942,326,'Raysere\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14944,326,'Vizan\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14946,326,'Ahremen\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14948,326,'Chelm\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14950,326,'Draclira\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(14952,326,'Brokara\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14954,326,'Tairei\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14956,326,'Selynne\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14958,326,'Raysere\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14960,326,'Vizan\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14962,326,'Ahremen\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14964,326,'Chelm\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14966,326,'Draclira\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(14968,326,'Brokara\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14970,326,'Tairei\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14972,326,'Selynne\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14974,326,'Raysere\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14976,326,'Vizan\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14978,326,'Ahremen\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14980,326,'Chelm\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14982,326,'Draclira\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(14984,326,'Brokara\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(14986,326,'Tairei\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(14988,326,'Selynne\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(14990,326,'Raysere\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(14992,326,'Vizan\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(14994,326,'Ahremen\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(14996,326,'Chelm\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(14998,326,'Draclira\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(15000,326,'Brokara\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15002,326,'Tairei\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15004,326,'Selynne\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15006,326,'Raysere\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15008,326,'Vizan\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15010,326,'Ahremen\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15012,326,'Chelm\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15014,326,'Draclira\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15016,328,'Brokara\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15018,328,'Tairei\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15020,328,'Selynne\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15022,328,'Raysere\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15024,328,'Vizan\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15026,328,'Ahremen\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15028,328,'Chelm\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15030,328,'Draclira\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15032,328,'Brokara\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15034,328,'Tairei\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15036,328,'Selynne\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15038,328,'Raysere\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15040,328,'Vizan\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15042,328,'Ahremen\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15044,328,'Chelm\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15046,328,'Draclira\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15048,328,'Brokara\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15050,328,'Tairei\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15052,328,'Selynne\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15054,328,'Raysere\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15056,328,'Vizan\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15058,328,'Ahremen\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15060,328,'Chelm\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15062,328,'Draclira\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15064,328,'Brokara\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15066,328,'Tairei\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15068,328,'Selynne\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15070,328,'Raysere\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15072,328,'Vizan\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15074,328,'Ahremen\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15076,328,'Chelm\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15078,328,'Draclira\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15080,767,'Brokara\'s Modified Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(15082,767,'Tairei\'s Modified Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(15084,767,'Selynne\'s Modified Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(15086,767,'Raysere\'s Modified Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(15088,767,'Vizan\'s Modified Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(15090,767,'Ahremen\'s Modified Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(15092,767,'Chelm\'s Modified Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(15094,767,'Draclira\'s Modified Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(15096,766,'Brokara\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15098,766,'Tairei\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15100,766,'Selynne\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15102,766,'Raysere\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15104,766,'Vizan\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15106,766,'Ahremen\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15108,766,'Chelm\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15110,766,'Draclira\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15112,769,'Brokara\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15114,769,'Tairei\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15116,769,'Selynne\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15118,769,'Raysere\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15120,769,'Vizan\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15122,769,'Ahremen\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15124,769,'Chelm\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15126,769,'Draclira\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15128,76,'Brokara\'s Modified Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,70258.0000,1,701,0),(15130,76,'Tairei\'s Modified Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,70258.0000,1,701,0),(15132,76,'Selynne\'s Modified Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,70258.0000,1,701,0),(15134,76,'Raysere\'s Modified Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,70258.0000,1,701,0),(15136,76,'Vizan\'s Modified Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,70258.0000,1,701,0),(15138,76,'Ahremen\'s Modified Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,70258.0000,1,701,0),(15140,76,'Chelm\'s Modified Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,70258.0000,1,701,0),(15142,76,'Draclira\'s Modified Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,70258.0000,1,701,0),(15144,302,'Brynn\'s Modified Magnetic Field Stabilizer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24994.0000,1,648,0),(15146,302,'Tuvan\'s Modified Magnetic Field Stabilizer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24994.0000,1,648,0),(15148,302,'Setele\'s Modified Magnetic Field Stabilizer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24994.0000,1,648,0),(15150,302,'Cormack\'s Modified Magnetic Field Stabilizer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24994.0000,1,648,0),(15152,72,'Brynn\'s Modified Large Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(15154,72,'Tuvan\'s Modified Large Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(15156,72,'Setele\'s Modified Large Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(15158,72,'Cormack\'s Modified Large Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,1,381,0),(15160,62,'Brynn\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(15161,62,'Tuvan\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(15162,62,'Setele\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(15163,62,'Cormack\'s Modified Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(15164,98,'Brynn\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(15166,98,'Tuvan\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(15168,98,'Setele\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(15170,98,'Cormack\'s Modified Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(15172,98,'Brynn\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(15174,98,'Tuvan\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(15176,98,'Setele\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(15178,98,'Cormack\'s Modified Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(15180,98,'Brynn\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(15182,98,'Tuvan\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(15184,98,'Setele\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(15186,98,'Cormack\'s Modified EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(15188,98,'Brynn\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(15190,98,'Tuvan\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(15192,98,'Setele\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(15194,98,'Cormack\'s Modified Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(15196,98,'Brynn\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(15198,98,'Tuvan\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(15200,98,'Setele\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(15202,98,'Cormack\'s Modified Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(15204,326,'Brynn\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(15206,326,'Tuvan\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(15208,326,'Setele\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(15210,326,'Cormack\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(15212,326,'Brynn\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(15214,326,'Tuvan\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(15216,326,'Setele\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(15218,326,'Cormack\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(15220,326,'Brynn\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(15222,326,'Tuvan\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(15224,326,'Setele\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(15226,326,'Cormack\'s Modified Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(15228,326,'Brynn\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(15230,326,'Tuvan\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(15232,326,'Setele\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(15234,326,'Cormack\'s Modified Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(15236,326,'Brynn\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15238,326,'Tuvan\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15240,326,'Setele\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15242,326,'Cormack\'s Modified Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(15244,328,'Brynn\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15246,328,'Tuvan\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15248,328,'Setele\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15250,328,'Cormack\'s Modified Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(15252,328,'Brynn\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15254,328,'Tuvan\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15256,328,'Setele\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15258,328,'Cormack\'s Modified Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(15260,328,'Brynn\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15262,328,'Tuvan\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15264,328,'Setele\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15266,328,'Cormack\'s Modified Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(15268,328,'Brynn\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15270,328,'Tuvan\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15272,328,'Setele\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15274,328,'Cormack\'s Modified Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(15276,212,'Brynn\'s Modified Sensor Booster','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9870.0000,1,671,0),(15278,212,'Tuvan\'s Modified Sensor Booster','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9870.0000,1,671,0),(15280,212,'Setele\'s Modified Sensor Booster','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9870.0000,1,671,0),(15282,212,'Cormack\'s Modified Sensor Booster','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9870.0000,1,671,0),(15284,213,'Brynn\'s Modified Tracking Computer','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9900.0000,1,706,0),(15286,213,'Tuvan\'s Modified Tracking Computer','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9900.0000,1,706,0),(15288,213,'Setele\'s Modified Tracking Computer','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9900.0000,1,706,0),(15290,213,'Cormack\'s Modified Tracking Computer','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9900.0000,1,706,0),(15292,766,'Brynn\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15294,766,'Tuvan\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15296,766,'Setele\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15298,766,'Cormack\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(15300,769,'Brynn\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15302,769,'Tuvan\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15304,769,'Setele\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15306,769,'Cormack\'s Modified Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,9920.0000,1,659,0),(15308,285,'Brynn\'s Modified Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,1,676,0),(15310,285,'Tuvan\'s Modified Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,1,676,0),(15312,285,'Setele\'s Modified Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,1,676,0),(15314,285,'Cormack\'s Modified Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,1,676,0),(15316,314,'Galeptos Medicine','Galeptos is a rare type of medicine developed by the famous Gallentean scientist, Darven Galeptos. It is produced from a blend of organic and chemical material, used to cure a rare and deadly viral infection which has been creeping up more frequently as of late.  \r\r\n\r\r\nRumor has it that Galeptos manufactured the virus himself, then sold the cure for billions of credits. Of course his corporation, Galeptos Medicines, steadfastly denies any such \"unfounded\" accusations and has threatened legal action to anyone who mentions it in public.',5,1,0,1,NULL,100.0000,1,492,0),(15317,1034,'Genetically Enhanced Livestock','Livestock are domestic animals raised for home use or for profit, whether it be for their meat or dairy products. This particular breed of livestock has been genetically enhanced using the very latest technology.',0,1.5,0,1,NULL,100.0000,1,1335,0),(15318,314,'Top-Secret Design Documents','These top-secret Design Documents are hidden in a large, sealed container.  A stamp has been placed on the container with the words \"DO NOT OPEN\" written in big, red letters.',1,1,0,1,NULL,100.0000,1,NULL,0),(15319,314,'Large Special Delivery','This box may contain personal items or commodities intended only for the delivery\'s recipient.  This container is rather large and cumbersome.',800,1000,0,1,NULL,100.0000,1,NULL,0),(15320,673,'Caldari Navy Moa','The Moa-class is almost exclusively used by the Caldari Navy, and only factions or persons in very good standing with the Caldari State can acquire one. The Moa was designed as an all-out combat ship, and its heavy armament allows the Moa to tackle almost anything that floats in space. Threat level: Deadly',10100000,101000,250,1,1,0.0000,0,NULL,0),(15322,668,'Imperial Navy Maller','The Maller is the largest cruiser class used by the Amarrians. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches. In the Amarr Imperial Navy, the Maller is commonly used as the spearhead for large military operations. Threat level: Deadly',12750000,118000,280,1,4,0.0000,0,NULL,0),(15323,668,'Ammatar Navy Maller','The Maller is the largest cruiser class used by the Amarrians. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches. In the Amarr Imperial Navy, the Maller is commonly used as the spearhead for large military operations. Threat level: Deadly',12750000,118000,280,1,4,0.0000,0,NULL,0),(15324,705,'Republic Fleet Rupture','The Rupture is slow for a Minmatar ship, but it more than makes up for it in power. The Rupture has superior firepower and is used by the Minmatar Republic both to defend space stations and other stationary objects and as part of massive attack formations. Threat level: Deadly',11500000,96000,300,1,2,0.0000,0,NULL,0),(15325,678,'Federation Navy Thorax','The Thorax-class cruisers are the latest combat ships commissioned by the Federation. In the few times it has seen action since its christening, it has performed admirably. The hordes of combat drones it carries allow it to strike against unwary opponents far away and to easily fight many opponents at the same time. Threat level: Deadly',12000000,112000,265,1,8,0.0000,0,NULL,0),(15326,674,'Caldari Navy Scorpion','The first Scorpion-class battleship was launched only a couple of years ago, and those that have been built are considered to be prototypes. Little is known of its capabilities, but what has been garnered suggests that the Scorpion is crammed to the brink with sophisticated hi-tech equipment that few can match.  Threat level: Deadly',20500000,1040000,550,1,1,0.0000,0,NULL,0),(15327,706,'Republic Fleet Typhoon','The Typhoon class battleship has an unusually strong structural integrity for a Minmatar ship. Threat level: Deadly',19000000,920000,625,1,2,0.0000,0,NULL,0),(15328,667,'Imperial Navy Armageddon','The mighty Armageddon class is the main warship of the Amarr Empire. Its heavy armaments and strong front are specially designed to crash into any battle like a juggernaut and deliver swift justice in the name of the Emperor. Threat level: Deadly',20500000,1100000,600,1,4,0.0000,0,NULL,0),(15329,667,'Ammatar Navy Armageddon','The mighty Armageddon class is the main warship of the Amarr Empire. Its heavy armaments and strong front are specially designed to crash into any battle like a juggernaut and deliver swift justice in the name of the Emperor. Threat level: Deadly',20500000,1100000,600,1,4,0.0000,0,NULL,0),(15330,680,'Federation Navy Dominix','The Dominix is one of the old warhorses that dates backs to the Gallente-Caldari War. The Dominix is no longer regarded as the top-of-the-line battleship, but this by no means makes it obsolete. Its formidable hulk and powerful weapon batteries means that anyone not in the largest and latest battleships will regret that they ever locked into combat with it. Threat level: Deadly',19000000,1010000,600,1,8,0.0000,0,NULL,0),(15331,526,'Metal Scraps','This mechanical hardware has obviously outlived its use, and is now ready to be recycled. Many station maintenance departments use the material gained from recycling these scraps to manufacture steel plates which replace worn out existing plates in the station hull. Most station managers consider this a cost-effective approach, rather than to send out a costly mining expedition for the ore, although these scraps rarely are enough to satisfy demand.\r\r\n\r\r\nThis commodity is not affected by the scrap metal processing skill any more than any other recyclable item.',10000,0.01,0,1,NULL,1000.0000,1,20,0),(15333,817,'Pirate Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(15334,817,'Smuggler Freight','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(15335,667,'Imperial Navy Fleet Commander','Designed by master starship engineers and constructed in the royal shipyards of the Emperor himself, the imperial issue of the dreaded Apocalypse battleship is held in awe throughout the Empire. Given only as an award to those who have demonstrated their fealty to the Emperor in a most exemplary way, it is considered a huge honor to command, let alone own, one of these majestic and powerful battleships. These metallic monstrosities see to it that the word of the Emperor is carried out among the denizens of the Empire and beyond. Threat level: Deadly.',20500000,1150000,675,1,4,0.0000,0,NULL,0),(15336,667,'Ammatar Navy Fleet Commander','Designed by master starship engineers and constructed in the royal shipyards of the Emperor himself, the imperial issue of the dreaded Apocalypse battleship is held in awe throughout the Empire. Given only as an award to those who have demonstrated their fealty to the Emperor in a most exemplary way, it is considered a huge honor to command, let alone own, one of these majestic and powerful battleships. These metallic monstrosities see to it that the word of the Emperor is carried out among the denizens of the Empire and beyond.  Threat Level:  Deadly',20500000,1150000,675,1,4,0.0000,0,NULL,0),(15337,680,'Federation Navy Fleet Commander','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.\r\r\n\r\r\nThe Federal Issue is a unique ship, commissioned by Gallentean president Foiritan as an honorary award for given to those individuals whose outstanding achivements benefit the entire Federation.  Threat level:  Deadly',19000000,1140000,675,1,8,0.0000,0,NULL,0),(15338,674,'Caldari Navy Fleet Commander','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.  Threat level:  Deadly',20500000,1080000,665,1,1,0.0000,0,NULL,0),(15341,706,'Republic Fleet Command Ship','The Tempest battleship can become a real behemoth when fully equipped.\r\r\nThreat level: Deadly',19000000,850000,600,1,2,0.0000,0,NULL,0),(15342,683,'Republic Fleet Squad Leader','A Squad Leader controls a small unit of ships during battle.  Seldom are they found without a few escorts with them.  Threat level: Deadly.',1100000,27289,130,1,2,0.0000,0,NULL,0),(15343,705,'Republic Fleet Raid Leader','Raid Leaders are high ranking commanding officers within the Fleet.',10250000,89000,440,1,2,0.0000,0,NULL,0),(15344,665,'Imperial Navy Squad Leader','A Squad Leader controls a small unit of ships during battle.  Seldom are they found without a few escorts with them. Threat level: Deadly.',1425000,28600,135,1,4,0.0000,0,NULL,0),(15345,677,'Federation Navy Squad Leader','A Squad Leader controls a small unit of ships during battle.  Seldom are they found without a few escorts with them. Threat level: Deadly.',1250000,26500,140,1,8,0.0000,0,NULL,0),(15346,671,'Caldari Navy Squad Leader','A Squad Leader controls a small unit of ships during battle.  Seldom are they found without a few escorts with them.  Threat level: Deadly.',1450000,16500,130,1,1,0.0000,0,NULL,0),(15347,665,'Ammatar Navy Squad Leader','A Squad Leader controls a small unit of ships during battle.  Seldom are they found without a few escorts with them. Threat level: Deadly.',1425000,28600,135,1,4,0.0000,0,NULL,0),(15349,673,'Caldari Navy Raid Leader','Raid Leaders are high ranking commanding officers within the Navy.',13000000,107000,485,1,1,0.0000,0,NULL,0),(15350,668,'Imperial Navy Raid Leader','Raid Leaders are high ranking commanding officers within the Navy.  ',12250000,115000,465,1,4,0.0000,0,NULL,0),(15351,680,'Federation Navy Raid Leader','Raid Leaders are high ranking commanding officers within the Navy.',12250000,113000,235,1,8,0.0000,0,NULL,0),(15352,668,'Ammatar Navy Raid Leader','Raid Leaders are high ranking commanding officers within the Navy.',12250000,115000,465,1,4,0.0000,0,NULL,0),(15353,314,'Research Tools','This sealed container contains a heap of tools used in all sorts of scientific research.',1,1,0,1,NULL,100.0000,1,20,0),(15354,818,'DED Scout Drone','DED Scout Drone. Threat level: Moderate',2600500,26005,120,1,2,0.0000,0,NULL,0),(15355,680,'Gallentean Luxury Yacht','The Gallentean Luxury Yachts are normally used by the entertainment industry for pleasure tours for wealthy Gallente citizens.  These Opux Luxury Yacht cruisers are rarely seen outside of Gallente controlled space, but are extremely popular within the Federation.    ',13075000,115000,1750,1,8,0.0000,0,NULL,0),(15390,817,'Hari Kaimo','Hari is a famous Caldari bounty hunter who is best known for his remarkable capture of Garuzzo Mench, a Gallentean pirate who was for a time the 6th most wanted man within the Gallente Federations.  Garuzzo was a ruthless murderer and vagabond, who had terrorized over a dozen systems with random attacks and lootings of unwary travelers.  Hari was hired by the family of one of the victims, and eventually caught up with Garuzzo and his gang, who were no match for the talented Caldari pilot.  \r\r\n\r\r\nToday Hari is best known for his dealings with wealthy businessmen who pay him well to do their dirty work.  Threat level: Deadly',10100000,101000,250,1,1,0.0000,0,NULL,0),(15391,817,'Pierre Turon','Pierre used to be an infamous pirate within the Gallente Federation, but was eventually captured by the authorities and sentenced to 20 years in prison.  He served half of his sentence before he was released due to good behavior.  Afterwards he vowed to behave himself, and stay away from the dark life of the pirate which he had once led, mainly for the sake of his wife and children.  \r\r\n\r\r\nToday Pierre is best known as a bounty hunter who specializes in assassinating pirates.  He works only for trustworthy Gallenteans who have no obvious connections to the underworld, and prides himself with his current good relationship with the Gallentean authorities.  \r\r\n\r\r\n\r\r\n Threat level: Deadly',12000000,112000,265,1,8,0.0000,0,NULL,0),(15392,818,'Zack Mead','Zack Mead is a small time criminal turned bounty hunter.  He used to work as an agent for the Serpentis but eventually switched to the job as a freelancer once he had the funds to purchase his own frigate.  Many wealthy Gallenteans turn to men such as Zack when they feel the law is not adequate in dealing with their problem.  Threat level: Very high',1680000,17400,90,1,1,0.0000,0,NULL,0),(15393,816,'Jared Kalem','Jared is a former member of the Angel Cartel who turned freelance bounty hunter.  Today he is known to work for anyone, anywhere, if the price is right.  Concord advice utmost caution when approaching this outlaw.  Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(15394,816,'Taisu Magdesh','Taisu comes from a powerful family of mercenaries within the Mordus Legion.  Famous for their \"no questions asked\" approach, the Magdesh family is prized as first class fighter pilots, who normally lead a fleet of warships.  Only powerful leaders or extremely wealthy individuals can afford the likes of Taisu, who commands a deadly Raven battleship.  Threat level: Deadly',19000000,1080000,665,1,1,0.0000,0,NULL,0),(15395,337,'Construction Freight','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',110500000,1105000,4000,1,8,0.0000,0,NULL,0),(15396,821,'General Luther Veron','This is General Luther Veron\'s personal battleship, fitted with the very finest modules available in the Gallente Federation.  ',21000000,1140000,675,1,8,0.0000,0,NULL,0),(15397,205,'Luther Veron\'s Modified Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,0,NULL,0),(15399,53,'Luther Veron\'s Modified Dual Heavy Beam Laser','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,600000.0000,0,NULL,0),(15401,53,'Luther Veron\'s Modified Mega Beam Laser','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1200000.0000,0,NULL,0),(15403,53,'Luther Veron\'s Modified Tachyon Beam Laser','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1500000.0000,0,NULL,0),(15405,72,'Luther Veron\'s Modified Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,312496.0000,0,NULL,0),(15407,77,'Luther Veron\'s Modified Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,0,NULL,0),(15408,38,'Luther Veron\'s Modified Shield Extender','Increases the maximum strength of the shield.',0,20,0,1,NULL,167344.0000,0,NULL,0),(15410,314,'Neophite','This priceless mineral was discovered by a band of Gallente explorers during the Caldari-Gallente war over a century ago.  Closely related to morphite, its composition is only slightly different yet enough so that it has not been able to serve the same function.  Only a few samples of it are known to remain intact, in the possession of some of the most wealthy collectors in the known universe.  ',1,0.1,0,1,NULL,0.0000,1,492,0),(15411,667,'Amarr Luxury Yacht','The Opux Luxury Yacht cruisers are developed and produced by the Gallente, for the wealthy citizens and entertainment industry within the Federation.  Some Amarrian nobels have taken up buying these luxury yachts for their personal pleasure, and have given them slight modifications to bring an Amarrian \"feel\" to them.',13075000,115000,1750,1,8,0.0000,0,NULL,0),(15412,818,'Andres Sikvatsen','Andres Sikvatsen is a small time criminal turned bounty hunter.  He used to work as an agent for the Angel Cartel but eventually switched to the job of a freelancer once he had the funds to purchase his own frigate.  Many wealthy individuals turn to men such as Andres when they feel the law is not adequate in dealing with their problem.  Threat level: Very high',1200000,19100,110,1,2,0.0000,0,NULL,0),(15413,821,'Commander Terachi TashMurkon','Commander Terachi TashMurkon is one of the highest ranking officers within the Tash-Murkon militia.  He received this magnificent battleship as a personal gift from the Emperor himself, fitted with the very finest modules the Imperial Armaments had to offer.  Few pilots in the galaxy would ever dare face this monstrosity in combat.',17500000,1150000,675,1,4,0.0000,0,NULL,0),(15414,821,'Warlord Shaqil Dragat','Shaqil Dragat is one of the most prominent Warlords within the Brutor Tribe of the Minmatar Republic.  Known for his enormous size, even for a Brutor, Shaqil is feared not only for the fleet of warships he commands, but also in person.  He also commands one of the most devastating battleships in the entire Minmatar fleet.',21000000,850000,600,1,2,0.0000,0,NULL,0),(15415,821,'Fleet Commander Naiyon Tai','Fleet Commander Naiyon Tai is one of the highest ranking officers within the Caldari Navy.  Operating one of the finest and most well equipped battleships the Caldari Navy has to offer, Naiyon is not to be taken lightly.  ',21000000,1080000,665,1,1,0.0000,0,NULL,0),(15416,302,'Naiyon\'s Modified Magnetic Field Stabilizer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24994.0000,1,648,0),(15418,77,'Naiyon\'s Modified Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,63062.0000,0,NULL,0),(15419,65,'Naiyon\'s Modified Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,22488.0000,0,NULL,0),(15421,74,'Naiyon\'s Modified 425mm Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,NULL,1500000.0000,0,NULL,0),(15423,74,'Naiyon\'s Modified 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,0,NULL,0),(15425,285,'Naiyon\'s Modified Co-Processor','Increases CPU output.',0,5,0,1,NULL,14996.0000,0,NULL,0),(15427,53,'Makur\'s Modified Dual Heavy Beam Laser','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,600000.0000,0,NULL,0),(15429,53,'Makur\'s Modified Mega Beam Laser','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1200000.0000,0,NULL,0),(15431,52,'Makur\'s Modified Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,0,1935,0),(15433,52,'Makur\'s Modified Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,39424.0000,0,1936,0),(15435,205,'Makur\'s Modified Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,0,NULL,0),(15437,767,'Makur\'s Modified Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,9744.0000,1,667,0),(15439,766,'Makur\'s Modified Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,0,NULL,0),(15443,55,'Shaqil\'s Modified 1200mm Artillery Cannon','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',750,20,1,1,NULL,1200000.0000,0,NULL,0),(15445,55,'Shaqil\'s Modified 1400mm Howitzer Artillery','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1500,20,0.5,1,NULL,1500000.0000,0,NULL,0),(15447,59,'Shaqil\'s Modified Gyrostabilizer','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,24320.0000,1,646,0),(15449,506,'Shaqil\'s Modified Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.65,1,NULL,99996.0000,0,NULL,0),(15451,68,'Shaqil\'s Modified Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(15453,326,'Shaqil\'s Modified Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(15455,326,'Shaqil\'s Modified Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(15457,303,'Standard X-Instinct Booster','This energizing booster grants its user a vastly improved economy of effort when parsing the data streams needed to sustain space flight. The main benefits of this lie not in improved performance but less waste of transmission and extraneous micromaneuvers, making the pilot\'s ship sleeker in performance and harder to detect. The booster\'s only major drawback is the crazed notion that the pilot\'s inventory would look so much better if merely rearranged ONE MORE TIME.',1,1,0,1,NULL,65536.0000,1,977,0),(15458,303,'Improved X-Instinct Booster','This energizing booster grants its user a vastly improved economy of effort when parsing the data streams needed to sustain space flight. The main benefits of this lie not in improved performance but less waste of transmission and extraneous micromaneuvers, making the pilot\'s ship sleeker in performance and harder to detect. The booster\'s only major drawback is the crazed notion that the pilot\'s inventory would look so much better if merely rearranged ONE MORE TIME.',1,1,0,1,NULL,65536.0000,1,977,0),(15459,303,'Strong X-Instinct Booster','This energizing booster grants its user a vastly improved economy of effort when parsing the data streams needed to sustain space flight. The main benefits of this lie not in improved performance but less waste of transmission and extraneous micromaneuvers, making the pilot\'s ship sleeker in performance and harder to detect. The booster\'s only major drawback is the crazed notion that the pilot\'s inventory would look so much better if merely rearranged ONE MORE TIME.',1,1,0,1,NULL,65536.0000,1,977,0),(15460,303,'Standard Frentix Booster','This strong concoction of painkillers helps the pilot block out all inessential thought processes (along with the occasional needed one) and to focus his attention completely on the task at hand. When that task is to hit a target, it certainly makes for better aim, though it does tend to make one\'s extremities go numb for short periods.',1,1,0,1,NULL,65536.0000,1,977,0),(15461,303,'Improved Frentix Booster','This strong concoction of painkillers helps the pilot block out all inessential thought processes (along with the occasional needed one) and to focus his attention completely on the task at hand. When that task is to hit a target, it certainly makes for better aim, though it does tend to make one\'s extremities go numb for short periods.',1,1,0,1,NULL,65536.0000,1,977,0),(15462,303,'Strong Frentix Booster','This strong concoction of painkillers helps the pilot block out all inessential thought processes (along with the occasional needed one) and to focus his attention completely on the task at hand. When that task is to hit a target, it certainly makes for better aim, though it does tend to make one\'s extremities go numb for short periods.',1,1,0,1,NULL,65536.0000,1,977,0),(15463,303,'Standard Mindflood Booster','This booster relaxant allows the pilot to control his ship more instinctively and expend less energy in doing so. This in turn lets the ship utilize more of its resources for mechanical functions, most notably its capacitor, rather than constantly having to compensate for the usual exaggerated motions of a stressed pilot.',1,1,0,1,NULL,65536.0000,1,977,0),(15464,303,'Improved Mindflood Booster','This booster relaxant allows the pilot to control his ship more instinctively and expend less energy in doing so. This in turn lets the ship utilize more of its resources for mechanical functions, most notably its capacitor, rather than constantly having to compensate for the usual exaggerated motions of a stressed pilot.',1,1,0,1,NULL,65536.0000,1,977,0),(15465,303,'Strong Mindflood Booster','This booster relaxant allows the pilot to control his ship more instinctively and expend less energy in doing so. This in turn lets the ship utilize more of its resources for mechanical functions, most notably its capacitor, rather than constantly having to compensate for the usual exaggerated motions of a stressed pilot.',1,1,0,1,NULL,65536.0000,1,977,0),(15466,303,'Standard Drop Booster','This booster throws a pilot into temporary dementia, making every target feel like a monstrous threat that must be destroyed at all cost. The pilot manages to force his turrets into better tracking, though it may take a while before he stops wanting to kill everything in sight.',1,1,0,1,NULL,65536.0000,1,977,0),(15477,303,'Improved Drop Booster','This booster throws a pilot into temporary dementia, making every target feel like a monstrous threat that must be destroyed at all cost. The pilot manages to force his turrets into better tracking, though it may take a while before he stops wanting to kill everything in sight.',1,1,0,1,NULL,65536.0000,1,977,0),(15478,303,'Strong Drop Booster','This booster throws a pilot into temporary dementia, making every target feel like a monstrous threat that must be destroyed at all cost. The pilot manages to force his turrets into better tracking, though it may take a while before he stops wanting to kill everything in sight.',1,1,0,1,NULL,65536.0000,1,977,0),(15479,303,'Standard Exile Booster','This booster hardens a pilot\'s resistance to attacks, letting him withstand their impact to a greater extent. The discomfort of having his armor reduced piecemeal remains unaltered, but the pilot is filled with such a surge of rage that he bullies through it like a living tank.',1,1,0,1,NULL,65536.0000,1,977,0),(15480,303,'Improved Exile Booster','This booster hardens a pilot\'s resistance to attacks, letting him withstand their impact to a greater extent. The discomfort of having his armor reduced piecemeal remains unaltered, but the pilot is filled with such a surge of rage that he bullies through it like a living tank.',1,1,0,1,NULL,65536.0000,1,977,0),(15508,100,'Vespa I','Medium Scout Drone',5000,10,0,1,1,21406.0000,1,838,0),(15509,176,'Vespa I Blueprint',' ',0,0.01,0,1,NULL,1600000.0000,1,1532,0),(15510,100,'Valkyrie I','Medium Scout Drone',5000,10,0,1,2,16392.0000,1,838,0),(15511,176,'Valkyrie I Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1532,0),(15577,665,'Imperial Navy Elite Soldier','The Imperial Navy Elite Soldier class fighter ships are an uncommon sight within the Amarr Imperial armada.  These ships are specially modded to be slightly more powerful than the common Soldier class ships.  Threat level: Very high',1265000,18100,235,1,4,0.0000,0,NULL,0),(15578,665,'Ammatar Navy Elite Soldier','The Ammatar Navy Elite Soldier class fighter ships are an uncommon sight within the Ammatar armada.  These ships are specially modded to be slightly more powerful than the common Soldier class ships.  Threat level: Very high',1265000,18100,235,1,4,0.0000,0,NULL,0),(15579,671,'Caldari Navy Elite Soldier','The Caldari Navy Elite Soldier class fighter ships are an uncommon sight within the Caldari State armada.  These ships are specially modded to be slightly more powerful than the common Soldier class ships.  Threat level: Very high',1680000,17400,90,1,1,0.0000,0,NULL,0),(15580,677,'Federation Navy Elite Soldier','The Federation Navy Elite Soldier class fighter ships are an uncommon sight within the Gallente Federation armada.  These ships are specially modded to be slightly more powerful than the common Soldier class ships.  Threat level: Very high',2040000,20400,200,1,8,0.0000,0,NULL,0),(15581,683,'Republic Fleet Elite Soldier','The Minmatar Fleet Elite Soldier class fighter ships are an uncommon sight within the Minmatar Republic armada.  These ships are specially modded to be slightly more powerful than the common Soldier class ships.  Threat level: Very high',1200000,12000,80,1,2,0.0000,0,NULL,0),(15582,817,'Captain Yeni Sarum','Captain Yeni Sarum is a high-ranking commanding officer within the Navy, personally appointed to the post by Jamyl Sarum herself.',12250000,115000,465,1,4,0.0000,0,NULL,0),(15583,817,'Captain Jerek Zuomi','Captain Jerek Zuomi is a high ranking commanding officer within the Navy.  Jerek is renowned for his long and loyal servitude to the Ammatar and the Empire.',12250000,115000,465,1,4,0.0000,0,NULL,0),(15584,817,'Captain Mizuma Gomi','Captain Mizuma Gomi is a high ranking commanding officer within the Navy.  Coming from a powerful family within the Caldari State, many would argue that he had been given his position on a silver platter.',13000000,107000,485,1,1,0.0000,0,NULL,0),(15585,817,'Captain Jerome Leman','Captain Jerome Leman is a high-ranking commanding officer within the Navy.  A tight-lipped and strict officer, Jerome is reknowned for his love of protocol.',12250000,113000,235,1,8,0.0000,0,NULL,0),(15586,817,'Captain Kali Midez','Captain Kali Midez is a commanding officer within the Fleet.  He had a long and glorious career within the Minmatar Freedom Fighters before he joined the Minmatar Republic military.',10250000,89000,440,1,2,0.0000,0,NULL,0),(15587,409,'Federation Navy Midshipman Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,4500.0000,1,734,0),(15588,409,'Federation Navy Midshipman Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,8000.0000,1,734,0),(15589,409,'Federation Navy Midshipman Insignia III','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,15000.0000,1,734,0),(15590,409,'Federation Navy Sergeant Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,20000.0000,1,734,0),(15591,409,'Federation Navy Sergeant Major Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,30000.0000,1,734,0),(15592,409,'Federation Navy Fleet Captain Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,60000.0000,1,734,0),(15593,409,'Federation Navy Fleet Major Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,100000.0000,1,734,0),(15594,409,'Federation Navy Fleet Colonel Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,500000.0000,1,734,0),(15596,409,'Caldari Navy Midshipman Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,4500.0000,1,732,0),(15597,409,'Caldari Navy Midshipman Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,8000.0000,1,732,0),(15598,409,'Caldari Navy Midshipman Insignia III','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,15000.0000,1,732,0),(15599,409,'Caldari Navy Captain Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,20000.0000,1,732,0),(15600,409,'Caldari Navy Captain Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,25000.0000,1,732,0),(15601,409,'Caldari Navy Captain Insignia III','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,30000.0000,1,732,0),(15602,409,'Caldari Navy Commodore Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,60000.0000,1,732,0),(15604,409,'Caldari Navy Admiral Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,750000.0000,1,732,0),(15605,409,'Caldari Navy Vice Admiral Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,500000.0000,1,732,0),(15607,409,'Imperial Navy Midshipman Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,4500.0000,1,730,0),(15608,409,'Imperial Navy Midshipman Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,8000.0000,1,730,0),(15609,409,'Imperial Navy Midshipman Insignia III','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,15000.0000,1,730,0),(15610,409,'Imperial Navy Sergeant Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,20000.0000,1,730,0),(15611,409,'Imperial Navy Sergeant Major Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,30000.0000,1,730,0),(15612,409,'Imperial Navy Captain Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,50000.0000,1,730,0),(15613,409,'Imperial Navy Major Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,60000.0000,1,730,0),(15614,409,'Imperial Navy Colonel Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,100000.0000,1,730,0),(15615,409,'Imperial Navy General Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,500000.0000,1,730,0),(15617,409,'Ammatar Navy Midshipman Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,4500.0000,1,731,0),(15618,409,'Ammatar Navy Midshipman Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,8000.0000,1,731,0),(15619,409,'Ammatar Navy Midshipman Insignia III','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,15000.0000,1,731,0),(15620,409,'Ammatar Navy Sergeant Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,20000.0000,1,731,0),(15621,409,'Ammatar Navy Sergeant Major Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,30000.0000,1,731,0),(15622,409,'Ammatar Navy Captain Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,45000.0000,1,731,0),(15623,409,'Ammatar Navy Major Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,50000.0000,1,731,0),(15625,409,'Republic Fleet Midshipman Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,4500.0000,1,736,0),(15626,409,'Republic Fleet Midshipman Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,8000.0000,1,736,0),(15627,409,'Republic Fleet Midshipman Insignia III','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,15000.0000,1,736,0),(15628,409,'Republic Fleet Private Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,20000.0000,1,736,0),(15629,409,'Republic Fleet Private Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,25000.0000,1,736,0),(15630,409,'Republic Fleet Captain Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,60000.0000,1,736,0),(15631,409,'Republic Fleet High Captain Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,100000.0000,1,736,0),(15632,409,'Republic Fleet Commander Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,500000.0000,1,736,0),(15634,409,'Imperial Navy Squad Leader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,50000.0000,1,730,0),(15635,409,'Imperial Navy Raid Leader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,100000.0000,1,730,0),(15636,409,'Imperial Navy Sergeant Elite Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,60000.0000,1,730,0),(15637,409,'Yeni Sarum\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,0.0000,1,737,0),(15638,409,'Terachi Tash-Murkon\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,0.0000,1,737,0),(15639,409,'Karzo Sarum\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,0.0000,1,737,0),(15640,409,'Ammatar Navy Squad Leader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,50000.0000,1,731,0),(15641,409,'Ammatar Navy Raid Leader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,100000.0000,1,731,0),(15642,409,'Ammatar Navy Sergeant Elite Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,60000.0000,1,731,0),(15643,409,'Ammatar Navy Fleet Commander Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,2000000.0000,1,731,0),(15644,409,'Zerim Kurzon\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,0.0000,1,NULL,0),(15645,409,'Jerek Zuomi\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,0.0000,1,737,0),(15646,409,'Federation Navy Command Sergeant Major Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,50000.0000,1,734,0),(15647,409,'Federation Navy Squad Leader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,50000.0000,1,734,0),(15648,409,'Federation Navy Raid Leader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,100000.0000,1,734,0),(15649,409,'Federation Navy Sergeant Elite Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,60000.0000,1,734,0),(15650,409,'Federation Navy Fleet Commander Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,2000000.0000,1,734,0),(15651,409,'Jerome Leman\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,0.0000,1,NULL,0),(15652,409,'Luther Veron\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,0.0000,1,NULL,0),(15653,409,'Caldari Navy Captain Elite Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,60000.0000,1,732,0),(15654,409,'Caldari Navy Squad Leader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,50000.0000,1,732,0),(15655,409,'Caldari Navy Raid Leader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,100000.0000,1,732,0),(15656,409,'Caldari Navy Commodore Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,100000.0000,1,732,0),(15657,409,'Caldari Navy Fleet Commander Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,2000000.0000,1,732,0),(15658,409,'Naiyon Tai\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,1,0.0000,1,737,0),(15659,409,'Mizuma Gomi\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,0.0000,1,737,0),(15660,409,'Republic Fleet Private Insignia III','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,30000.0000,1,736,0),(15661,409,'Republic Fleet Commander Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,750000.0000,1,736,0),(15662,409,'Republic Fleet Squad Leader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,50000.0000,1,736,0),(15663,409,'Republic Fleet Raid Leader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,100000.0000,1,736,0),(15664,409,'Republic Fleet Navy Commander Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,2000000.0000,1,736,0),(15666,409,'Republic Fleet Private Elite Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,60000.0000,1,736,0),(15667,409,'Kali Midez\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,0.0000,1,737,0),(15668,409,'Shaqil Dragat\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,0.0000,1,737,0),(15669,409,'Imperial Navy General Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,750000.0000,1,730,0),(15670,409,'Imperial Navy Fleet Commander Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,2000000.0000,1,730,0),(15671,409,'Ammatar Navy Colonel Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,750000.0000,1,731,0),(15672,409,'Ammatar Navy Major Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,100000.0000,1,731,0),(15673,409,'Federation Navy Fleet Colonel Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,750000.0000,1,734,0),(15674,409,'Minmatar Freedom Fighter Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,20000.0000,1,736,0),(15675,285,'Caldari Navy Co-Processor','Increases CPU output.',0,5,0,1,NULL,16428.0000,1,676,0),(15676,346,'Caldari Navy Co-Processor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15677,285,'Federation Navy Co-Processor','Increases CPU output.',0,5,0,1,NULL,16428.0000,1,676,0),(15678,346,'Federation Navy Co-Processor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15681,367,'Caldari Navy Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,85006.0000,1,645,0),(15682,400,'Caldari Navy Ballistic Control System Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15683,367,'Republic Fleet Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,85006.0000,1,645,0),(15684,400,'Republic Fleet Ballistic Control System Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15685,98,'Imperial Navy Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1665,0),(15686,163,'Imperial Navy Thermic Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15687,98,'Imperial Navy EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1668,0),(15688,163,'Imperial Navy EM Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15689,98,'Imperial Navy Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1667,0),(15690,163,'Imperial Navy Explosive Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15691,98,'Imperial Navy Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1666,0),(15692,163,'Imperial Navy Kinetic Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15693,98,'Imperial Navy Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,8304.0000,1,1670,0),(15694,163,'Imperial Navy Adaptive Nano Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15695,98,'Republic Fleet Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1665,0),(15696,163,'Republic Fleet Thermic Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15697,98,'Republic Fleet EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1668,0),(15698,163,'Republic Fleet EM Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15699,98,'Republic Fleet Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1667,0),(15700,163,'Republic Fleet Explosive Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15701,98,'Republic Fleet Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1666,0),(15702,163,'Republic Fleet Kinetic Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15703,98,'Republic Fleet Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,8304.0000,1,1670,0),(15704,163,'Republic Fleet Adaptive Nano Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15705,328,'Imperial Navy Armor Thermic Hardener','An enhanced version of the standard Thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,277634.0000,1,1678,0),(15706,348,'Imperial Navy Armor Thermic Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15707,328,'Imperial Navy Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,340756.0000,1,1679,0),(15708,348,'Imperial Navy Armor Kinetic Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15709,328,'Imperial Navy Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,397768.0000,1,1680,0),(15710,348,'Imperial Navy Armor Explosive Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15711,328,'Imperial Navy Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,225690.0000,1,1681,0),(15712,348,'Imperial Navy Armor EM Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15713,328,'Republic Fleet Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,277634.0000,1,1678,0),(15714,348,'Republic Fleet Armor Thermic Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15715,328,'Republic Fleet Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,340756.0000,1,1679,0),(15716,348,'Republic Fleet Armor Kinetic Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15717,328,'Republic Fleet Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,397768.0000,1,1680,0),(15718,348,'Republic Fleet Armor Explosive Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15719,328,'Republic Fleet Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,225690.0000,1,1681,0),(15720,348,'Republic Fleet Armor EM Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15721,326,'Imperial Navy Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1683,0),(15722,163,'Imperial Navy Energized Thermic Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15723,326,'Imperial Navy Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1684,0),(15724,163,'Imperial Navy Energized EM Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15725,326,'Imperial Navy Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1682,0),(15726,163,'Imperial Navy Energized Explosive Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15727,326,'Imperial Navy Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1685,0),(15728,163,'Imperial Navy Energized Kinetic Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15729,326,'Imperial Navy Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,120202.0000,1,1686,0),(15730,163,'Imperial Navy Energized Adaptive Nano Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15731,326,'Federation Navy Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1683,0),(15732,163,'Federation Navy Energized Thermic Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15733,326,'Federation Navy Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1684,0),(15734,163,'Federation Navy Energized EM Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15735,326,'Federation Navy Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1682,0),(15736,163,'Federation Navy Energized Explosive Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15737,326,'Federation Navy Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1685,0),(15738,163,'Federation Navy Energized Kinetic Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15739,326,'Federation Navy Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,120202.0000,1,1686,0),(15740,163,'Federation Navy Energized Adaptive Nano Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15741,62,'Ammatar Navy Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,4,9996.0000,1,1049,0),(15742,62,'Ammatar Navy Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,4,19916.0000,1,1050,0),(15743,62,'Ammatar Navy Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(15744,62,'Federation Navy Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,4,9996.0000,1,1049,0),(15745,62,'Federation Navy Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,4,19916.0000,1,1050,0),(15746,62,'Federation Navy Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(15747,46,'Republic Fleet 5MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,34998.0000,1,131,0),(15748,126,'Republic Fleet 5MN Microwarpdrive Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(15749,46,'Republic Fleet 1MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,7104.0000,1,542,0),(15750,126,'Republic Fleet 1MN Afterburner Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15751,46,'Republic Fleet 50MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,192086.0000,1,131,0),(15752,126,'Republic Fleet 50MN Microwarpdrive Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(15753,46,'Republic Fleet 10MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,35804.0000,1,542,0),(15754,126,'Republic Fleet 10MN Afterburner Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15755,46,'Republic Fleet 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,1076506.0000,1,131,0),(15756,126,'Republic Fleet 500MN Microwarpdrive Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(15757,46,'Republic Fleet 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,189896.0000,1,542,0),(15758,126,'Republic Fleet 100MN Afterburner Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15759,46,'Federation Navy 5MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,34998.0000,1,131,0),(15760,126,'Federation Navy 5MN Microwarpdrive Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(15761,46,'Federation Navy 1MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,7104.0000,1,542,0),(15762,126,'Federation Navy 1MN Afterburner Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15764,46,'Federation Navy 50MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,192086.0000,1,131,0),(15765,126,'Federation Navy 50MN Microwarpdrive Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(15766,46,'Federation Navy 10MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,35804.0000,1,542,0),(15767,126,'Federation Navy 10MN Afterburner Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15768,46,'Federation Navy 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,1076506.0000,1,131,0),(15769,126,'Federation Navy 500MN Microwarpdrive Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(15770,46,'Federation Navy 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,189896.0000,1,542,0),(15771,126,'Federation Navy 100MN Afterburner Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15772,76,'Ammatar Navy Small Capacitor Booster','Provides a quick injection of power into the capacitor.',0,5,12,1,NULL,20010.0000,1,699,0),(15773,156,'Ammatar Navy Small Capacitor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15774,76,'Ammatar Navy Micro Capacitor Booster','Provides a quick injection of power into the capacitor.',0,2.5,8,1,NULL,4500.0000,1,698,0),(15776,76,'Ammatar Navy Medium Capacitor Booster','Provides a quick injection of power into the capacitor.',0,10,32,1,NULL,40356.0000,1,700,0),(15777,156,'Ammatar Navy Medium Capacitor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15778,76,'Ammatar Navy Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,78242.0000,1,701,0),(15779,156,'Ammatar Navy Heavy Capacitor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15780,76,'Imperial Navy Small Capacitor Booster','Provides a quick injection of power into the capacitor.',0,5,12,1,NULL,20010.0000,1,699,0),(15781,156,'Imperial Navy Small Capacitor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15782,76,'Imperial Navy Micro Capacitor Booster','Provides a quick injection of power into the capacitor.',0,2.5,8,1,NULL,4992.0000,1,698,0),(15783,156,'Imperial Navy Micro Capacitor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15784,76,'Imperial Navy Medium Capacitor Booster','Provides a quick injection of power into the capacitor.',0,10,32,1,NULL,40356.0000,1,700,0),(15785,156,'Imperial Navy Medium Capacitor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15786,76,'Imperial Navy Heavy Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,78242.0000,1,701,0),(15787,156,'Imperial Navy Heavy Capacitor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15788,43,'Ammatar Navy Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,33662.0000,1,665,0),(15789,123,'Ammatar Navy Cap Recharger Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15790,330,'Caldari Navy Cloaking Device','This prototype of an advanced cloaking mechanism was one of the last major technological breakthroughs to come out of Crielere Labs. Although it does work it is not really a finished product and has some serious drawbacks, most notably the fact that the module creates high sensor disruption while fitted and can not operate unless at minimum velocity.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,807618.0000,1,675,0),(15791,401,'Caldari Navy Cloaking Device Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15792,213,'Federation Navy Tracking Computer','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,18282.0000,1,706,0),(15793,224,'Federation Navy Tracking Computer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15794,71,'Ammatar Navy Small Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,40456.0000,1,689,0),(15795,151,'Ammatar Navy Small Energy Neutralizer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15796,71,'Ammatar Navy Medium Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,173776.0000,1,690,0),(15797,151,'Ammatar Navy Medium Energy Neutralizer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15798,71,'Ammatar Navy Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,850636.0000,1,691,0),(15799,151,'Ammatar Navy Heavy Energy Neutralizer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15800,71,'Imperial Navy Small Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,40456.0000,1,689,0),(15801,151,'Imperial Navy Small Energy Neutralizer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15802,71,'Imperial Navy Medium Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,173776.0000,1,690,0),(15803,151,'Imperial Navy Medium Energy Neutralizer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15804,71,'Imperial Navy Heavy Energy Neutralizer','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,850636.0000,1,691,0),(15805,151,'Imperial Navy Heavy Energy Neutralizer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15806,59,'Republic Fleet Gyrostabilizer','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,30626.0000,1,646,0),(15807,139,'Republic Fleet Gyrostabilizer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15808,205,'Ammatar Navy Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,40456.0000,1,647,0),(15809,218,'Ammatar Navy Heat Sink Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15810,205,'Imperial Navy Heat Sink','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,40456.0000,1,647,0),(15811,218,'Imperial Navy Heat Sink Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15812,764,'Republic Fleet Overdrive Injector','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,2,512.0000,1,1087,0),(15813,763,'Republic Fleet Nanofiber Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,2,512.0000,1,1196,0),(15814,74,'Caldari Navy Dual 250mm Railgun','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,1,98972.0000,1,566,0),(15815,74,'Caldari Navy Dual 150mm Railgun','This cruiser-sized weapon is a double-barreled version of the frigate class 150mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2,1,1,10000.0000,1,565,0),(15816,74,'Caldari Navy 75mm Railgun','A small multi-barreled railgun for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,1,1000.0000,1,564,0),(15817,74,'Caldari Navy 425mm Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,1,744812.0000,1,566,0),(15818,74,'Caldari Navy 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1395890.0000,1,566,0),(15819,154,'Caldari Navy 350mm Railgun Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15820,74,'Caldari Navy 250mm Railgun','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,0.5,1,1,74980.0000,1,565,0),(15821,74,'Caldari Navy 200mm Railgun','The 200mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,NULL,129736.0000,1,565,0),(15822,154,'Caldari Navy 200mm Railgun Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15823,74,'Caldari Navy 150mm Railgun','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,1,7496.0000,1,564,0),(15824,74,'Caldari Navy 125mm Railgun','The 125mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,1,4484.0000,1,564,0),(15825,74,'Federation Navy Neutron Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,4,595840.0000,1,563,0),(15826,74,'Federation Navy Light Neutron Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,4,5996.0000,1,561,0),(15827,74,'Federation Navy Light Ion Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.3,1,4,4484.0000,1,561,0),(15828,74,'Federation Navy Light Electron Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,4,1976.0000,1,561,0),(15829,74,'Federation Navy Ion Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,3,1,4,448700.0000,1,563,0),(15830,74,'Federation Navy Heavy Neutron Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,4,59676.0000,1,562,0),(15831,74,'Federation Navy Heavy Ion Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1.5,1,4,44740.0000,1,562,0),(15832,74,'Federation Navy Heavy Electron Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2.5,1,4,25888.0000,1,562,0),(15833,74,'Federation Navy Electron Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,5,1,4,298716.0000,1,563,0),(15834,74,'Federation Navy Dual 250mm Railgun','This battleship-sized weapon is a double-barreled version of the cruiser class 250mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,4,1,1,98972.0000,1,566,0),(15835,74,'Federation Navy Dual 150mm Railgun','This cruiser-sized weapon is a double-barreled version of the frigate class 150mm railgun. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2,1,1,10000.0000,1,565,0),(15836,74,'Federation Navy 75mm Railgun','A small multi-barreled railgun for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,1,1000.0000,1,564,0),(15837,74,'Federation Navy 425mm Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,1,744812.0000,1,566,0),(15838,74,'Federation Navy 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1395890.0000,1,566,0),(15839,154,'Federation Navy 350mm Railgun Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15840,74,'Federation Navy 250mm Railgun','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,0.5,1,1,74980.0000,1,565,0),(15841,74,'Federation Navy 200mm Railgun','The 200mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1,1,NULL,129736.0000,1,565,0),(15842,154,'Federation Navy 200mm Railgun Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15843,74,'Federation Navy 150mm Railgun','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,1,7496.0000,1,564,0),(15844,74,'Federation Navy 125mm Railgun','The 125mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,1,4484.0000,1,564,0),(15845,53,'Ammatar Navy Tachyon Beam Laser','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,744812.0000,1,569,0),(15846,53,'Ammatar Navy Quad Beam Laser','Uses four light laser focusing systems. Low powered, but makes up for it with a fast firing rate. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,10000.0000,1,568,0),(15847,53,'Ammatar Navy Mega Pulse Laser','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,448700.0000,1,573,0),(15848,53,'Ammatar Navy Mega Beam Laser','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,595840.0000,1,569,0),(15849,53,'Ammatar Navy Small Focused Pulse Laser','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,5984.0000,1,570,0),(15850,53,'Ammatar Navy Small Focused Beam Laser','A high-powered beam laser. Good for medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,7484.0000,1,567,0),(15851,53,'Ammatar Navy Heavy Pulse Laser','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,59676.0000,1,572,0),(15852,53,'Ammatar Navy Heavy Beam Laser','A high-energy heavy laser designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,74980.0000,1,568,0),(15853,53,'Ammatar Navy Gatling Pulse Laser','Rapid fire multi-barreled energy weapon that delivers a steady stream of damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,1000.0000,1,570,0),(15854,53,'Ammatar Navy Focused Medium Pulse Laser','A high-energy, concentrated laser designed for short to medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,25888.0000,1,572,0),(15855,53,'Ammatar Navy Focused Medium Beam Laser','A high-energy, concentrated laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,44740.0000,1,568,0),(15856,53,'Ammatar Navy Dual Light Pulse Laser','This light pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. Good skirmish weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: gamma, infrared, microwave, multifrequency, radio, standard, ultraviolet, xray.',500,5,1,1,4,1976.0000,1,570,0),(15857,53,'Ammatar Navy Dual Light Beam Laser','This light beam laser uses two separate laser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,3472.0000,1,567,0),(15858,53,'Ammatar Navy Dual Heavy Pulse Laser','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,98972.0000,1,573,0),(15859,53,'Ammatar Navy Dual Heavy Beam Laser','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,298716.0000,1,569,0),(15860,53,'Imperial Navy Tachyon Beam Laser','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,744812.0000,1,569,0),(15861,53,'Imperial Navy Quad Beam Laser','Uses four light laser focusing systems. Low powered, but makes up for it with a fast firing rate. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,10000.0000,1,568,0),(15862,53,'Imperial Navy Mega Pulse Laser','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,448700.0000,1,573,0),(15863,53,'Imperial Navy Mega Beam Laser','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,595840.0000,1,569,0),(15864,53,'Imperial Navy Small Focused Pulse Laser','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,5984.0000,1,570,0),(15865,53,'Imperial Navy Small Focused Beam Laser','A high-powered beam laser. Good for medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,7484.0000,1,567,0),(15866,53,'Imperial Navy Heavy Pulse Laser','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,59676.0000,1,572,0),(15867,53,'Imperial Navy Heavy Beam Laser','A high-energy heavy laser designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,74980.0000,1,568,0),(15868,53,'Imperial Navy Gatling Pulse Laser','Rapid fire multi-barreled energy weapon that delivers a steady stream of damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,1000.0000,1,570,0),(15869,53,'Imperial Navy Focused Medium Pulse Laser','A high-energy, concentrated laser designed for short to medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,25888.0000,1,572,0),(15870,53,'Imperial Navy Focused Medium Beam Laser','A high-energy, concentrated laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,4,44740.0000,1,568,0),(15871,53,'Imperial Navy Dual Light Pulse Laser','This light pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. Good skirmish weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,1976.0000,1,570,0),(15872,53,'Imperial Navy Dual Light Beam Laser','This light beam laser uses two separate laser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,3472.0000,1,567,0),(15873,53,'Imperial Navy Dual Heavy Pulse Laser','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,98972.0000,1,573,0),(15874,53,'Imperial Navy Dual Heavy Beam Laser','This heavy beam laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,4,298716.0000,1,569,0),(15875,68,'Ammatar Navy Small Nosferatu','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,51194.0000,1,692,0),(15876,148,'Ammatar Navy Small Nosferatu Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15877,68,'Ammatar Navy Medium Nosferatu','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,315910.0000,1,693,0),(15878,148,'Ammatar Navy Medium Nosferatu Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15879,68,'Ammatar Navy Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,1663554.0000,1,694,0),(15880,148,'Ammatar Navy Heavy Nosferatu Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15881,68,'Imperial Navy Small Nosferatu','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,51194.0000,1,692,0),(15882,148,'Imperial Navy Small Nosferatu Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15883,68,'Imperial Navy Medium Nosferatu','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module does not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,315910.0000,1,693,0),(15884,148,'Imperial Navy Medium Nosferatu Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15885,68,'Imperial Navy Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,1663554.0000,1,694,0),(15886,148,'Imperial Navy Heavy Nosferatu Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15887,52,'Caldari Navy Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,47476.0000,1,1936,0),(15888,132,'Caldari Navy Warp Scrambler Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15889,52,'Caldari Navy Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,47476.0000,1,1935,0),(15890,132,'Caldari Navy Warp Disruptor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15891,52,'Republic Fleet Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,47476.0000,1,1935,0),(15892,132,'Republic Fleet Warp Disruptor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15893,52,'Republic Fleet Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,47476.0000,1,1936,0),(15894,132,'Republic Fleet Warp Scrambler Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15895,302,'Federation Navy Magnetic Field Stabilizer','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27772.0000,1,648,0),(15896,139,'Federation Navy Magnetic Field Stabilizer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15897,40,'Caldari Navy X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(15898,40,'Caldari Navy Small Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,1,4554.0000,1,609,0),(15899,40,'Caldari Navy Medium Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,1,18216.0000,1,610,0),(15900,40,'Caldari Navy Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(15901,40,'Republic Fleet X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(15902,40,'Republic Fleet Small Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,1,4554.0000,1,609,0),(15903,40,'Republic Fleet Medium Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,1,18216.0000,1,610,0),(15904,40,'Republic Fleet Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(15905,338,'Caldari Navy Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,531040.0000,1,613,0),(15906,360,'Caldari Navy Shield Boost Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15907,338,'Republic Fleet Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,531040.0000,1,613,0),(15908,360,'Republic Fleet Shield Boost Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15909,295,'Caldari Navy EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1691,0),(15910,296,'Caldari Navy EM Ward Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15911,295,'Caldari Navy Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1689,0),(15912,296,'Caldari Navy Kinetic Deflection Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15913,295,'Caldari Navy Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1688,0),(15914,296,'Caldari Navy Thermic Dissipation Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15915,295,'Caldari Navy Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1690,0),(15916,296,'Caldari Navy Explosive Deflection Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15917,295,'Republic Fleet EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1691,0),(15918,296,'Republic Fleet EM Ward Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15919,295,'Republic Fleet Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1689,0),(15920,296,'Republic Fleet Kinetic Deflection Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15921,295,'Republic Fleet Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1688,0),(15922,296,'Republic Fleet Thermic Dissipation Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15923,295,'Republic Fleet Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1690,0),(15924,296,'Republic Fleet Explosive Deflection Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15925,72,'Caldari Navy Small Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',10,5,0,1,NULL,62370.0000,1,382,0),(15926,152,'Caldari Navy Small Graviton Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15927,72,'Caldari Navy Micro Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,2.5,0,1,NULL,24018.0000,1,380,0),(15928,152,'Caldari Navy Micro Graviton Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15929,72,'Caldari Navy Medium Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,10,0,1,NULL,43770.0000,1,383,0),(15930,152,'Caldari Navy Medium Graviton Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15931,72,'Caldari Navy Large Graviton Smartbomb','Radiates an omnidirectional pulse from the ship that causes kinetic damage to surrounding vessels.',100,50,0,1,NULL,347216.0000,1,381,0),(15932,152,'Caldari Navy Large Graviton Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15933,72,'Republic Fleet Micro Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,2.5,0,1,NULL,19988.0000,1,380,0),(15935,72,'Republic Fleet Small Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',10,5,0,1,NULL,62370.0000,1,382,0),(15936,152,'Republic Fleet Small Proton Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15937,72,'Republic Fleet Medium Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,10,0,1,NULL,43770.0000,1,383,0),(15938,152,'Republic Fleet Medium Proton Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15939,72,'Republic Fleet Large Proton Smartbomb','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,50,0,1,NULL,347216.0000,1,381,0),(15940,152,'Republic Fleet Large Proton Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15941,72,'Ammatar Navy Small EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',10,5,0,1,NULL,62370.0000,1,382,0),(15942,152,'Ammatar Navy Small EMP Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15943,72,'Ammatar Navy Micro EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,2.5,0,1,NULL,19988.0000,1,380,0),(15945,72,'Ammatar Navy Medium EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,10,0,1,NULL,43770.0000,1,383,0),(15946,152,'Ammatar Navy Medium EMP Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15947,72,'Ammatar Navy Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,347216.0000,1,381,0),(15948,152,'Ammatar Navy Large EMP Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15949,72,'Federation Navy Small Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',10,5,0,1,NULL,78754.0000,1,382,0),(15950,152,'Federation Navy Small Plasma Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15951,72,'Federation Navy Micro Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,2.5,0,1,NULL,19988.0000,1,380,0),(15953,72,'Federation Navy Medium Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,10,0,1,NULL,43770.0000,1,383,0),(15954,152,'Federation Navy Medium Plasma Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15955,72,'Federation Navy Large Plasma Smartbomb','Radiates an omnidirectional pulse from the ship that causes thermal damage to surrounding vessels.',100,50,0,1,NULL,347216.0000,1,381,0),(15956,152,'Federation Navy Large Plasma Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15957,72,'Imperial Navy Small EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',10,5,0,1,NULL,62370.0000,1,382,0),(15958,152,'Imperial Navy Small EMP Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15959,72,'Imperial Navy Micro EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,2.5,0,1,NULL,24018.0000,1,380,0),(15960,152,'Imperial Navy Micro EMP Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15961,72,'Imperial Navy Medium EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,10,0,1,NULL,43770.0000,1,383,0),(15962,152,'Imperial Navy Medium EMP Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15963,72,'Imperial Navy Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,347216.0000,1,381,0),(15964,152,'Imperial Navy Large EMP Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15965,211,'Republic Fleet Tracking Enhancer','Enhances the range and improves the tracking speed of turrets.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,15764.0000,1,707,0),(15966,344,'Republic Fleet Tracking Enhancer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15967,209,'Federation Navy Remote Tracking Computer','Establishes a fire control link with another ship, thereby boosting the turret range and tracking speed of that ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,33284.0000,1,708,0),(15968,345,'Federation Navy Remote Tracking Computer  Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(15969,671,'Caldari Navy Gamma I Support Frigate','This is a Caldari Navy support ship. Developed by Lai Dai, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',1970000,19700,235,1,1,0.0000,0,NULL,0),(15970,671,'Caldari Navy Gamma II Support Frigate','This is a Caldari Navy support ship. Developed by Lai Dai, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',1000000,19400,235,1,1,0.0000,0,NULL,0),(15971,671,'Caldari Navy Delta I Support Frigate','This is a Caldari Navy support ship. Developed by Lai Dai, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2040000,20400,130,1,1,0.0000,0,NULL,0),(15972,671,'Caldari Navy Delta II Support Frigate','This is a Caldari Navy support ship. Developed by Lai Dai, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2040000,20400,125,1,1,0.0000,0,NULL,0),(15973,683,'Republic Fleet C-2 Support Frigate','This is a Minmatar Fleet support ship. Support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',1740000,17400,175,1,2,0.0000,0,NULL,0),(15974,683,'Republic Fleet D-2 Support Frigate','This is a Minmatar Fleet support ship. Support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',1740000,17400,110,1,2,0.0000,0,NULL,0),(15975,683,'Republic Fleet C-1 Support Frigate','This is a Minmatar Fleet support ship. Support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',1100000,17400,120,1,2,0.0000,0,NULL,0),(15976,683,'Republic Fleet D-1 Support Frigate','This is a Minmatar Fleet support ship. Support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',5000000,28100,110,1,2,0.0000,0,NULL,0),(15977,665,'Ammatar Navy Gamma II Support Frigate','This is a Ammatar Navy support ship. Developed by Carthum Conglomerate, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2870000,28700,235,1,4,0.0000,0,NULL,0),(15978,665,'Ammatar Navy Gamma I Support Frigate','This is a Ammatar Navy support ship. Developed by Carthum Conglomerate, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2870000,28700,312,1,4,0.0000,0,NULL,0),(15979,409,'Ammatar Slave Trader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,15000.0000,1,731,0),(15980,409,'Amarr Empire Slave Trader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,15000.0000,1,737,0),(15981,409,'Khanid Slave Trader Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,15000.0000,1,735,0),(15982,665,'Ammatar Navy Delta I Support Frigate','This is an Ammatar Navy support ship. Developed by Carthum Conglomerate, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2810000,28100,135,1,4,0.0000,0,NULL,0),(15983,665,'Ammatar Navy Delta II Support Frigate','This is an Ammatar Navy support ship. Developed by Carthum Conglomerate, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2810000,28100,235,1,4,0.0000,0,NULL,0),(15984,665,'Imperial Navy Gamma II Support Frigate','This is an Imperial Navy support ship. Developed by Carthum Conglomerate, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2870000,28700,235,1,4,0.0000,0,NULL,0),(15985,665,'Imperial Navy Gamma I Support Frigate','This is an Imperial Navy support ship. Developed by Carthum Conglomerate, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2870000,28700,200,1,4,0.0000,0,NULL,0),(15986,665,'Imperial Navy Delta II Support Frigate','This is an Imperial Navy support ship. Developed by Carthum Conglomerate, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2810000,28100,200,1,4,0.0000,0,NULL,0),(15987,665,'Imperial Navy Delta I Support Frigate','This is an Imperial Navy support ship. Developed by Carthum Conglomerate, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2810000,28100,235,1,4,0.0000,0,NULL,0),(15988,677,'Federation Navy Gamma II Support Frigate','This is a Federation Navy support ship. Developed by Duvolle Laboratories, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2300000,23000,235,1,8,0.0000,0,NULL,0),(15989,677,'Federation Navy Delta II Support Frigate','This is a Federation Navy support Ship. Developed by Duvolle Laboratories, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2300000,23000,235,1,8,0.0000,0,NULL,0),(15990,677,'Federation Navy Gamma I Support Frigate','This is a Federation Navy support Ship. Developed by Duvolle Laboratories, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2650000,26500,140,1,8,0.0000,0,NULL,0),(15991,677,'Federation Navy Delta I Support Frigate','This is a Federation Navy support Ship. Developed by Duvolle Laboratories, support ships such as these are used to paralyze their targets, disabling their warping device and hindering ship velocity by employing micro energy streams. Threat level: High',2300000,23000,60,1,8,0.0000,0,NULL,0),(15992,409,'Imperial Navy Sergeant Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,25000.0000,1,730,0),(15993,409,'Ammatar Navy Sergeant Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,25000.0000,1,731,0),(15994,409,'Federation Navy Sergeant Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,25000.0000,1,734,0),(15996,409,'Caldari Navy Captain Insignia IV','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,1,30000.0000,1,732,0),(15997,409,'Republic Fleet Private Insignia IV','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,30000.0000,1,736,0),(15998,409,'Republic Fleet Private Insignia V','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,50000.0000,1,736,0),(15999,409,'Caldari Navy Captain Insignia V','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,50000.0000,1,732,0),(16000,409,'Imperial Navy Sergeant Insignia III','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,30000.0000,1,730,0),(16001,409,'Ammatar Navy Sergeant Insignia III','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,30000.0000,1,731,0),(16002,409,'Federation Navy Sergeant Insignia III','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,30000.0000,1,734,0),(16003,747,'Eifyr and Co. \'Rogue\' Navigation NN-605','A Eifyr and Co hardwiring designed to enhance pilot navigation skill.\r\r\n\r\r\n5% bonus to ship velocity.',0,1,0,1,NULL,0.0000,1,1489,0),(16004,747,'Eifyr and Co. \'Rogue\' Evasive Maneuvering EM-705','A neural interface upgrade designed to enhance pilot Maneuvering skill.\r\r\n\r\r\n5% bonus to ship agility.',0,1,0,1,NULL,0.0000,1,1490,0),(16005,747,'Eifyr and Co. \'Rogue\' Fuel Conservation FC-805','Improved control over afterburner energy consumption.\r\r\n\r\r\n5% reduction in afterburner capacitor needs.',0,1,0,1,NULL,0.0000,1,1491,0),(16006,747,'Eifyr and Co. \'Rogue\' High Speed Maneuvering HS-905','Improves the performance of microwarpdrives.\r\r\n\r\r\n5% reduction in capacitor need of modules requiring High Speed Maneuvering.',0,1,0,1,NULL,0.0000,1,1492,0),(16008,747,'Eifyr and Co. \'Rogue\' Acceleration Control AC-603','Improves speed boosting velocity.\r\r\n\r\r\n3% bonus to afterburner and microwarpdrive speed increase.',0,1,0,1,NULL,0.0000,1,1489,0),(16009,747,'Eifyr and Co. \'Rogue\' Acceleration Control AC-605','Improves speed boosting velocity. \r\r\n\r\r\n5% bonus to afterburner and microwarpdrive speed increase.',0,1,0,1,NULL,0.0000,1,1489,0),(16010,818,'Mercenary Wingman','This is a mercenary support fighter, which usually acts as backup for larger and more powerful ships.  Beware of its deadly warp scrambling ability. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(16019,699,'Mordus Rookie','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',1612000,16120,80,1,1,0.0000,0,NULL,0),(16020,699,'Mordus Sabre','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2025000,20250,65,1,1,0.0000,0,NULL,0),(16021,699,'Mordus Rapier','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2040000,20400,235,1,1,0.0000,0,NULL,0),(16022,699,'Mordus Gladius','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(16023,699,'Mordus Katana','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(16024,699,'Mordus Squad Leader','A Squad Leader controls a small unit of ships during battle.  Seldom are they found without a few escorts with them. Threat level: Deadly.',1650000,16500,235,1,1,0.0000,0,NULL,0),(16025,384,'Decapitator Light Missile','An ultra rare type of Light assault missile, manufactured by Kaalkiota.  A very limited supply of these missiles exists, which are rumored to use stolen Jovian technology.  ',700,0.015,0,100,NULL,500.0000,0,NULL,0),(16027,701,'Mordus Bobcat','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',9600000,96000,450,1,1,0.0000,0,NULL,0),(16028,701,'Mordus Cheetah','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',9200000,92000,235,1,1,0.0000,0,NULL,0),(16029,135,'800mm Repeating Cannon II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(16030,701,'Mordus Puma','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(16031,701,'Mordus Leopard','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(16032,135,'150mm Light AutoCannon II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(16033,701,'Mordus Lion','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(16034,703,'Mordus Phanti','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(16035,703,'Mordus Sequestor','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',22000000,1080000,235,1,1,0.0000,0,NULL,0),(16036,703,'Mordus Gigamar','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(16037,703,'Mordus Mammoth','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,22000000,235,1,1,0.0000,0,NULL,0),(16038,701,'Mordus Raid Leader','Raid Leaders are high ranking commanding officers within the Mordus Legion.',10100000,101000,235,1,1,0.0000,0,NULL,0),(16039,703,'Mordus Fleet Commander','As one of the highest commanding officers within the Mordus Legion, the Fleet Commanders are a force to be reckoned with.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(16040,699,'Mordus Bounty Hunter','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(16041,314,'Colossal Sealed Cargo Containers','These colossal containers are fitted with a password-protected security lock.',10000,1000,0,1,NULL,100.0000,1,NULL,0),(16042,314,'Medium Sized Sealed Cargo Containers','These containers are fitted with a password-protected security lock.',500,50,0,1,NULL,100.0000,1,NULL,0),(16043,314,'Giant Sealed Cargo Containers','These giant containers are fitted with a password-protected security lock.',5000,500,0,1,NULL,100.0000,1,NULL,0),(16044,314,'Small Sealed Cargo Containers','These small containers are fitted with a password-protected security lock.',100,10,0,1,NULL,100.0000,1,NULL,0),(16045,314,'Large Sealed Cargo Containers','These large containers are fitted with a password-protected security lock.',1000,100,0,1,NULL,100.0000,1,NULL,0),(16046,55,'Republic Fleet 125mm Autocannon','This multi-barrel autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',750,5,0.5,1,2,1000.0000,1,574,0),(16047,55,'Republic Fleet 1200mm Artillery','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',750,20,1,1,2,595840.0000,1,579,0),(16048,55,'Republic Fleet 1400mm Howitzer Artillery','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1500,20,0.5,1,2,744812.0000,1,579,0),(16049,55,'Republic Fleet 150mm Autocannon','A simple but effective close combat autocannon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',20,5,0.4,1,2,1976.0000,1,574,0),(16050,55,'Republic Fleet 200mm Autocannon','A powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',15,5,0.3,1,2,4484.0000,1,574,0),(16051,55,'Republic Fleet 220mm Autocannon','This autocannon is designed for skirmish warfare. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',12,10,2,1,2,25888.0000,1,575,0),(16052,55,'Republic Fleet 250mm Artillery','This artillery is one of the most powerful weapons that can be mounted on a frigate. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',150,5,0.1,1,2,5996.0000,1,577,0),(16053,55,'Republic Fleet 280mm Howitzer Artillery','Rocket-assisted artillery projectiles designed for long-range combat. It is the most powerful projectile weapon able to be fitted onto frigates. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',5,5,0.05,1,2,7496.0000,1,577,0),(16054,55,'Republic Fleet 425mm Autocannon','The 425mm is a behemoth that will inflict severe damage on most cruisers and frigates in short-range battles. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',8,10,1.5,1,2,44740.0000,1,575,0),(16055,55,'Republic Fleet 650mm Artillery','A powerful long-range artillery. One of the most damaging weapons mountable on a cruiser. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',125,10,0.5,1,2,59676.0000,1,578,0),(16056,55,'Republic Fleet 720mm Howitzer Artillery','This rocket-assisted howitzer is designed for long-range bombardment. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',50,10,0.25,1,2,74980.0000,1,578,0),(16057,55,'Republic Fleet 800mm Repeating Cannon','An autocannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,20,3,1,2,448700.0000,1,576,0),(16058,55,'Republic Fleet Dual 180mm Autocannon','This autocannon is a simple but effective close combat weapon. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',12.5,10,2.5,1,2,10000.0000,1,575,0),(16059,55,'Republic Fleet Dual 425mm Autocannon','Combines the damage output of two 425mm intermediate-range autocannons. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',200,20,5,1,2,98972.0000,1,576,0),(16060,55,'Republic Fleet Dual 650mm Repeating Cannon','Powerful, intermediate-range repeating autocannon with a decent rate of fire. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,4,1,2,298716.0000,1,576,0),(16061,511,'Caldari Navy Rapid Light Missile Launcher','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.315,1,1,4224.0000,1,641,0),(16062,506,'Caldari Navy Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.5,1,NULL,204004.0000,1,643,0),(16063,136,'Caldari Navy Cruise Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(16064,510,'Caldari Navy Heavy Missile Launcher','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,1.35,1,1,14996.0000,1,642,0),(16065,507,'Caldari Navy Rocket Launcher','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.2813,1,NULL,3336.0000,1,639,0),(16066,136,'Caldari Navy Rocket Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(16067,508,'Caldari Navy Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.3,1,1,20580.0000,1,644,0),(16068,509,'Caldari Navy Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.',0,5,0.9,1,1,3000.0000,1,640,0),(16069,1210,'Remote Armor Repair Systems','Operation of remote armor repair systems. 5% reduced capacitor need for remote armor repair system modules per skill level.',0,0.01,0,1,NULL,85000.0000,1,1745,0),(16087,818,'EoM Imp','This is a frigate class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Low',1612000,16120,80,1,4,0.0000,0,NULL,0),(16088,818,'EoM Fiend','This is a frigate class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Moderate',2025000,20250,65,1,4,0.0000,0,NULL,0),(16089,818,'EoM Incubus','This is a frigate class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Significant',2040000,20400,235,1,4,0.0000,0,NULL,0),(16090,818,'EoM Succubus','This is a frigate class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe.  Threat level: High',1650000,16500,130,1,4,0.0000,0,NULL,0),(16091,818,'EoM Demon','This is a frigate class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Very high',1650000,16500,235,1,4,0.0000,0,NULL,0),(16092,818,'EoM Saboteur','This is a frigate class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Very high',1650000,16500,235,1,4,0.0000,0,NULL,0),(16093,817,'EoM Priest','This is a cruiser class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Deadly',9600000,96000,450,1,4,0.0000,0,NULL,0),(16094,817,'EoM Prophet','This is a cruiser class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Deadly',9200000,92000,235,1,4,0.0000,0,NULL,0),(16095,817,'EoM Black Priest','This is a cruiser class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Deadly',10100000,101000,235,1,4,0.0000,0,NULL,0),(16096,817,'EoM Crusader','This is a cruiser class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Deadly',10100000,101000,235,1,4,0.0000,0,NULL,0),(16097,817,'EoM Death Knight','This is a cruiser class combat ship for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Deadly',10100000,101000,235,1,4,0.0000,0,NULL,0),(16098,816,'EoM Hydra','This is a battleship class combat vessel for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Deadly',21000000,1040000,235,1,4,0.0000,0,NULL,0),(16099,816,'EoM Death Lord','This is a battleship class combat vessel for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Deadly',21000000,1040000,235,1,4,0.0000,0,NULL,0),(16100,816,'EoM Ogre','This is a battleship class combat vessel for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Deadly',22000000,1080000,235,1,4,0.0000,0,NULL,0),(16101,816,'EoM Behemoth','This is a battleship class combat vessel for the fanatical organization, Equilibrium of Mankind.  Originally Amarrian in origin, EoM can be found in most corners of Empire space, attempting to accomplish their devious plan of annihilating the human race within the Eve universe. Threat level: Deadly',19000000,22000000,235,1,4,0.0000,0,NULL,0),(16102,337,'Ore Supply Freight','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',13500000,1020000,5250,1,1,0.0000,0,NULL,0),(16103,411,'Force Field','A spherical barrier, centered around some object.',0,0,0,1,NULL,0.0000,0,NULL,0),(16104,337,'CONCORD Surveillance Drone','This is a surveillance drone used by all of the CONCORD sub-factions.',100000,60,1200,1,NULL,0.0000,0,NULL,0),(16105,693,'DED Soldier 3rd Class','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',2025000,20250,65,1,NULL,0.0000,0,NULL,0),(16106,693,'DED Soldier 2nd Class','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',2040000,20400,235,1,NULL,0.0000,0,NULL,0),(16107,693,'DED Soldier 1st Class','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',1650000,16500,130,1,NULL,0.0000,0,NULL,0),(16108,693,'DED Special Ops Piranha','This is a fighter-ship belonging to the DED Special Ops.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',1650000,16500,235,1,NULL,0.0000,0,NULL,0),(16109,693,'DED Special Ops Panther','This is a fighter-ship belonging to the DED Special Ops.    Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',1650000,16500,235,1,NULL,0.0000,0,NULL,0),(16110,695,'DED Officer 3rd Class','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',12155000,101000,450,1,NULL,0.0000,0,NULL,0),(16111,695,'DED Officer 2nd Class','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',12155000,101000,235,1,NULL,0.0000,0,NULL,0),(16112,695,'DED Officer 1st Class','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',12155000,101000,900,1,NULL,0.0000,0,NULL,0),(16114,695,'DED Captain','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',12155000,101000,235,1,NULL,0.0000,0,NULL,0),(16115,695,'DED Special Ops Raptor','This is a fighter-ship belonging to DED Special Ops.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',10100000,101000,235,1,NULL,0.0000,0,NULL,0),(16116,697,'DED Army Colonel','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',20500000,1080000,400,1,NULL,0.0000,0,NULL,0),(16117,697,'DED Army General','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',20500000,1080000,235,1,NULL,0.0000,0,NULL,0),(16118,409,'CONCORD Officer Emblem','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,NULL,65000.0000,1,733,0),(16119,409,'CONCORD Soldier Emblem','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,NULL,10000.0000,1,733,0),(16120,409,'CONCORD Piranha Emblem','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,NULL,35000.0000,1,733,0),(16121,409,'CONCORD Panther Emblem','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,NULL,65000.0000,1,733,0),(16122,409,'CONCORD Captain Emblem','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,NULL,150000.0000,1,733,0),(16123,409,'CONCORD Raptor Emblem','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,NULL,200000.0000,1,733,0),(16124,409,'CONCORD Colonel Emblem','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,NULL,1000000.0000,1,733,0),(16125,409,'CONCORD General Emblem','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,NULL,2000000.0000,1,733,0),(16126,330,'CONCORD Modified Cloaking Device','This prototype of an advanced cloaking mechanism was one of the last major technological breakthroughs to come out of Crielere Labs. Although it does work it is not really a finished product and has some serious drawbacks, most notably the fact that the module creates high sensor disruption while fitted and can not operate unless at minimum velocity.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,475000.0000,1,675,0),(16128,53,'CONCORD Medium Pulse Laser','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,NULL,5984.0000,0,NULL,0),(16129,53,'CONCORD Dual Heavy Pulse Laser','This heavy pulse laser uses two separate laser focusing systems to reduce the cool down period between shots. A great weapon for medium to long range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,200000.0000,0,NULL,0),(16131,53,'CONCORD Heavy Pulse Laser','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,NULL,59676.0000,0,NULL,0),(16132,74,'CONCORD 150mm Railgun','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,NULL,7496.0000,0,NULL,0),(16133,74,'CONCORD 250mm Railgun','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,0.5,1,1,74980.0000,0,NULL,0),(16134,74,'CONCORD 350mm Railgun','The 350mm railgun works much the same as its big brother except that it is considerably faster but also less powerful. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1000000.0000,0,NULL,0),(16136,509,'CONCORD Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.9,1,1,3000.0000,0,NULL,0),(16137,510,'CONCORD Heavy Missile Launcher','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,1.35,1,NULL,14996.0000,0,NULL,0),(16138,506,'CONCORD Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.5,1,NULL,99996.0000,0,NULL,0),(16140,52,'CONCORD Modified Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,39424.0000,0,1936,0),(16142,38,'CONCORD Micro Shield Extender','Increases the maximum strength of the shield.',0,2.5,0,1,NULL,37178.0000,0,NULL,0),(16144,38,'CONCORD Medium Shield Extender','Increases the maximum strength of the shield.',0,10,0,1,NULL,114760.0000,0,NULL,0),(16146,38,'CONCORD Large Shield Extender','Increases the maximum strength of the shield.',0,20,0,1,NULL,167344.0000,0,NULL,0),(16148,55,'CONCORD 1200mm Artillery','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',750,20,1,1,2,595840.0000,0,NULL,0),(16149,55,'CONCORD 650mm Artillery','A powerful long-range artillery. One of the most damaging weapons mountable on a cruiser. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',125,10,0.5,1,NULL,59676.0000,0,NULL,0),(16150,55,'CONCORD 200mm Autocannon','A powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',15,5,0.3,1,NULL,4484.0000,0,NULL,0),(16151,328,'CONCORD Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,0,NULL,0),(16153,328,'CONCORD Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,0,NULL,0),(16155,328,'CONCORD Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,0,NULL,0),(16157,328,'CONCORD Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,0,NULL,0),(16159,32,'Alliance',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(16160,927,'Gallente Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',109000000,1090000,3000,1,8,0.0000,0,NULL,0),(16161,668,'Amarr Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(16162,673,'Caldari Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(16163,705,'Minmatar Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',89000000,890000,3400,1,2,0.0000,0,NULL,0),(16164,668,'Ammatar Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(16165,595,'Angel Cartel Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',89000000,890000,2000,1,2,0.0000,0,NULL,0),(16166,604,'Blood Raider Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(16167,622,'Sanshas Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(16168,631,'Serpentis Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',110500000,1105000,4000,1,8,0.0000,0,NULL,0),(16169,613,'Guristas Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(16170,691,'Khanid Personnel Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',19000000,1120000,3200,1,4,0.0000,0,NULL,0),(16171,687,'Khanid Rookie','This is a fighter for the Khanid Navy.  Threat level: Moderate',1740000,17400,220,1,4,0.0000,0,NULL,0),(16172,687,'Khanid Sparrow','This is a Khanid Navy Special Ops ship.  It\'s main purpose is to act as a support ship for the Khanid Navys cruisers and battleships.',2870000,28700,235,1,4,0.0000,0,NULL,0),(16173,689,'Khanid Hawk','This is a fighter for the Khanid Navy. Threat level: Deadly',12500000,120000,235,1,4,0.0000,0,NULL,0),(16174,689,'Khanid Eagle','This is a fighter for the Khanid Navy. Threat level: Deadly',11950000,118000,235,1,4,0.0000,0,NULL,0),(16175,689,'Khanid Warbird','This is a fighter for the Khanid Navy. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(16176,691,'Khanid High Commander','The Khanid High Commanders are one of the highest ranking officers in the Khanid Navy, answering only the Khanid Royalty itself.',19000000,1100000,235,1,4,0.0000,0,NULL,0),(16177,691,'Khanid Kazmaar','The legendary Khanid Kazmaar is reserved for the leaders within the Khanid Royalty.  Few have witnessed its awesome majesty, as it is only used on special occasions.',19000000,1150000,235,1,4,0.0000,0,NULL,0),(16178,687,'Khanid Scout','This is a scout for the Khanid Navy.  Usually where there are scouts, a fleet is not far behind. Threat level: High',1000000,28100,120,1,4,0.0000,0,NULL,0),(16179,409,'Khanid Rookie Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,4500.0000,1,735,0),(16180,409,'Khanid Fighter Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,12000.0000,1,735,0),(16181,409,'Khanid Elite Fighter Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,25000.0000,1,735,0),(16182,409,'Khanid Scout Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,12000.0000,1,735,0),(16183,409,'Khanid Sparrow Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,30000.0000,1,735,0),(16184,409,'Khanid Officer Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,30000.0000,1,735,0),(16185,409,'Khanid Hawk Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,35000.0000,1,735,0),(16186,409,'Khanid Eagle Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,50000.0000,1,735,0),(16187,409,'Khanid Warbird Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,100000.0000,1,735,0),(16188,409,'Khanid High Commander Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,500000.0000,1,735,0),(16189,409,'Khanid Royal Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,1000000.0000,1,735,0),(16190,818,'Rogue Agent','This ship was purchased through the black market.  The current owner has chosen to remain anonymous.',1650000,24500,220,1,8,0.0000,0,NULL,0),(16191,818,'Kaphyr','Raised by the Angel Cartel, Kaphyr quickly found out that he didn\'t have what it takes to rise up the ranks within the Cartel from his job as a patroller.  So he joined up with the Kurzon mercenary network, which allowed him to work as a freelancer for the highest bidder. Threat level: Significant',1200000,21120,165,1,2,0.0000,0,NULL,0),(16192,818,'Claudius','This is a mercenary, who is obviously starting out in his profession.  Most mercenaries are not hostile unless they are on a specific mission to eliminate you, or view you as a threat.  Caution is advised when approaching such vessels however, as they are normally armed and dangerous.  Threat level: Moderate',1000000,28100,220,1,4,0.0000,0,NULL,0),(16193,818,'Lemonn','This is a mercenary, who is obviously starting out in his profession.  Most mercenaries are not hostile unless they are on a specific mission to eliminate you, or view you as a threat.  Caution is advised when approaching such vessels however, as they are normally armed and dangerous.  Threat level: Moderate',1000000,28100,220,1,4,0.0000,0,NULL,0),(16194,283,'Mercenary Pilot','A pilot of a mercenary ship.',80,1,0,1,NULL,0.0000,1,NULL,0),(16195,818,'Jade Lebache','This is a bounty hunter.  These freelancers can be of any race and come from all walks of life, sometimes they have mercenaries aiding them, but they usually work solo.  Normally, unless sent to kill you, they will leave you alone.  Threat level: High',1600000,10000,130,1,8,0.0000,0,NULL,0),(16196,818,'Yuki Tamaru','This is a bounty hunter.  These freelancers can be of any race and come from all walks of life, sometimes they have mercenaries aiding them, but they usually work solo.  Normally, unless sent to kill you, they will leave you alone.  Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(16197,818,'Sami Kurzon','Sami is a bounty hunter employed by the Kurzon mercenary network, and a close relative to the founder. Threat level: Very high',1450000,16500,80,1,1,0.0000,0,NULL,0),(16198,817,'Kaltoh Kurzon','Brother to Zerim Kurzon himself, the founder of the Kurzon mercenary network, Kaltoh is very experienced in the field of bounty hunting.  He has reportedly been working for various factions throughout the galaxy of late, as an independent mercenary. Threat level: Deadly',10900000,109000,235,1,2,0.0000,0,NULL,0),(16199,817,'Gaabu Moniq','This is a bounty hunter.  These freelancers can be of any race and come from all walks of life, sometimes they have mercenaries aiding them, but they usually work solo.  Normally, unless sent to kill you, they will leave you alone.   Threat level: Deadly',10250000,89000,420,1,2,0.0000,0,NULL,0),(16200,816,'Jerek Shapuir','This is a bounty hunter.  These freelancers can be of any race and come from all walks of life, sometimes they have mercenaries aiding them, but they usually work solo.  Normally, unless sent to kill you, they will leave you alone. Threat level: Deadly',19000000,1100000,600,1,4,0.0000,0,NULL,0),(16201,816,'Ioan Lafonte','This is a bounty hunter.  These freelancers can be of any race and come from all walks of life, sometimes they have mercenaries aiding them, but they usually work solo.  Normally, unless sent to kill you, they will leave you alone.',19000000,1140000,675,1,8,0.0000,0,NULL,0),(16202,816,'Tauron','Tauron is of a rare breed of bounty hunters, who have been given the title of Master by the Universal League of Bounty Hunters (ULBH).  After his long and prosperous servitude for the Angel Cartel, Master Bounty Hunter Tauron recieved his first Battleship from that organization.  \r\r\n\r\r\nTauron was given the name \"Dwenehaven Darmetsoko\" by his foster parents, but quickly took up the name Tauron after he aquired his official Bounty Hunter status within the ULBH.\r\r\n\r\r\nAfter a brief dispute with a drug lord within the Angel Cartel, he left the organization to persue an independent mercenary career.  \r\r\n\r\r\nOnly the wealthiest corporations in Eve would even attempt to buy the services of this ancient bounty hunter.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16203,816,'Kyokan','Master Bounty Hunter Kyokan is a former special ops pilot of the Mordus Legion that turned freelance bounty hunter.  When his wealthy father died, he inherited a vast sum of credits, which he used to purchase a magnificent Tyrent battleship off the black market.  With his valuable experience from serving as a special ops pilot, and his well fitted battleship, Kyokan is a force to be reckoned with.\r\r\n\r\r\nThe Universal League of Bounty Hunters (ULBH) awarded Kyokan the title of Master Bounty Hunter not long ago, after over a decade of service to various factions throughout the Eve universe.\r\r\n\r\r\nKyokan is most famous for his use of the \'Doom\' torpedo, which is an enhanced version of the Inferno torpedo.  He has never revealed his supplier of the famous but extremely rare torpedo, which is mainly used to rip through large structures such as outposts or battleships, but some expect them to be of Jovian origin.  The claim has never been proven though.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16206,100,'Hellhound I','Heavy Attack Drone',12000,25,0,1,8,70000.0000,0,NULL,0),(16208,818,'Ex-Secret Agent','An ex-secret agent who has turned to blackmailing his former corporation for money.',2250000,22500,75,1,2,0.0000,0,NULL,0),(16209,817,'Ex-Elite Secret Agent','This is a recently laid off elite secret agent.',10900000,109000,120,1,2,0.0000,0,NULL,0),(16210,805,'Spider Drone I','A popular drone amongst bounty hunters, the rare Spider drone has been sold in the thousands on the black market since it began being manufactured by CreoDron corporation.  The conceptual design of it was created by the multi-awarded scientist, Yeeti Mourir.  Built on the old Wasp drone model, the Spider drone sacrifices its damaging capabilities for a more powerful force-shield and stasis webifying ability, as well as ultra fast speed.  \r\r\n\r\r\nUnfortunately it is not currently available on the public market.  CreoDron and Yeeti Mourir have waged a long and ugly battle in Gallente courtrooms to try and acquire the sole manufacturing rights on the Spider drone, which has kept it off of public markets for legal reasons.  Yet that did not keep the drone from being built for the Gallente military, nor has it kept the Serpentis from acquiring hundreds of batches of the drone and smuggling it out of Gallente space for the lucrative black market.',3500,250,235,1,NULL,0.0000,0,NULL,0),(16211,805,'Spider Drone II','A popular drone amongst bounty hunters, the rare Spider drone has been sold in the thousands on the black market since it began being manufactured by CreoDron corporation.  The conceptual design of it was created by the multi-awarded scientist, Yeeti Mourir.  Built on the old Wasp drone model, the Spider drone sacrifices its damaging capabilities for a more powerful force-shield and stasis webifying ability, as well as ultra fast speed.  \r\r\n\r\r\nUnfortunately it is not currently available on the public market.  CreoDron and Yeeti Mourir have waged a long and ugly battle in Gallente courtrooms to try and acquire the sole manufacturing rights on the Spider drone, which has kept it off of public markets for legal reasons.  Yet that did not keep the drone from being built for the Gallente military, nor has it kept the Serpentis from acquiring hundreds of batches of the drone and smuggling it out of Gallente space for the lucrative black market.',3500,250,235,1,NULL,0.0000,0,NULL,0),(16212,687,'Khanid Wingman','This is a support ship for the Khanid Navy.  Threat level: Very high',1425000,28600,120,1,4,0.0000,0,NULL,0),(16213,365,'Caldari Control Tower','At first the Caldari Control Towers were manufactured by Kaalakiota, but since they focused their efforts mostly on other, more profitable installations, they soon lost the contract and the Sukuuvestaa corporation took over the Control Towers\' development and production.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Missile Battery Rate of Fire\r\r\n50% bonus to Missile Velocity\r\r\n-75% bonus to ECM Jammer Battery Target Cycling Speed',200000000,8000,140000,1,1,400000000.0000,1,478,0),(16214,365,'Minmatar Control Tower','The Matari aren\'t really that high-tech, preferring speed rather than firepower or involved technology. Unfortunately that doesn\'t apply very well to stationary objects, much to the liking of the Amarr Empire.  \r\r\n\r\r\nAmarrians call it a scrapheap of epic proportions. But don\'t underestimate these structures. Minmatar commanders usually have the last laugh when it comes to combat.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Projectile Sentry Optimal Range\r\r\n50% bonus to Projectile Sentry Fall Off Range\r\r\n25% bonus to Projectile Sentry RoF',200000000,8000,140000,1,2,400000000.0000,1,478,0),(16215,319,'Small Armory','This small armory has a thick layer of reinforced tritanium and a customized shield module for deflecting incoming fire.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(16216,413,'Research Laboratory','Portable laboratory facilities, anchorable within control tower fields. This structure has Material Efficiency research and Time Efficiency research activities.\r\r\n\r\r\nActivity bonuses:\r\r\n30% reduction in research ME required time\r\r\n30% reduction in research TE required time',100000000,3000,25000,1,NULL,100000000.0000,1,933,0),(16217,414,'Small Auxiliary Power Array',' ',50000000,100,0,1,NULL,0.0000,0,NULL,0),(16219,364,'Small Storage Array','Mobile Storage',100000000,1150,8850,1,NULL,0.0000,0,NULL,0),(16220,397,'Rapid Equipment Assembly Array','A mobile assembly facility where modules, implants, deployables, structures and containers can be manufactured quickly but at increased mineral cost due to waste.\r\r\n\r\r\nActivity modifiers:\r\r\n35% reduction in manufacturing required time\r\r\n5% increase in required manufacturing materials',100000000,6250,1000000,1,NULL,10000000.0000,1,932,0),(16221,416,'Moon Harvesting Array','A deployable array designed to gather raw minerals from moons. Can harvest a good deal of material per cycle, after which it needs to be linked with either a silo (for storage) or a reactor (for chemically molding the materials into something else).',200000000,4000,1,1,NULL,5000000.0000,1,488,0),(16222,417,'Light Missile Battery','A launcher array designed to fit light missiles. Fires at those the Control Tower deems its enemies.\r\r\n',50000000,1150,5000,1,NULL,128.0000,0,NULL,0),(16223,418,'Shield Generation Array','Aids control tower shield in some way.',200000000,1,0,1,NULL,0.0000,0,NULL,0),(16226,816,'Kurzon Destroyer','The Kurzon Destroyer is a rare sight indeed.  Purchased from the black market for a hefty price, the Kurzon Mercenary Network uses them occasionally when the stakes are very high.  Zerim Kurzon himself fitted the Destroyers with hand-picked modules, making them tougher than most mercenary battleships.',19000000,980000,120,1,2,0.0000,0,NULL,0),(16227,419,'Ferox','Designed as much to look like a killing machine as to be one, the Ferox will strike fear into the heart of anyone unlucky enough to get caught in its crosshairs.  With the potential for sizable armament as well as tremendous electronic warfare capability, this versatile gunboat is at home in a great number of scenarios.',13250000,252000,475,1,1,60187424.0000,1,471,0),(16228,489,'Ferox Blueprint',' ',0,0.01,0,1,NULL,540000000.0000,1,590,0),(16229,419,'Brutix','One of the most ferocious war vessels to ever spring from Gallente starship design, the Brutix is a behemoth in every sense of the word.  When this hard-hitting monster appears, the battlefield takes notice.',12500000,270000,475,1,8,59855886.0000,1,472,0),(16230,489,'Brutix Blueprint',' ',0,0.01,0,1,NULL,570000000.0000,1,591,0),(16231,419,'Cyclone','The Cyclone was created in order to meet the increasing demand for a vessel capable of providing muscle for frigate detachments while remaining more mobile than a battleship.  To this end, the Cyclone\'s seven high-power slots and powerful thrusters have proved ideal.',12500000,216000,450,1,2,66214804.0000,1,473,0),(16232,489,'Cyclone Blueprint',' ',0,0.01,0,1,NULL,525000000.0000,1,592,0),(16233,419,'Prophecy','The Prophecy is built on an ancient Amarrian warship design dating back to the earliest days of starship combat.  Originally intended as a full-fledged battleship, it was determined after mixed fleet engagements with early prototypes that the Prophecy would be more effective as a slightly smaller, more mobile form of artillery support.',12900000,234000,400,1,4,56099454.0000,1,470,0),(16234,489,'Prophecy Blueprint',' ',0,0.01,0,1,NULL,555000000.0000,1,589,0),(16236,420,'Coercer','Noticing the alarming increase in Minmatar frigate fleets, the Imperial Navy made its plans for the Coercer, a vessel designed specifically to seek and destroy the droves of fast-moving frigate rebels. ',1650000,47000,375,1,4,1326320.0000,1,465,0),(16237,487,'Coercer Blueprint',' ',0,0.01,0,1,NULL,8635240.0000,1,583,0),(16238,420,'Cormorant','The Cormorant is the only State-produced space vessel whose design has come from a third party.  Rumors abound, of course, but the designer\'s identity has remained a tightly-kept secret in the State\'s inner circle.',1700000,52000,425,1,1,1229506.0000,1,466,0),(16239,487,'Cormorant Blueprint',' ',0,0.01,0,1,NULL,8416400.0000,1,584,0),(16240,420,'Catalyst','Ideally suited for both skirmish warfare and fleet support, the Catalyst is touted as one of the best anti-frigate platforms out there. Faced with its top-of-the-line tracking equipment, not many can argue.',1550000,55000,450,1,8,1195526.0000,1,467,0),(16241,487,'Catalyst Blueprint',' ',0,0.01,0,1,NULL,7887800.0000,1,585,0),(16242,420,'Thrasher','Engineered as a supplement to its big brother the Cyclone, the Thrasher\'s tremendous turret capabilities and advanced tracking computers allow it to protect its larger counterpart from smaller, faster menaces.',1600000,43000,400,1,2,1121470.0000,1,468,0),(16243,487,'Thrasher Blueprint',' ',0,0.01,0,1,NULL,7500000.0000,1,586,0),(16244,665,'Sarum Spider','This is a Sarum support frigate, designed to paralyze the target while it\'s being attacked by Sarum cruisers and battleships.',2870000,28700,235,1,4,0.0000,0,NULL,0),(16245,749,'Zainou \'Gnome\' Shield Upgrades SU-605','A neural Interface upgrade that reduces the shield upgrade module power needs.\r\r\n\r\r\n5% reduction in power grid needs of modules requiring the Shield Upgrades skill.',0,1,0,1,NULL,0.0000,1,1480,0),(16246,749,'Zainou \'Gnome\' Shield Management SM-705','Improved skill at regulating shield capacity.\r\r\n\r\r\n5% bonus to shield capacity.',0,1,0,1,NULL,0.0000,1,1481,0),(16247,749,'Zainou \'Gnome\' Shield Emission Systems SE-805','A neural Interface upgrade that reduces the capacitor need for shield emission system modules such as shield transfer array.\r\r\n\r\r\n5% reduction in capacitor need of modules requiring the Shield Emission Systems skill.',0,1,0,1,NULL,0.0000,1,1482,0),(16248,749,'Zainou \'Gnome\' Shield Operation SP-905','A neural Interface upgrade that boosts the recharge rate of the shields of the pilots ship.\r\r\n\r\r\n5% boost to shield recharge rate.',0,1,0,1,NULL,0.0000,1,1483,0),(16249,742,'Zainou \'Gnome\' Weapon Upgrades WU-1005','A neural Interface upgrade that lowers turret CPU needs.\r\r\n\r\r\n5% reduction in the CPU required by turrets.',0,1,0,1,NULL,0.0000,1,1502,0),(16250,817,'Maylan Falek','A shroud of secrecy surrounds Maylans identity.  All that is known is he is a top secret agent working for the Minmatar Republic military, with close ties to certain high ranking officials of the Minmatar Republic.  His ethniticity is most likely that of the Krusual tribe.  ',11500000,96000,300,1,2,0.0000,0,NULL,0),(16251,817,'Freedom Patriot','The Freedom Patriot is a Bellicose class cruiser used by the Minmatar Freedom Fighter network.  Threat level: Deadly',10750000,85000,420,1,2,0.0000,0,NULL,0),(16252,816,'Freedom Liberty','The Liberty battleship is one of the biggest assets of the Minmatar Freedom Fighter network.  After it had aquired massive support within the Minmatar Republic, it could finally afford these gigantic Typhoon class battleships, which were nicknamed \'Liberty\'. Threat level: Deadly',19000000,920000,625,1,2,0.0000,0,NULL,0),(16253,283,'Minmatar Emissary','This is an emissary from the Minmatar Republic.',70,0.1,0,1,NULL,0.0000,1,NULL,0),(16254,817,'Kuzak Obliterator','The Kuzak Obliterator is a deadly cruiser class ship, designed as a lightly armored vessel that can pack a serious punch. Threat level: Extreme',12155000,99000,450,1,2,0.0000,0,NULL,0),(16256,817,'Nugoeihuvi Agent','A Nugoeihuvi secret agent.  Threat level: Deadly',13000000,107000,305,1,1,0.0000,0,NULL,0),(16258,422,'Argon Gas','A colorless and odorless inert gas; one of the six inert gases.',0,0.1,0,1,NULL,0.0000,0,NULL,0),(16259,422,'Xenon','Xenon is a member of the zero-valence elements that are called noble or inert gases, however, \"inert\" is not a completely accurate description of this chemical series since some noble gas compounds have been synthesized. In a gas filled tube, xenon emits a blue glow when the gas is excited by electrical discharge. Using tens of gigapascals of pressure, xenon has been forced into a metallic phase.[3] Xenon can also form clathrates with water when atoms of it are trapped in a lattice of the water molecules.',0,0.1,0,1,NULL,0.0000,0,NULL,0),(16260,422,'Gaseous Neon Isotopes','Neon is the second-lightest noble gas, glows reddish-orange in a vacuum discharge tube and has over 40 times the refrigerating capacity of liquid helium and three times that of liquid hydrogen (on a per unit volume basis). In most applications it is a less expensive refrigerant than helium. Neon has the most intense discharge at normal voltages and currents of all the rare gases.',0,0.1,0,1,NULL,0.0000,0,NULL,0),(16261,422,'Gaseous Krypton Isotopes','A colorless, odorless, tasteless noble gas, krypton occurs in trace amounts in the atmosphere, is isolated by fractionating liquefied air, and is often used with other rare gases in fluorescent lamps. Krypton is inert for most practical purposes but it is known to form compounds with fluorine. Krypton can also form clathrates with water when atoms of it are trapped in a lattice of the water molecules.',0,0.1,0,1,NULL,0.0000,0,NULL,0),(16262,465,'Clear Icicle','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. These crystalline formations can be found scattered around many an ice field, and are known as the universe\'s primary source of helium isotopes.\r\r\n\r\r\nAvailable in <color=\'0xFF33FFFF\'>1.0</color> security status solar systems or lower.',1000,1000,0,1,NULL,519000.0000,1,1855,0),(16263,465,'Glacial Mass','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. Glacial masses are known to contain hydrogen isotopes in abundance, in addition to smatterings of heavy water and liquid ozone.\r\r\n\r\r\nAvailable in <color=\'0xFF33FFFF\'>1.0</color> security status solar systems or lower.',1000,1000,0,1,NULL,105000.0000,1,1855,0),(16264,465,'Blue Ice','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. Due to its unique chemical composition and the circumstances under which it forms, blue ice contains more oxygen isotopes than any other ice asteroid.\r\r\n\r\r\nAvailable in <color=\'0xFF33FFFF\'>1.0</color> security status solar systems or lower.',1000,1000,0,1,NULL,105000.0000,1,1855,0),(16265,465,'White Glaze','When star fusion processes occur near high concentrations of silicate dust, such as those found in interstellar ice fields, the substance known as White Glaze is formed. White Glaze is extremely high in nitrogen-14 and other stable nitrogen isotopes, and is thus a necessity for the sustained operation of certain kinds of control tower.\r\r\n\r\r\nAvailable in <color=\'0xFF33FFFF\'>1.0</color> security status solar systems or lower.',1000,1000,0,1,NULL,105000.0000,1,1855,0),(16266,465,'Glare Crust','In areas with high concentrations of electromagnetic activity, ice formations such as this one, containing large amounts of heavy water and liquid ozone, are spontaneously formed during times of great electric flux. Glare crust also contains a small amount of strontium clathrates.\r\r\n\r\r\nAvailable in <color=\'0xFFFF6600\'>0.3</color> security status solar systems or lower.',1000,1000,0,1,NULL,2107000.0000,1,1855,0),(16267,465,'Dark Glitter','Dark glitter is one of the rarest of the interstellar ices, formed only in areas with large amounts of residual electrical current. Little is known about the exact way in which it comes into being; the staggering amount of liquid ozone to be found inside one of these rocks makes it an intriguing mystery for stellar physicists and chemists alike. In addition, it contains large amounts of heavy water and a decent measure of strontium clathrates.\r\r\n\r\r\nAvailable in <color=\'0xFFE53300\'>0.1</color> security status solar systems or lower.',1000,1000,0,1,NULL,2141000.0000,1,1855,0),(16268,465,'Gelidus','Fairly rare and very valuable, Gelidus-type ice formations are a large-scale source of strontium clathrates, one of the rarest ice solids found in the universe, in addition to which they contain unusually large concentrations of heavy water and liquid ozone.\r\r\n\r\r\nAvailable in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1000,1000,0,1,NULL,1140000.0000,1,1855,0),(16269,465,'Krystallos','The universe\'s richest known source of strontium clathrates, Krystallos ice formations are formed only in areas where a very particular combination of environmental factors are at play. Krystallos compounds also include quite a bit of liquid ozone.\r\r\n\r\r\nAvailable in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1000,1000,0,1,NULL,1037000.0000,1,1855,0),(16272,423,'Heavy Water','Dideuterium oxide. Water with significant nuclear properties which make it extremely effective as a neutron moderator in various types of power reactors. One of the materials required to keep Control Towers online.\r\r\n\r\r\nMay be obtained by reprocessing the following ice ores:\r\r\n\r\r\n<color=\'0xFF33FFFF\'>1.0</color> security status solar system or lower:\r\r\n<a href=showinfo:16264>Blue Ice</a>\r\r\n<a href=showinfo:16262>Clear Icicle</a>\r\r\n<a href=showinfo:16263>Glacial Mass</a>\r\r\n<a href=showinfo:16265>White Glaze</a>\r\r\n\r\r\n<color=\'0xFFFF6600\'>0.3</color> security status solar system or lower:\r\r\n<a href=showinfo:16266>Glare Crust</a>\r\r\n\r\r\n<color=\'0xFFE53300\'>0.1</color> security status solar system or lower:\r\r\n<a href=showinfo:16267>Dark Glitter</a>\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:17978>Enriched Clear Icicle</a>\r\r\n<a href=showinfo:16268>Gelidus</a>\r\r\n<a href=showinfo:16269>Krystallos</a>\r\r\n<a href=showinfo:17976>Pristine White Glaze</a>\r\r\n<a href=showinfo:17977>Smooth Glacial Mass</a>\r\r\n<a href=showinfo:17975>Thick Blue Ice</a>',0,0.4,0,1,NULL,1000.0000,1,1033,0),(16273,423,'Liquid Ozone','Liquid Ozone is used as a cleaning and disinfectant substance, and plays a vital role in ensuring the smooth day-to-day operation of a starbase. One of the materials required to keep Control Towers online.\r\r\n\r\r\nMay be obtained by reprocessing the following ice ores:\r\r\n\r\r\n<color=\'0xFF33FFFF\'>1.0</color> security status solar system or lower:\r\r\n<a href=showinfo:16264>Blue Ice</a>\r\r\n<a href=showinfo:16262>Clear Icicle</a>\r\r\n<a href=showinfo:16263>Glacial Mass</a>\r\r\n<a href=showinfo:16265>White Glaze</a>\r\r\n\r\r\n<color=\'0xFFFF6600\'>0.3</color> security status solar system or lower:\r\r\n<a href=showinfo:16266>Glare Crust</a>\r\r\n\r\r\n<color=\'0xFFE53300\'>0.1</color> security status solar system or lower:\r\r\n<a href=showinfo:16267>Dark Glitter</a>\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:17978>Enriched Clear Icicle</a>\r\r\n<a href=showinfo:16268>Gelidus</a>\r\r\n<a href=showinfo:16269>Krystallos</a>\r\r\n<a href=showinfo:17976>Pristine White Glaze</a>\r\r\n<a href=showinfo:17977>Smooth Glacial Mass</a>\r\r\n<a href=showinfo:17975>Thick Blue Ice</a>',0,0.4,0,1,NULL,1000.0000,1,1033,0),(16274,423,'Helium Isotopes','The Helium-3 isotope is extremely sought-after for use in fusion processes, and also has various applications in the fields of cryogenics and machine cooling.  One of the materials required to keep Amarr Control Towers online.\r\r\n\r\r\nMay be obtained by reprocessing the following ice ores:\r\r\n\r\r\n<color=\'0xFF33FFFF\'>1.0</color> security status solar system or lower:\r\r\n<a href=showinfo:16262>Clear Icicle</a>\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:17978>Enriched Clear Icicle</a>',0,0.1,0,1,NULL,1000.0000,1,1033,0),(16275,423,'Strontium Clathrates','An unstable compound of strontium molecules encased in the crystal structure of water. When fed to a Control Tower\'s force field generator, these clathrates bond with the molecules already in place in the field to create a nigh-invulnerable barrier of energy. A necessary ingredient for Control Towers to go into reinforced mode.\r\r\n\r\r\nMay be obtained by reprocessing the following ice ores:\r\r\n\r\r\n<color=\'0xFF33FFFF\'>1.0</color> security status solar system or lower:\r\r\n<a href=showinfo:16264>Blue Ice</a>\r\r\n<a href=showinfo:16262>Clear Icicle</a>\r\r\n<a href=showinfo:16263>Glacial Mass</a>\r\r\n<a href=showinfo:16265>White Glaze</a>\r\r\n\r\r\n<color=\'0xFFFF6600\'>0.3</color> security status solar system or lower:\r\r\n<a href=showinfo:16266>Glare Crust</a>\r\r\n\r\r\n<color=\'0xFFE53300\'>0.1</color> security status solar system or lower:\r\r\n<a href=showinfo:16267>Dark Glitter</a>\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:17978>Enriched Clear Icicle</a>\r\r\n<a href=showinfo:16268>Gelidus</a>\r\r\n<a href=showinfo:16269>Krystallos</a>\r\r\n<a href=showinfo:17976>Pristine White Glaze</a>\r\r\n<a href=showinfo:17977>Smooth Glacial Mass</a>\r\r\n<a href=showinfo:17975>Thick Blue Ice</a>',0,3,0,1,NULL,1000.0000,1,1033,0),(16278,464,'Ice Harvester I','A unit used to extract valuable materials from ice asteroids. Used on Mining barges and Exhumers.',0,25,0,1,NULL,5666716.0000,1,1038,0),(16279,490,'Ice Harvester I Blueprint',' ',0,0.01,0,1,NULL,15003680.0000,1,338,0),(16281,1218,'Ice Harvesting','Skill at harvesting ice. 5% reduction per skill level to the cycle time of ice harvesters.',0,0.01,0,1,NULL,375000.0000,1,1323,0),(16282,425,'Low Cost Mercenary Assault Unit','This is the most simple assault unit, comprised of mercenaries willing to kill for a low sum of money, not caring about their fate living only for the next Z-rated holoreel and pleasure hub visit. They are known for committing unnecessary atrocities when overtaking structures in space, showing total disregard for human life and dignity. Combined with the fact that their fee is laughably low, one cannot but question their motives for choosing this profession.',37500,500,0,10,NULL,50000.0000,0,NULL,0),(16286,365,'QA Control Tower','This structure does not exist.',1000000,1,140000,1,4,400000000.0000,0,NULL,0),(16287,818,'Tazmyr\'s Capsule','This is an escape capsule which is released upon the destruction of ones ship.',32000,1000,0,1,NULL,0.0000,0,NULL,0),(16288,818,'Tazmyr','Tazmyr the Amarrian. Flies a Minmatar frigate when in Minmatar space to blend in with the locals.  Threat level: Very high',1000000,12000,80,1,2,0.0000,0,NULL,0),(16297,315,'\'Accord\' Core Compensation','When installed this unit attempts to compensate for fluctuations and disruptions of the ship\'s warp core.',0,5,0,1,NULL,9994.0000,1,1088,0),(16299,315,'\'Repose\' Core Compensation','When installed this unit attempts to compensate for fluctuations and disruptions of the ship\'s warp core.',0,5,0,1,NULL,9994.0000,1,1088,0),(16301,315,'\'Stoic\' Core Equalizer I','When installed this unit attempts to compensate for fluctuations and disruptions of the ship\'s warp core.',0,5,0,1,NULL,9994.0000,1,1088,0),(16303,315,'\'Halcyon\' Core Equalizer I','When installed this unit attempts to compensate for fluctuations and disruptions of the ship\'s warp core.',0,5,0,1,NULL,9994.0000,1,1088,0),(16305,98,'Upgraded Adaptive Nano Plating I','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(16307,98,'Limited Adaptive Nano Plating I','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(16309,98,'\'Collateral\' Adaptive Nano Plating I','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(16311,98,'\'Refuge\' Adaptive Nano Plating I','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(16313,98,'Upgraded Kinetic Plating I','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(16315,98,'Limited Kinetic Plating I','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(16317,98,'Experimental Kinetic Plating I','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(16319,98,'\'Aegis\' Explosive Plating I','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',1,5,0,1,NULL,4974.0000,1,1667,0),(16321,98,'Upgraded Explosive Plating I','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(16323,98,'Limited Explosive Plating I','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(16325,98,'Experimental Explosive Plating I','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(16327,98,'\'Element\' Kinetic Plating I','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',1,5,0,1,NULL,4974.0000,1,1666,0),(16329,98,'Upgraded EM Plating I','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(16331,98,'Limited EM Plating I','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(16333,98,'\'Contour\' EM Plating I','Attempts to distribute electro-magnetic energy over the entire plating. Grants a bonus to EM resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(16335,98,'\'Spiegel\' EM Plating I','Attempts to distribute Electro-Magnetic energy over the entire plating. Grants a bonus to EM resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(16337,98,'Upgraded Thermic Plating I','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(16339,98,'Limited Thermic Plating I','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(16341,98,'Experimental Thermic Plating I','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(16343,98,'Prototype Thermic Plating I','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(16345,98,'Upgraded Layered Plating I','This plating is composed of several additional tritanium layers, effectively increasing its hit points.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1669,0),(16347,98,'Limited Layered Plating I','This plating is composed of several additional tritanium layers, effectively increasing its hit points.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1669,0),(16349,98,'\'Scarab\' Layered Plating I','This plating is composed of several additional tritanium layers, effectively increasing its hit points.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1669,0),(16351,98,'\'Grail\' Layered Plating I','This plating is composed of several additional tritanium layers, effectively increasing its hit points.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1669,0),(16353,328,'Upgraded Armor EM Hardener I','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(16355,328,'Limited Armor EM Hardener I','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(16357,328,'Experimental Armor EM Hardener I','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(16359,328,'Prototype Armor EM Hardener I','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(16361,328,'Upgraded Armor Explosive Hardener I','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(16363,328,'Limited Armor Explosive Hardener I','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(16365,328,'Experimental Armor Explosive Hardener I','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(16367,328,'Prototype Armor Explosive Hardener I','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(16369,328,'Upgraded Armor Kinetic Hardener I','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(16371,328,'Limited Armor Kinetic Hardener I','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(16373,328,'Experimental Armor Kinetic Hardener I','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(16375,328,'Prototype Armor Kinetic Hardener I','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(16377,328,'Upgraded Armor Thermic Hardener I','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(16379,328,'Limited Armor Thermic Hardener I','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(16381,328,'Experimental Armor Thermic Hardener I','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(16383,328,'Prototype Armor Thermic Hardener I','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(16385,326,'Upgraded Energized Adaptive Nano Membrane I','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(16387,326,'Limited Energized Adaptive Nano Membrane I','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(16389,326,'Experimental Energized Adaptive Nano Membrane I','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(16391,326,'Prototype Energized Adaptive Nano Membrane I','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(16393,326,'Upgraded Energized Kinetic Membrane I','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(16395,326,'Limited Energized Kinetic Membrane I','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(16397,326,'Experimental Energized Kinetic Membrane I','An enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(16399,326,'Prototype Energized Kinetic Membrane I','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(16401,326,'Upgraded Energized Explosive Membrane I','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(16403,326,'Limited Energized Explosive Membrane I','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(16405,326,'Experimental Energized Explosive Membrane I','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(16407,326,'Prototype Energized Explosive Membrane I','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(16409,326,'Upgraded Energized EM Membrane I','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(16411,326,'Limited Energized EM Membrane I','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(16413,326,'Experimental Energized EM Membrane I','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(16415,326,'Prototype Energized EM Membrane I','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(16417,326,'Upgraded Energized Armor Layering Membrane I','An enhanced version of the standard layered armor plating. Uses advanced magnetic field generators to strengthen the integrity of the plating.',1,5,0,1,NULL,75000.0000,1,1687,0),(16419,326,'Limited Energized Armor Layering Membrane I','An enhanced version of the standard layered armor plating. Uses advanced magnetic field generators to strengthen the integrity of the plating.',1,5,0,1,NULL,75000.0000,1,1687,0),(16421,326,'Experimental Energized Armor Layering Membrane I','An enhanced version of the standard layered armor plating. Uses advanced magnetic field generators to strengthen the integrity of the plating.',1,5,0,1,NULL,75000.0000,1,1687,0),(16423,326,'Prototype Energized Armor Layering Membrane I','An enhanced version of the standard layered armor plating. Uses advanced magnetic field generators to strengthen the integrity of the plating.',1,5,0,1,NULL,75000.0000,1,1687,0),(16425,326,'Upgraded Energized Thermic Membrane I','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(16427,326,'Limited Energized Thermic Membrane I','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(16429,326,'Experimental Energized Thermic Membrane I','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(16431,326,'Prototype Energized Thermic Membrane I','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(16433,325,'Small I-ax Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,1059,0),(16435,325,'Small Coaxial Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,1059,0),(16437,325,'Small \'Arup\' Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,1059,0),(16439,325,'Small \'Solace\' Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,1059,0),(16441,325,'Medium I-ax Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,12470.0000,1,1058,0),(16443,325,'Medium Coaxial Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,12470.0000,1,1058,0),(16445,325,'Medium \'Arup\' Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,12470.0000,1,1058,0),(16447,325,'Medium \'Solace\' Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,12470.0000,1,1058,0),(16449,325,'Large I-ax Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,50,0,1,NULL,31244.0000,1,1057,0),(16451,325,'Large Coaxial Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,50,0,1,NULL,31244.0000,1,1057,0),(16453,325,'Large \'Arup\' Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,50,0,1,NULL,31244.0000,1,1057,0),(16455,325,'Large \'Solace\' Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,50,0,1,NULL,31244.0000,1,1057,0),(16457,367,'Cross-linked Bolt Array I','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,49920.0000,1,645,0),(16459,367,'Muon Coil Bolt Array I','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,49920.0000,1,645,0),(16461,367,'Multiphasic Bolt Array I','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,49920.0000,1,645,0),(16463,367,'\'Pandemonium\' Ballistic Enhancement','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,49920.0000,1,645,0),(16465,71,'Medium Rudimentary Energy Destabilizer I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,99840.0000,1,690,0),(16467,71,'Medium \'Gremlin\' Power Core Disruptor I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,99840.0000,1,690,0),(16469,71,'50W Infectious Power System Malfunction','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,99840.0000,1,690,0),(16471,71,'Medium Unstable Power Fluctuator I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,99840.0000,1,690,0),(16473,71,'Heavy Rudimentary Energy Destabilizer I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(16475,71,'Heavy \'Gremlin\' Power Core Disruptor I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(16477,71,'500W Infectious Power System Malfunction','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(16479,71,'Heavy Unstable Power Fluctuator I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,499674.0000,1,691,0),(16481,67,'Large Asymmetric Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,78840.0000,1,697,0),(16483,67,'Large Murky Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,78840.0000,1,697,0),(16485,67,'Large Partial E95c Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,78840.0000,1,697,0),(16487,67,'Large \'Regard\' Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,78840.0000,1,697,0),(16489,67,'Medium Asymmetric Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,696,0),(16491,67,'Medium Murky Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,696,0),(16493,67,'Medium Partial E95b Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,696,0),(16495,67,'Medium \'Regard\' Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,696,0),(16497,68,'Heavy \'Ghoul\' Energy Siphon I','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(16499,68,'Heavy \'Knave\' Energy Drain','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(16501,68,'E500 Prototype Energy Vampire','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(16503,68,'Heavy Diminishing Power System Drain I','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(16505,68,'Medium \'Ghoul\' Energy Siphon I','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,197520.0000,1,693,0),(16507,68,'Medium \'Knave\' Energy Drain','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,197520.0000,1,693,0),(16509,68,'E50 Prototype Energy Vampire','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,197520.0000,1,693,0),(16511,68,'Medium Diminishing Power System Drain I','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,197520.0000,1,693,0),(16513,506,'\'Malkuth\' Cruise Launcher I','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.05,1,NULL,80118.0000,1,643,0),(16515,506,'\'Limos\' Cruise Launcher I','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,1.1,1,NULL,80118.0000,1,643,0),(16517,506,'XT-9000 Cruise Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.15,1,NULL,80118.0000,1,643,0),(16519,506,'\'Arbalest\' Cruise Launcher I','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,1.2,1,NULL,80118.0000,1,643,0),(16521,507,'\'Malkuth\' Rocket Launcher I','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.2,1,NULL,3000.0000,1,639,0),(16523,507,'\'Limos\' Rocket Launcher I','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.2063,1,NULL,3000.0000,1,639,0),(16525,507,'OE-5200 Rocket Launcher','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.2188,1,NULL,3000.0000,1,639,0),(16527,507,'\'Arbalest\' Rocket Launcher I','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.225,1,NULL,3000.0000,1,639,0),(16529,338,'Ionic Field Accelerator I','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(16531,338,'5a Prototype Shield Support I','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(16533,338,'\'Stalwart\' Particle Field Magnifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(16535,338,'\'Copasetic\' Particle Field Acceleration','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(16537,339,'Vigor Compact Micro Auxiliary Power Core','Supplements the main Power core providing more power',0,5,0,1,4,150000.0000,1,660,0),(16539,339,'Micro B88 Core Augmentation','Supplements the main Power core providing more power',0,5,0,1,NULL,150000.0000,0,NULL,0),(16541,339,'Micro K-Exhaust Core Augmentation','Supplements the main Power core providing more power',0,5,0,1,NULL,150000.0000,0,NULL,0),(16543,339,'Micro \'Vigor\' Core Augmentation','Supplements the main Power core providing more power',0,5,0,1,NULL,150000.0000,0,NULL,0),(16545,817,'Pleasure Cruiser','A large pleasure cruiser, built for casual exploration of space while the inhabitants indulge themselves in various luxuries.',13075000,115000,3200,1,8,0.0000,0,NULL,0),(16546,267,'Bureaucratic Connections','Understanding of corporate bureaucracies.\r\r\n\r\r\nImproves loyalty point gain by 5% per level when working for agents in the following corporation divisions:\r\r\n\r\r\nAdministration \r\r\nInternal Security\r\r\nPersonnel\r\r\nStorage\r\r\nArchives \r\r\nFinancial\r\r\n',0,0.01,0,1,NULL,20000000.0000,0,NULL,0),(16547,267,'Financial Connections','Understanding of Corporate Finances.\r\r\n\r\r\nImproves loyalty point gain by 5% per level when working for agents in the following corporation divisions:\r\r\n\r\r\nPublic Relations \r\r\nMarketing \r\r\nLegal \r\r\nAccounting \r\r\nFinancial \r\r\nDistribution\r\r\n',0,0.01,0,1,NULL,20000000.0000,0,NULL,0),(16548,267,'Political Connections','Understanding of political concepts and stratagems.\r\r\n\r\r\nImproves loyalty point gain by 5% per level when working for agents in the following corporation divisions: \r\r\n\r\r\nSecurity\r\r\nLegal\r\r\nAdministration\r\r\nAdvisory\r\r\nCommand \r\r\nPublic Relations\r\r\n',0,0.01,0,1,NULL,20000000.0000,0,NULL,0),(16549,267,'Military Connections','Understanding of military culture.\r\r\n\r\r\nImproves loyalty point gain by 5% per level when working for agents in the following corporation divisions:\r\r\n\r\r\nIntelligence\r\r\nSecurity \r\r\nAstrosurveying \r\r\nCommand \r\r\nInternal Security \r\r\nSurveillance\r\r\n',0,0.01,0,1,NULL,20000000.0000,0,NULL,0),(16550,267,'Labor Connections','Understanding of corporate culture on the industrial level and the plight of the worker.\r\r\n\r\r\nImproves loyalty point gain by 5% per level when working for agents in the following corporation divisions:   \r\r\n\r\r\nManufacturing\r\r\nProduction\r\r\nPersonnel\r\r\nMining\r\r\nAstrosurveying\r\r\n',0,0.01,0,1,NULL,20000000.0000,0,NULL,0),(16551,267,'Trade Connections','Understanding of the way trade is conducted at the corporate level.\r\r\n\r\r\nImproves loyalty point gain by 5% per level when working for agents in the following corporation divisions:     \r\r\n\r\r\nDistribution\r\r\nStorage\r\r\nProduction\r\r\nAccounting\r\r\nMining\r\r\nMarketing\r\r\n',0,0.01,0,1,NULL,20000000.0000,0,NULL,0),(16552,267,'High Tech Connections','Understanding of high-tech corporate culture.\r\r\n\r\r\nImproves loyalty point gain by 5% per level when working for agents in the following corporation divisions:\r\r\n \r\r\nArchives\r\r\nAdvisory\r\r\nIntelligence\r\r\nManufacturing\r\r\nSurveillance\r\r\n',0,0.01,0,1,NULL,20000000.0000,0,NULL,0),(16553,818,'Wallekon Nezmar','A secret agent working for the Minmatar Republic - flies an Ammatar ship due to his undercover job as a pilot within the Ammatar Fleet.  Threat level: Very high',1265000,18100,235,1,4,0.0000,0,NULL,0),(16554,818,'Velzion Drekin','A secret agent working for the Minmatar Republic - flies an Ammatar ship due to his undercover job as a pilot within the Ammatar Fleet.  Threat level: Very high',1265000,18100,235,1,4,0.0000,0,NULL,0),(16555,817,'Terrens Glokuir','A secret agent working for the Minmatar Republic - flies an Ammatar ship due to his undercover job as a pilot within the Ammatar Fleet.  Threat Level = Extraordinary',12500000,120000,280,1,4,0.0000,0,NULL,0),(16556,817,'Karbim Dula','A secret agent working for the Minmatar Republic - flies an Ammatar ship due to his undercover job as a pilot within the Ammatar Fleet.  Threat Level = Extraordinary',12750000,118000,280,1,4,0.0000,0,NULL,0),(16557,818,'Guerin Marduke','A secret agent working for the Ammatar - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet.  Threat level: Very high',1200000,12000,80,1,2,0.0000,0,NULL,0),(16558,818,'Jhelom Marek','A secret agent working for the Ammatar - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet.  Threat level: Very high',1200000,12000,80,1,2,0.0000,0,NULL,0),(16559,817,'Malad Dorsin','A secret agent working for the Ammatar - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet. Threat level: Extraordinary',12500000,120000,300,1,1,0.0000,0,NULL,0),(16560,817,'Umeni Kurr','A secret agent working for the Ammatar - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet. Threat level: Deadly',10250000,89000,300,1,2,0.0000,0,NULL,0),(16561,550,'Angel Viper','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(16562,550,'Angel Webifier','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(16563,606,'Blood Wraith','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(16564,606,'Blood Disciple','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2870000,28700,135,1,4,0.0000,0,NULL,0),(16565,615,'Guristas Kyoukan','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(16566,615,'Guristas Webifier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(16567,624,'Sansha\'s Demon','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(16568,624,'Sansha\'s Berserker','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,200,1,4,0.0000,0,NULL,0),(16569,633,'Guardian Veteran','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(16570,818,'Jenai Taen','A secret agent working for the Amarr Empire - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet. ',1200000,28700,235,1,2,0.0000,0,NULL,0),(16571,818,'Ralek Schult','A secret agent working for the Amarr Empire - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet.   Threat level: High',1200000,28700,315,1,2,0.0000,0,NULL,0),(16572,817,'Thoriam Delvar','A secret agent working for the Amarr Empire - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet.  Threat level: Extraordinary',11500000,96000,235,1,2,0.0000,0,NULL,0),(16573,817,'Zenin Mirae','A secret agent working for the Amarr Empire - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet.  Threat level: Deadly',10000000,80000,235,1,2,0.0000,0,NULL,0),(16574,817,'Borain Doleni','A secret agent working for the Thukker Tribe - flies a Khanid ship due to his undercover job as a pilot within the Khanid Navy.  Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(16575,817,'Tsejani Kulvin','A secret agent working for the Thukker Tribe - flies a Khanid ship due to his undercover job as a pilot within the Khanid Navy.  Threat level: Extraordinary',12750000,100100,235,1,4,0.0000,0,NULL,0),(16576,818,'Oggenon Shafi','A secret agent working for the Thukker Tribe - flies a Khanid ship due to his undercover job as a pilot within the Khanid Navy.   Threat level: High',2870000,28700,315,1,4,0.0000,0,NULL,0),(16577,818,'Thomas Pulver','A secret agent working for the Thukker Tribe - flies a Khanid ship due to his undercover job as a pilot within the Khanid Navy. ',2870000,28700,235,1,4,0.0000,0,NULL,0),(16578,818,'Zidan Kloveni','A secret agent working for the Khanid Kingdom - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet.  Threat level: Very high',1200000,12000,80,1,2,0.0000,0,NULL,0),(16579,818,'Tudor Brem','A secret agent working for the Khanid Kingdom - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet.  Threat level: Very high',1200000,12000,80,1,2,0.0000,0,NULL,0),(16580,817,'Maccen Aman','A secret agent working for the Khanid Kingdom - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet. Threat level: Extraordinary',12500000,120000,300,1,2,0.0000,0,NULL,0),(16581,817,'Keizo Veron','A secret agent working for the Khanid Kingdom - flies a Minmatar ship due to his undercover job as a pilot within the Minmatar Fleet. Threat level: Deadly',10250000,89000,300,1,2,0.0000,0,NULL,0),(16582,818,'Kyani Torrin','A secret agent working for the Caldari State - flies a Gallente ship due to his undercover job as a pilot within the Gallente Navy. ',2650000,26500,140,1,8,0.0000,0,NULL,0),(16583,818,'Aiko Temura','A secret agent working for the Caldari State - flies a Gallente ship due to his undercover job as a pilot within the Gallente Navy.  Threat level: Very high',2040000,20400,200,1,8,0.0000,0,NULL,0),(16584,817,'Juddi Temu','A secret agent working for the Caldari State - flies a Gallente ship due to his undercover job as a pilot within the Gallente Navy. Threat level: Extraordinary',12500000,120000,265,1,8,0.0000,0,NULL,0),(16585,817,'Kimo Sekuta','A secret agent working for the Caldari State - flies a Gallente ship due to his undercover job as a pilot within the Gallente Navy. Threat level: Deadly',12000000,112000,265,1,8,0.0000,0,NULL,0),(16586,818,'Ivan Minelli','A secret agent working for the Gallente Federation - flies a Caldari ship due to his undercover job as a pilot within the Caldari Navy.',1970000,19700,235,1,1,0.0000,0,NULL,0),(16587,818,'Torstan Kreoman','A secret agent working for the Gallente Federation - flies a Caldari ship due to his undercover job as a pilot within the Caldari Navy. Threat level: Very high',1680000,17400,90,1,1,0.0000,0,NULL,0),(16588,817,'Jaques Klemont','A secret agent working for the Gallente Federation - flies a Caldari ship due to his undercover job as a pilot within the Caldari Navy. Threat level: Extraordinary',12500000,120000,250,1,1,0.0000,0,NULL,0),(16590,817,'Tobi Lafonte','A secret agent working for the Gallente Federation - flies a Caldari ship due to his undercover job as a pilot within the Caldari Navy. Threat level: Deadly',10100000,101000,250,1,1,0.0000,0,NULL,0),(16591,257,'Heavy Assault Cruisers','Skill for operation of Heavy Assault Cruisers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,32000000.0000,1,377,0),(16593,283,'Angel Cartel Prisoners','Transporting prisoners is a task that requires trust and loyalty to the empire\'s legislative arm, but it is one of the least sought-after jobs in the known universe.',400,1,0,1,NULL,0.0000,1,NULL,0),(16594,274,'Procurement','Proficiency at placing remote buy orders on the market. Level 1 allows for the placement of orders within the same solar system, Level 2 extends that range to systems within 5 jumps, and each subsequent level then doubles it. Level 5 allows for placement of remote buy orders anywhere within current region.  \r\n\r\nNote: placing buy orders and directly buying an item are not the same thing. Direct remote purchase requires no skill.',0,0.01,0,1,NULL,1500000.0000,1,378,0),(16595,274,'Daytrading','Allows for remote modification of buy and sell orders. Each level of skill increases the range at which orders may be modified. Level 1 allows for modification of orders within the same solar system, Level 2 extends that range to systems within 5 jumps, and each subsequent level then doubles it. Level 5 allows for market order modification anywhere within current region.',0,0.01,0,1,NULL,12500000.0000,1,378,0),(16596,274,'Wholesale','Ability to organize and manage large-scale market operations. Each level raises the limit of active orders by 16. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,35000000.0000,1,378,0),(16597,274,'Margin Trading','Ability to make potentially risky investments work in your favor. Each level of skill reduces the percentage of ISK placed in market escrow when entering buy orders. Starting with an escrow percentage of 100% at Level 0 (untrained skill), each skill level cumulatively reduces the percentage by 25%. This will bring your total escrow down to approximately 24% at level 5. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,20000000.0000,1,378,0),(16598,274,'Marketing','Skill at selling items remotely. Each level increases the range from the seller to the item being sold. Level 1 allows for the sale of items within the same solar system, Level 2 extends that range to systems within 5 jumps, and each subsequent level then doubles it. Level 5 allows for sale of items located anywhere within current region.',0,0.01,0,1,NULL,3500000.0000,1,378,0),(16599,43,'Brokara\'s Modified Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,23750.0000,1,665,0),(16601,43,'Selynne\'s Modified Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,23750.0000,1,665,0),(16603,43,'Vizan\'s Modified Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,23750.0000,1,665,0),(16605,43,'Chelm\'s Modified Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,23750.0000,1,665,0),(16607,818,'Horak Mane','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',1740000,17400,220,1,2,0.0000,0,NULL,0),(16608,818,'Lori Tzen','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(16609,817,'Jabar Kurr','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(16610,818,'Xulan Anieu','This is a leader within the Angel Cartel, and the youngest brother of Ballet Anieu of Dominations. Threat level: Significant',1766000,17660,120,1,2,0.0000,0,NULL,0),(16611,817,'Tehmi Anieu','This is a leader within the Angel Cartel.  Is best known for being the Sibling of Ballet Anieu, COO of Dominations. Threat level: Deadly',10900000,109000,1400,1,2,0.0000,0,NULL,0),(16612,817,'Zerone Anieu','This is a leader within the Angel Cartel.  Zerone Anieu is best known for being the half-brother of Ballet Anieu, COO of Dominations. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(16613,816,'Korien Anieu','This is a leader within the Angel Cartel.  Korien Anieu is best known for being the oldest sibling of Ballet Anieu, COO of Dominations.  Korien Anieu was given a Tyrent class battleship from the Cartel after he aquired his current rank within the organization. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16614,314,'Message from the Governor','This message is sealed with the personal emblem of the Governor himself.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(16615,697,'CONCORD Starship','The CONCORD Starship is solely used for transporting or escorting people of extreme importance within CONCORD patrolled space.  It is built for defense with very light offensive capability.',20500000,1080000,665,1,NULL,0.0000,0,NULL,0),(16616,697,'CONCORD ship','This is a fighter-ship belonging to the CONCORD Army.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.  Only a fool would mess with a CONCORD Star Destroyer.',20500000,1080000,235,1,NULL,0.0000,0,NULL,0),(16617,409,'CONCORD Star Emblem','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,NULL,10000000.0000,1,733,0),(16618,818,'Veri Monnani','The Chief of Security. Threat level: Significant',1200000,19400,160,1,NULL,0.0000,0,NULL,0),(16619,818,'Guemo Kajinn','The Chief of Security. Threat level: Very high',1200000,17400,90,1,NULL,0.0000,0,NULL,0),(16620,817,'Telhia Hurst','This is a fighter-ship belonging to the CONCORD Army.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',10100000,101000,235,1,NULL,0.0000,0,NULL,0),(16621,816,'Hyan Vezzon','The Chief of Security.',19000000,1080000,235,1,NULL,0.0000,0,NULL,0),(16622,274,'Accounting','Proficiency at squaring away the odds and ends of business transactions, keeping the check books tight.  Each level of skill reduces transaction tax by 10%.',0,0.01,0,1,NULL,5000000.0000,1,378,0),(16623,283,'The Chief of Security','The Chief of Security.',90,0.1,0,1,NULL,0.0000,1,NULL,0),(16626,817,'Militia Guardian','A local militia cruiser.  Threat level: Deadly',1200000,109000,120,1,2,0.0000,0,NULL,0),(16627,818,'Militia Protector','A local militia frigate.  Threat level: Very high',1200000,16450,120,1,2,0.0000,0,NULL,0),(16628,818,'Militia Leader','Militia Leader.  Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(16630,283,'The Militia Leader','This is the leader of the militia forces.',60,0.1,0,1,NULL,0.0000,1,NULL,0),(16631,426,'Small Artillery Battery','Fires a barrage of medium projectiles at those the Control Tower deems its enemies. Effective at long-range bombardment and can do some damage, but lacks the speed to track the fastest targets.',50000000,500,50,1,2,500000.0000,1,594,0),(16633,427,'Hydrocarbons','Raw fossil fuels such as petroleum and mineral oil. Hydrocarbons are crucial building blocks in the production of organic chemicals, plastics and waxes, and are thus one of the most useful materials harvestable from any source.',0,0.1,1,1,NULL,2.0000,1,501,0),(16634,427,'Atmospheric Gases','Nitrogen, oxygen, neon, helium, xenon, methane, nitrous oxide, ozone -- a host of trapped vapours that can be used to catalyze numerous chemical processes.',0,0.1,1,1,NULL,2.0000,1,501,0),(16635,427,'Evaporite Deposits','Deposits formed by the precipitation of mineral-rich water. Usable for many purposes, mostly as building-block components for more complex materials.\r\r\n',0,0.1,1,1,NULL,2.0000,1,501,0),(16636,427,'Silicates','Various types of silicon- and oxygen-based rock formations.',0,0.1,1,1,NULL,2.0000,1,501,0),(16637,427,'Tungsten','One of the hardest metals in existence. Able to form extremely durable alloys with various other elements, and very useful in a number of deep-space scenarios.',7720,0.4,1,1,NULL,8.0000,1,501,0),(16638,427,'Titanium','An extremely fatigue-resistant yet light-weight metallic element, useful as a refractory metal and employable in a wide variety of potential scenarios. One of the primary building blocks of a whole host of materials.',1800,0.4,1,1,NULL,8.0000,1,501,0),(16639,427,'Scandium','A transition element harnessed from rare minerals, Scandium commonly sees use as a component of high-intensity light fixtures for deep-space environments, as well as being a strong building block in many deep-space structures and spacecraft due to its extremely high melting point.',1196,0.4,1,1,NULL,8.0000,1,501,0),(16640,427,'Cobalt','A silvery ferromagnetic element, used among other things in superalloys, magnetics, battery electrodes, and various metals and steels.',3544,0.4,1,1,NULL,8.0000,1,501,0),(16641,427,'Chromium','A steel-gray, lustrous metal with a wide variety of applications. Commonly used as a catalyst for chemical processes.',4290,0.6,1,1,NULL,16.0000,1,501,0),(16642,427,'Vanadium','A soft, white metal with a wide-ranging arsenal of applications both nuclear and structural. Also a versatile catalyst in compound form.',6000,1,1,1,NULL,16.0000,1,501,0),(16643,427,'Cadmium','A soft, malleable metal often occuring with zinc ores. Has a wide variety of applications; used in electroplating, superconductors, and as an alloy in various types of structure and equipment.',3476,0.4,1,1,NULL,16.0000,1,501,0),(16644,427,'Platinum','A corrosion-resistant precious metal with an extremely wide range of applications. Often used as a chemical catalyst.',21460,1,1,1,NULL,16.0000,1,501,0),(16646,427,'Mercury','Also known as quicksilver, mercury is a silvery liquid metal whose primary characteristic is the ease with which it forms amalgamatic alloys with other metals. It is therefore extremely useful as a base-block component.',10826,0.8,1,1,NULL,64.0000,1,501,0),(16647,427,'Caesium','A golden Alkali metal used primarily in propulsion systems. Also performs a variety of catalytic functions in the nuclear and photoelectric arenas.',1544,0.8,1,1,NULL,64.0000,1,501,0),(16648,427,'Hafnium','A silvery, corrosion-resistant metal used in various metal alloys and, to a lesser extent, in hybrid weapons systems.',10640,0.8,1,1,NULL,64.0000,1,501,0),(16649,427,'Technetium','A silvery metal, primarily used as a corrosion inhibitor and a superconductor.',8800,0.8,1,1,NULL,64.0000,1,501,0),(16650,427,'Dysprosium','A relatively rare soft metal, easily dissolvable in mineral acids. Used primarily in the production of laser materials.',8550,1,1,1,NULL,256.0000,1,501,0),(16651,427,'Neodymium','A rare, silvery metal. Due to its atmospheric reactiveness, Neodymium is used primarily for light-refractive purposes and as a colorant for other materials.',7010,1,1,1,NULL,256.0000,1,501,0),(16652,427,'Promethium','An extremely radioactive luminescent metal, sometimes used as a heating component and a building block for laser generators.',7260,1,1,1,NULL,256.0000,1,501,0),(16653,427,'Thulium','A soft, rare, silvery-gray metal.  Used in the creation of lasers, in addition to possessing a range of radiation-related production applications.',9320,1,1,1,NULL,256.0000,1,501,0),(16654,428,'Titanium Chromide','Titanium Chromide is in high demand among technicians and manufacturers for its unique combination of strength, light weight and catalytic potential.',0,1,0,1,NULL,40.0000,1,500,0),(16655,428,'Crystallite Alloy','A polynuclear heterometallic compound created from cobalt and cadmium. Crystallite alloys are a fundamental building block in the creation of crystalline composites.',0,1,0,1,NULL,40.0000,1,500,0),(16656,428,'Fernite Alloy','An intensely durable and extremely versatile alloy, Fernite, when combined with certain other materials, is a crucial stepping stone in the creation of a whole host of advanced technologies.',0,1,0,1,NULL,40.0000,1,500,0),(16657,428,'Rolled Tungsten Alloy','An extremely strong compound, made from tungsten rolled in a sheath of platinum. A crucial component in the creation of carbides which have a wide field of utility in the manufacture of various equipment.',0,1,0,1,NULL,40.0000,1,500,0),(16658,428,'Silicon Diborite','A mineral composite which, in large quantities, gives off a distinct crystalline glow. When combined with other composites, is usable for a variety of manufacturing purposes.',0,1,0,1,NULL,8.0000,1,500,0),(16659,428,'Carbon Polymers','A synthetic carbon compound created from raw hydrocarbons and silicate rock materials.  Important ingredients in a variety of carbon- and gel-based composites.',0,1,0,1,NULL,8.0000,1,500,0),(16660,428,'Ceramic Powder','A fine powder synthesized from various natural gases and solids through reactant processes.  Used as a strengthening agent in both armor plating and shield generators, as well as constituting an important part of many other composite materials.',0,1,0,1,NULL,8.0000,1,500,0),(16661,428,'Sulfuric Acid','A strong mineral acid, used in many chemical reactions and production processes. One of the most widely used chemicals in history.',0,1,0,1,NULL,8.0000,1,500,0),(16662,428,'Platinum Technite','An intensely resilient alloy composed of platinum and technetium. Highly sought-after in the machinery and armament industries.',0,1,0,1,NULL,80.0000,1,500,0),(16663,428,'Caesarium Cadmide','A dark-golden hued alloy composed of cadmium and caesium.  Often confused with tritanium due to its tint. An essential ingredient in various composites and condensates.',0,1,0,1,NULL,80.0000,1,500,0),(16664,428,'Solerium','When chromium and caesium are combined with raw silicates in the proper proportions, Solerium is created.  Since its initial discovery, Solerium\'s uniquely shifting dark-to-bright red hue has prompted poet and musician alike to create hymns in praise of its uniquely shifting deep red hue.',0,1,0,1,NULL,120.0000,1,500,0),(16665,428,'Hexite','A chemical compound, formed through electrosporadic oxidization of chromium and platinum.  Has a wide range of applications in the production of advanced technology and is highly sought-after by industrial manufacturers.',0,1,0,1,NULL,120.0000,1,500,0),(16666,428,'Hyperflurite','Hyperflurite is one of the most radioactive substances known to man. Composed of a mixture of radioactive metals and raw hydrocarbons, this luminescent goop provides catalysis for a variety of generative and reactive machine processes.',0,1,0,1,NULL,320.0000,1,500,0),(16667,428,'Neo Mercurite','A silvery, shimmering liquid compound, Neo Mercurite is a crucial element in many forms of advanced sensor and processor technology.',0,1,0,1,NULL,320.0000,1,500,0),(16668,428,'Dysporite','Quicksilver mixed with dysprosium forms the soft but extremely resilient dysporite, an amalgamatic alloy which plays a key role in most advanced sensor and reactor technologies.',0,1,0,1,NULL,320.0000,1,500,0),(16669,428,'Ferrofluid','Ferrofluids are superparamagnetic fluids containing tiny particles of magnetic solids suspended in liquid. The primary component in the creation of ferrogels.',0,1,0,1,NULL,512.0000,1,500,0),(16670,429,'Crystalline Carbonide','An exeptionally hard material created from crystallite alloys and carbon polymers, crystalline carbonite is a primary component in various forms of advanced Gallente technology, such as thrusters and armor plating.',0,0.01,0,1,NULL,10.0000,1,499,0),(16671,429,'Titanium Carbide','Due to its immense strength and molecular malleability, Titanium Carbide has become the darling of the Caldari technological industry, seeing use in everything from reactor units to weapons systems.',0,0.01,0,1,NULL,10.0000,1,499,0),(16672,429,'Tungsten Carbide','Tungsten Carbide is a much-used composite, greatly favored by the Amarrians for construction of their advanced technologies.',0,0.01,0,1,NULL,10.0000,1,499,0),(16673,429,'Fernite Carbide','A revolutionary ceramic carbide compound, much favored by the Matari both for its earthy quality and its extremely wide range of technological uses.',0,0.01,0,1,NULL,10.0000,1,499,0),(16678,429,'Sylramic Fibers','Extremely strong fibers, used in laminated armor plating.',0,0.05,0,1,NULL,20.0000,1,499,0),(16679,429,'Fullerides','Fullerides are highly superconductive materials used in capacitors, armor plating and weapons systems.  ',0,0.15,0,1,NULL,230.0000,1,499,0),(16680,429,'Phenolic Composites','A extremely heat-resistant material used in thrusters and as heat shielding.',0,0.2,0,1,NULL,600.0000,1,499,0),(16681,429,'Nanotransistors','Extremely complex molecular-level transistors used in nanoscale electronics, such as microprocessors and capacitor units.',0,0.25,0,1,NULL,700.0000,1,499,0),(16682,429,'Hypersynaptic Fibers','Whenever the transmission of visual or numerical data is a matter of life and death, the data network needs the fastest possible relay system. Hypersynaptic fibers, due to their immense frequency range and speed of conduction, have become the industry standard for sensor arrays and targeting systems.',0,0.6,0,1,NULL,2560.0000,1,499,0),(16683,429,'Ferrogel','A magnetised liquid, used to control the flow of cold plasma fields in shield systems, reactor cores, pulse generators and thruster systems.',0,1,0,1,NULL,5500.0000,1,499,0),(16686,314,'Manufacturing Tools','Tools used in various construction projects, such as ship, module or ground vehicle manufacturing.',10,100,0,1,NULL,0.0000,1,20,0),(16688,426,'Medium Artillery Battery','Fires a barrage of large projectiles at those the Control Tower deems its enemies. Very effective at long-range bombardment and packs a punch, but lacks the speed to track fast and up-close targets effectively. ',50000000,1000,65,1,2,2500000.0000,1,594,0),(16689,426,'Large Artillery Battery','Fires a barrage of extra large projectiles at those the Control Tower deems its enemies. Extremely effective at long-range bombardment and hits hard, but lacks the speed to track fast and up-close targets.   ',50000000,5000,165,1,NULL,12500000.0000,1,594,0),(16690,449,'Small Railgun Battery','Fires a barrage of medium hybrid slugs at those the Control Tower deems its enemies. Provides high damage output and is effective at long ranges.',100000000,500,120,1,1,500000.0000,1,595,0),(16691,449,'Medium Railgun Battery','Fires a barrage of large hybrid slugs at those the Control Tower deems its enemies. Provides high damage output and is effective at long ranges.',100000000,1000,160,1,1,2500000.0000,1,595,0),(16692,449,'Large Railgun Battery','Fires a barrage of extra large hybrid slugs at those the Control Tower deems its enemies. Provides high damage output and is effective at long ranges.',100000000,5000,400,1,NULL,12500000.0000,1,595,0),(16693,287,'Enhanced Training Drone','This weak but hostile training drone allows rookie-pilots to experience combat without too much risk. This is the enhanced version of the original Training Drone prototype. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(16694,430,'Large Beam Laser Battery','Fires a deep modulated energy beam using extra large sized frequency crystals at those the Control Tower deems its enemies. Effective at very long ranges, but tracks slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,5000,1,1,NULL,12500000.0000,1,596,0),(16695,417,'Heavy Missile Battery','A launcher array designed to fit heavy missiles. Fires at those the Control Tower deems its enemies.\r\r\n',50000000,1150,5000,1,NULL,128.0000,0,NULL,0),(16696,417,'Cruise Missile Battery','A launcher array designed to fit cruise missiles. Fires at those the Control Tower deems its enemies.\r\r\n',50000000,500,3500,1,NULL,500000.0000,1,479,0),(16697,417,'Torpedo Battery','A launcher array designed to fit torpedos. Fires at those the Control Tower deems its enemies.\r\r\n',50000000,1000,4500,1,NULL,2500000.0000,1,479,0),(16698,818,'Vivian Menure','A member of a team of gladiators which make their living off nationwide Gladiator shows.  Threat level: Moderate',1200000,17400,220,1,2,0.0000,0,NULL,0),(16699,818,'Uenia Khann','A member of a team of gladiators which make their living off nationwide Gladiator shows. Threat level: Very high',1200000,12000,80,1,2,0.0000,0,NULL,0),(16700,818,'Mullok Bloodsworn','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,235,1,4,0.0000,0,NULL,0),(16701,818,'Javvyn Bloodsworn','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2860000,28600,235,1,4,0.0000,0,NULL,0),(16702,818,'Terror Bloodsworn','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(16703,699,'Mordur Bloodsworn','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(16712,314,'Novice Medal','A medal awarded to those that have completed the Novice Trial of the Legends Trials.',0.1,0.1,0,1,NULL,0.0000,1,492,0),(16713,314,'Intermediate Medal','A medal awarded to those that have completed the Intermediate Trial of the Legends Trials.',0.1,0.1,0,1,NULL,0.0000,1,492,0),(16714,314,'Legends Medal','A medal awarded to those that have completed the final trial of the Legends Trials. Only the greatest combat pilots of the Eve universe can claim to have accomplished this great feat.',0.1,0.1,0,1,NULL,0.0000,1,492,0),(16715,23,'Clone Grade Pi',' ',0,1,0,1,NULL,5460000.0000,0,NULL,0),(16718,23,'Clone Grade Rho',' ',0,1,0,1,NULL,9100000.0000,0,NULL,0),(16720,306,'Ammo_Container','The wrecked container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(16721,306,'Armor_Container','The wrecked container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(16722,306,'Electronic_Container','The wrecked container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(16723,306,'Mineral Container','The wrecked container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(16724,306,'Rogue Drone Container','The drone-built container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(16725,306,'weapon_container','The wrecked container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(16726,319,'Amarr Cathedral','This impressive structure operates as a place for religious practice and the throne of a high ranking member within the clergy.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16727,319,'Blood Raider Cathedral','This impressive structure operates as a place for religious practice and the throne of a high ranking member within the clergy.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16728,319,'Asteroid Installation','Where geographical conditions allow, outposts such as this one are a good way of increasing the effectiveness of deep-space mining operations.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16729,319,'Cargo Rig','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16730,319,'Amarr Chapel','This decorated structure serves as a place for religious practice.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16731,319,'Blood Raider Chapel','This decorated structure serves as a place for religious practice.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16732,319,'Drone Structure II','This gigantic superstructure was built by the effort of thousands of rogue drones. While the structure appears to be incomplete, its intended shape remains a mystery to clueless carbon-based lifeforms.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16733,319,'Drone Structure I','This gigantic superstructure was built by the effort of thousands of rogue drones. While the structure appears to be incomplete, its intended shape remains a mystery to the clueless carbon-based lifeforms.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16734,319,'Partially constructed Megathron','This Megathron battleship is partially complete, with decks and inner-hull systems exposed to the cold of surrounding space.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16735,319,'Landing Pad','This outpost has a docking pad designed to receive and process large shipments of cargo.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16736,319,'Infested station ruins','To speed up the construction process of rogue drone structures, certain strains of drones have been known to salvage the ruins of their defeated enemies, using them either as a base or to slowly dissolve them into their desired final shape. This particular object seems to be a Gallente station and two Megathron battleships, partially broken down into a construction lattice around an asteroid.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16737,319,'Ruined Stargate','This ruined stargate has at least a few internal power generators left but is nevertheless currently inoperational, unable to serve its intended function of hurling starships to distant solar systems.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16738,319,'Solar Harvester','This gigantic construction uses electromagnetic conductors to harvest solar power from the system\'s sun.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16739,383,'Tower Sentry Amarr III','Amarr tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(16740,383,'Tower Sentry Angel III','Angel 1400mm howitzer sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(16741,383,'Tower Sentry Bloodraider III','Blood Raider tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(16742,383,'Tower Sentry Caldari III','Caldari 425mm railgun sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(16743,383,'Tower Sentry Gallente III','Gallente ion blaster cannon sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(16744,383,'Tower Sentry Guristas III','Guristas 425mm railgun sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(16745,383,'Tower Sentry Minmatar III','Minmatar 1400mm howitzer sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(16746,383,'Tower Sentry Sansha III','Sansha tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(16747,383,'Tower Sentry Serpentis III','Serpentis ion blaster cannon sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(16748,319,'Occupied Amarr Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,4,0.0000,0,NULL,0),(16749,319,'Amarr Elevator','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16750,319,'Amarr Junction','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16751,319,'Amarr Lookout','A lookout post, constructed so that its inhabitants may have a better look at the vast expanses of space and whatever wonders they may hold.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16752,319,'Amarr Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16753,319,'Amarr Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other. They are also commonly used to transport liquid or gas between structures.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16754,319,'Amarr Fence','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16755,319,'Amarr Barrier','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16756,319,'Amarr Battery','A small missile battery designed to repel invaders and other hazards.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16757,319,'Angel Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16758,319,'Angel Elevator','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16759,319,'Angel Junction','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16760,319,'Angel Lookout','A lookout post, constructed so that its inhabitants may have a better look at the vast expanses of space and whatever wonders they may hold.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16761,319,'Angel Battery','A small missile battery, designed to repel invaders and other hazards.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16762,319,'Angel Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16763,319,'Angel Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16764,319,'Angel Fence','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16765,319,'Angel Barrier','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16766,319,'Blood Raider Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16767,319,'Blood Raider Elevator','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16768,319,'Blood Raider Junction','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16769,319,'Blood Raider Lookout','A lookout post, constructed so that its inhabitants may have a better look at the vast expanses of space and whatever wonders they may hold.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16770,319,'Blood Raider Battery','A small missile battery, designed to repel invaders and other hazards.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16771,319,'Blood Raider Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16772,319,'Blood Raider Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16773,319,'Blood Raider Fence','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16774,319,'Blood Raider Barrier','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16775,319,'Caldari Elevator','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16776,319,'Caldari Junction','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16777,319,'Caldari Lookout','A lookout post, constructed so that its inhabitants may have a better look at the vast expanses of space and whatever wonders they may hold.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16778,319,'Caldari Battery','A small missile battery, designed to repel invaders and other hazards.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16779,319,'Caldari Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16780,319,'Caldari Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16781,319,'Caldari Fence','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16782,319,'Caldari Barrier','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16784,319,'Gallente Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16785,319,'Gallente Elevator','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16786,319,'Gallente Junction','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16787,319,'Gallente Lookout','A lookout post, constructed so that its inhabitants may have a better look at the vast expanses of space and whatever wonders they may hold.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16788,319,'Gallente Battery','A small missile battery, designed to repel invaders and other hazards.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16789,319,'Gallente Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16790,319,'Gallente Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16791,319,'Gallente Fence','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16792,319,'Gallente Barrier','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16793,319,'Guristas Great Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16794,319,'Guristas Battery','A small missile battery, designed to repel invaders and other hazards.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16796,319,'Guristas Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16797,319,'Guristas Elevator','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16798,319,'Guristas Junction','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16799,319,'Guristas Lookout','A lookout post, constructed so that its inhabitants may have a better look at the vast expanses of space and whatever wonders they may hold.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16800,319,'Guristas Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16801,319,'Guristas Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16802,319,'Guristas Fence','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16803,319,'Guristas Barrier','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16804,319,'Minmatar Barrier','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16805,319,'Minmatar Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16806,319,'Minmatar Elevator','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16807,319,'Minmatar Junction','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16808,319,'Minmatar Lookout','A lookout post, constructed so that its inhabitants may have a better look at the vast expanses of space and whatever wonders they may hold.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16809,319,'Minmatar Battery','A small missile battery, designed to repel invaders and other hazards.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16810,319,'Minmatar Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16811,319,'Minmatar Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16812,319,'Minmatar Fence','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16813,319,'Sansha Fence','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16814,319,'Sansha Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16815,319,'Sansha Elevator','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16816,319,'Sansha Junction','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16817,319,'Sansha Lookout','A lookout post, constructed so that its inhabitants may have a better look at the vast expanses of space and whatever wonders they may hold.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16818,319,'Sansha Battery','A small missile battery, designed to repel invaders and other hazards.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16819,319,'Sansha Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16820,319,'Sansha Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16821,319,'Sansha Barrier','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16822,319,'Serpentis Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16823,319,'Serpentis Elevator','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16824,319,'Serpentis Junction','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16825,319,'Serpentis Lookout','A lookout post, constructed so that its inhabitants may have a better look at the vast expanses of space and whatever wonders they may hold.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16826,319,'Serpentis Battery','A small missile battery, designed to repel invaders and other hazards.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16827,319,'Serpentis Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16828,319,'Serpentis Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16829,319,'Serpentis Fence','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16830,319,'Serpentis Barrier','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16831,319,'Radio Telescope','This huge radio telescope contains fragile but advanced sensory equipment. A structure such as this has enormous capabilities in crunching survey data from nearby systems and constellations.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16832,314,'Sansha Data Sheets','Secrent documents used by the Sansha\'s Nation.',1,1,0,1,NULL,0.0000,1,NULL,0),(16836,319,'Amarr Deadspace Refiner','Built to reprocess ores into minerals without the tedious interlude of a station visit. All for the glory of the Emperor and the prominence of the Amarr Empire.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(16837,319,'Amarr Deadspace Repair Unit','The Amarr Empire spreads far and wide and the presence of repair outposts at strategic locations ensures the will of the Emperor prevails in its every far flung corner.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(16838,319,'Amarr Deadspace Tactical Unit','Feudal obligations in the Amarr Empire force every lord loyal to the Emperor to participate in the defense of the realm. Tactical outposts serve as the backbone to the first line of defense the empire enjoys.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(16839,319,'Asteroid Factory','Highly vulnerable, but economically extremely feasible, asteroid factories are one of the major boons of the expanding space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16840,319,'Asteroid Colony','Highly vulnerable, but economically extremely feasible, asteroid factories are one of the major boons of the expanding space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16841,319,'Asteroid Construct','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16842,319,'Asteroid Prime Colony','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16843,319,'Asteroid Structure','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16844,319,'Asteroid Secondary Colony','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16845,319,'Meat Popsicle','The inhospitability of space no longer bothers this individual.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16846,319,'Asteroid Colony Tower','This is a building dedicated to offices and staff quarters mostly, though spacious halls and special installments allow for some flexibility in function.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16847,319,'Asteroid Micro-Colony','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16848,319,'Empty Station Battery','Forlorn hulk of a depleted station battery. Once a vital part of the complex, it now only serves to remind us that in space the only thing eternal is death.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16849,319,'Deadspace Particle Accelerator','The science allowed by zero gravity can be as mind-boggling as it is beautiful, as demonstrated by this particle accelerating superstructure.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16850,319,'Caldari Deadspace Refining Outpost','The Caldari State was the first to employ ore refineries outside space stations, a natural move for an entity that values efficiency above everything else.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(16851,319,'Caldari Deadspace Repair Outpost','First used during the Gallente-Caldari War, \"the black smithy,\" as it is fondly called by the Caldari Navy, has since saved countless numbers of pilots the indignity of a disintegrating ship.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(16852,319,'Caldari Deadspace Tactical Outpost','These structures saw heavy use during the days of the Gallente-Caldari war.  Built to allow the State\'s Navy vessels the opportunity to make fortified pit stops in otherwise sparsely populated areas, they were also a tremendous help in pushing back the battle lines.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(16853,319,'Circle Construct','A massive circular construction, made of a reinforced tritanium alloy.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16854,319,'Pulsating Sensor','Built for up-to-the-minute analysis of tactical and environmental data, these outposts can be found dotted around many a deadspace complex.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(16855,319,'Gallentean Deadspace Outpost','Equally equipped for scientific observation and entertainment of all sorts, these multi-purpose structures, while not quite big enough to be classified as stations, nonetheless see quite a bit of use by both tourists and professionals.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(16856,319,'Pressure Silo','Built to withstand assault, these behemoths can each hold roughly 8.5 million m3 worth of materials.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16857,319,'Minmatar Deadspace Refining Outpost','Though built cheaply, this refinery is able to process most ores at the same level of efficiency found on any station-based refinery platform.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(16858,319,'Minmatar Deadspace Repair Outpost','Due to their amazing cost-effectiveness and the speed at which they can be built, these outposts are seeing greater and greater use among Matari freedom fighters and other warriors and travelers who need to be able to stay mobile in dangerous territory.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(16859,319,'Minmatar Deadspace Tactical Outpost','Outfitted with makeshift sensor arrays and second-hand tactical data analysis equipment, these outposts will, to anyone not in the know, look like useless scrapyards.  Which is exactly what the Matari would have you think.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(16860,319,'Freight Pad','Built for up-to-the-minute analysis of tactical and environmental data, these pads can be found dotted around many a deadspace complex.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(16861,319,'Subspace Frequency Generator','Utilizing advanced auto-locomotive electrocardic subroutines, this miniscule generator is able to generate power equal to far bigger versions of older models.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16862,319,'Blasted Neon Sign','Once the pride and joy of its parent corporation, this broken-down heap of neon and metal is now no more than a symbolic manifestation of capitalistic decline.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16864,319,'Low-Tech Deadspace Energy Harvester','Containing only a handful of mechanical components, this simple wonder harvests energy from the system\'s sun by virtue of the unique EM refractive qualities in its scartate fabric.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16865,319,'Rapid Pulse Sentry','Emitting a high-frequency electromagnetic pulse, this scanner sentry is able to assimilate and store environmental data with remarkable efficiency.  Particularly effective at picking up miniscule fluctuations in the particle field within its range.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16866,319,'Magnetic Retainment Field','This bubble was built around a subspace ionization convergence.  Its main purpose is to contain the energy emanating from the convergence until a way can be found to properly harness it.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(16867,430,'Ultra Fast Mobile Laser Sentry',' ',100000000,1150,5000,1,NULL,0.0000,0,NULL,0),(16868,661,'Standard Blue Pill Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(16869,438,'Complex Reactor Array','An arena for various different substances to mix and match. The Complex Reactor Array is where chemical processes take place that can turn a simple element into a complex composite, and thus plays an important part in the harnessing of moon minerals.\r\r\n\r\r\nNote: the Complex Reactor Array is capable of running both simple and complex reactions, albeit only one at a time.',100000000,4000,1,1,NULL,25000000.0000,1,490,0),(16870,818,'Captain Numek Kradin','This is a CONCORD Special Ops Captain.  Consider him a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',1650000,16500,235,1,NULL,0.0000,0,NULL,0),(16871,816,'General Krayek Tsunomi','This is a General within the CONCORD Army.  Consider him a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',19000000,1080000,235,1,NULL,0.0000,0,NULL,0),(16873,817,'Captain Jym Muntoya','This is a captain within the CONCORD Army.  Consider him a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',10100000,101000,235,1,NULL,0.0000,0,NULL,0),(16874,597,'Gistii Ambusher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1910000,19100,120,1,2,0.0000,0,NULL,0),(16875,595,'Gistum Depredator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',9900000,99000,1900,1,2,0.0000,0,NULL,0),(16876,597,'Gistii Fugitive','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2112000,21120,100,1,2,0.0000,0,NULL,0),(16877,597,'Gistii Hijacker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2112000,21120,100,1,2,0.0000,0,NULL,0),(16878,597,'Gistii Hunter','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1910000,19100,80,1,2,0.0000,0,NULL,0),(16879,597,'Gistii Impaler','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(16880,595,'Gistum Crusher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(16881,595,'Gistum Smasher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,1400,1,2,0.0000,0,NULL,0),(16882,597,'Gistii Nomad','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',1750000,17500,180,1,2,0.0000,0,NULL,0),(16883,597,'Gistii Outlaw','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',1740000,17400,220,1,2,0.0000,0,NULL,0),(16884,595,'Gistum Predator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',9900000,99000,120,1,2,0.0000,0,NULL,0),(16885,597,'Gistii Raider','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(16886,597,'Gistii Rogue','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2250000,22500,75,1,2,0.0000,0,NULL,0),(16887,597,'Gistii Ruffian','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',1766000,17660,120,1,2,0.0000,0,NULL,0),(16888,597,'Gistii Thug','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2600500,26005,120,1,2,0.0000,0,NULL,0),(16889,595,'Gistum Breaker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(16890,597,'Arch Gistii Hijacker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(16891,595,'Gistum Marauder','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(16892,594,'Gist Commander','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16893,594,'Gist General','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16894,597,'Arch Gistii Thug','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(16895,597,'Arch Gistii Outlaw','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(16896,595,'Gistum Liquidator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(16897,597,'Arch Gistii Rogue','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(16898,595,'Gistum Defeater','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(16899,594,'Gist Warlord','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16900,594,'Gist War General','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16901,597,'Gistii Domination Hijacker','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',2112000,21120,100,1,2,0.0000,0,NULL,0),(16902,597,'Gistii Domination Rogue','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',2250000,22500,75,1,2,0.0000,0,NULL,0),(16903,597,'Gistii Domination Outlaw','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1740000,17400,220,1,2,0.0000,0,NULL,0),(16904,597,'Gistii Domination Thug','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',2600500,26005,120,1,2,0.0000,0,NULL,0),(16905,597,'Gistii Domination Ambusher','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1910000,19100,120,1,2,0.0000,0,NULL,0),(16906,595,'Gistum Domination Depredator','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',9900000,99000,1900,1,2,0.0000,0,NULL,0),(16907,597,'Gistii Domination Hunter','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1910000,19100,80,1,2,0.0000,0,NULL,0),(16908,597,'Gistii Domination Impaler','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1645000,16450,120,1,2,0.0000,0,NULL,0),(16909,595,'Gistum Domination Crusher','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(16910,595,'Gistum Domination Smasher','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,1400,1,2,0.0000,0,NULL,0),(16911,597,'Gistii Domination Nomad','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1750000,17500,180,1,2,0.0000,0,NULL,0),(16912,595,'Gistum Domination Predator','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',9900000,99000,120,1,2,0.0000,0,NULL,0),(16913,597,'Gistii Domination Raider','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1645000,16450,110,1,2,0.0000,0,NULL,0),(16914,597,'Gistii Domination Ruffian','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1766000,17660,120,1,2,0.0000,0,NULL,0),(16915,595,'Gistum Domination Breaker','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(16916,595,'Gistum Domination Defeater','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(16917,595,'Gistum Domination Marauder','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(16918,595,'Gistum Domination Phalanx','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(16919,595,'Gistum Domination Liquidator','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(16920,595,'Gistum Domination Centurion','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(16921,594,'Gist Domination Commander','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16922,594,'Gist Domination General','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16923,594,'Gist Domination War General','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16924,594,'Gist Domination Saint','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16925,594,'Gist Domination Nephilim','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16926,594,'Gist Domination Warlord','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(16927,604,'Corpum Arch Engraver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',12000000,120000,450,1,4,0.0000,0,NULL,0),(16928,604,'Corpum Arch Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(16929,604,'Corpum Arch Reaver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',11500000,115000,465,1,4,0.0000,0,NULL,0),(16930,604,'Corpum Arch Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(16931,604,'Corpum Arch Templar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(16932,606,'Corpii Diviner','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2860000,28600,235,1,4,0.0000,0,NULL,0),(16933,606,'Corpii Upholder','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2810000,28100,135,1,4,0.0000,0,NULL,0),(16934,603,'Corpus Prophet','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(16935,606,'Corpii Collector','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2810000,28100,315,1,4,0.0000,0,NULL,0),(16936,606,'Corpii Follower','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2810000,28100,120,1,4,0.0000,0,NULL,0),(16937,606,'Corpii Fugitive','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2810000,28100,120,1,4,0.0000,0,NULL,0),(16938,603,'Corpus Oracle','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(16939,606,'Elder Corpii Herald','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2870000,28700,135,1,4,0.0000,0,NULL,0),(16940,606,'Corpii Reaver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2870000,28700,135,1,4,0.0000,0,NULL,0),(16941,603,'Corpus Apostle','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(16942,606,'Elder Corpii Upholder','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(16943,606,'Elder Corpii Follower','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2870000,28700,235,1,4,0.0000,0,NULL,0),(16944,604,'Corpum Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(16945,606,'Corpii Raider','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2870000,28700,235,1,4,0.0000,0,NULL,0),(16946,606,'Corpii Herald','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2810000,28100,235,1,4,0.0000,0,NULL,0),(16947,606,'Corpii Seeker','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2810000,28100,165,1,4,0.0000,0,NULL,0),(16948,604,'Corpum Revenant','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(16949,604,'Corpum Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(16950,606,'Corpii Worshipper','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2820000,24398,235,1,4,0.0000,0,NULL,0),(16951,606,'Elder Corpii Worshiper','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2860000,28600,235,1,4,0.0000,0,NULL,0),(16952,603,'Corpus Archon','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(16953,606,'Corpii Engraver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(16954,606,'Dark Corpii Reaver','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2870000,28700,135,1,4,0.0000,0,NULL,0),(16955,606,'Dark Corpii Follower','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,120,1,4,0.0000,0,NULL,0),(16956,604,'Dark Corpum Arch Engraver','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',12000000,120000,450,1,4,0.0000,0,NULL,0),(16957,604,'Dark Corpum Arch Priest','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(16958,604,'Dark Corpum Dark Priest','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(16959,604,'Dark Corpum Arch Reaver','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11500000,115000,465,1,4,0.0000,0,NULL,0),(16960,604,'Dark Corpum Arch Sage','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(16961,604,'Dark Corpum Shadow Sage','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(16962,604,'Dark Corpum Arch Templar','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(16963,606,'Dark Corpii Diviner','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2860000,28600,235,1,4,0.0000,0,NULL,0),(16964,606,'Dark Corpii Upholder','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,135,1,4,0.0000,0,NULL,0),(16965,603,'Dark Corpus Prophet','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(16966,606,'Dark Corpii Collector','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,315,1,4,0.0000,0,NULL,0),(16967,603,'Dark Corpus Oracle','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',20500000,1100000,235,1,4,0.0000,0,NULL,0),(16968,603,'Dark Corpus Archbishop','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',20500000,1100000,235,1,4,0.0000,0,NULL,0),(16969,603,'Dark Corpus Apostle','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(16970,603,'Dark Corpus Harbinger','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(16971,604,'Dark Corpum Priest','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(16972,606,'Dark Corpii Raider','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2870000,28700,235,1,4,0.0000,0,NULL,0),(16973,606,'Dark Corpii Herald','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,235,1,4,0.0000,0,NULL,0),(16974,606,'Dark Corpii Seeker','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,165,1,4,0.0000,0,NULL,0),(16975,604,'Dark Corpum Revenant','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(16976,604,'Dark Corpum Sage','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(16977,606,'Dark Corpii Worshipper','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2820000,24398,235,1,4,0.0000,0,NULL,0),(16978,603,'Dark Corpus Archon','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',20500000,1100000,235,1,4,0.0000,0,NULL,0),(16979,606,'Dark Corpii Engraver','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2860000,28600,235,1,4,0.0000,0,NULL,0),(16980,613,'Pithum Killer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',9200000,92000,235,1,1,0.0000,0,NULL,0),(16981,615,'Pithi Arrogator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',1500100,15001,45,1,1,0.0000,0,NULL,0),(16982,613,'Pithum Ascriber','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',9600000,96000,450,1,1,0.0000,0,NULL,0),(16983,615,'Dire Pithi Infiltrator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(16984,612,'Pith Dismantler','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(16985,615,'Dire Pithi Invader','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(16986,615,'Pithi Demolisher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(16987,615,'Pithi Despoiler','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2040000,20400,100,1,1,0.0000,0,NULL,0),(16988,612,'Pith Obliterator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',22000000,1080000,235,1,1,0.0000,0,NULL,0),(16989,615,'Pithi Destructor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(16990,615,'Dire Pithi Imputor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(16991,613,'Pithum Inferno','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(16992,612,'Pith Eradicator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(16993,615,'Pithi Fugitive','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',1500100,15001,45,1,1,0.0000,0,NULL,0),(16994,615,'Pithi Imputor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',1612000,16120,80,1,1,0.0000,0,NULL,0),(16995,613,'Pithum Mortifier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(16996,615,'Pithi Infiltrator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2025000,20250,235,1,1,0.0000,0,NULL,0),(16997,615,'Pithi Invader','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2025000,20250,65,1,1,0.0000,0,NULL,0),(16998,613,'Pithum Nullifier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(16999,615,'Dire Pithi Arrogator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(17000,613,'Pithum Murderer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(17001,615,'Pithi Plunderer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(17002,615,'Pithi Saboteur','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2040000,20400,235,1,1,0.0000,0,NULL,0),(17003,613,'Pithum Annihilator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(17004,613,'Pithum Silencer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',10700000,107000,850,1,1,0.0000,0,NULL,0),(17005,612,'Pith Extinguisher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(17006,615,'Pithi Wrecker','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(17007,613,'Dread Pithum Killer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',9200000,92000,235,1,1,0.0000,0,NULL,0);
INSERT INTO `invTypes` VALUES (17008,615,'Dread Pithi Arrogator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',1500100,15001,45,1,1,0.0000,0,NULL,0),(17009,613,'Dread Pithum Ascriber','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',9600000,96000,450,1,1,0.0000,0,NULL,0),(17010,612,'Dread Pith Dismantler','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',21000000,1040000,235,1,1,0.0000,0,NULL,0),(17011,612,'Dread Pith Eliminator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',21000000,1040000,235,1,1,0.0000,0,NULL,0),(17012,615,'Dread Pithi Demolisher','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',1650000,16500,235,1,1,0.0000,0,NULL,0),(17013,615,'Dread Pithi Despoiler','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',2040000,20400,100,1,1,0.0000,0,NULL,0),(17014,612,'Dread Pith Obliterator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',22000000,1080000,235,1,1,0.0000,0,NULL,0),(17015,615,'Dread Pithi Destructor','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',1970000,19700,235,1,1,0.0000,0,NULL,0),(17016,613,'Dread Pithum Inferno','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(17017,613,'Dread Pithum Abolisher','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(17018,612,'Dread Pith Eradicator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',21000000,1040000,235,1,1,0.0000,0,NULL,0),(17019,615,'Dread Pithi Imputor','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',1612000,16120,80,1,1,0.0000,0,NULL,0),(17020,613,'Dread Pithum Mortifier','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(17021,613,'Dread Pithum Eraser','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(17022,615,'Dread Pithi Infiltrator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',2025000,20250,235,1,1,0.0000,0,NULL,0),(17023,615,'Dread Pithi Invader','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',2025000,20250,65,1,1,0.0000,0,NULL,0),(17024,613,'Dread Pithum Nullifier','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(17025,613,'Dread Pithum Murderer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(17026,615,'Dread Pithi Plunderer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',1970000,19700,125,1,1,0.0000,0,NULL,0),(17027,615,'Dread Pithi Saboteur','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',2040000,20400,235,1,1,0.0000,0,NULL,0),(17028,613,'Dread Pithum Annihilator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(17029,613,'Dread Pithum Silencer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10700000,107000,850,1,1,0.0000,0,NULL,0),(17030,612,'Dread Pith Extinguisher','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',21000000,22000000,235,1,1,0.0000,0,NULL,0),(17031,612,'Dread Pith Exterminator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',21000000,22000000,235,1,1,0.0000,0,NULL,0),(17032,615,'Dread Pithi Wrecker','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',1650000,16500,130,1,1,0.0000,0,NULL,0),(17033,631,'Corelum Chief Protector','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(17034,630,'Core Rear Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(17035,633,'Coreli Guardian Scout','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,235,1,8,0.0000,0,NULL,0),(17036,630,'Core Port Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,1010000,480,1,8,0.0000,0,NULL,0),(17037,630,'Core Commodore','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(17038,630,'Core Baron','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,1010000,480,1,8,0.0000,0,NULL,0),(17039,631,'Corelum Chief Guard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(17040,633,'Coreli Guardian Initiate','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,60,1,8,0.0000,0,NULL,0),(17041,633,'Coreli Guardian Spy','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,140,1,8,0.0000,0,NULL,0),(17042,631,'Corelum Chief Safeguard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(17043,633,'Coreli Guardian Agent','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(17044,631,'Corelum Chief Defender','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(17045,631,'Shadow Corelum Chief Guard','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(17046,631,'Shadow Corelum Chief Sentinel','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(17047,631,'Shadow Corelum Chief Protector','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(17048,631,'Shadow Corelum Chief Infantry','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(17049,630,'Shadow Core Port Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',19000000,1010000,480,1,8,0.0000,0,NULL,0),(17050,630,'Shadow Core Vice Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(17051,630,'Shadow Core Commodore','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(17052,630,'Shadow Core Baron','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',19000000,1010000,480,1,8,0.0000,0,NULL,0),(17053,630,'Shadow Core Flotilla Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',19000000,1010000,480,1,8,0.0000,0,NULL,0),(17054,630,'Shadow Core Rear Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(17055,631,'Shadow Corelum Chief Safeguard','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(17056,631,'Shadow Corelum Chief Defender','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(17057,622,'Centum Beast','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(17058,621,'Centus Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(17059,624,'Centii Butcher','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(17060,624,'Centii Loyal Minion','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2112000,21120,200,1,4,0.0000,0,NULL,0),(17061,624,'Centii Loyal Ravener','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(17062,622,'Centum Slaughterer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(17063,624,'Centii Enslaver','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2112000,21120,235,1,4,0.0000,0,NULL,0),(17064,624,'Centii Fugitive','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2000000,20000,235,1,4,0.0000,0,NULL,0),(17065,622,'Centum Juggernaut','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(17066,621,'Centus Slave Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(17067,624,'Centii Manslayer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,200,1,4,0.0000,0,NULL,0),(17068,624,'Centii Minion','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2112000,21120,100,1,4,0.0000,0,NULL,0),(17069,624,'Centii Loyal Servant','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2112000,21120,235,1,4,0.0000,0,NULL,0),(17070,622,'Centum Torturer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(17071,621,'Centus Mutant Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(17072,624,'Centii Plague','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2112000,21120,200,1,4,0.0000,0,NULL,0),(17073,622,'Centum Ravager','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',10010000,100100,200,1,4,0.0000,0,NULL,0),(17074,624,'Centii Ravener','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2000000,20000,235,1,4,0.0000,0,NULL,0),(17075,622,'Centum Ravisher','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sancha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',10010000,100100,235,1,4,0.0000,0,NULL,0),(17076,624,'Centii Savage','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2000000,20000,200,1,4,0.0000,0,NULL,0),(17077,624,'Centii Scavenger','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2000000,20000,200,1,4,0.0000,0,NULL,0),(17078,624,'Centii Servant','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2000000,20000,235,1,4,0.0000,0,NULL,0),(17079,624,'Centii Loyal Scavenger','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,200,1,4,0.0000,0,NULL,0),(17080,622,'Centum Mutilator','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(17081,624,'Centii Slavehunter','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2112000,21120,235,1,4,0.0000,0,NULL,0),(17082,621,'Centus Savage Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(17083,622,'Centum Execrator','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(17084,622,'True Centum Beast','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17085,621,'True Centus Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17086,624,'True Centii Butcher','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,235,1,4,0.0000,0,NULL,0),(17087,622,'True Centum Slaughterer','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17088,624,'True Centii Enslaver','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,235,1,4,0.0000,0,NULL,0),(17089,622,'True Centum Juggernaut','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17090,621,'True Centus Slave Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17091,624,'True Centii Manslayer','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,200,1,4,0.0000,0,NULL,0),(17092,624,'True Centii Minion','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,100,1,4,0.0000,0,NULL,0),(17093,622,'True Centum Torturer','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17094,622,'True Centum Hellhound','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17095,621,'True Centus Mutant Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17096,621,'True Centus Plague Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17097,624,'True Centii Plague','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,200,1,4,0.0000,0,NULL,0),(17098,622,'True Centum Ravager','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,200,1,4,0.0000,0,NULL,0),(17099,624,'True Centii Ravener','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2000000,20000,235,1,4,0.0000,0,NULL,0),(17100,622,'True Centum Ravisher','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17101,624,'True Centii Savage','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2000000,20000,200,1,4,0.0000,0,NULL,0),(17102,624,'True Centii Scavenger','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2000000,20000,200,1,4,0.0000,0,NULL,0),(17103,624,'True Centii Servant','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2000000,20000,235,1,4,0.0000,0,NULL,0),(17104,622,'True Centum Mutilator','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17105,622,'True Centum Fiend','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17106,624,'True Centii Slavehunter','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,235,1,4,0.0000,0,NULL,0),(17107,621,'True Centus Beast Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17108,621,'True Centus Savage Lord','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17109,622,'True Centum Execrator','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(17110,631,'Corelum Chief Watchman','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11500000,115000,235,1,8,0.0000,0,NULL,0),(17111,631,'Corelum Chief Patroller','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(17112,631,'Corelum Chief Scout','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',11300000,113000,235,1,8,0.0000,0,NULL,0),(17113,633,'Coreli Safeguard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,235,1,8,0.0000,0,NULL,0),(17114,631,'Corelum Chief Spy','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',11600000,116000,900,1,8,0.0000,0,NULL,0),(17115,633,'Coreli Fugitive','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2450000,24500,60,1,8,0.0000,0,NULL,0),(17116,633,'Coreli Watchman','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2950000,29500,175,1,8,0.0000,0,NULL,0),(17117,633,'Coreli Scout','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2250000,22500,125,1,8,0.0000,0,NULL,0),(17118,633,'Coreli Agent','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2250000,22500,235,1,8,0.0000,0,NULL,0),(17119,633,'Coreli Defender','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,140,1,8,0.0000,0,NULL,0),(17120,633,'Coreli Patroller','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2950000,29500,235,1,8,0.0000,0,NULL,0),(17121,633,'Coreli Initiate','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2450000,24500,60,1,8,0.0000,0,NULL,0),(17122,633,'Coreli Protector','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(17123,631,'Shadow Corelum Chief Watchman','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',11500000,115000,235,1,8,0.0000,0,NULL,0),(17124,631,'Shadow Corelum Chief Patroller','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(17125,631,'Shadow Corelum Chief Scout','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',11300000,113000,235,1,8,0.0000,0,NULL,0),(17126,633,'Shadow Coreli Safeguard','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2300000,23000,235,1,8,0.0000,0,NULL,0),(17127,631,'Shadow Corelum Chief Spy','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',11600000,116000,900,1,8,0.0000,0,NULL,0),(17128,633,'Shadow Coreli Watchman','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2950000,29500,175,1,8,0.0000,0,NULL,0),(17129,633,'Shadow Coreli Scout','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2250000,22500,125,1,8,0.0000,0,NULL,0),(17130,633,'Shadow Coreli Agent','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2250000,22500,235,1,8,0.0000,0,NULL,0),(17131,633,'Shadow Coreli Defender','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2650000,26500,140,1,8,0.0000,0,NULL,0),(17132,633,'Shadow Coreli Patroller','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2950000,29500,235,1,8,0.0000,0,NULL,0),(17133,633,'Shadow Coreli Initiate','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2450000,24500,60,1,8,0.0000,0,NULL,0),(17134,633,'Shadow Coreli Protector','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2650000,26500,235,1,8,0.0000,0,NULL,0),(17135,494,'Stargate under construction and repair','The construction of a stargate within a Deadspace Complex has not yet been successful due to environmental factors. But the Angel Corporation is obviously trying...',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17136,1040,'Ukomi Superconductors','Highly isolated coils with minimal friction, used in high-voltage electrical devices. The Ukomi Superconductors are a new brand developed and manufactured by the Kaalakiota corporation. Today every Caldari station has a stockpile of these highly rated Superconductors, which are in quite high demand in most foreign black markets due to their superior technology.',0,6,0,1,NULL,5000.0000,1,1336,0),(17138,319,'Augmented Angel Battlestation','This gigantic suprastructure is one of the military installations of the Angel pirate corporation. Even for its size, it has no commercial station services or docking bay to receive guests.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(17140,319,'Security Outpost','This outpost is the base of security operations in this deadspace complex\'s inner perimeter.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(17141,821,'Tritan - The Underground Overseer','Inside this Deadspace Complex, the focus of attention seems to be this imposing battleship. An unusual glow makes the hull shimmer from time to time.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(17142,821,'The Battlestation Admiral','This elite Domination Defense General has been stationed here for some unannounced purpose. Sits and waits...',19000000,19000000,120,1,2,0.0000,0,NULL,0),(17143,314,'Gallentean Planetary Vehicles','Tracked, wheeled and hover vehicles used within planetary atmosphere for personal and business use. Gallentean vehicles (or the \'luxury edition\' as they are sometimes called) have been specially modified with numerous gadgets to make the ride more comfortable, and enjoyable. A high-tech personal entertainment system has been put in all of the passenger seats, the seats have been made far more comfy, etc.',2500,2,0,1,NULL,10000.0000,1,492,0),(17144,383,'Tower Sentry Bloodraider II','Blood Raider tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17145,383,'Tower Sentry Bloodraider I','Blood Raider tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17146,383,'Tower Sentry Angel II','Angel 1400mm howitzer sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17147,383,'Tower Sentry Angel I','Angel 1400mm howitzer sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17148,383,'Tower Sentry Caldari II','Caldari 425mm railgun sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17149,383,'Tower Sentry Caldari I','Caldari 425mm railgun sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17150,383,'Tower Sentry Gallente II','Gallente ion blaster cannon sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17151,383,'Tower Sentry Gallente I','Gallente ion blaster cannon sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17152,383,'Tower Sentry Guristas I','Guristas 425mm railgun sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17153,383,'Tower Sentry Guristas II','Guristas 425mm railgun sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17154,383,'Tower Sentry Minmatar II','Minmatar 1400mm howitzer sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17155,383,'Tower Sentry Minmatar I','Minmatar 1400mm howitzer sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17156,383,'Tower Sentry Sansha II','Sansha tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17157,383,'Tower Sentry Sansha I','Sansha tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17158,383,'Tower Sentry Serpentis II','Serpentis ion blaster cannon sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17159,383,'Tower Sentry Serpentis I','Serpentis ion blaster cannon sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17160,383,'Tower Sentry Amarr I','Amarr tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17161,383,'Tower Sentry Amarr II','Amarr tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17162,821,'The Stronghold General','This sinister looking battleship is guarding the center of this deadspace pocket.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(17163,383,'Serpentis Stasis Tower','Serpentis stasis web sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17164,383,'Tower Missile Battery Serpentis I','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17165,820,'Control Headquarters','This looks much like a standard cruiser fighting for the Angel Cartel, but somehow that one looks slightly foreboding.',10900000,109000,120,1,2,0.0000,0,NULL,0),(17166,820,'Security Coordinator','This looks much like a standard cruiser fighting for the Angel Cartel, but this one\'s weapon module glisten and gleam in an uncanny way.',10900000,109000,120,1,2,0.0000,0,NULL,0),(17167,430,'Small Beam Laser Battery','Fires a deep modulated energy beam using medium sized frequency crystals at those the Control Tower deems its enemies. Effective at relatively long ranges, but tracks fairly slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,500,3,1,4,500000.0000,1,596,0),(17168,430,'Medium Beam Laser Battery','Fires a deep modulated energy beam using large sized frequency crystals at those the Control Tower deems its enemies. Effective at long ranges, but tracks relatively slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,1000,2,1,4,2500000.0000,1,596,0),(17172,414,'Medium Auxiliary Power Array',' ',50000000,100,0,1,NULL,0.0000,0,NULL,0),(17173,414,'Large Auxiliary Power Array',' ',50000000,100,0,1,NULL,0.0000,0,NULL,0),(17174,439,'Ion Field Projection Battery','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(17175,439,'Phase Inversion Battery','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(17176,439,'Spatial Destabilization Battery','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(17177,439,'White Noise Generation Battery','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(17178,441,'Stasis Webification Battery','The webifier\'s big brother. Designed to protect structures from fast-moving ships by making them into slow-moving ships.',100000000,4000,0,1,NULL,5000000.0000,1,481,0),(17179,494,'UNUSED_Gist_Battlestation_LCS_ID31_DL1_DCP1','This gigantic suprastructure is one of the military installations of the Angel pirate corporation. Even for it\'s size it has no commercial station services or docking bay to receive guests.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17180,440,'Sensor Dampening Battery','Deployable structure that cycle dampens enemy sensors.',100000000,4000,0,1,NULL,1250000.0000,1,481,0),(17181,443,'Warp Disruption Battery','Deployable warp jamming structure.',100000000,4000,0,1,NULL,5000000.0000,1,481,0),(17182,443,'Warp Scrambling Battery','Deployable warp jamming structure.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(17184,444,'Ballistic Deflection Array','Boosts the control tower\'s shield resistance against kinetic damage. Using more than one unit of this structure or similar structures that affect the same attribute on the control tower will yield diminishing returns.',100000000,4000,0,1,NULL,10000000.0000,1,485,0),(17185,444,'Explosion Dampening Array','Boosts the control tower\'s shield resistance against explosive damage. Using more than one unit of this structure or similar structures that affect the same attribute on the control tower will yield diminishing returns.',100000000,4000,0,1,NULL,10000000.0000,1,485,0),(17186,444,'Heat Dissipation Array','Boosts the control tower\'s shield resistance against thermal damage. Using more than one unit of this structure or similar structures that affect the same attribute on the control tower will yield diminishing returns.',100000000,4000,0,1,NULL,10000000.0000,1,485,0),(17187,444,'Photon Scattering Array','Boosts the control tower\'s shield resistance against EM damage. Using more than one unit of this structure or similar structures that affect the same attribute on the control tower will yield diminishing returns.',100000000,4000,0,1,NULL,10000000.0000,1,485,0),(17188,445,'Force Field Array','Projects a password protected force field around structures that are outside the range of a control tower\'s shields.',100,100,0,1,NULL,1000000.0000,0,NULL,0),(17190,370,'Angel Bronze Tag','This bronze tag carries the rank insignia equivalent of a private within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,740,0),(17192,370,'Angel Diamond Tag','This diamond tag carries the rank insignia equivalent of a captain within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,740,0),(17194,370,'Angel Gold Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,740,0),(17196,370,'Angel Platinum Tag','This platinum tag carries the rank insignia equivalent of a lieutenant within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,740,0),(17199,370,'Angel Electrum Tag','This electrum tag carries the rank insignia equivalent of a corporal within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,740,0),(17200,370,'Blood Copper Tag','This copper tag carries the rank insignia equivalent of a private within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,741,0),(17201,370,'Blood Diamond Tag','This diamond tag carries the rank insignia equivalent of a captain within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,741,0),(17202,370,'Blood Palladium Tag','This palladium tag carries the rank insignia equivalent of a lieutenant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,741,0),(17203,370,'Blood Electrum Tag','This electrum tag carries the rank insignia equivalent of a corporal within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,741,0),(17204,370,'Blood Brass Tag','This brass tag carries the rank insignia equivalent of a sergeant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,741,0),(17205,370,'Guristas Copper Tag','This copper tag carries the rank insignia equivalent of a private within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,745,0),(17206,370,'Guristas Diamond Tag','This diamond tag carries the rank insignia equivalent of a captain within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,745,0),(17207,370,'Guristas Brass Tag','This brass tag carries the rank insignia equivalent of a sergeant within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,745,0),(17208,370,'Guristas Palladium Tag','This palladium tag carries the rank insignia equivalent of a lieutenant within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,745,0),(17209,370,'Guristas Electrum Tag','This electrum tag carries the rank insignia equivalent of a corporal within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,745,0),(17210,370,'Sansha Copper Tag','This copper tag carries the rank insignia equivalent of a private within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,746,0),(17211,370,'Sansha Diamond Tag','This diamond tag carries the rank insignia equivalent of a captain within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,746,0),(17212,370,'Sansha Brass Tag','This brass tag carries the rank insignia equivalent of a sergeant within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,746,0),(17213,370,'Sansha Palladium Tag','This palladium tag carries the rank insignia equivalent of a lieutenant within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,746,0),(17214,370,'Sansha Electrum Tag','This electrum tag carries the rank insignia equivalent of a corporal within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,746,0),(17215,370,'Serpentis Copper Tag','This copper tag carries the rank insignia equivalent of a private within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,747,0),(17216,370,'Serpentis Diamond Tag','This diamond tag carries the rank insignia equivalent of a captain within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,747,0),(17217,370,'Serpentis Brass Tag','This brass tag carries the rank insignia equivalent of a sergeant within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,747,0),(17218,370,'Serpentis Palladium Tag','This palladium tag carries the rank insignia equivalent of a lieutenant within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,747,0),(17219,370,'Serpentis Electrum Tag','This electrum tag carries the rank insignia equivalent of a corporal within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,747,0),(17220,370,'Domination Brass Tag','This brass tag carries the rank insignia equivalent of a sergeant within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,743,0),(17221,370,'Domination Bronze Tag','This bronze tag carries the rank insignia equivalent of a private within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,743,0),(17222,370,'Domination Copper Tag','This copper tag carries the rank insignia equivalent of a private within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,743,0),(17223,370,'Domination Crystal Tag','This crystal tag carries the rank insignia equivalent of a captain within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,743,0),(17224,370,'Domination Diamond Tag','This diamond tag carries the rank insignia equivalent of a captain within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,743,0),(17225,370,'Domination Electrum Tag','This electrum tag carries the rank insignia equivalent of a corporal within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,743,0),(17226,370,'Domination Gold Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,743,0),(17227,370,'Domination Palladium Tag','This palladium tag carries the rank insignia equivalent of a lieutenant within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,743,0),(17229,370,'Domination Platinum Tag','This platinum tag carries the rank insignia equivalent of a lieutenant within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,743,0),(17230,370,'Domination Silver Tag','This silver tag carries the rank insignia equivalent of a corporal within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,743,0),(17231,370,'Dark Blood Brass Tag','This brass tag carries the rank insignia equivalent of a sergeant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,742,0),(17232,370,'Dark Blood Bronze Tag','This bronze tag carries the rank insignia equivalent of a private within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,742,0),(17233,370,'Dark Blood Copper Tag','This copper tag carries the rank insignia equivalent of a private within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,742,0),(17234,370,'Dark Blood Crystal Tag','This crystal tag carries the rank insignia equivalent of a captain within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,742,0),(17235,370,'Dark Blood Diamond Tag','This diamond tag carries the rank insignia equivalent of a captain within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,742,0),(17236,370,'Dark Blood Electrum Tag','This electrum tag carries the rank insignia equivalent of a corporal within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,742,0),(17237,370,'Dark Blood Palladium Tag','This palladium tag carries the rank insignia equivalent of a lieutenant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,742,0),(17238,370,'Dark Blood Gold Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,742,0),(17239,370,'Dark Blood Silver Tag','This silver tag carries the rank insignia equivalent of a corporal within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,742,0),(17240,370,'Dark Blood Platinum Tag','This platinum tag carries the rank insignia equivalent of a lieutenant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,742,0),(17241,370,'Dread Guristas Brass Tag','This brass tag carries the rank insignia equivalent of a sergeant within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,744,0),(17242,370,'Dread Guristas Bronze Tag','This bronze tag carries the rank insignia equivalent of a private within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,744,0),(17243,370,'Dread Guristas Copper Tag','This copper tag carries the rank insignia equivalent of a private within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,744,0),(17244,370,'Dread Guristas Crystal Tag','This crystal tag carries the rank insignia equivalent of a captain within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,744,0),(17245,370,'Dread Guristas Diamond Tag','This diamond tag carries the rank insignia equivalent of a captain within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,744,0),(17247,370,'Dread Guristas Electrum Tag','This electrum tag carries the rank insignia equivalent of a corporal within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,744,0),(17248,370,'Dread Guristas Gold Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,744,0),(17249,370,'Dread Guristas Palladium Tag','This palladium tag carries the rank insignia equivalent of a lieutenant within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,744,0),(17250,370,'Dread Guristas Platinum Tag','This platinum tag carries the rank insignia equivalent of a lieutenant within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,744,0),(17251,370,'Dread Guristas Silver Tag','This silver tag carries the rank insignia equivalent of a corporal within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,744,0),(17252,370,'True Sansha Brass Tag','This brass tag carries the rank insignia equivalent of a sergeant within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,749,0),(17253,370,'True Sansha Bronze Tag','This bronze tag carries the rank insignia equivalent of a private within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,749,0),(17254,370,'True Sansha Copper Tag','This copper tag carries the rank insignia equivalent of a private within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,749,0),(17255,370,'True Sansha Crystal Tag','This crystal tag carries the rank insignia equivalent of a captain within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,749,0),(17256,370,'True Sansha Diamond Tag','This diamond tag carries the rank insignia equivalent of a captain within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,749,0),(17257,370,'True Sansha Electrum Tag','This electrum tag carries the rank insignia equivalent of a corporal within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,749,0),(17258,370,'True Sansha Gold Tag','This gold tag carries the rank insignia equivalent of a sergeant within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,749,0),(17259,370,'True Sansha Palladium Tag','This palladium tag carries the rank insignia equivalent of a lieutenant within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,749,0),(17260,370,'True Sansha Platinum Tag','This platinum tag carries the rank insignia equivalent of a lieutenant within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,749,0),(17261,370,'True Sansha Silver Tag','This silver tag carries the rank insignia equivalent of a corporal within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,749,0),(17262,370,'Shadow Serpentis Brass Tag','This brass tag carries the rank insignia equivalent of a sergeant within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,748,0),(17263,370,'Shadow Serpentis Bronze Tag','This bronze tag carries the rank insignia equivalent of a private within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,748,0),(17264,370,'Shadow Serpentis Copper Tag','This copper tag carries the rank insignia equivalent of a private within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,748,0),(17266,370,'Shadow Serpentis Crystal Tag','This crystal tag carries the rank insignia equivalent of a captain within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,748,0),(17267,370,'Shadow Serpentis Diamond Tag','This diamond tag carries the rank insignia equivalent of a captain within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,748,0),(17268,370,'Shadow Serpentis Electrum Tag','This electrum tag carries the rank insignia equivalent of a corporal within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,748,0),(17269,370,'Shadow Serpentis Palladium Tag','This palladium tag carries the rank insignia equivalent of a lieutenant within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,748,0),(17270,370,'Shadow Serpentis Gold Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,748,0),(17271,370,'Shadow Serpentis Platinum Tag','This platinum tag carries the rank insignia equivalent of a lieutenant within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,748,0),(17272,370,'Shadow Serpentis Silver Tag','This silver tag carries the rank insignia equivalent of a corporal within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,748,0),(17273,494,'Biodome Gardens','This previous Gallentean pleasure resort has been heavily modified by the Amarrians and is now used for the production of biochemicals for food production. It uses substances harvested from the surrounding deadspace pockets as well as supplies flown in from distant starbases.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(17274,496,'Stuffed Container','The bolted container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,2750,2700,1,NULL,0.0000,0,NULL,0),(17275,494,'Oofus\'s Repair Shop','This gigantic suprastructure is one of the military installations of the Angel pirate corporation. Even for its size, it has no commercial station services or docking bay to receive guests.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(17276,496,'Container with blast marks','This reinforced container is outfitted with a capturing mechanism to pick up data from nearby sensor arrays.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(17277,496,'Electronically Sealed Container','The wrecked container drifts silently amongst the stars, your sensors pick up signs of something rolling within it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(17278,633,'Coreli Guard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,60,1,8,0.0000,0,NULL,0),(17279,633,'Coreli Spy','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2500000,25000,60,1,8,0.0000,0,NULL,0),(17280,633,'Shadow Coreli Guard','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2300000,23000,60,1,8,0.0000,0,NULL,0),(17281,633,'Shadow Coreli Spy','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2500000,25000,60,1,8,0.0000,0,NULL,0),(17283,819,'Sansha Black Ops Squad Leader','Although this frigate at first glance appears to be a standard Sansha\'s nation light frigate a preliminary signature scan seems to indicate that it may possess some inteceptor technology.  ',2000000,20000,200,1,4,0.0000,0,NULL,0),(17284,820,'Guristas Scout Officer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',9200000,92000,235,1,1,0.0000,0,NULL,0),(17285,819,'Centus Black Ops Commander','Although this frigate at first glance appears to be a standard Sansha\'s nation light frigate a preliminary signature scan seems to indicate that it may possess some inteceptor technology.  ',2000000,20000,200,1,4,0.0000,0,NULL,0),(17286,446,'Amarr Customs Captain','This is a security vessel of the Amarr Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',2870000,28700,200,1,4,0.0000,0,NULL,0),(17287,370,'Chelm Soran\'s Tag','Chelm Soran\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17288,370,'Vizan Ankonin\'s Tag','Vizan Ankonin\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17289,370,'Selynne Mardakar\'s Tag','Selynne Mardakar\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17290,370,'Brokara Ryver\'s Tag','Brokara Ryver\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17291,370,'Cormack Vaaja\'s Tag','Cormack Vaaja\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17292,370,'Setele Schellan\'s Tag','Setele Schellan\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17293,370,'Tuvan Orth\'s Tag','Tuvan Orth\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17294,370,'Brynn Jerdola\'s Tag','Brynn Jerdola\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17295,370,'Estamel Tharchon\'s Tag','Estamel Tharchon\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17296,370,'Vepas Minimala\'s Tag','Vepas Minimala\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17297,370,'Thon Eney\'s Tag','Thon Eney\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17298,370,'Kaikka Peunato\'s Tag','Kaikka Peunato\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17299,370,'Draclira Merlonne\'s Tag','Draclira Merlonne\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17300,370,'Ahremen Arkah\'s Tag','Ahremen Arkah\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17301,370,'Raysere Giant\'s Tag','Raysere Giant\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17302,370,'Tairei Namazoth\'s Tag','Tairei Namazoth\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17303,370,'Tobias Kruzhor\'s Tag','Tobias Kruzhor\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17304,370,'Gotan Kreiss\'s Tag','Gotan Kreiss\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17305,370,'Hakim Stormare\'s Tag','Hakim Stormare\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17306,370,'Mizuro Cybon\'s Tag','Mizuro Cybon\'s Tag. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17317,429,'Fermionic Condensates','One of the most complex composites known to man, fermionic condensates consist of superconductive boson particles all occupying the same quantum state, thus creating a nearly resistance-free environment for electric current. These condensates have therefore become a staple in advanced reactor manufacture.',0,1.3,0,1,NULL,12000.0000,1,499,0),(17322,447,'Thermonuclear Trigger Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1595,0),(17323,447,'Crystalline Carbonide Armor Plate Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1594,0),(17324,447,'Plasma Thruster Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1595,0),(17325,447,'Nanomechanical Microprocessor Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1595,0),(17326,447,'Nuclear Pulse Generator Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1595,0),(17327,447,'Scalar Capacitor Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1593,0),(17328,447,'Titanium Diborite Armor Plate Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1593,0),(17329,447,'Ion Thruster Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1594,0),(17330,447,'Nanoelectrical Microprocessor Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1592,0),(17331,447,'Fusion Reactor Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1594,0),(17332,447,'Graviton Pulse Generator Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1593,0),(17333,447,'Ladar Sensor Cluster Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1595,0),(17334,447,'Tesseract Capacitor Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1592,0),(17335,447,'EM Pulse Generator Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1592,0),(17336,447,'Radar Sensor Cluster Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1592,0),(17337,447,'Oscillator Capacitor Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1594,0),(17338,447,'Antimatter Reactor Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1592,0),(17339,447,'Plasma Pulse Generator Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1594,0),(17340,447,'Gravimetric Sensor Cluster Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1593,0),(17341,447,'Pulse Shield Emitter Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1594,0),(17342,447,'Nuclear Reactor Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1595,0),(17344,447,'Particle Accelerator Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1594,0),(17345,447,'Magnetometric Sensor Cluster Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1594,0),(17346,447,'Deflection Shield Emitter Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1595,0),(17347,447,'Electrolytic Capacitor Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1595,0),(17348,447,'Laser Focusing Crystals Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1592,0),(17349,447,'Fusion Thruster Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1592,0),(17350,447,'Tungsten Carbide Armor Plate Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1592,0),(17351,447,'Quantum Microprocessor Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1593,0),(17352,447,'Sustained Shield Emitter Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1593,0),(17353,447,'Graviton Reactor Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1593,0),(17354,447,'Superconductor Rails Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1593,0),(17355,447,'Fernite Carbide Composite Armor Plate Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1595,0),(17356,447,'Magpulse Thruster Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1593,0),(17357,447,'Photon Microprocessor Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1594,0),(17359,447,'Linear Shield Emitter Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1592,0),(17360,25,'Immovable Enigma','The mysterious Enigma.',1200000,20400,600,1,2,0.0000,0,NULL,0),(17363,448,'Small Audit Log Secure Container','This small audit log container is fitted with a password-protected security lock.',10000,100,120,1,NULL,50000.0000,1,1652,0),(17364,448,'Medium Audit Log Secure Container','This medium audit log container is fitted with a password-protected security lock.',100000,325,390,1,NULL,145000.0000,1,1652,0),(17365,448,'Large Audit Log Secure Container','This large audit log container is fitted with a password-protected security lock.',1000000,650,780,1,NULL,310000.0000,1,1652,0),(17366,448,'Station Container','This is a Station Container. It is fitted with a password-protected security lock and computerized inventory auditing. Although the construction of a Station Container is much like that of other Cargo Containers a Station Container is far too big to fit in a ship\'s cargo hold and is only used for storage and inventory management at stations. ',3000000,2000000,1000000,1,NULL,10000.0000,1,1658,0),(17367,448,'Station Vault Container','This is a Station Vault Container. It is fitted with a password-protected security lock and computerized inventory auditing. Although the construction of a Station Vault Container is much like that of other Cargo Containers a Station Vault Container is far too big to fit in a ship\'s cargo hold and is only used for storage and inventory management at stations. ',6000000,5000000,10000000,1,NULL,100000.0000,1,1658,0),(17368,448,'Station Warehouse Container','This is a Station Warehouse Container. It is fitted with a password-protected security lock and computerized inventory auditing. Although the construction of a Station Warehouse Container is much like that of other Cargo Containers a Station Warehouse Container is far too big to fit in a ship\'s cargo hold and is only used for storage and inventory management at stations. ',18000000,10000000,100000000,1,NULL,1000000.0000,1,1658,0),(17380,319,'Blood Raider Deadspace Tactical Unit','This Blood Raider outpost looks as if it could hold some surprises...',100000,100000000,10000,1,4,0.0000,0,NULL,0),(17381,319,'Sansha Deadspace Outpost I','Containing an inner habitation core surrounded by an outer shell filled with a curious fluid, the purpose of which remains unclear, this outpost is no doubt the brain-child of some nameless True Slave engineer.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17382,319,'Guristas Deadspace Tactical Outpost','This structure was originally built by the Caldari State and was intended to go to Mordu\'s Legion as part of a surplus shipment, but the convoy was intercepted by a Gurista strike force in what has become famously known as the \"Pure Blind Bonanza.\"  Aside from a different coat of paint and an added layer of armor plating, this outpost looks just like its Caldari counterpart.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17388,494,'UNUSED_Gist_Bunker_LCS_ID104_DL5_DCP1','This gigantic suprastructure has been fitted with internal docking bays to receive the guests visiting this pleasure resort. It is a popular chill-out spot for weary smugglers.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17390,494,'Gardan\'s Fantasy Complex',' ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17391,314,'Ulamon\'s Data Chip','Ulamon\'s Data Chip.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17392,1040,'Data Chips','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,6,0,1,NULL,1.0000,1,1336,0),(17393,319,'Bloodsport Arena','To escape the jurisdiction of those who would curb their entertainments, full-contact fight promoters and unlicensed, duel-to-the-death Clash Masters have taken to setting up these deep-space arenas for their brutal games to take place in.  A hive of scum and villainy -- or, alternatively, a wonderland of sport and blood-stained jollity.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17394,319,'Habitation Module - Brothel','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17395,319,'Habitation Module - Residential','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17396,319,'Habitation Module - Narcotics supermarket','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17397,319,'Habitation Module - Casino','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17398,319,'Habitation Module - Pleasure hub','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17399,319,'Habitation Module - Police base','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17400,319,'Habitation Module - Prison','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17401,319,'Habitation Module - Roadhouse','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17402,449,'Large Blaster Battery','Fires a barrage of extra large hybrid slugs at those the Control Tower deems its enemies. Only effective at fairly close ranges, but extremely deadly in terms of sheer damage output. ',100000000,5000,2400,1,NULL,10000000.0000,1,595,0),(17403,449,'Medium Blaster Battery','Fires a barrage of large hybrid slugs at those the Control Tower deems its enemies. Only effective at fairly close ranges, but very deadly in terms of sheer damage output. ',100000000,1000,960,1,8,2000000.0000,1,595,0),(17404,449,'Small Blaster Battery','Fires a barrage of medium hybrid slugs at those the Control Tower deems its enemies. Only effective at fairly close ranges, but deadly in terms of sheer damage output. ',100000000,500,720,1,8,400000.0000,1,595,0),(17406,430,'Large Pulse Laser Battery','Fires a pulsed energy beam using extra large sized frequency crystals at those the Control Tower deems its enemies. Effective at fairly long ranges, tracks moderately fast and has a higher rate of fire than its beam laser counterpart. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,5000,2,1,NULL,10000000.0000,1,596,0),(17407,430,'Medium Pulse Laser Battery','Fires a pulsed energy beam using large sized frequency crystals at those the Control Tower deems its enemies. Effective at fairly long ranges, tracks fast and has a higher rate of fire than its beam laser counterpart. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,1000,4,1,4,2000000.0000,1,596,0),(17408,430,'Small Pulse Laser Battery','Fires a pulsed energy beam using medium sized frequency crystals at those the Control Tower deems its enemies. Effective only at relatively short range, but tracks very fast and has a higher rate of fire than any other laser battery. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,500,6,1,4,400000.0000,1,596,0),(17409,283,'Former Slaves','These former slaves have been cleanched of their Vitoc dependancy.',400,1,0,1,NULL,0.0000,1,NULL,0),(17412,821,'Phi-Operation Protector','This ominous battleship has been modified somewhat. It is at the approximate center of this Deadspace Pocket.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(17413,821,'Captain Rouge','If Angel\'s Red Light District really is the den of carnal pleasures, then this would be the head pimp.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(17422,494,'Angels Retirement Home','This is where elderly Angel Cartel members are supposed to enjoy the last few years of existence. It is popular amongst them to bring with them memorabilia from past conquests and even work on some projects in the quiet and solitude of the Deadspace Complexes.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17423,314,'Gallente 106 Election Holoreel','This holoreel contains most of the advertisements used in the Gallente propoganda machine for each of the candidates vying for the presidency, as well as a detailed biography of each person.',100,0.5,0,1,NULL,0.0000,1,492,0),(17424,314,'Amarrian Wheat','Cereal grasses have been localized on hundreds of worlds. The grains of the wheat plant make a solid foundation for the production of foodstuffs within empire space. Amarrian Wheat is known for its purity, and has reputedly never been tampered with by genetic engineering.',1000,1.15,0,1,NULL,10000.0000,1,492,0),(17425,450,'Crimson Arkonor','While fairly invisible to all but the most experienced miners, there are significant molecular differences between arkonor and its crimson counterpart, so-named because of the blood-red veins running through it.\r\r\n\r\r\nThe rarest and most sought-after ore in the known universe. A sizable nugget of this can sweep anyone from rags to riches in no time. Arkonor has the largest amount of megacyte of any ore, and also contains some mexallon and tritanium.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,2882712.0000,1,512,0),(17426,450,'Prime Arkonor','Prime arkonor is the rarest of the rare; the king of ores. Giving a 10% greater mineral yield than regular arkonor, this is the stuff that makes billionaires out of people lucky enough to stumble upon a vein.\r\r\n\r\r\nThe rarest and most sought-after ore in the known universe. A sizable nugget of this can sweep anyone from rags to riches in no time. Arkonor has the largest amount of megacyte of any ore, and also contains some mexallon and tritanium.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,3019984.0000,1,512,0),(17428,451,'Triclinic Bistot','Bistot with a triclinic crystal system occurs very rarely under natural conditions, but is highly popular with miners due to its extra-high concentrations of the zydrine and megacyte minerals.\r\r\n\r\r\nBistot is a very valuable ore as it holds large portions of two of the rarest minerals in the universe, zydrine and megacyte. It also contains a decent amount of pyerite.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,1929664.0000,1,514,0),(17429,451,'Monoclinic Bistot','Monoclinic bistot is a variant of bistot with a slightly different crystal structure. It is highly sought-after, as it gives a slightly higher yield than its straightforward counterpart.\r\r\n\r\r\nBistot is a very valuable ore as it holds large portions of two of the rarest minerals in the universe, zydrine and megacyte. It also contains a decent amount of pyerite.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,2020480.0000,1,514,0),(17432,452,'Sharp Crokite','In certain belts, environmental conditions will carve sharp, jagged edges into crokite rocks, resulting in the formation of sharp crokite.\r\r\n\r\r\nCrokite is a very heavy ore that is always in high demand because it has the largest ratio of nocxium for any ore in the universe. Valuable deposits of zydrine and tritanium can also be found within this rare ore.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,743492.0000,1,521,0),(17433,452,'Crystalline Crokite','Crystalline crokite is the stuff of legend in 0.0 space. Not only does it give a 10% greater yield than regular crokite, but chunks of the rock glitter beautifully in just the right light, making crystalline crokite popular as raw material for jewelry.\r\r\n\r\r\nCrokite is a very heavy ore that is always in high demand because it has the largest ratio of nocxium for any ore in the universe. Valuable deposits of zydrine and tritanium can also be found within this rare ore.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,779384.0000,1,521,0),(17436,453,'Onyx Ochre','Shiny black nuggets of onyx ochre look very nice and are occasionally used in ornaments. But the great amount of nocxium is what miners are really after. Like in all else, good looks are only an added bonus. \r\r\n\r\r\nConsidered a worthless ore for years, dark ochre was ignored by most miners until improved reprocessing techniques managed to extract the huge amount of isogen inside it. Dark ochre also contains useful amounts of tritanium and nocxium.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,8,0,100,4,300552.0000,1,522,0),(17437,453,'Obsidian Ochre','Obsidian ochre, the most valuable member of the dark ochre family, was only first discovered a decade ago. The sleek black surface of this ore managed to absorb scanning waves, making obsidian ochre asteroids almost invisible. Advances in scanning technology revealed these beauties at last.\r\r\n\r\r\nConsidered a worthless ore for years, dark ochre was ignored by most miners until improved reprocessing techniques managed to extract the huge amount of isogen inside it. Dark ochre also contains useful amounts of tritanium and nocxium.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,8,0,100,4,314864.0000,1,522,0),(17440,454,'Vitric Hedbergite','When asteroids containing hedbergite pass close to suns or other sources of intense heat can cause the hedbergite to glassify. The result is called vitric hedbergite and has 5% better yield than normal hedbergite. \r\r\n\r\r\nHedbergite is sought after for its high concentration of nocxium and isogen. However hedbergite also yields some  pyerite and zydrine.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF4D00\'>0.2</color> security status solar systems or lower.',1e35,3,0,100,4,130000.0000,1,527,0),(17441,454,'Glazed Hedbergite','Asteroids containing this shiny ore were formed in intense heat, such as might result from a supernova. The result, known as glazed hedbergite, is a more concentrated form of hedbergite that has 10% higher yield.\r\r\n\r\r\nHedbergite is sought after for its high concentration of nocxium and isogen. However hedbergite also yields some  pyerite and zydrine.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF4D00\'>0.2</color> security status solar systems or lower.',1e35,3,0,100,4,136288.0000,1,527,0),(17444,455,'Vivid Hemorphite','Hemorphite exists in many different color variations. Interestingly, the more colorful it becomes, the better yield it has. Vivid hemorphite has 5% better yield than its more bland brother.\r\r\n\r\r\nWith a large portion of nocxium, hemorphite is always a good find. It is common enough that even novice miners can expect to run into it. Hemorphite also has a bit of tritanium, isogen and zydrine.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF4D00\'>0.2</color> security status solar systems or lower.',1e35,3,0,100,4,115340.0000,1,528,0),(17445,455,'Radiant Hemorphite','Hemorphite exists in many different color variations. Interestingly, the more colorful it becomes, the better yield it has. Radiant hemorphite has 10% better yield than its more bland brother.\r\r\n\r\r\nWith a large portion of nocxium, hemorphite is always a good find. It is common enough that even novice miners can expect to run into it. Hemorphite also has a bit of tritanium, isogen and zydrine.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF4D00\'>0.2</color> security status solar systems or lower.',1e35,3,0,100,4,121320.0000,1,528,0),(17448,456,'Pure Jaspet','Pure Jaspet is popular amongst corporate miners who are looking for various minerals for manufacturing, rather than mining purely for profit.\r\r\n\r\r\nJaspet has three valuable mineral types, making it easy to sell. It has a large portion of mexallon plus some nocxium and zydrine.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFE58000\'>0.4</color> security status solar systems or lower.',1e35,2,0,100,4,68608.0000,1,529,0),(17449,456,'Pristine Jaspet','Pristine Jaspet is very rare, which is not so surprising when one considers that it is formed when asteroids collide with comets or ice moons. It has 10% better yield than normal Jaspet.\r\r\n\r\r\nJaspet has three valuable mineral types, making it easy to sell. It has a large portion of mexallon plus some nocxium and zydrine.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFE58000\'>0.4</color> security status solar systems or lower.',1e35,2,0,100,4,73248.0000,1,529,0),(17452,457,'Luminous Kernite','Prophets tell of the mystical nature endowed in luminous kernite. To the rest of us, it\'s an average looking ore that has 5% more yield than normal kernite and can make you rich if you mine it 24/7 and live to be very old.\r\r\n\r\r\nKernite is a fairly common ore type that yields a large amount of mexallon. Besides mexallon the kernite also has a bit of tritanium and isogen.\r\r\n\r\r\nAvailable in <color=\'0xFF00FF00\'>0.7</color> security status solar systems or lower.',1e35,1.2,0,100,NULL,27322.0000,1,523,0),(17453,457,'Fiery Kernite','Known as Rage Stone to veteran miners after a discovery of a particularly rich vein of it caused a bar brawl of epic proportions in the Intaki Syndicate. It has a 10% higher yield than basic kernite.\r\r\n\r\r\nKernite is a fairly common ore type that yields a large amount of mexallon. Besides mexallon the kernite also has a bit of tritanium and isogen.\r\r\n\r\r\nAvailable in <color=\'0xFF00FF00\'>0.7</color> security status solar systems or lower.',1e35,1.2,0,100,NULL,28648.0000,1,523,0),(17455,458,'Azure Plagioclase','Azure plagioclase was made infamous in the melancholic song prose Miner Blues by the Gallentean folk singer Jaroud Dertier three decades ago.\r\r\n\r\r\nPlagioclase is not amongst the most valuable ore types around, but it contains a large amount of pyerite and is thus always in constant demand. It also yields some tritanium and mexallon.\r\r\n\r\r\nAvailable in <color=\'0xFF4DFFCC\'>0.9</color> security status solar systems or lower.',1e35,0.35,0,100,NULL,5634.0000,1,516,0),(17456,458,'Rich Plagioclase','With rich plagioclase, having 10% better yield than the normal one, miners can finally regard plagioclase as a mineral that provides a noteworthy profit.\r\r\n\r\r\nPlagioclase is not amongst the most valuable ore types around, but it contains a large amount of pyerite and is thus always in constant demand. It also yields some tritanium and mexallon.\r\r\n\r\r\nAvailable in <color=\'0xFF4DFFCC\'>0.9</color> security status solar systems or lower.',1e35,0.35,0,100,NULL,5892.0000,1,516,0),(17459,459,'Solid Pyroxeres','Solid Pyroxeres, sometimes called the Flame of Dam\'Torsad, is a relative of normal Pyroxeres. The Flame has 5% higher yield than its more common cousin. \r\r\n\r\r\nPyroxeres is an interesting ore type, as it is very plain in most respects except one - deep core reprocessing yields a little bit of nocxium, increasing its value considerably. It also has a large portion of tritanium and some pyerite and mexallon.\r\r\n\r\r\nAvailable in <color=\'0xFF4DFFCC\'>0.9</color> security status solar systems or lower.',1e35,0.3,0,100,NULL,5202.0000,1,515,0),(17460,459,'Viscous Pyroxeres','Viscous Pyroxeres is the secret behind the success of ORE in the early days. ORE has since then moved into more profitable minerals, but Viscous Pyroxeres still holds a special place in the hearts of all miners dreaming of becoming the next mining moguls of EVE.\r\r\n\r\r\nPyroxeres is an interesting ore type, as it is very plain in most respects except one - deep core reprocessing yields a little bit of nocxium, increasing its value considerably. It also has a large portion of tritanium and some pyerite and mexallon.\r\r\n\r\r\nAvailable in <color=\'0xFF4DFFCC\'>0.9</color> security status solar systems or lower.',1e35,0.3,0,100,NULL,5310.0000,1,515,0),(17463,460,'Condensed Scordite','Condensed Scordite is a close cousin of normal Scordite, but with 5% better yield. The increase may seem insignificant, but matters greatly to new miners where every ISK counts.\r\r\n\r\r\nScordite is amongst the most common ore types in the known universe. It has a large portion of tritanium plus a fair bit of pyerite. Good choice for those starting their mining careers.\r\r\n\r\r\nAvailable in <color=\'0xFF33FFFF\'>1.0</color> security status solar systems or lower.',1e35,0.15,0,100,NULL,2184.0000,1,519,0),(17464,460,'Massive Scordite','Massive Scordite was the stuff of legend in the early days of space exploration. Though it has long since been taken over in value by other ores it still has a special place in the hearts of veteran miners.\r\r\n\r\r\nScordite is amongst the most common ore types in the known universe. It has a large portion of tritanium plus a fair bit of pyerite. Good choice for those starting their mining careers.\r\r\n\r\r\nAvailable in <color=\'0xFF33FFFF\'>1.0</color> security status solar systems or lower.',1e35,0.15,0,100,NULL,2282.0000,1,519,0),(17466,461,'Bright Spodumain','Spodumain is occasionally found with crystalline traces in its outer surface. Known as bright spodumain, the crystal adds considerable value to an already valuable mineral.  \r\r\n\r\r\nSpodumain is amongst the most desirable ore types around, as it contains high volumes of the four most heavily demanded minerals. Huge volumes of tritanium and pyerite, as well as moderate amounts of mexallon and isogen can be obtained by refining these rocks.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,349928.0000,1,517,0),(17467,461,'Gleaming Spodumain','Once in a while Spodumain is found with crystalline veins running through it. The 10% increased value this yields puts a gleam in the eye of any miner lucky enough to find it.\r\r\n\r\r\nSpodumain is amongst the most desirable ore types around, as it contains high volumes of the four most heavily demanded minerals. Huge volumes of tritanium and pyerite, as well as moderate amounts of mexallon and isogen can be obtained by refining these rocks.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,16,0,100,4,366520.0000,1,517,0),(17470,462,'Concentrated Veldspar','Clusters of veldspar, called concentrated veldspar, are sometimes found in areas where normal veldspar is already in abundance.\r\r\n\r\r\nThe most common ore type in the known universe, veldspar can be found almost everywhere. It is still in constant demand as it holds a large portion of the much-used tritanium mineral.\r\r\n\r\r\nAvailable in <color=\'0xFF33FFFF\'>1.0</color> security status solar systems or lower.',4000,0.1,0,100,NULL,872.0000,1,518,0),(17471,462,'Dense Veldspar','In asteroids above average size, the intense pressure can weld normal veldspar into what is known as dense veldspar, increasing the yield by 10%. \r\r\n\r\r\nThe most common ore type in the known universe, veldspar can be found almost everywhere. It is still in constant demand as it holds a large portion of the much-used tritanium mineral.\r\r\n\r\r\nAvailable in <color=\'0xFF33FFFF\'>1.0</color> security status solar systems or lower.',4000,0.1,0,100,NULL,914.0000,1,518,0),(17475,282,'Radioactive Waste','This radioactively contaminated material is normally recycled or processed into fuel.  It can be highly dangerous to any lifeforms that come into contact with it.',2000,1,0,1,NULL,0.0000,1,NULL,0),(17476,463,'Covetor','The mining barge was designed by <a href=showinfo:30//500014>ORE</a> to facilitate advancing the mining profession to a new level. Each barge was created to excel at a specific function, the Covetor\'s being mining yield and mining laser range. This additional yield comes at a price, as the Covetor has weaker defenses and a smaller ore bay than the other mining barges.\r\r\nMining barges are equipped with electronic subsystems specifically designed to accommodate Strip Mining and Ice Harvesting modules.',30000000,200000,350,1,128,29881812.0000,1,494,0),(17477,477,'Covetor Blueprint',' ',0,0.01,0,1,NULL,2000000000.0000,1,497,0),(17478,463,'Retriever','The mining barge was designed by <a href=showinfo:30//500014>ORE</a> to facilitate advancing the mining profession to a new level. Each barge was created to excel at a specific function, the Retriever\'s being storage. A massive ore hold allows the Retriever to operate for extended periods without requiring as much support as other barges.\r\r\nMining barges are equipped with electronic subsystems specifically designed to accommodate Strip Mining and Ice Harvesting modules.',20000000,150000,450,1,128,25397674.0000,1,494,0),(17479,477,'Retriever Blueprint',' ',0,0.01,0,1,NULL,1700000000.0000,1,497,0),(17480,463,'Procurer','The mining barge was designed by <a href=showinfo:30//500014>ORE</a> to facilitate advancing the mining profession to a whole new level. Each barge was created to excel at a specific function, the Procurer\'s being durability and self-defense. With that in mind, the designers could only make space to fit one mining or ice harvesting module. To mitigate the effect this would have on the ship\'s mining output, they came up with a unique loading system that allows this one module to work with vastly increased efficiency.\r\r\nMining barges are equipped with electronic subsystems specifically designed to accommodate Strip Mining and Ice Harvesting modules.',10000000,100000,350,1,128,20916992.0000,1,494,0),(17481,477,'Procurer Blueprint',' ',0,0.01,0,1,NULL,1400000000.0000,1,497,0),(17482,464,'Strip Miner I','A bulk ore extractor designed for use on Mining Barges and Exhumers.',0,25,0,1,NULL,5469262.0000,1,1040,0),(17483,490,'Strip Miner I Blueprint',' ',0,0.01,0,1,NULL,16130080.0000,1,338,0),(17484,511,'Republic Fleet Rapid Light Missile Launcher','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.315,1,2,4224.0000,1,641,0),(17485,506,'Republic Fleet Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.35,1,NULL,204004.0000,1,643,0),(17486,136,'Republic Fleet Cruise Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17487,510,'Republic Fleet Heavy Missile Launcher','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,1.23,1,2,14996.0000,1,642,0),(17488,507,'Republic Fleet Rocket Launcher','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.2531,1,NULL,3336.0000,1,639,0),(17489,136,'Republic Fleet Rocket Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17490,508,'Republic Fleet Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2,1,2,20580.0000,1,644,0),(17491,509,'Republic Fleet Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.9,1,2,3000.0000,1,640,0),(17492,62,'Republic Fleet Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(17493,62,'Republic Fleet Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,4,19916.0000,1,1050,0),(17494,62,'Republic Fleet Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,4,9996.0000,1,1049,0),(17495,77,'Caldari Navy Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,2,5808.0000,1,1693,0),(17496,77,'Caldari Navy Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,1,45412.0000,1,1694,0),(17497,77,'Caldari Navy Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,8,45412.0000,1,1692,0),(17498,77,'Caldari Navy Adaptive Invulnerability Field','Boosts shield resistance against all damage types. <br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,1,63062.0000,1,1696,0),(17499,77,'Caldari Navy EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,4,45412.0000,1,1695,0),(17500,65,'Caldari Navy Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,24988.0000,1,683,0),(17501,145,'Caldari Navy Stasis Webifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17502,328,'Ammatar Navy Armor EM Hardener','An enhanced version of the standard em armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,225690.0000,1,1681,0),(17503,348,'Ammatar Navy Armor EM Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17504,328,'Ammatar Navy Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,397768.0000,1,1680,0),(17505,348,'Ammatar Navy Armor Explosive Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17506,328,'Ammatar Navy Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,340756.0000,1,1679,0),(17507,348,'Ammatar Navy Armor Kinetic Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17508,328,'Ammatar Navy Armor Thermic Hardener','An enhanced version of the standard Thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,277634.0000,1,1678,0),(17509,348,'Ammatar Navy Armor Thermic Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17510,767,'Ammatar Navy Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,10656.0000,1,667,0),(17511,137,'Ammatar Navy Capacitor Power Relay Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17512,98,'Ammatar Navy Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1666,0),(17513,163,'Ammatar Navy Kinetic Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17514,98,'Ammatar Navy Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,8304.0000,1,1670,0),(17515,163,'Ammatar Navy Adaptive Nano Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17516,98,'Ammatar Navy Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1667,0),(17517,163,'Ammatar Navy Explosive Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17518,98,'Ammatar Navy EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1668,0),(17519,163,'Ammatar Navy EM Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17520,212,'Federation Navy Sensor Booster','Gives an increase to targeting range and scan resolution. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,10940.0000,1,671,0),(17521,223,'Federation Navy Sensor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17522,769,'Ammatar Navy Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,10976.0000,1,659,0),(17523,137,'Ammatar Navy Reactor Control Unit Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17524,766,'Ammatar Navy Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,14544.0000,1,658,0),(17525,137,'Ammatar Navy Power Diagnostic System Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17526,43,'Imperial Navy Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,33662.0000,1,665,0),(17527,123,'Imperial Navy Cap Recharger Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17528,767,'Imperial Navy Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,10656.0000,1,667,0),(17529,137,'Imperial Navy Capacitor Power Relay Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17536,326,'Ammatar Navy Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,120202.0000,1,1686,0),(17537,163,'Ammatar Navy Energized Adaptive Nano Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17538,326,'Ammatar Navy Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1685,0),(17539,163,'Ammatar Navy Energized Kinetic Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17540,326,'Ammatar Navy Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1682,0),(17541,163,'Ammatar Navy Energized Explosive Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17542,326,'Ammatar Navy Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1684,0),(17543,163,'Ammatar Navy Energized EM Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17544,326,'Ammatar Navy Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1683,0),(17545,163,'Ammatar Navy Energized Thermic Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17546,62,'Imperial Navy Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(17547,62,'Imperial Navy Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,4,19916.0000,1,1050,0),(17548,62,'Imperial Navy Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,4,9996.0000,1,1049,0),(17549,98,'Federation Navy Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,8304.0000,1,1670,0),(17550,163,'Federation Navy Adaptive Nano Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17551,98,'Federation Navy Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1666,0),(17552,163,'Federation Navy Kinetic Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17553,98,'Federation Navy Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1667,0),(17554,163,'Federation Navy Explosive Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17555,98,'Federation Navy EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1668,0),(17556,163,'Federation Navy EM Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17557,98,'Federation Navy Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1665,0),(17558,163,'Federation Navy Thermic Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17559,65,'Federation Navy Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,24988.0000,1,683,0),(17561,145,'Federation Navy Stasis Webifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17563,494,'UNUSED_CargoRig_LCS_DL1_DCP1','This gigantic suprastructure is one of the military installations of the Angel pirate corporation. Even for it\'s size it has no commercial station services or docking bay to receive guests.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17565,470,'Unanchoring Drone','A drone that can be used to destabilize structures that are anchored in place.  They are not good for much else but are pretty versatile at what they do.',37500,500,0,1,NULL,14986.0000,0,NULL,0),(17568,383,'Serpentis Point Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17569,383,'Serpentis Light Missile Battery','This light missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17570,383,'Serpentis Heavy Missile Battery','This heavy missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17571,383,'Serpentis Cruise Missile Battery','This cruise missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17572,383,'Angel Point Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17573,383,'Angel Light Missile Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17574,383,'Angel Heavy Missile Battery','This heavy missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17575,383,'Angel Cruise Missile Battery','This cruise missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17576,383,'Minmatar Point Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17577,383,'Minmatar Light Missile Battery','This light missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17578,383,'Minmatar Heavy Missile Battery','This heavy missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17579,383,'Minmatar Cruise Missile Battery','This cruise missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17580,383,'Sansha Point Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17581,383,'Sansha Light Missile Battery','This light missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17582,383,'Sansha Heavy Missile Battery','This heavy missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17583,383,'Sansha Cruise Missile Battery','This cruise missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17584,383,'Gallente Point Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17585,383,'Gallente Light Missile Battery','This light missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17586,383,'Gallente Heavy Missile Battery','This heavy missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17587,383,'Gallente Cruise Missile Battery','This cruise missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17588,383,'Amarr Point Defense Battery','This Light missile Sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17589,383,'Amarr Light Missile Battery','This Light missile Sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17590,383,'Amarr Heavy Missile Battery','This heavy missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17591,383,'Amarr Cruise Missile Battery','This cruise missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17592,383,'Blood Point Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17593,383,'Blood Light Missile Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17594,383,'Blood Heavy Missile Battery','This heavy missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17595,383,'Blood Cruise Missile Battery','This cruise missile sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17596,383,'Guristas Point Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17597,383,'Guristas Light Missile Battery','This light missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17598,383,'Guristas Heavy Missile Battery','This heavy missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17599,383,'Guristas Cruise Missile Batteries','This cruise missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17600,383,'Caldari Point Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17601,383,'Caldari Light Missile Battery','This light missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17602,383,'Caldari Heavy Missile Battery','This heavy missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17603,383,'Caldari Cruise Missile Battery','This cruise missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17605,383,'Angel Stasis Tower','Angel stasis web sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17606,383,'Minmatar Stasis Tower','Minmatar stasis web sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17607,383,'Sansha Stasis Tower','Sansha stasis web sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17608,383,'Gallente Stasis Tower','Gallente stasis web sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17609,383,'Amarr Stasis Tower','Amarr stasis web sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17610,383,'Blood Stasis Tower','Blood Raider stasis web sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17611,383,'Guristas Stasis Tower','Guristas stasis web sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17612,383,'Caldari Stasis Tower','Caldari stasis web sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17613,494,'Inner Sanctum','This structure houses the senior members of the Zatah corpus blood raider sect.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17614,494,'Thorak\'s Biodome Garden','This biodome is used for cultivation of plants and animals alike. Minmatar corporations have contracted the operation to the Angel Cartel and there is a healthy profit to be made from the luxury foods manufactured here. The prime buyers are the newly rich.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(17615,820,'Corpus Crimson Commander','Commands and directions emanate from this vessel as if the person at the helm owns the place. Perhaps he does...',11800000,118000,235,1,4,0.0000,0,NULL,0),(17616,820,'Mul-Zatath Gatekeeper','DED\'s scout report database has this vessel simply listed as \"The Top Dog\".',11800000,118000,235,1,4,0.0000,0,NULL,0),(17617,353,'QA Speed Limiter Module','This module does not exist.',50,1,0,1,NULL,24998.0000,0,NULL,0),(17619,25,'Caldari Navy Hookbill','Long struggling with a reputation for being the ugly duckling of the Caldari ship repertoire, the Hookbill recently got a new lease on life, being upgraded from a routine patrol vessel into a fleet-standard frigate. With the advancements brought on by the upgrade, the time is nigh for this little slugger to prove itself on battlefields throughout Caldari space and beyond.',1081000,16500,140,1,1,362790.0000,1,1366,0),(17620,105,'Caldari Navy Hookbill Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17621,471,'Corporate Hangar Array','A large hangar structure with divisional compartments, for easy separation and storage of materials and modules.',10000000,4000,3000000,1,NULL,10000000.0000,1,506,0),(17622,818,'Jenmai Hirokan','This is the infamous Angel Cartel pilot Jenmai.  Born a Caldari citizen, Jenmai was quickly taken and raised by the Guristas after his birth.  Many years later, after learning about his true past, he defected to the Angel Cartel, serving them quite well for the past decade.  Few can claim to rival Jenmais skills as a fighter pilot.',1650000,16500,235,1,1,0.0000,0,NULL,0),(17623,370,'Jenmei\'s Tag','Jenmei\'s Tag.',1,0.1,0,1,NULL,0.0000,1,750,0),(17624,314,'Elena Gazky\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis is a DNA sample taken from a member of the infamous pirate gang \'The Seven\'.\r\r\n',1,0.1,0,1,NULL,0.0000,1,752,0),(17625,818,'Imai Kenon','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(17626,319,'Stationary Bestower','This Bestower-class industrial is currently undergoing maintenance.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(17627,319,'Stationary Mammoth','This Mammoth-class industrial is currently undergoing maintenance.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(17628,319,'Stationary Iteron V','This Iteron V-class industrial is currently undergoing maintenance.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(17629,319,'Stationary Tayra','This Tayra-class industrial is currently undergoing maintenance.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(17630,370,'Imai Kenon\'s Tag','Imai Kenon\'s Tag.',1,0.1,0,1,NULL,0.0000,1,750,0),(17631,494,'Deadspace Synchronization HQ','These habitats house offices and processing utilities for the asteroid mining facility.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17632,494,'CreoCorp Main Factory','This is where small parts are built to be used in all kinds of spaceships further down the production line.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17633,494,'UNUSED_HabMod_Residential_LCS','This is a luxury version of the CreoDron Habitation Module for miners and deep space explorers. It is packed with hard working prospectors.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17634,26,'Caracal Navy Issue','Created specifically in order to counter the ever-increasing numbers of pirate invaders in Caldari territories, the Navy Issue Caracal has performed admirably in its task.  Sporting added defensive capability as well as increased fitting potential, it is seeing ever greater use in defense of the homeland.',9600000,101000,450,1,1,12103580.0000,1,1370,0),(17635,106,'Caracal Navy Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17636,27,'Raven Navy Issue','The Navy Issue Raven represents the best the Caldari have to offer on the battlefield: an all-out assault vessel with tremendous electronic warfare capabilities.  Commissioned by Caldari Navy Special Operations Command in YC 104 in response to a campaign of coordinated Gurista attacks which threatened to decimate the populations of several planets in the Obe system, this hefty warship has since proven its worth many times over.',97300000,486000,625,1,1,198117134.0000,1,1379,0),(17637,107,'Raven Navy Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17638,383,'Sentinel Bloodraider','This Blood Raider Station has been refitted with huge citadel torpedo batteries and a long range stasis web generators  ',1000,1000,1000,1,4,0.0000,0,NULL,0),(17639,409,'Taisu Magdesh\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,0.0000,1,NULL,0),(17640,314,'Mordur\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.',1,0.1,0,1,NULL,0.0000,1,752,0),(17641,594,'Arch Angel Raelek','This is the Commander of the top Angel Cartel outpost in the Caldari State territories.  He virtually controls all Cartel activities inside the State. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(17642,370,'Raelek\'s Tag','This diamond tag carries the rank insignia equivalent of a captain within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17643,314,'Caldari AZ-1 Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Kaalakiota scientists for the Caldari Navy, made to be of better quality than what is available on the open market. \r\r\n\r\r\n\r\r\nThe AZ-1 chip is designed for battleship class vessels.',1,0.1,0,1,NULL,8000000.0000,1,738,0),(17644,319,'Asteroid Deadspace Mining Post','Where geographical conditions allow, outposts such as this one are a good way of increasing the effectiveness of deep-space mining operations.',0,1,0,1,NULL,0.0000,0,NULL,0),(17645,494,'Deadspace Control Station','Bases such as this one are commonly used as on-site mining posts or colonies. They are often obscurely located and vulnerable as well and therefore it is common that pirates make their homes in them, sometimes with the resident\'s full consent. This one looks unusually exposed and vulnerable due to what appear to be major renovations.',0,1,0,1,NULL,0.0000,0,NULL,0),(17646,314,'Caldari CU-1 Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Kaalakiota scientists for the Caldari Navy, made to be of better quality than what is available on the open market. \r\r\n  \r\r\n\r\r\nThe CU-1 chip is designed for cruiser class vessels.',1,0.1,0,1,NULL,2000000.0000,1,738,0),(17647,314,'Caldari BY-1 Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Kaalakiota scientists for the Caldari Navy, made to be of better quality than what is available on the open market. \r\r\n \r\r\n\r\r\nThe BY-1 chip is designed for frigate class vessels.',1,0.1,0,1,NULL,500000.0000,1,738,0),(17648,85,'Antimatter Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nConsists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.5,0.125,0,100,NULL,111132.0000,1,504,0),(17649,167,'Antimatter Charge XL Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,598,0),(17650,85,'Iridium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nConsists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.5,0.125,0,100,NULL,44446.0000,1,504,0),(17651,167,'Iridium Charge XL Blueprint',' ',0,0.01,0,1,NULL,4000000.0000,1,598,0),(17652,85,'Iron Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nConsists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.5,0.125,0,100,NULL,22210.0000,1,504,0),(17653,167,'Iron Charge XL Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,598,0),(17654,85,'Lead Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nConsists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.5,0.125,0,100,NULL,55556.0000,1,504,0),(17655,167,'Lead Charge XL Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,598,0),(17656,85,'Plutonium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nConsists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.5,0.125,0,100,NULL,88850.0000,1,504,0),(17657,167,'Plutonium Charge XL Blueprint',' ',0,0.01,0,1,NULL,8000000.0000,1,598,0),(17658,85,'Thorium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nConsists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.5,0.125,0,100,NULL,66656.0000,1,504,0),(17659,167,'Thorium Charge XL Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,1,598,0),(17660,85,'Tungsten Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nConsists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.5,0.125,0,100,NULL,33184.0000,1,504,0),(17661,167,'Tungsten Charge XL Blueprint',' ',0,0.01,0,1,NULL,3000000.0000,1,598,0),(17662,85,'Uranium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nConsists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.5,0.125,0,100,NULL,77776.0000,1,504,0),(17663,167,'Uranium Charge XL Blueprint',' ',0,0.01,0,1,NULL,7000000.0000,1,598,0),(17664,83,'Carbonized Lead XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,22210.0000,1,502,0),(17665,165,'Carbonized Lead XL Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,597,0),(17666,83,'Depleted Uranium XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.125,0,100,NULL,55556.0000,1,502,0),(17667,165,'Depleted Uranium XL Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,597,0),(17668,83,'EMP XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,111132.0000,1,502,0),(17669,165,'EMP XL Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,597,0),(17670,83,'Fusion XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,77776.0000,1,502,0),(17671,165,'Fusion XL Blueprint',' ',0,0.01,0,1,NULL,7000000.0000,1,597,0),(17672,83,'Nuclear XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts.  Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,33184.0000,1,502,0),(17673,165,'Nuclear XL Blueprint',' ',0,0.01,0,1,NULL,3000000.0000,1,597,0),(17674,83,'Phased Plasma XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,88850.0000,1,502,0),(17675,165,'Phased Plasma XL Blueprint',' ',0,0.01,0,1,NULL,8000000.0000,1,597,0),(17676,83,'Proton XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,44446.0000,1,502,0),(17677,165,'Proton XL Blueprint',' ',0,0.01,0,1,NULL,4000000.0000,1,597,0),(17678,83,'Titanium Sabot XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation flechettes that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.125,0,100,NULL,66656.0000,1,502,0),(17679,165,'Titanium Sabot XL Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,1,597,0),(17680,86,'Gamma XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased damage.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3885880.0000,1,503,0),(17681,168,'Gamma XL Blueprint',' ',0,0.01,0,1,NULL,35000000.0000,1,599,0),(17682,86,'Infrared XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the infrared frequencies. Slightly improved range.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1108552.0000,1,503,0),(17683,168,'Infrared XL Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,599,0),(17684,86,'Microwave XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the microwave frequencies. Improved range. \r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2218720.0000,1,503,0),(17685,168,'Microwave XL Blueprint',' ',0,0.01,0,1,NULL,20000000.0000,1,599,0),(17686,86,'Multifrequency XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nRandomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4443296.0000,1,503,0),(17687,168,'Multifrequency XL Blueprint',' ',0,0.01,0,1,NULL,40000000.0000,1,599,0),(17688,86,'Radio XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3336522.0000,1,503,0),(17689,168,'Radio XL Blueprint',' ',0,0.01,0,1,NULL,30000000.0000,1,599,0),(17690,86,'Standard XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the visible light spectrum. \r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1391864.0000,1,503,0),(17691,168,'Standard XL Blueprint',' ',0,0.01,0,1,NULL,12500000.0000,1,599,0),(17692,86,'Ultraviolet XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased damage.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1666464.0000,1,503,0),(17693,168,'Ultraviolet XL Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,599,0),(17694,86,'Xray XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased damage.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2779152.0000,1,503,0),(17695,168,'Xray XL Blueprint',' ',0,0.01,0,1,NULL,25000000.0000,1,599,0),(17696,472,'Old System Scanner','Trash me if you find me.',0,5,0,1,NULL,0.0000,0,NULL,0),(17701,473,'Tracking Array','Boosts turret sentries\' optimal range and tracking speed.',100000000,4000,0,1,NULL,5000000.0000,1,NULL,0),(17703,25,'Imperial Navy Slicer','The Slicer is the Imperial Navy\'s pride and joy, and one of its biggest weapons in the continual fight against Matari insurgents.  Boasting tremendous range and versatility in equipment fittings, a great deal of armor strength and a powerful capacitor, the skilled Slicer pilot is able to take out most frigates with ease.',1003000,16500,130,1,4,344106.0000,1,1366,0),(17704,105,'Imperial Navy Slicer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17705,25,'Khanid Navy Frigate','Navy Frig.',1450000,16500,130,1,1,334766.0000,0,NULL,0),(17706,105,'Khanid Navy Frigate Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(17707,25,'Mordus Frigate','Navy Frig.',1450000,16500,130,1,1,334766.0000,0,NULL,0),(17708,105,'Mordus Frigate Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(17709,26,'Omen Navy Issue','The Omen Navy Issue was originally conceived as a multipurpose search and rescue vessel with strong combat capabilities. In response to the increasing need for ships capable of countering frigate swarms, its designers additionally included a drone bay intended to give the ship a greater range of options when faced with mixed enemy squadrons. The end result is a somewhat more flexible offering than Amarr design philosophy generally dictates, but don\'t be fooled: this crusher still packs all the punch one would expect from a ship of the golden fleet.',10850000,101000,400,1,4,11316814.0000,1,1370,0),(17710,106,'Omen Navy Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17713,26,'Stabber Fleet Issue','Responding to voices stating that the Stabber needed an upgrade to be viable as a fleet vessel of military standards, the Republic Fleet commissioned the creation of the Fleet Issue Stabber; a slower, hardier version of the original that packs quite a bit more firepower.  Being as new as it is on the battlefield, the Fleet Issue Stabber hasn\'t seen many large engagements yet, but its engineers as well as Fleet command are very optimistic about its performance.',10810000,101000,450,1,2,12058220.0000,1,1370,0),(17714,106,'Stabber Fleet Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17715,26,'Gila','Taking what he had learned from his days in the Caldari Navy, Korako  The Rabbit\' Kosakami, Gurista leader, decided that he would rub salt in the State\'s wounds by souping up their designs and making strikes against his former masters in ships whose layout was obviously stolen from them.  To this end the Gila, bastard twin of the Moa, has served him well.',9600000,101000,440,1,1,11579728.0000,1,1371,0),(17716,106,'Gila Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17718,26,'Phantasm','As with other Sansha ships, not much is known about the origin of this design.  Its form -- while harshly alien in shape -- bears the mark of extremely advanced physics research, lines and corners coalescing to form a shape whose resilience and structural integrity are hard to match.  Coupled with advanced hardpoint technology and an extremely efficient powercore, the Phantasm\'s legendary status is well-deserved.\r\r\n',9600000,101000,410,1,4,11579728.0000,1,1371,0),(17719,106,'Phantasm Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17720,26,'Cynabal','The Cynabal was one of the earliest designs put forth by the Angel Cartel, and to this day it remains their most-used.  The ship\'s origins are unknown, but as with most Cartel ships persistent rumors of Jovian influence continue to linger.  Whether these tales have basis in reality or not, the facts are on the table: the Cynabal is one of the fastest, most powerful cruisers to be found anywhere.',9047000,101000,400,1,2,11579728.0000,1,1371,0),(17721,106,'Cynabal Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17722,26,'Vigilant','The Vigilant was the first Gallente design the Guardian Angels would steal and make their own, but it wouldn\'t be the last.  Building on the Thorax\'s natural strengths, it is a deadly vessel both by itself and in fleet tandem.  A group of these sluggers is a sight to fear.',9830000,101000,450,1,8,11579728.0000,1,1371,0),(17723,106,'Vigilant Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17726,27,'Apocalypse Navy Issue','The Empire\'s inner circle of armaments manufacturers has long been proud of the expert methods utilized to harden the Navy Issue Apocalypse\'s armor plating and structural framework to such an amazing degree.  Its shield systems are also state-of-the-art, rivalling even Caldari Prime\'s best.  Fearsome by reputation, this is the flagship vessel of the Imperial Navy\'s elite wing.  Not many are unfortunate enough to have ever actually met one on the field of battle, and those who do usually do not live to tell the tale. ',97100000,495000,625,1,4,191326268.0000,1,1379,0),(17727,107,'Apocalypse Navy Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17728,27,'Megathron Navy Issue','The powerful Navy Megathron has seen the end of many a threat to the Federation\'s security, and it\'s only getting better.  Recent improvements in the original design have paved the way for its use in a wider field of tactical operations than originally intended, making it one of the most useful war vessels to be found anywhere.',98400000,486000,650,1,8,196998872.0000,1,1379,0),(17729,107,'Megathron Navy Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17732,27,'Tempest Fleet Issue','The Fleet Tempest originally came into being as a variant licensed by the Fleet to Core Complexion Inc., who intended to improve on the existing design with their now-famous emphasis on strong defensive capability. The designer, one Enoksur Steidentet, performed so well in this task that the Fleet promptly bought all rights to the design back from him for undisclosed billions, catapulting his small production and design corp into the major leagues.  ',103300000,486000,650,1,2,195872044.0000,1,1379,0),(17733,107,'Tempest Fleet Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17736,27,'Nightmare','When this terror was first seen haunting the spacelanes, rumors abounded about its design, which bore the indelible stamp of Sansha Kuvakei\'s unique madness. Who else, the conspiracy theorists argued, could come up with such marvelously twisted designs?\r\r\n\r\r\nThese and other theories were all but confirmed during the Sansha invasions of YC 111-112, as endless swarms of Nightmare fleets descended upon planet dweller and capsuleer alike, eager to serve their returned master Sansha Kuvakei once again. ',99300000,486000,665,1,4,157405934.0000,1,1380,0),(17737,107,'Nightmare Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17738,27,'Machariel','While its utilitarian look may not give much of an indication, many are convinced that the Machariel is based on an ancient Jovian design uncovered by the Angel Cartel in one of their extensive exploratory raids into uncharted territory some years ago.  Whatever the case may be, this behemoth appeared on the scene suddenly and with little fanfare, and has very quickly become one of the Arch Angels\' staple war vessels.\r\r\n',94680000,595000,665,1,2,157405934.0000,1,1380,0),(17739,107,'Machariel Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17740,27,'Vindicator','Basing their design on the Federation Navy\'s much-vaunted Megathron, the Guardian Angels\' engineers set out to create a battleship that would instill fear in anyone fool enough to square off against the Cartel or its Serpentis protectorate.  Based on the reputation this ship has engendered, they seem to have succeeded admirably.',105200000,486000,665,1,8,157405934.0000,1,1380,0),(17741,107,'Vindicator Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17742,818,'Uleen Bloodsworn','This is a fighter for the Blood Raiders. She is protecting the assets of the Blood Raiders and may attack anyone she perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(17743,370,'Uleen Bloodsworn\'s Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17744,821,'Purple Particle Research Patrol','This deadly adversary houses the control bridge for the particle accelerator. Its defenses are considerable.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(17745,821,'General Hixous Puxley','Your sensors indicate that this battleship is the source of a lot of coded transmissions.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(17746,821,'Supply Headman','This ship looks like a standard Domination Seraphim vessel except this one is fitted with at least double the amount of what you normally see of missile turrets.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(17747,494,'Docked & Loaded Mammoth','This Mammoth class industrial seems to be undergoing maintainance, but your sensors indicate that for some purpose, it is protected behind an extremely powerful shield...',100000,100000000,10000,1,2,0.0000,0,NULL,0),(17748,494,'Megathron under frantic repair','There is a lot of activity around this partially constructed Megathron. As you start to wonder why, you notice that your sensors indicate it is protected by an extremely durable shield.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17749,821,'The Antimatter Channeler','If you ever saw a silent and unpredictable presence, this would be it.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(17754,283,'Activists','People engaged in anti-establishment activity of some sort, most often political or economical in nature.',400,1,0,1,NULL,0.0000,1,754,0),(17755,314,'Pro-Trade Pamphlets','Propaganda prose by supporters of Eman Autrech, singing the praise of free trade and universal love.',1,0.1,0,1,NULL,0.0000,1,754,0),(17756,314,'Virgin Forest Pulp','Tree pulp used to produce paper.',1000,2,0,1,NULL,0.0000,1,754,0),(17757,314,'Bronze Sculpture','Bronze Sculpture of president Souro Foiritan.',100,5,0,1,NULL,0.0000,1,NULL,0),(17759,314,'Silver Sculpture','Silver Sculpture of president Souro Foiritan.',100,5,0,1,NULL,0.0000,1,NULL,0),(17761,314,'Gold Sculpture','Gold sculpture of president Souro Foiritan.',100,5,0,1,NULL,0.0000,1,NULL,0),(17763,319,'Powerful EM Forcefield','A reinforced antimatter generator powered by muonal crystals, creating a perfect circle of electro-magnetic radiance.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17764,404,'Ultra Fast Silo','Used to store or provide resources.',100000000,1150,8850,1,NULL,2819328.0000,0,NULL,0),(17765,283,'Exotic Dancers, Female','Exotic dancing is considered an art form, even though not everyone might agree. Exposing the flesh in public places may be perfectly acceptable within the Federation, but in the Amarr Empire it\'s considered a grave sin and a sign of serious deviancy.',50,1,0,1,NULL,0.0000,1,23,0),(17767,283,'Kameiras','An elite type of foot soldier, originally bred from Minmatar slaves by the Amarr Empire. Raised from birth to become soldiers, they serve the Empire, Khanid Kingdom and Ammatar well, although always kept on a tight leash.',90,1,0,1,NULL,50000.0000,1,23,0),(17769,428,'Fluxed Condensates','When combined with other materials and alloys, fluxed condensates help contribute to a unique quantum state highly conducive to efficient reactor operation.',0,1,0,1,NULL,512.0000,1,500,0),(17770,426,'Large AutoCannon Battery','Fires a barrage of extra large projectiles at those the Control Tower deems its enemies. Maintains a consistent spread of fire and is able to track the faster-moving targets, but lacks the sheer bludgeoning force of its artillery counterpart.',50000000,5000,2500,1,NULL,10000000.0000,1,594,0),(17771,426,'Medium AutoCannon Battery','Fires a barrage of large projectiles at those the Control Tower deems its enemies. Maintains a consistent spread of fire and is able to track fast-moving targets, but lacks some of the power of its artillery counterpart.',50000000,1000,1000,1,2,2000000.0000,1,594,0),(17772,426,'Small AutoCannon Battery','Fires a barrage of medium projectiles at those the Control Tower deems its enemies. Maintains a very rapid spread of fire and is able to track the fastest targets at close ranges, but lacks some of the punch evidenced by its artillery counterpart.',50000000,500,750,1,2,400000.0000,1,594,0),(17773,417,'Citadel Torpedo Battery','A torpedo launcher capable of firing the most powerful type of torpedo ever invented. A volley of these deathbringers can make piecemeal of most anything that floats in space.',50000000,5000,4500,1,NULL,12500000.0000,1,479,0),(17774,9,'Ice Field',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(17775,319,'Starbase Major Assembly Array','Assembly Arrays are oftentimes required to manufacture many high-tech and illegal modules that the empires don\'t want manufactured in their stations.  This is one of the biggest of its kind, able to churn out a great deal of equipment in relatively short order.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(17776,319,'Starbase Minor Assembly Array','Assembly Arrays are oftentimes required to manufacture many high-tech and illegal modules that the empires don\'t want manufactured in their stations.  While humble in size, this one is able to operate at a high level of efficiency, bringing its operators quality modules with surprising speed.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17777,319,'Amarr Starbase Control Tower','The Amarr have always been fond of majestic and intimidating constructions. Their Control Towers do not deviate from that tradition and are truly big and powerful structures, intended more for preservation of territorial interests than commercial benefits.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(17778,319,'Caldari Starbase Control Tower','At first the Caldari Control Towers were manufactured by Kaalakiota, but since they focused their efforts mostly on other, more profitable installations, they soon lost the contract and the Ishukone corporation took over the Control Towers\' development and production.',100000,1150,8850,1,1,0.0000,0,NULL,0),(17779,319,'Gallente Starbase Control Tower','Gallente Control Towers are more pleasing to the eye than they are strong or powerful. They have above average electronic countermeasures, average CPU output, and decent power output compared to towers from the other races, but are quite lacking in sophisticated defenses.',100000,1150,8850,1,8,0.0000,0,NULL,0),(17780,319,'Minmatar Starbase Control Tower','The Matari aren\'t really that high-tech, preferring speed rather than firepower or involved technology. Unfortunately that doesn\'t apply very well to stationary objects, much to the liking of the Amarr Empire.\r\r\n\r\r\nAmarrians call it a scrapheap of epic proportions. But don\'t underestimate these structures. Minmatar commanders usually have the last laugh when it comes to combat.',100000,1150,8850,1,2,0.0000,0,NULL,0),(17781,319,'Starbase Hangar','A stand-alone deep-space construction designed to allow pilots to dock and refit their ships on the fly.',100000,1150,8850,1,NULL,0.0000,0,NULL,0),(17782,319,'Starbase Ion Field Projection Battery','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors.',100,100,0,1,NULL,0.0000,0,NULL,0),(17783,319,'Starbase Force Field Array','This array projects a password-protected force field around structures outside the range of a control tower\'s shields.',100,100,0,1,NULL,0.0000,0,NULL,0),(17784,319,'Starbase Auxiliary Power Array','These arrays provide considerable added power output, allowing for an increased number of deployable structures in the starbase\'s field of operation.',100,100,0,1,NULL,0.0000,0,NULL,0),(17785,319,'Starbase Reactor Array','Moon Harvesting Arrays yield a number of moon materials that are then fed to Reactors. Reactors then process the materials in order to produce intermediate or final materials for use in keeping the Starbase\'s structures on-line and functioning.',1000000,1150,1,1,NULL,0.0000,0,NULL,0),(17786,319,'Starbase Shield Generator','Smaller confined shield generators with their own access restrictions can be deployed outside the Control Tower\'s defense perimeter. This allows for lesser security areas around the Starbase, for purposes of storage or pickup. ',1,1,0,1,NULL,0.0000,0,NULL,0),(17787,319,'Starbase Storage Facility','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(17788,319,'Starbase Moon Harvester','A harvesting factory for collecting moon minerals.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(17789,319,'Starbase Medium Refinery','The refinery is the heart of any industrial outpost, increasing the efficiency of any mining operation through reduced travel time. They are less efficient than full fledged stations, but the benefits of not having to move unrefined ore outweighs this drawback considerably. ',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(17790,319,'Starbase Minor Refinery','A factory that refines ore into minerals.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(17791,283,'Freedom Fighters','Freedom Fighters have dedicated their life to freeing those who have been enslaved by the Amarr Empire, Khanid Kingdom or various pirate factions.  Their purpose is to bring freedom and equality to the population of the galaxy.  \r\r\n\r\r\nBut although their ultimate goal may be noble, their methods are often not approved by the Minmatar authorities, nor their allies the Gallente Federation.  Their opponents call them terrorists, and they have been banned from the Caldari State due to the State\'s historical relationship with the Khanid Kingdom.',400,2,0,1,NULL,0.0000,1,23,0),(17793,314,'Amarr TIL-1 Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Viziam scientists for the Imperial Navy, made to be of better quality than what is available on the open market. \r\n\r\n\r\nThe TIL-1 chip is designed for battleship class vessels.',1,0.1,0,1,NULL,8000000.0000,1,738,0),(17794,314,'Amarr KIU-1 Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Viziam scientists for the Imperial Navy, made to be of better quality than what is available on the open market. \r\n  \r\n\r\nThe KIU-1 chip is designed for cruiser class vessels.',1,0.1,0,1,NULL,2000000.0000,1,738,0),(17795,314,'Amarr MIY-1 Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Viziam scientists for the Imperial Navy, made to be of better quality than what is available on the open market. \r\n \r\n\r\nThe MIY-1 chip is designed for frigate class vessels.',1,0.1,0,1,NULL,500000.0000,1,738,0),(17796,283,'Elite Slaves','Slavery has always been a questionable industry, favored by the Amarr Empire and detested by the Gallente Federation.  These elite slaves are exceptionally well suited for physical labor.',300,1,0,1,NULL,4000.0000,1,23,0),(17798,496,'Dented Cask','This reinforced container is outfitted with a capturing mechanism to pick up data from nearby sensor arrays. The cargo ship carrying this to its destination seems to have met some kind of disasterous end.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(17799,494,'Non-Secured Asteroid Colony','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry. The construction of this one is underway and the defenses are weak.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17800,819,'Retired Mining Veteran','The communication sensors on your ship are going haywire. Judging from the signals and coding being transmitted from this vessel, it could just be the big cahuna in this deadspace pocket. Who knows?',1612000,16120,80,1,1,0.0000,0,NULL,0),(17801,409,'Akori\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,1,0.0000,1,NULL,0),(17802,409,'Ibrahim\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,0.0000,1,NULL,0),(17803,409,'Karothas\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,1,0.0000,1,NULL,0),(17812,25,'Republic Fleet Firetail','The Firetail is modeled off a fighter frigate known as the Shamrock, a design used by a small, now-extinct pirate faction known as Lazari Dromitus.  The blueprint found its way into the hands of Matari military forces after a raid on Lazari Dromitus\'s headquarters succeeded in killing its leader, thus beheading the organization and scattering its remnants to the four winds.  It has since been improved upon and upgraded, and the Firetail is now a mainstay in most Republic Fleet patrols.',1098000,16500,135,1,2,348060.0000,1,1366,0),(17813,105,'Republic Fleet Firetail Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17814,314,'Minmatar UUC Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Boundless Creation scientists for the Minmatar Fleet, made to be of better quality than what is available on the open market. \r\r\n\r\r\n\r\r\nThe UUC chip is designed for battleship class vessels.',1,0.1,0,1,NULL,8000000.0000,1,738,0),(17815,314,'Minmatar UUA Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Boundless Creation scientists for the Minmatar Fleet, made to be of better quality than what is available on the open market. \r\r\n \r\r\n\r\r\nThe UUA chip is designed for frigate class vessels.',1,0.1,0,1,NULL,500000.0000,1,738,0),(17816,314,'Minmatar UUB Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Boundless Creation scientists for the Minmatar Fleet, made to be of better quality than what is available on the open market. \r\r\n  \r\r\n\r\r\nThe UUB chip is designed for cruiser class vessels.',1,0.1,0,1,NULL,2000000.0000,1,738,0),(17817,409,'Genom Tara\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.  \r\r\n\r\r\nGenom Tara is a legendary Ammatar commander who bears deep hatred of the Minmatar Republic.  He is most notable for refusing to obey direct orders from the Ammatar government to withdraw from his position in the Minmatar - Ammatar border.',0.1,0.1,0,1,2,0.0000,1,737,0),(17818,494,'Serpentis Supply Stronghold','This gigantic station is one of the Serpentis military installations and a black jewel of the alliance between The Guardian Angels and The Serpentis Corporation. Even for it\'s size it has no commercial station services or docking bay to receive guests.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(17820,494,'Supply Traffic Management','Equally equipped for scientific observation and entertainment of all sorts, these multi-purpose structures, while not quite big enough to be classified as stations, nonetheless see quite a bit of use by both tourists and professionals.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(17821,494,'Slaver Rig Control Tower','Amarr Control Tower',100000,100000000,10000,1,4,0.0000,0,NULL,0),(17822,494,'Staff Quarters','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(17823,820,'Serpentis Chief of Security','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(17824,820,'Serpentis Refinery Headmaster','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',11600000,116000,900,1,8,0.0000,0,NULL,0),(17826,474,'Traffic Management Passkey','This security passkey is manufactured by the Serpentis Corporation and allows the user to unlock a specific acceleration gate to a check-in tunnel. The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the key\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17827,474,'Serpentis Staff Passcard','This security passcard is distributed by the Serpentis Corporation and allows the user to unlock a specific acceleration gate to central warehouses. The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17828,474,'Security Corridor Pass','This security passkey is distributed by the Serpentis Corporation and allows the user to unlock a specific acceleration gate to central warehouses. The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the key\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17829,474,'Headmaster Administration Keycard','This security passcard is manufactured by the Serpentis Corporation and allows the user to unlock a specific acceleration gate to an administration sector. The gate will remain open for a short period of time and the keycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17830,474,'Inner Sanctum Passcard','This security passkey \"liberated\" from a Mul-Zatah  Gatekeepers opens the outer perimeter gate of their Monasteries . The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the key\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17831,366,'Acceleration Gate','Acceleration gate technology reaches far back to the expansion era of the empires that survived the great EVE gate collapse. While their individual setup might differ in terms of ship size they can transport and whether they require a certain passkey or code to be used, all share the same fundamental function of hurling space vessels to a destination beacon within solar system boundaries.',100000,0,0,1,NULL,0.0000,0,NULL,0),(17832,328,'Federation Navy Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,225690.0000,1,1681,0),(17833,348,'Federation Navy Armor EM Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17834,328,'Federation Navy Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,397768.0000,1,1680,0),(17835,348,'Federation Navy Armor Explosive Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17836,328,'Federation Navy Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,340756.0000,1,1679,0),(17837,348,'Federation Navy Armor Kinetic Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17838,328,'Federation Navy Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,277634.0000,1,1678,0),(17839,348,'Federation Navy Armor Thermic Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17840,314,'Zor\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n',1,0.1,0,1,NULL,0.0000,1,752,0),(17841,25,'Federation Navy Comet','The Comet\'s design comes from one Arnerore Rylerave, an engineer and researcher of the Roden Shipyards corporation.  Originally created as a standard-issue police patrol vessel, its tremendous maneuverability and great offensive capabilities catapulted it into the Navy\'s ranks, where it is now a widely-used skirmish vessel.',970000,16500,145,1,8,372184.0000,1,1366,0),(17842,105,'Federation Navy Comet Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17843,26,'Vexor Navy Issue','The Vexor Navy-Issued cruiser was originally designed to carry advanced on-board technologies requiring a great deal of skill to operate, but at the last moment the Federation Navy decided to scrap the more complex designs in favor of simple upgrades to the standard Vexor\'s armor, shields, hull and drone bandwidth.  The result: a monster of a combat cruiser.\r\r\n',11310000,112000,460,1,8,11660310.0000,1,1370,0),(17844,106,'Vexor Navy Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17846,818,'Lazarus Trezun','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(17847,370,'Lazarus\'s Tag','This electrum tag carries the rank insignia equivalent of a corporal within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17848,314,'Gallente Gamma Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Duvolle scientists for the Gallente Navy, made to be of better quality than what is available on the open market. \r\r\n \r\r\n\r\r\nThe Gamma chip is designed for frigate class vessels.',1,0.1,0,1,NULL,500000.0000,1,738,0),(17849,314,'Gallente Beta Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Duvolle scientists for the Gallente Navy, made to be of better quality than what is available on the open market. \r\r\n \r\r\n\r\r\nThe Beta chip is designed for cruiser class vessels.',1,0.1,0,1,NULL,2000000.0000,1,738,0),(17850,314,'Gallente Alpha Nexus Chip','This small data chip stores the key elements of a ship\'s artificial intelligence system, and is used primarily for controlling the vessel\'s autonomous functions. This particular chip has been modified by top Duvolle scientists for the Gallente Navy, made to be of better quality than what is available on the open market. \r\r\n \r\r\n\r\r\nThe Alpha chip is designed for battleship class vessels.',1,0.1,0,1,NULL,8000000.0000,1,738,0),(17851,816,'Faramon Zaccori','Faramon Zaccori. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(17852,370,'Faramon\'s Tag','This diamond tag carries the rank insignia equivalent of a captain within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(17853,474,'Crimson Hand Level 3 Passcard','This security passkey grants access to slave processing. The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the key\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17854,474,'Crimson Hand Level 1 Passcard','This security passkey grants access to slave processing. The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the key\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17855,474,'Crimson Hand Level 2 Passcard','This security passkey grants access to slave processing. The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the key\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17856,474,'Crimson Hand Level 4 Passcard','This security passkey grants access to slave processing. The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the key\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17857,476,'Mjolnir Citadel Torpedo','Citadel Torpedoes are behemoths designed for maximum firepower against capital ships and installations. They are usable only by capital ships and starbase defense batteries.\r\r\n\r\r\nNothing more than a baby nuclear warhead, this guided missile wreaks havoc with the delicate electronic systems aboard a starship. Specifically designed to damage shield systems, it is able to ravage heavily shielded targets in no time.',1500,0.3,0,100,NULL,656504.0000,1,1193,0),(17858,166,'Mjolnir Citadel Torpedo Blueprint',' ',1,0.01,0,1,NULL,100000000.0000,1,617,0),(17859,476,'Scourge Citadel Torpedo','Citadel Torpedoes are behemoths designed for maximum firepower against capital ships and installations. They are usable only by capital ships and starbase defense batteries.\r\r\n\r\r\nFitted with a graviton pulse generator, this weapon causes massive damage as it overwhelms ships\' internal structures, tearing bulkheads and armor plating apart with frightening ease.',1500,0.3,0,100,NULL,627336.0000,1,1193,0),(17860,166,'Scourge Citadel Torpedo Blueprint',' ',1,0.01,0,1,NULL,80000000.0000,1,617,0),(17861,476,'Inferno Citadel Torpedo','Citadel Torpedoes are behemoths designed for maximum firepower against capital ships and installations. They are usable only by capital ships and starbase defense batteries.\r\r\n\r\r\nPlasma suspended in an electromagnetic field gives this torpedo the ability to deliver a flaming inferno of destruction, wreaking almost unimaginable havoc.',1500,0.3,0,100,NULL,383274.0000,1,1193,0),(17862,166,'Inferno Citadel Torpedo Blueprint',' ',1,0.01,0,1,NULL,90000000.0000,1,617,0),(17863,476,'Nova Citadel Torpedo','Citadel Torpedoes are behemoths designed for maximum firepower against capital ships and installations. They are usable only by capital ships and starbase defense batteries.\r\r\n\r\r\nNocxium atoms captured in morphite matrices form this missile\'s devastating payload. A volley of these is able to completely obliterate most everything that floats in space, be it vehicle or structure.',1500,0.3,0,100,NULL,415674.0000,1,1193,0),(17864,166,'Nova Citadel Torpedo Blueprint',' ',1,0.01,0,1,NULL,70000000.0000,1,617,0),(17865,467,'Iridescent Gneiss','Gneiss is often the first major league ore that up and coming miners graduate to. Finding the more expensive variation of Gneiss, called Iridescent Gneiss, is a major coup for these miners.\r\r\n\r\r\nGneiss is a popular ore type because it holds significant volumes of three heavily used minerals, increasing its utility value. It has a quite a bit of mexallon as well as some pyerite and isogen.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,5,0,100,4,139440.0000,1,525,0),(17866,467,'Prismatic Gneiss','Prismatic Gneiss has fracturized molecule-structure, which explains its unique appearance. It is the most sought after member of the Gneiss family, as it yields 10% more than common Gneiss.\r\r\n\r\r\nGneiss is a popular ore type because it holds significant volumes of three heavily used minerals, increasing its utility value. It has a quite a bit of mexallon as well as some pyerite and isogen.\r\r\n\r\r\nAvailable primarily in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,5,0,100,4,146080.0000,1,525,0),(17867,469,'Silvery Omber','Silvery Omber was first discovered some fifty years ago in an asteroid belt close to a large moon. The luminescence from the moon made this uncommon cousin of normal Omber seem silvery in appearance, hence the name.\r\r\n\r\r\nOmber is a common ore that is still an excellent ore for novice miners as it has a sizeable portion of isogen, as well as some tritanium and pyerite. A few trips of mining this and a novice is quick to rise in status.\r\r\n\r\r\nAvailable in <color=\'0xFF00FF00\'>0.7</color> security status solar systems or lower.',1e35,0.6,0,100,NULL,11988.0000,1,526,0),(17868,469,'Golden Omber','Golden Omber spurred one of the largest gold rushes in the early days of space faring, when isogen was the king of minerals. The 10% extra yield it offers over common Omber was all it took to make it the most sought after ore for a few years.\r\r\n\r\r\nOmber is a common ore that is still an excellent ore for novice miners as it has a sizeable portion of isogen, as well as some tritanium and pyerite. A few trips of mining this and a novice is quick to rise in status.\r\r\n\r\r\nAvailable in <color=\'0xFF00FF00\'>0.7</color> security status solar systems or lower.',1e35,0.6,0,100,NULL,12524.0000,1,526,0),(17869,468,'Magma Mercoxit','Though it floats through the frigid depths of space, magma mercoxit\'s striking appearance and sheen gives it the impression of bubbling magma. If this visual treasure wasn\'t enticing enough, the 5% higher yield certainly attracts admirers.\r\r\n\r\r\nMercoxit is a very dense ore that must be mined using specialized deep core mining techniques. It contains massive amounts of the extraordinary morphite mineral but few other minerals of note.\r\r\n\r\r\nAvailable in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,40,0,100,NULL,10321920.0000,1,530,0),(17870,468,'Vitreous Mercoxit','Vitreous mercoxit gleams in the dark, like a siren of myth. Found only in rare clusters in space vitreous mercoxit is very rare, but very valuable, due to its much higher 10% yield.\r\r\n\r\r\nMercoxit is a very dense ore that must be mined using specialized deep core mining techniques. It contains massive amounts of the extraordinary morphite mineral but few other minerals of note.\r\r\n\r\r\nAvailable in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1e35,40,0,100,NULL,10813440.0000,1,530,0),(17871,738,'Inherent Implants \'Noble\' Remote Armor Repair Systems RA-703','A neural Interface upgrade that boosts the pilot\'s skill in the operation of remote armor repair systems.\r\r\n\r\r\n3% reduced capacitor need for remote armor repair system modules.',0,1,0,1,NULL,0.0000,1,1515,0),(17873,472,'System Scanner I','Scans the ore make-up of an asteroid.',0,5,0,1,NULL,2222.0000,0,NULL,0),(17874,478,'System Scanner I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(17875,383,'Sentinel Angel','This Angel Station has been refitted with huge citadel torpedo batteries and a long range stasis web generators  ',1000,1000,1000,1,2,0.0000,0,NULL,0),(17876,383,'Sentinel Sansha','This Sansha Station has been refitted with huge citadel torpedo batteries and a long range stasis web generators ',1000,1000,1000,1,4,0.0000,0,NULL,0),(17877,383,'Sentinel Serpentis','This Serpentis Battlestation has several formidable defensive systems. ',1000,1000,1000,1,8,0.0000,0,NULL,0),(17878,383,'Sentinel Chimera Strain Mother','This Drone station has several formidable defensive systems. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17879,383,'Sentinel Jormungand Strain Mother','This Drone station has several formidable defensive systems. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17880,383,'Sentinel Gallente','This Gallente Battlestation has several formidable defensive systems. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(17884,472,'Recon System Scanner','An advanced version of the system scanner. Scans the system for micro gravity wells in an attempt to locate something the ship\'s gravity capacitor can lock onto and thus warp to. Generally used for finding ships and bases hidden in dead space.',0,5,0,1,NULL,2222.0000,0,NULL,0),(17885,478,'Recon System Scanner Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(17887,423,'Oxygen Isotopes','Stable O-16 isotopes, crucial for maintenance of Gallente Control Towers.\r\r\n\r\r\nMay be obtained by reprocessing the following ice ores:\r\r\n\r\r\n<color=\'0xFF33FFFF\'>1.0</color> security status solar system or lower:\r\r\n<a href=showinfo:16264>Blue Ice</a>\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:17975>Thick Blue Ice</a>',0,0.1,0,1,NULL,0.0000,1,1033,0),(17888,423,'Nitrogen Isotopes','Nitrogen-14 is a stable, non-radioactive isotope, crucial for maintenance of Caldari Control Towers.\r\r\n\r\r\nMay be obtained by reprocessing the following ice ores:\r\r\n\r\r\n<color=\'0xFF33FFFF\'>1.0</color> security status solar system or lower:\r\r\n<a href=showinfo:16265>White Glaze</a>\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:17976>Pristine White Glaze</a>',0,0.1,0,1,NULL,0.0000,1,1033,0),(17889,423,'Hydrogen Isotopes','Hydrogen-2, otherwise known as Deuterium. Due to its unique properties the hydrogen-2 isotope is able to very effectively fuse with other atoms. Useful in a variety of nuclear scenarios, and an essential material for the maintenance of Minmatar Control Towers.\r\r\n\r\r\nMay be obtained by reprocessing the following ice ores:\r\r\n\r\r\n<color=\'0xFF33FFFF\'>1.0</color> security status solar system or lower:\r\r\n<a href=showinfo:16263>Glacial Mass</a>\r\r\n\r\r\n<color=\'0xFFFF0000\'>0.0</color> security status solar system or lower:\r\r\n<a href=showinfo:17977>Smooth Glacial Mass</a>',0,0.1,0,1,NULL,0.0000,1,1033,0),(17890,819,'Serpentis Drugstore Overseer','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2500000,25000,60,1,8,0.0000,0,NULL,0),(17891,494,'Gate Security','This Blood Raider outpost looks as if it could hold some surprises...',100000,100000000,10000,1,4,0.0000,0,NULL,0),(17892,474,'Drugdealer Passcard to Storage Area','This security passcard is manufactured by the Serpentis Corporation and allows the user to unlock a specific acceleration gate to a storage area. The gate will remain open for a short period of time and the passcard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17893,314,'High-Tech Data Chip','A small wafer of semiconductor material that forms the base for an integrated circuit. High-Tech Data Chips have more capacity than their lower tech counter-parts.',1,0.01,0,1,4,10000.0000,1,20,0),(17894,314,'High-Tech Scanner','A device for sensing recorded data or transmission signals.',2500,0.01,0,1,4,10000.0000,1,20,0),(17895,314,'High-Tech Manufacturing Tools','Tools used in various construction projects, such as ship, module or ground vehicle manufacturing. High-Tech tools are of better quality than the more common prototypes, and are more expensive.',10,0.01,0,1,4,10000.0000,1,20,0),(17897,314,'High-Tech Small Arms','These weapons are of superior quality to those normally found on the public market, although more expensive as well.\r\r\n\r\r\nThey are implemented with a safety net which prevents them from being used illegally in stations where most types of small arms are prohibited. Therefore many regions do not apply the small arms ban on these weapons.',1,0.01,0,1,4,10000.0000,1,20,0),(17898,1040,'High-Tech Transmitters','An electronic device that generates and amplifies a carrier wave, modulates it with a meaningful signal derived from speech or other sources, and radiates the resulting signal from an antenna. The High-Tech prototype is almost immune to any type of de-scrambling devices, making the transmission more secure.',0,6,0,1,NULL,10000.0000,1,1336,0),(17899,480,'Stealth Emitter Array','Decreases signature radius of control tower.',100000000,4000,0,1,NULL,100000.0000,0,NULL,0),(17900,821,'Crimson Lord','This Crimson Lord is packing some serious firepower and it seems quite clear that it will not go down without a vicious fight.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(17901,481,'Scan Probe Launcher II','A missile launcher shell modified to fit scanner and recon probes. Can also be used to launch survey probes. Only one probe launcher can be fitted per ship.',0,5,8,1,NULL,0.0000,0,NULL,0),(17902,918,'Scan Probe Launcher II Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(17903,819,'Outpost Security Officer','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2000000,20000,200,1,4,0.0000,0,NULL,0),(17904,474,'Sansha Outpost Securitycard','This securitycard is manufactured by Sansha\'s Nation and allows the user to unlock a specific acceleration gate to a recuperation camp. The gate will remain open for a short period of time and the securitycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17905,474,'Creo-Synchronization Pass','This security passkey is manufactured by the Angel Cartel and allows the user to unlock the acceleration gate to the second Creo-Corp deadspace pocket in the Angel Creo-Corp Mining complex. The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the key\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17906,474,'Factory Gatekey','This security passkey is manufactured by the Angel Cartel and allows the user to unlock the acceleration gate to the third Creo-Corp deadspace pocket in the Angel Creo-Corp Mining complex. The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the key\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17907,474,'Dented Cipher','This cipher unlocks the first acceleration gate in the Angel Military Operations Complex. The gate will remain open for a short period of time and using the cipher will cause it to self destruct, so use wisely.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17908,386,'QA Cruise Missile','This charge does not exist.',1250,0.001,0,100,NULL,12500.0000,0,NULL,0),(17910,474,'Ruined Stargate Cipher','This cipher unlocks any of the acceleration gates in the second deadspace pocket in the Angel Military Operations Complex. The gate will remain open for a short period of time and using the cipher will cause it to self destruct, so use wisely.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17911,474,'Supply Ship Pass','This cipher unlocks the third acceleration gate in the Angel Military Operations Complex. The gate will remain open for a short period of time and using the cipher will cause it to self destruct, so use wisely.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17912,483,'Modulated Strip Miner II','The Modulated Strip Miner II uses many of the same crystal frequency modulation technologies as the Modulated Deep Core Miner II, except it lacks the deep core mining capacity of its smaller sibling. \r\r\n\r\r\nCan only be fit to Mining Barges and Exhumers.\r\r\n\r\r\nUses mining crystals. \r\r\n\r\r\nCannot fit a mercoxit mining crystal.',0,5,10,1,NULL,6486278.0000,1,1040,0),(17913,490,'Modulated Strip Miner II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17916,474,'Tritan\'s Forked Key','This is a strangely shaped chaos-logic keycard. It was in the possession of the Overseer in the Angel Military Operations Complex. Upon using it to open the gate from that pocket the cipher will self destruct and the gate will remain open for a short time.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17917,818,'Rogue Pirate Grunt','Threat level: Moderate',1740000,17400,220,1,2,0.0000,0,NULL,0),(17918,27,'Rattlesnake','In the time-honored tradition of pirates everywhere, Korako  Rabbit\' Kosakami shamelessly stole the idea of the Scorpion-class battleship and put his own spin on it.  The result: the fearsome Rattlesnake, flagship of any large Gurista attack force.  There are, of course, also those who claim things were the other way around; that the notorious silence surrounding the Scorpion\'s own origins is, in fact, an indication of its having been designed by Kosakami all along.',99300000,486000,665,1,1,157405934.0000,1,1380,0),(17919,107,'Rattlesnake Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17920,27,'Bhaalgorn','Named after a child-devouring demon of Amarrian legend, the Bhaalgorn is the pride and joy of the Blood Raider cabal.  Though it is known to be based on an Armageddon blueprint, the design\'s origin remains shrouded in mystery.  Those of a superstitious persuasion whisper in the dark of eldritch ceremonies and arcane rituals, but for most people, the practical aspect of the matter will more than suffice: you see one of these blood-red horrors looming on the horizon, it\'s time to make yourself scarce.',97100000,486000,675,1,4,165728608.0000,1,1380,0),(17921,107,'Bhaalgorn Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17922,26,'Ashimmu','In those of the Empire\'s regions where naughty children are frightened into submission with tales of the Blood Raiders and their gallery of horrors, the terrible spear of the Ashimmu is known by all as a bringer of things worse than death.  This is one of the few things that small children and capsule pilots generally agree upon.',11010000,118000,430,1,4,11934190.0000,1,1371,0),(17923,106,'Ashimmu Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17924,25,'Succubus','The Succubus is one of the most feared frigates ever to harrow the spacelanes and asteroid belts of civilized space, and with good reason: tales abound of its superiority over ships twice or three times its size.  Whether you believe this to be fact or rumor, the Succubus will still strike fear in your heart.\r\r\n\r\r\n',965000,28600,135,1,4,355044.0000,1,1365,0),(17925,105,'Succubus Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17926,25,'Cruor','Mottled, dark red, and shaped like a leech, the Cruor presents a fitting metaphor for the Blood Raiders\' philosophy.  Designed almost solely to engage in their disturbingly effective tactic of energy draining and stasis webbing, this ship is a cornerstone in any effective Blood Raider fleet - and could play an intriguing role in more standard ones.',1003000,28600,135,1,4,355044.0000,1,1365,0),(17927,105,'Cruor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17928,25,'Daredevil','Little hard data is to be had on the Daredevil\'s exact origin, but it is believed that Guardian Angel engineers created it to serve as a defensive complement to the Cartel\'s Dramiel frigate.  In both flair and utility it closely resembles its counterpart, but it eschews offensive capabilities in favor of greater defensive potential and stronger armor plating.  A tough nut to crack.\r\r\n',823000,26500,140,1,8,341568.0000,1,1365,0),(17929,105,'Daredevil Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17930,25,'Worm','Korako \'The Rabbit\' Kosakami, Gurista leader, has a particular love for stealing the Caldari\'s ship designs, souping them up, and turning them on their creators.  With the Worm, he has taken the Merlin design so familiar to Caldari pilots and turned it into a defensive powerhouse capable of firing its volleys at terrifying speeds.\r\r\n\r\r\n',981000,16500,130,1,1,334766.0000,1,1365,0),(17931,105,'Worm Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17932,25,'Dramiel','The Dramiel is the most long-standing and often-used ship design in the Angel Cartel\'s vast repertoire of vessels.  A frigate workhorse if ever there was one, this sharp-tusked, dangerous beauty can sting unimaginably hard if one is not prepared for its assault.\r\r\n\r\r\n',950000,27289,130,1,2,346080.0000,1,1365,0),(17933,105,'Dramiel Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(17938,481,'Core Probe Launcher I','Launcher for <a href=showinfo:30013>Core Scanner Probes</a>, which are used to scan down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a> in space.\r\r\n\r\r\nNote: Only one probe launcher can be fitted per ship.',0,5,0.8,1,NULL,6670.0000,1,712,0),(17939,918,'Core Probe Launcher I Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,1198,0),(17940,257,'Mining Barge','Skill at operating ORE Mining Barges. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,500000.0000,1,377,0),(17941,436,'Caesarium Cadmide Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17942,436,'Carbon Polymers Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17943,436,'Ceramic Powder Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17944,436,'Crystallite Alloy Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17945,436,'Dysporite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17946,436,'Fernite Alloy Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17947,436,'Ferrofluid Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17948,436,'Fluxed Condensates Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17949,436,'Hexite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17950,436,'Hyperflurite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17951,436,'Neo Mercurite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17952,436,'Platinum Technite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17953,436,'Rolled Tungsten Alloy Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17954,436,'Silicon Diborite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17955,436,'Solerium Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17956,436,'Sulfuric Acid Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17957,436,'Titanium Chromide Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17958,436,'Vanadium Hafnite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17959,428,'Vanadium Hafnite','A stable binary compound composed of vanadium and hafnium. Performs a variety of catalytic functions, and is an important intermediate for more complex construction processes.',0,1,0,1,NULL,80.0000,1,500,0),(17960,428,'Prometium','A highly radioactive cadmium-promethium compound, used as a catalytic agent in the manufacturing of thrusters, reactor units and shield emitters, among other things.',0,1,0,1,NULL,320.0000,1,500,0),(17961,436,'Prometium Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(17962,484,'Titanium Carbide Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17963,484,'Crystalline Carbonide Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17964,484,'Fernite Carbide Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17965,484,'Tungsten Carbide Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17966,484,'Sylramic Fibers Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17967,484,'Fulleride Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17968,484,'Phenolic Composites Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17969,484,'Nanotransistors Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17970,484,'Hypersynaptic Fibers Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17971,484,'Ferrogel Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17972,484,'Fermionic Condensates Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(17973,821,'Angel Cartel Jailor','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(17974,474,'Battlement Accesscard','This security accesscard is distributed by the Serpentis Corporation and allows the user to unlock a specific acceleration gate to the prison battlements. The gate will remain open for a short period of time and the accesscard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17975,465,'Thick Blue Ice','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles.  Due to its unique chemical composition and the circumstances under which it forms, blue ice will, under normal circumstances, contain more oxygen isotopes than any other ice asteroid. This particular formation is an old one and therefore contains even more than its less mature siblings.\r\r\n\r\r\nAvailable in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1000,1000,0,1,NULL,160000.0000,1,1855,0),(17976,465,'Pristine White Glaze','When star fusion processes occur near high concentrations of silicate dust, such as those found in interstellar ice fields, the substance known as White Glaze is formed. While White Glaze generally is extremely high in nitrogen-14 and other stable nitrogen isotopes, a few rare fragments, such as this one, have stayed free of radioactive contaminants and are thus richer in isotopes than their more impure counterparts.\r\r\n\r\r\nAvailable in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1000,1000,0,1,NULL,160000.0000,1,1855,0),(17977,465,'Smooth Glacial Mass','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. Glacial masses are known to contain hydrogen isotopes in abundance, but the high surface diffusion on this particular mass means it has considerably more than its coarser counterparts.\r\r\n\r\r\nAvailable in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1000,1000,0,1,NULL,160000.0000,1,1855,0),(17978,465,'Enriched Clear Icicle','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. These crystalline formations can be found scattered around many an ice field and are known as the universe\'s primary source of helium isotopes. Due to environmental factors, this fragment\'s isotope deposits have become even richer than its regular counterparts\'.\r\r\n\r\r\nAvailable in <color=\'0xFFFF0000\'>0.0</color> security status solar systems or lower.',1000,1000,0,1,NULL,643000.0000,1,1855,0),(17979,494,'Scramble Wave Generator','This shield generator is disrupting the acceleration gate through an encoded datastream. The generator contains the cypher required to ride the gate into the main prison block.',1,1,0,1,NULL,0.0000,0,NULL,0),(17982,404,'Coupling Array','Coupling arrays are typically used in situations where small buffers are required to regulate the flow of materials in industrial processes.\r\r\n',100000000,4000,1500,1,NULL,2500000.0000,1,483,0),(17983,474,'Armorer Keycard','This is a chaos-logic keycard. It had been issued to the captain of a docked Mammoth in the third deadspace pocket of Angel Cartel\'s Naval Shipyard. It will open the acceleration gate for a short time and then self-destruct.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17984,474,'The Repairer\'s Keycard','This is a chaos-logic keycard. It had been issued to the captain of a docked Megatron in the fourth deadspace pocket of Angel Cartel\'s Naval Shipyard. It will open the acceleration gate for a short time and then self-destruct.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17985,474,'Scratched and Dented Keycard','This cipher unlocks the first acceleration gate in the Pith-Robux Asteroid Mining complex. The gate will remain open for a short period of time and using the cipher will cause it to self destruct, so use wisely.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17986,474,'Dusty Keycard','This cipher unlocks the second acceleration gate in the Pith-Robux Asteroid Mining complex. The gate will remain open for a short period of time and using the cipher will cause it to self destruct, so use wisely.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17987,474,'Command Relay Key','This security passkey allows access into the core area of sansha\'s command relay stations ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17988,474,'Gardan\'s Private Key','Gardan personally distributes keys to the acceleration gate near his Fantasy Complex. These unlock the acceleration gate behind it and the gate will remain open for a short period of time. The access cards are singe-use.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17989,474,'Thorak\'s Private Key','Thorak holds on to the passkey to the second deadspace pocket with his dear life. It unlocks the acceleration gate which will remain open for a short period of time. The key has a self-destruct mechanism, activated upon use.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17990,474,'Security Cypher for Angel Prison','This cypher unlocks the acceleration gate in an Angel Prison Complex. The gate will remain open for a short period of time and using the cypher will cause it to self destruct.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17991,474,'9D Logic Keycard','This keycard will activate the first acceleration gate in the Angel Cartel Naval Shipyard. This key is particularly hard to forge and is lost in a dimensional shift once it is used.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17992,474,'Puxley\'s 9D Pass','This nine-dimensional pass unlocks the second acceleration gate in the Angel Cartel Naval Shipyard. It is destroyed on use.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17993,495,'Crimson Sentinel','This Blood Raider station has been refitted with huge citadel torpedo batteries and a long range stasis web generators.',1000,1000,1000,1,4,0.0000,0,NULL,0),(17994,494,'Assembly Management HQ','From here, the assembly managers synchronize and concentrate their efforts. Much of what goes on is actually remote controlled from here.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(17995,474,'Stolen Passkey','This passkey unlocks the acceleration gate into the Drugrunner Hideout of the Serpentis-Phi Outpost complex. It is single-use only.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17996,496,'Crimson Hand Container','The wrecked container drifts silently amongst the stars, your sensors pick up signs of something rolling within it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(17997,819,'Blockade General Sade','The naval blockade commander is renown for his cruelty towards his captives.',1612000,16120,80,1,1,0.0000,0,NULL,0),(17998,474,'Sade\'s Pass','This pass will open the acceleration gate that Pith Guristas\' pirate Sade guards. The gate will remain open for a short period of time and the passkey will be rendered useless after uploading the key\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(17999,409,'Ammatar Navy Colonel Insignia I','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,500000.0000,1,731,0),(18000,383,'Hive mother','Drone hive mother',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18001,383,'Hive mother 2','Hive mother',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18004,819,'Supply Station Manager','The Supply Station Manager perpetually patrols the area.',1612000,16120,80,1,1,0.0000,0,NULL,0),(18012,319,'Drone Bunker','This large metal bunker is thoroughly infested with rogue drones.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18013,319,'Drone Elevator','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18014,319,'Drone Junction','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18015,319,'Drone Lookout','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18016,319,'Drone Battery','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18017,319,'Drone Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18018,319,'Drone Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18019,319,'Drone Fence','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18020,319,'Drone Barrier','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18021,319,'Inactive Drone Sentry','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18023,383,'Drone Wall Sentry Gun','Drone Wall Sentry Gun',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18024,819,'The Superintendent','The superindendent of this pocket has been elected Tracy Mullen, a former Minmatar agent. She is respected by her peers for her combat skills.',1612000,16120,80,1,1,0.0000,0,NULL,0),(18025,1218,'Ice Processing','Skill for Ice reprocessing. Allows a skilled individual to utilize substandard reprocessing facilities at considerably greater efficiency.\r\r\n\r\r\n2% bonus to Ice reprocessing yield per skill level.',0,0.01,0,1,NULL,400000.0000,1,1323,0),(18026,383,'Tower Sentry Drone III','Drone ion blaster cannon sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18027,383,'Tower Sentry Drone II','Drone ion blaster cannon sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18028,383,'Tower Sentry Drone I','Drone ion blaster cannon sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18029,879,'Freed Slaves','Slaves recently released from the clutches of Amarrian slavelords. ',400,6,0,1,NULL,0.0000,1,23,0),(18031,383,'Drone Cruise Missile Battery','This cruise missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18032,383,'Drone Heavy Missile Battery','This heavy missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18033,383,'Drone Light Missile Battery','This light missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18034,383,'Serpentis Light Missile Battery','This light missile sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18035,383,'Drone Point Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(18036,482,'Arkonor Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Arkonor yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,213504.0000,1,593,0),(18037,727,'Arkonor Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,800000.0000,1,753,0),(18038,482,'Bistot Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Bistot yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,199168.0000,1,593,0),(18039,727,'Bistot Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,753,0),(18040,482,'Crokite Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Crokite yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,184832.0000,1,593,0),(18041,727,'Crokite Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,700000.0000,1,753,0),(18042,482,'Dark Ochre Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Dark Ochre yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,156672.0000,1,593,0),(18043,727,'Dark Ochre Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,753,0),(18044,482,'Gneiss Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Gneiss yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,142336.0000,1,593,0),(18045,727,'Gneiss Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,550000.0000,1,753,0),(18046,482,'Hedbergite Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Hedbergite yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,128000.0000,1,593,0),(18047,727,'Hedbergite Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,753,0),(18048,482,'Hemorphite Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Hemorphite yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,128000.0000,1,593,0),(18049,727,'Hemorphite Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,450000.0000,1,753,0),(18050,482,'Jaspet Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Jaspet yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,113664.0000,1,593,0),(18051,727,'Jaspet Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,753,0),(18052,482,'Kernite Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Kernite yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,99328.0000,1,593,0),(18053,727,'Kernite Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,350000.0000,1,753,0),(18054,663,'Mercoxit Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Mercoxit yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,455168.0000,1,593,0),(18055,727,'Mercoxit Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,753,0),(18056,482,'Omber Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Omber yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,71168.0000,1,593,0),(18057,727,'Omber Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,753,0),(18058,482,'Plagioclase Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Plagioclase yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,56832.0000,1,593,0),(18059,727,'Plagioclase Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,753,0),(18060,482,'Pyroxeres Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Pyroxeres yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,42496.0000,1,593,0),(18061,727,'Pyroxeres Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,753,0),(18062,482,'Scordite Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Scordite yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,28672.0000,1,593,0),(18063,727,'Scordite Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,150000.0000,1,753,0),(18064,482,'Spodumain Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Spodumain yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,170496.0000,1,593,0),(18065,727,'Spodumain Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,650000.0000,1,753,0),(18066,482,'Veldspar Mining Crystal I','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Veldspar yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,6,0,1,NULL,14336.0000,1,593,0),(18067,727,'Veldspar Mining Crystal I Blueprint',' ',0,0.01,0,1,NULL,100000.0000,1,753,0),(18068,483,'Modulated Deep Core Miner II','The modulated deep core miner is a technological marvel that combines the capacities of the commonly used Miner II with that of the deep core mining laser. Using a modular mining crystal system, it can be altered on the fly for maximum efficiency.\r\r\n\r\r\nIt\'s important to remember, however, that without the proper crystals this unit is only marginally useful for mining mercoxit, and highly inefficient for most anything else.\r\r\n    ',0,5,10,1,NULL,1223042.0000,1,1039,0),(18069,134,'Modulated Deep Core Miner II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18070,805,'Strain Splinter Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: High',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18071,805,'Strain Render Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: High',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18072,805,'Strain Decimator Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: High',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18073,801,'Defeater Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18074,801,'Crippler Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18075,801,'Striker Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18076,803,'Violator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18077,803,'Disintegrator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18078,803,'Bomber Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18079,805,'Sunder Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18080,805,'Raider Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18082,803,'Destructor Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18083,803,'Annihilator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18084,803,'Devastator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18085,805,'Devilfish Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18086,805,'Barracuda Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18087,805,'Splinter Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18088,805,'Render Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18113,806,'Incubus Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(18114,806,'Malphas Apis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(18564,805,'Hunter Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(18565,821,'Serpentis Executive Officer','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(18566,474,'Shipyard Code Part (One half)','This security code is one half of what is needed to enter the Serpentis Fleet HQ. The gate will remain open for a short period of time after the code will be used. After usage, the gate security system automatically creates a new password, rendering this code useless.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(18567,319,'Shipyard','Large construction tasks can be undertaken at this shipyard.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(18568,319,'Dark Shipyard','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(18569,319,'Dirty Shipyard','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(18573,817,'Rogue Mercenary Thorn','Rogue Mercenaries always work for the highest bidder.  Their ships and equipment varies, as they use whatever is available at the time.  Threat level: Deadly',10900000,109000,480,1,2,0.0000,0,NULL,0),(18574,818,'Seven Grunt','This is a fighter working for \'The Seven\', a vast criminal network which operates from a host of secret pirate strongholds strewn across the known universe. Threat level: Moderate',1740000,17400,220,1,2,0.0000,0,NULL,0),(18575,818,'Seven Death Dealer','This is a fighter working for \'The Seven\', a vast criminal network which operates from a host of secret pirate strongholds strewn across the known universe. Threat level: High',1910000,19100,120,1,2,0.0000,0,NULL,0),(18576,818,'Seven Deathguard','This is a fighter working for \'The Seven\', a vast criminal network which operates from a host of secret pirate strongholds strewn across the known universe. Threat level: Very high',1910000,19100,80,1,2,0.0000,0,NULL,0),(18577,817,'Seven Thug','This is a fighter working for \'The Seven\', a vast criminal network which operates from a host of secret pirate strongholds strewn across the known universe. Threat level: Deadly',10900000,109000,1400,1,2,0.0000,0,NULL,0),(18578,817,'Seven Assassin','This is a fighter working for \'The Seven\', a vast criminal network which operates from a host of secret pirate strongholds strewn across the known universe. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(18579,817,'Seven Bodyguard','This is a fighter working for Zazzmatazz, an influential rogue pirate leader who controls a vast amount of secret pirate strongholds strewn across the known universe.  Bodyguards serve to protect Zazzmatazz and his highest ranking henchmen, especially the members of the inner leadership, going under the name of \"The Seven\". Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(18580,274,'Tycoon','Ability to organize and manage ultra large-scale market operations. Each level raises the limit of active orders by 32. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,100000000.0000,1,378,0),(18581,409,'Zazzmatazz\'s Bodyguard Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(18582,496,'Storage Taxes','This reinforced container revolves silently in space, and is guarded by somewhat stronger ships than what you\'ve seen patrolling the enormous cargo rigs around it.',10000,10500,10000,1,NULL,0.0000,0,NULL,0),(18583,314,'Ornamental Necklace','Often given as a wedding gift.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(18584,820,'Intoxicated Commander','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(18585,474,'Weekend Pass for Sin Boulevard','This pass is handed out to Guristas operatives that have earned a special treatment in their reinvigoration camp. The gate will remain open for a short period of time and the accesscard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(18586,480,'BH Structure Anchoring Array','Testing Module Used to speed up POS online time.',100000000,4000,0,1,NULL,100000.0000,0,NULL,0),(18588,972,'Observator Deep Space Probe I','The deep-space probe uses directional measurements of the red shifting of scan signatures due to space-time expansion to give very coarse scanning of objects up to interstellar ranges. You only need one such probe for analysis, and it scans everything within 1000AU.',1,0.125,0,1,NULL,17670.0000,0,NULL,0),(18590,482,'Arkonor Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Arkonor yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,280064.0000,1,593,0),(18591,727,'Arkonor Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18592,482,'Bistot Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Bistot yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,260608.0000,1,593,0),(18593,727,'Bistot Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18594,482,'Crokite Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Crokite yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,243712.0000,1,593,0),(18595,727,'Crokite Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18596,482,'Dark Ochre Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Dark Ochre yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,207872.0000,1,593,0),(18597,727,'Dark Ochre Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18598,482,'Gneiss Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Gneiss yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,188416.0000,1,593,0),(18599,727,'Gneiss Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18600,482,'Hedbergite Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Hedbergite yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,171520.0000,1,593,0),(18601,727,'Hedbergite Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18602,482,'Hemorphite Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Hemorphite yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,166400.0000,1,593,0),(18603,727,'Hemorphite Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18604,482,'Jaspet Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Jaspet yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,149504.0000,1,593,0),(18605,727,'Jaspet Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18606,482,'Kernite Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Kernite yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,130048.0000,1,593,0),(18607,727,'Kernite Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18608,663,'Mercoxit Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Mercoxit yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,516608.0000,1,593,0),(18609,727,'Mercoxit Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18610,482,'Omber Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Omber yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,99328.0000,1,593,0),(18611,727,'Omber Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18612,482,'Plagioclase Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Plagioclase yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,79872.0000,1,593,0),(18613,727,'Plagioclase Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18614,482,'Pyroxeres Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Pyroxeres yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,62976.0000,1,593,0),(18615,727,'Pyroxeres Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18616,482,'Scordite Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Scordite yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,44032.0000,1,593,0),(18617,727,'Scordite Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18618,482,'Veldspar Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Veldspar yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,27136.0000,1,593,0),(18619,727,'Veldspar Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18624,482,'Spodumain Mining Crystal II','A custom-cut frequency crystal whose refractive qualities are specifically suited to boosting Spodumain yield. Due to their molecular make-up and the strength of the modulated miner\'s beam, these crystals will deteriorate through extended use. Can be loaded into modulated mining lasers only.',1,10,0,1,NULL,237056.0000,1,593,0),(18625,727,'Spodumain Mining Crystal II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(18626,492,'Quest Survey Probe I','The moon survey probe is launched in the direction of a nearby moon where it will eventually land and broadcast back atmospheric and soil analysis data.\r\r\n\r\r\nThe Quest is a cheap compact system that requires little in the way of skill to operate. However, it is extremely slow and can take up to 20 minutes to gather reliable survey data. ',1,5,0,1,NULL,49688.0000,1,1200,0),(18628,496,'Scratched Cask','The drone-built container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(18629,496,'Assembled Container','The drone-built container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(18630,495,'Serpentis Fleet Stronghold','This Serpentis Battlestation has several formidable defensive systems. ',1000,1000,1000,1,8,0.0000,0,NULL,0),(18631,495,'Angel Retention Facility','This Angel Station has been refitted with huge citadel torpedo batteries and a long range stasis web generators  ',1000,1000,1000,1,2,0.0000,0,NULL,0),(18632,494,'Radiating Telescope','This huge radio telescope contains fragile but advanced sensory equipment. A structure such as this has enormous capabilities in crunching survey data from nearby systems and constellations.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18633,494,'Sansha Outpost Administration Building','Containing an inner habitation core surrounded by an outer shell filled with a curious fluid, the purpose of which remains unclear, this outpost is no doubt the brain-child of some nameless True Slave engineer.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18634,494,'Serpentis Narcotics Storage','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18635,492,'Discovery Survey Probe I','The moon survey probe is launched in the direction of a nearby moon where it will eventually land and broadcast back atmospheric and soil analysis data.\r\r\n\r\r\nThe Discovery is the standard probe used by most moon mining operations. It is fairly fast - completing its survey in about 5 minutes - but that benefit is offset by its rather considerable bulk.',1,10,0,1,NULL,76080.0000,1,1200,0),(18637,492,'Gaze Survey Probe I','The moon survey probe is launched in the direction of a nearby moon where it will eventually land and broadcast back atmospheric and soil analysis data.\r\r\n\r\r\nThe Gaze system is a extremely fast survey system that can reliably scan a moon in under 2.5 minutes. However, it requires considerable skill to use.\r\r\n',1,5,0,1,NULL,107784.0000,1,1200,0),(18639,481,'Expanded Probe Launcher I','Launcher for <a href=showinfo:30013>Core Scanner Probes</a> and <a href=showinfo:30028>Combat Scanner Probes</a>.\r\r\n\r\r\n<a href=showinfo:30013>Core Scanner Probes</a> are used to scan down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a> in space.\r\r\n<a href=showinfo:30028>Combat Scanner Probes</a> are used to scan down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a>, starships, structures and drones.\r\r\n\r\r\nNote: Only one scan probe launcher can be fitted per ship.',0,5,8,1,NULL,6670.0000,1,712,0),(18640,918,'Expanded Probe Launcher I Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,1198,0),(18641,820,'Guristas Harlot Procurer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(18642,353,'QA Smartbomb','This module does not exist.',100,1,0,1,NULL,312496.0000,0,NULL,0),(18644,474,'High Roller\'s Passcard','This passcard is handed out to Guristas operatives that have earned access to the gambler\'s paradise in the guristas reinvigoration camp. The gate will remain open for a short period of time and the card will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(18645,494,'Captive Fighting Arena','To escape the jurisdiction of those who would curb their entertainments, full-contact fight promoters and unlicensed, duel-to-the-death Clash Masters have taken to setting up these deep-space arenas for their brutal games to take place in.  A hive of scum and villainy -- or, alternatively, a wonderland of sport and blood-stained jollity.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(18654,409,'Olufami\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,0.0000,1,NULL,0),(18655,314,'Olufami\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis is a DNA sample taken from a member of the infamous pirate gang \'The Seven\', who goes by the name of Olufami.',1,0.1,0,1,NULL,0.0000,1,752,0),(18656,817,'Shimon Jaen','Legendary Commander of the Khanid forces, Duke Shimon Jaen is feared amongst both his enemies and his allies.  He is known to be a ruthless leader and military genius, highly revered among his royal compatriots.  His other recognizable traits are his deep hatred of the Amarr Empire and his contempt for those who are not part of the royal family.',12250000,115000,465,1,4,0.0000,0,NULL,0),(18657,409,'Shimon Jaen\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,1,0.0000,1,737,0),(18658,46,'Gistii C-Type 1MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,161280.0000,1,542,0),(18660,46,'Gistum C-Type 10MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,161280.0000,1,542,0),(18662,46,'Gist C-Type 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(18664,46,'Gistii B-Type 1MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,161280.0000,1,542,0),(18666,46,'Gistum B-Type 10MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,161280.0000,1,542,0),(18668,46,'Gist B-Type 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(18670,46,'Gistii A-Type 1MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,161280.0000,1,542,0),(18672,46,'Gistum A-Type 10MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,161280.0000,1,542,0),(18674,46,'Gist A-Type 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(18676,46,'Gist X-Type 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(18678,816,'Zelfarios Kashnostramus','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(18679,370,'Zelfarios Kashnostramus\'s Tag','This diamond tag carries the rank insignia equivalent of a captain within Sansha\'s slave nation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(18680,46,'Coreli C-Type 1MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,161280.0000,1,542,0),(18682,46,'Corelum C-Type 10MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,161280.0000,1,542,0),(18684,46,'Core C-Type 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(18686,46,'Coreli B-Type 1MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,161280.0000,1,542,0),(18688,46,'Corelum B-Type 10MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,161280.0000,1,542,0),(18690,46,'Core B-Type 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(18692,46,'Coreli A-Type 1MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,161280.0000,1,542,0),(18694,46,'Corelum A-Type 10MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,161280.0000,1,542,0),(18696,46,'Core A-Type 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(18698,46,'Core X-Type 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,161280.0000,1,542,0),(18700,98,'Corpii C-Type Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(18702,98,'Centii C-Type Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(18704,98,'Corpii B-Type Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(18706,98,'Centii B-Type Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(18708,98,'Corpii A-Type Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(18710,98,'Centii A-Type Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(18712,98,'Corpii C-Type Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(18714,98,'Centii C-Type Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(18716,98,'Corpii C-Type Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(18718,98,'Centii C-Type Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(18720,98,'Corpii C-Type EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(18722,98,'Centii C-Type EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(18724,98,'Corpii C-Type Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(18726,98,'Centii C-Type Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(18728,98,'Corpii B-Type Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(18730,98,'Centii B-Type Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(18740,98,'Corpii B-Type Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(18742,98,'Centii B-Type Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(18744,98,'Corpii B-Type Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(18746,98,'Centii B-Type Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(18748,98,'Corpii B-Type EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(18750,98,'Centii B-Type EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(18752,98,'Corpii A-Type Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(18754,98,'Centii A-Type Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(18756,98,'Corpii A-Type Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(18758,98,'Centii A-Type Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(18760,98,'Corpii A-Type EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(18762,98,'Centii A-Type EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(18764,98,'Corpii A-Type Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(18766,98,'Centii A-Type Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(18768,98,'Coreli C-Type Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(18770,98,'Coreli C-Type Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(18772,98,'Coreli C-Type Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(18775,98,'Coreli C-Type EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(18777,98,'Coreli C-Type Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(18779,98,'Coreli B-Type Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(18781,98,'Coreli B-Type Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(18783,98,'Coreli B-Type Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(18785,98,'Coreli B-Type EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(18787,98,'Coreli B-Type Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(18789,98,'Coreli A-Type Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,7468.0000,1,1670,0),(18791,98,'Coreli A-Type Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1666,0),(18793,98,'Coreli A-Type Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1667,0),(18795,98,'Coreli A-Type EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1668,0),(18797,98,'Coreli A-Type Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,4974.0000,1,1665,0),(18799,326,'Corelum C-Type Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(18801,326,'Corelum C-Type Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(18803,326,'Corelum C-Type Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(18805,326,'Corelum C-Type Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(18807,326,'Corelum C-Type Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(18809,326,'Corelum B-Type Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(18811,326,'Corelum B-Type Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(18813,326,'Corelum B-Type Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(18815,326,'Corelum B-Type Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(18817,326,'Corelum B-Type Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(18819,326,'Corelum A-Type Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(18821,326,'Corelum A-Type Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(18823,326,'Corelum A-Type Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(18825,326,'Corelum A-Type Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(18827,326,'Corelum A-Type Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(18829,326,'Corpum C-Type Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(18831,326,'Centum C-Type Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(18833,326,'Corpum C-Type Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(18835,326,'Centum C-Type Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(18837,326,'Corpum C-Type Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(18839,326,'Centum C-Type Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(18841,326,'Corpum C-Type Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(18843,326,'Centum C-Type Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(18845,326,'Corpum C-Type Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(18847,326,'Centum C-Type Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(18849,326,'Corpum B-Type Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(18851,326,'Centum B-Type Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(18853,326,'Corpum B-Type Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(18855,326,'Centum B-Type Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(18857,326,'Corpum B-Type Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(18859,326,'Centum B-Type Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(18861,326,'Corpum B-Type Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(18863,326,'Centum B-Type Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(18865,326,'Corpum A-Type Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(18867,326,'Centum A-Type Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1683,0),(18869,326,'Corpum A-Type Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(18871,326,'Centum A-Type Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(18873,326,'Corpum A-Type Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(18875,326,'Centum A-Type Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1682,0),(18877,326,'Corpum A-Type Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(18879,326,'Centum A-Type Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1685,0),(18881,326,'Corpum A-Type Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(18883,326,'Centum A-Type Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,100000.0000,1,1686,0),(18885,328,'Corpus C-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18887,328,'Centus C-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18889,328,'Corpus C-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18891,328,'Centus C-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18893,328,'Corpus C-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18895,328,'Centus C-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18897,328,'Corpus C-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18899,328,'Centus C-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18901,328,'Corpus B-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18903,328,'Centus B-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18905,328,'Corpus B-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18907,328,'Centus B-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18909,328,'Corpus B-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18911,328,'Centus B-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18913,328,'Corpus B-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18915,328,'Centus B-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18917,328,'Corpus A-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18919,328,'Centus A-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18921,328,'Corpus A-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18923,328,'Centus A-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18925,328,'Corpus A-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18927,328,'Centus A-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18929,328,'Corpus A-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18931,328,'Centus A-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18933,328,'Corpus X-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18935,328,'Centus X-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18937,328,'Corpus X-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18939,328,'Centus X-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18941,328,'Corpus X-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18943,328,'Centus X-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18945,328,'Corpus X-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18947,328,'Centus X-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18949,328,'Core C-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18951,328,'Core C-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18953,328,'Core C-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18955,328,'Core C-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18957,328,'Core B-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18959,328,'Core B-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18961,328,'Core B-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18963,328,'Core B-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18965,328,'Core A-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18967,328,'Core A-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18969,328,'Core A-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18971,328,'Core A-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18973,328,'Core X-Type Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,200000.0000,1,1681,0),(18975,328,'Core X-Type Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,350000.0000,1,1680,0),(18977,328,'Core X-Type Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,300000.0000,1,1679,0),(18979,328,'Core X-Type Armor Thermic Hardener','An enhanced version of the standard thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,250000.0000,1,1678,0),(18981,325,'Coreli C-Type Small Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,1059,0),(18983,325,'Coreli B-Type Small Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,1059,0),(18985,325,'Coreli A-Type Small Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,1059,0),(18987,325,'Corelum C-Type Medium Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,12470.0000,1,1058,0),(18989,325,'Corelum B-Type Medium Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,12470.0000,1,1058,0),(18991,325,'Corelum A-Type Medium Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,12470.0000,1,1058,0),(18999,62,'Corpii C-Type Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,20000.0000,1,1049,0),(19001,62,'Corpii B-Type Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,20000.0000,1,1049,0),(19003,62,'Corpii A-Type Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,20000.0000,1,1049,0),(19005,62,'Centii C-Type Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,20000.0000,1,1049,0),(19007,62,'Centii B-Type Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,20000.0000,1,1049,0),(19009,62,'Centii A-Type Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,20000.0000,1,1049,0),(19011,62,'Coreli C-Type Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,20000.0000,1,1049,0),(19013,62,'Coreli B-Type Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,20000.0000,1,1049,0),(19015,62,'Coreli A-Type Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,20000.0000,1,1049,0),(19017,62,'Corpum C-Type Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,40000.0000,1,1050,0),(19019,62,'Corpum B-Type Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,40000.0000,1,1050,0),(19021,62,'Corpum A-Type Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,40000.0000,1,1050,0),(19023,62,'Centum C-Type Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,40000.0000,1,1050,0),(19025,62,'Centum B-Type Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,40000.0000,1,1050,0),(19027,62,'Centum A-Type Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,40000.0000,1,1050,0),(19029,62,'Corelum C-Type Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,40000.0000,1,1050,0),(19031,62,'Corelum B-Type Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,40000.0000,1,1050,0),(19033,62,'Corelum A-Type Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,40000.0000,1,1050,0),(19035,62,'Core C-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19036,62,'Core B-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19037,62,'Core A-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19038,62,'Core X-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19039,62,'Corpus C-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19040,62,'Centus C-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19041,62,'Corpus B-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19042,62,'Centus B-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19043,62,'Corpus A-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19044,62,'Centus A-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19045,62,'Corpus X-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19046,62,'Centus X-Type Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(19047,325,'Centii C-Type Small Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,1059,0),(19049,325,'Centii B-Type Small Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,1059,0),(19051,325,'Centii A-Type Small Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,1059,0),(19053,325,'Centum C-Type Medium Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,12470.0000,1,1058,0),(19055,325,'Centum B-Type Medium Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,12470.0000,1,1058,0),(19057,325,'Centum A-Type Medium Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,12470.0000,1,1058,0),(19065,67,'Corpii C-Type Small Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,695,0),(19067,67,'Corpii B-Type Small Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,695,0),(19069,67,'Corpii A-Type Small Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,695,0),(19071,67,'Centii C-Type Small Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,695,0),(19073,67,'Centii B-Type Small Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,695,0),(19075,67,'Centii A-Type Small Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,695,0),(19077,67,'Corpum C-Type Medium Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,696,0),(19079,67,'Corpum B-Type Medium Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,696,0),(19081,67,'Corpum A-Type Medium Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,696,0),(19083,67,'Centum C-Type Medium Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,696,0),(19085,67,'Centum B-Type Medium Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,696,0),(19087,67,'Centum A-Type Medium Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,30000.0000,1,696,0),(19101,68,'Corpii C-Type Small Nosferatu','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,39504.0000,1,692,0),(19103,68,'Corpii B-Type Small Nosferatu','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,39504.0000,1,692,0),(19105,68,'Corpii A-Type Small Nosferatu','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,39504.0000,1,692,0),(19107,68,'Corpum C-Type Medium Nosferatu','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,197520.0000,1,693,0),(19109,68,'Corpum B-Type Medium Nosferatu','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,197520.0000,1,693,0),(19111,68,'Corpum A-Type Medium Nosferatu','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,197520.0000,1,693,0),(19113,68,'Corpus C-Type Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(19115,68,'Corpus B-Type Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(19117,68,'Corpus A-Type Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(19119,68,'Corpus X-Type Heavy Nosferatu','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,987600.0000,1,694,0),(19129,41,'Gistii C-Type Small Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,NULL,4996.0000,1,603,0),(19131,41,'Gistii B-Type Small Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,NULL,4996.0000,1,603,0),(19133,41,'Gistii A-Type Small Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,NULL,4996.0000,1,603,0),(19135,41,'Pithi C-Type Small Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,NULL,4996.0000,1,603,0),(19137,41,'Pithi B-Type Small Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,NULL,4996.0000,1,603,0),(19139,41,'Pithi A-Type Small Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,NULL,4996.0000,1,603,0),(19141,41,'Gistum C-Type Medium Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,NULL,12470.0000,1,602,0),(19143,41,'Gistum B-Type Medium Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,NULL,12470.0000,1,602,0),(19145,41,'Gistum A-Type Medium Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,NULL,12470.0000,1,602,0),(19147,41,'Pithum C-Type Medium Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,NULL,12470.0000,1,602,0),(19149,41,'Pithum B-Type Medium Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,NULL,12470.0000,1,602,0),(19151,41,'Pithum A-Type Medium Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,10,0,1,NULL,12470.0000,1,602,0),(19169,40,'Gistii C-Type Small Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,NULL,9116.0000,1,609,0),(19171,40,'Gistii B-Type Small Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,NULL,9116.0000,1,609,0),(19173,40,'Gistii A-Type Small Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,NULL,9116.0000,1,609,0),(19175,40,'Pithi C-Type Small Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,NULL,9116.0000,1,609,0),(19177,40,'Pithi B-Type Small Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,NULL,9116.0000,1,609,0),(19179,40,'Pithi A-Type Small Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,NULL,9116.0000,1,609,0),(19181,40,'Gistum C-Type Medium Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,NULL,36464.0000,1,610,0),(19183,40,'Gistum B-Type Medium Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,NULL,36464.0000,1,610,0),(19185,40,'Gistum A-Type Medium Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,NULL,36464.0000,1,610,0),(19187,40,'Pithum C-Type Medium Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,NULL,36464.0000,1,610,0),(19189,40,'Pithum B-Type Medium Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,NULL,36464.0000,1,610,0),(19191,40,'Pithum A-Type Medium Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,NULL,36464.0000,1,610,0),(19193,40,'Gist C-Type Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(19194,40,'Gist B-Type Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(19195,40,'Gist C-Type X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(19196,40,'Gist B-Type X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(19197,40,'Gist A-Type X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(19198,40,'Gist X-Type X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(19199,40,'Gist A-Type Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(19200,40,'Gist X-Type Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(19201,40,'Pith C-Type Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(19202,40,'Pith C-Type X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(19203,40,'Pith B-Type Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(19204,40,'Pith B-Type X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(19205,40,'Pith A-Type Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(19206,40,'Pith A-Type X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(19207,40,'Pith X-Type Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,1,72864.0000,1,611,0),(19208,40,'Pith X-Type X-Large Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,1,291456.0000,1,612,0),(19209,295,'Pithum C-Type Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(19211,295,'Pithum C-Type Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(19213,295,'Pithum C-Type Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(19215,295,'Pithum C-Type EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(19217,295,'Pithum B-Type Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(19219,295,'Pithum B-Type Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(19221,295,'Pithum B-Type Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(19223,295,'Pithum B-Type EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(19225,295,'Pithum A-Type Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(19227,295,'Pithum A-Type Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(19229,295,'Pithum A-Type Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(19231,295,'Pithum A-Type EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(19233,295,'Gistum C-Type Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(19235,295,'Gistum B-Type Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(19237,295,'Gistum C-Type Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(19239,295,'Gistum B-Type Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(19241,295,'Gistum C-Type Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(19243,295,'Gistum B-Type Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(19245,295,'Gistum C-Type EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(19247,295,'Gistum B-Type EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(19249,295,'Gistum A-Type Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1690,0),(19251,295,'Gistum A-Type Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1688,0),(19253,295,'Gistum A-Type Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1689,0),(19255,295,'Gistum A-Type EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,18742.0000,1,1691,0),(19257,77,'Gist C-Type Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(19258,77,'Pith C-Type Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(19259,77,'Gist C-Type Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(19260,77,'Pith C-Type Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(19261,77,'Gist C-Type Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(19262,77,'Pith C-Type Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(19263,77,'Gist C-Type EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(19264,77,'Pith C-Type EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(19265,77,'Gist B-Type EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(19266,77,'Pith B-Type EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(19267,77,'Gist B-Type Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(19268,77,'Pith B-Type Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(19269,77,'Gist B-Type Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(19270,77,'Pith B-Type Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(19271,77,'Gist B-Type Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(19272,77,'Pith B-Type Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(19273,77,'Gist A-Type Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(19274,77,'Pith A-Type Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(19275,77,'Gist A-Type Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(19276,77,'Pith A-Type Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(19277,77,'Gist A-Type Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(19278,77,'Pith A-Type Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(19279,77,'Gist A-Type EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(19280,77,'Pith A-Type EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(19281,77,'Gist X-Type EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(19282,77,'Pith X-Type EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,4,45412.0000,1,1695,0),(19283,77,'Gist X-Type Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(19284,77,'Pith X-Type Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,8,45412.0000,1,1692,0),(19285,77,'Gist X-Type Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(19286,77,'Pith X-Type Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,1,45412.0000,1,1694,0),(19287,77,'Gist X-Type Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(19288,77,'Pith X-Type Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,2,5808.0000,1,1693,0),(19289,338,'Pith C-Type Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(19293,338,'Gist A-Type Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(19295,338,'Pith X-Type Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(19297,338,'Gist C-Type Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(19299,338,'Gist B-Type Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(19301,338,'Gist X-Type Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(19303,338,'Pith B-Type Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(19311,338,'Pith A-Type Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,350000.0000,1,613,0),(19313,46,'Coreli C-Type 5MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,790940.0000,1,131,0),(19315,46,'Corelum C-Type 50MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,790940.0000,1,131,0),(19317,46,'Core C-Type 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(19319,46,'Coreli B-Type 5MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,790940.0000,1,131,0),(19321,46,'Corelum B-Type 50MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,790940.0000,1,131,0),(19323,46,'Core B-Type 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(19325,46,'Coreli A-Type 5MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,790940.0000,1,131,0),(19327,46,'Corelum A-Type 50MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,790940.0000,1,131,0),(19329,46,'Core A-Type 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(19335,46,'Core X-Type 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(19337,46,'Gistii C-Type 5MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,790940.0000,1,131,0),(19339,46,'Gistum C-Type 50MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,790940.0000,1,131,0),(19341,46,'Gist C-Type 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(19343,46,'Gistii B-Type 5MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,790940.0000,1,131,0),(19345,46,'Gistum B-Type 50MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,790940.0000,1,131,0),(19347,46,'Gist B-Type 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(19349,46,'Gistii A-Type 5MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,790940.0000,1,131,0),(19351,46,'Gistum A-Type 50MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,790940.0000,1,131,0),(19353,46,'Gist A-Type 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(19359,46,'Gist X-Type 500MN Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,790940.0000,1,131,0),(19361,326,'Corpum B-Type Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(19363,326,'Centum B-Type Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,75000.0000,1,1684,0),(19365,446,'Sarum Customs General','This is a security vessel of the Sarum Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(19366,446,'Ammatar Customs General','This is a security vessel of the Ammatar Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(19367,446,'Caldari Customs Commissioner','This is a security vessel of the Caldari Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',20000000,1080000,14000,1,1,0.0000,0,NULL,0),(19368,446,'Khanid Customs General Major','This is a security vessel of the Khanid Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(19369,446,'Gallente Customs Major','This is a security vessel of the Gallente Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',20000000,1080000,14000,1,8,0.0000,0,NULL,0),(19370,446,'Minmatar Customs Commander','This is a security vessel of the Minmatar Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',20000000,1080000,14000,1,2,0.0000,0,NULL,0),(19371,446,'Amarr Customs General','This is a security vessel of the Amarr Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',20000000,1080000,14000,1,4,0.0000,0,NULL,0),(19372,446,'Amarr Customs Surveillance Officer','This is a security vessel of the Amarr Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',1810000,18100,275,1,4,0.0000,0,NULL,0),(19373,496,'The Prize Container','A container like this one often holds some valuables.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(19382,314,'Luther Veron\'s Head','This is the head of Gallente General Luther Veron in all its flabby, balding glory.  As it is not connected to his body at present it quite lacks the prestige it has grown accustomed to and, judging by the expression on its face, it\'s not at all content with this fact.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19383,446,'Gallente Customs Official','This is a security vessel of the Gallente Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',2040000,20400,160,1,8,0.0000,0,NULL,0),(19384,446,'Sarum Customs Surveillance Officer','This is a security vessel of the Sarum Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',1810000,18100,200,1,4,0.0000,0,NULL,0),(19385,446,'Caldari Customs Agent','This is a security vessel of the Caldari Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',1650000,16500,190,1,1,0.0000,0,NULL,0),(19386,446,'Khanid Customs Surveillance Officer','This is a security vessel of the Khanid Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',80000,20400,200,1,4,0.0000,0,NULL,0),(19387,446,'Ammatar Customs Surveillance Officer','This is a security vessel of the Ammatar Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',1810000,18100,200,1,4,0.0000,0,NULL,0),(19388,446,'Minmatar Customs Patroller','This is a security vessel of the Minmatar Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',1200000,12000,80,1,2,0.0000,0,NULL,0),(19398,284,'Confiscated Viral Agent','The causative agent of an infectious disease, the viral agent is a parasite with a noncellular structure composed mainly of nucleic acid within a protein coat.',100,0.5,0,1,NULL,0.0000,1,22,0),(19399,314,'Confiscated Vitoc','The Vitoc booster has become more than a simple strategy by the Amarrians in controlling their slaves. With the Vitoc method, slaves are injected with a toxic chemical substance that is fatal unless the recipient receives a constant supply of an antidote.',800,0.5,0,1,NULL,0.0000,1,NULL,0),(19400,493,'1st Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,10000.0000,1,751,0),(19401,493,'2nd Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,20000.0000,1,751,0),(19402,493,'3rd Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,40000.0000,1,751,0),(19403,493,'4th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,60000.0000,1,751,0),(19404,493,'5th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,180000.0000,1,751,0),(19405,493,'6th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,360000.0000,1,751,0),(19406,493,'7th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,600000.0000,1,751,0),(19407,493,'8th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,1200000.0000,1,751,0),(19408,493,'9th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,2100000.0000,1,751,0),(19409,493,'11th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,6300000.0000,1,751,0),(19410,493,'12th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,9900000.0000,1,751,0),(19411,493,'13th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,13200000.0000,1,751,0),(19412,493,'14th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,17160000.0000,1,751,0),(19413,493,'15th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,21840000.0000,1,751,0),(19414,493,'16th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,29120000.0000,1,751,0),(19415,493,'17th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,35700000.0000,1,751,0),(19416,493,'18th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,43200000.0000,1,751,0),(19417,493,'19th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,51680000.0000,1,751,0),(19418,493,'20th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,61200000.0000,1,751,0),(19419,493,'21st Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,80000000.0000,1,751,0),(19420,493,'22nd Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,101640000.0000,1,751,0),(19421,493,'23rd Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,133837000.0000,1,751,0),(19422,493,'10th Tier Overseer\'s Personal Effects','Obtaining a Deadspace Overseer\'s personal effects is proof that you have finished clearing all major obstacles in a deadspace pocket and decimated the leading figure. <p>Anyone that procures an OPE (from the pirates themselves, their bases or from guarded containers) can sell them to Concord or DED for a reasonable amount of cash. <p>Concord has rated Deadspace Overseers by the threat they pose to society and divided them into tiers that dictate how much a seller gets for their effects.',25,10,0,1,NULL,3360000.0000,1,751,0),(19423,821,'Watch Officer','An overseer of the Angel Cartel the Watch Officer controls his troops with determination.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(19424,821,'Serpentis Shipyard Defender','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(19425,496,'Black Drone Container','The drone-built container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(19426,494,'Strain Operation Bunker','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19427,494,'Hive Under Construction','This gigantic superstructure was built by the effort of thousands of rogue drones. While the structure appears to be incomplete, its intended shape remains a mystery to the clueless carbon-based lifeforms.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19430,257,'Omnipotent','Those who possess this are all knowing and all seeing with unlimited power and authority.',0,0.01,0,1,16,0.0000,0,NULL,0),(19459,498,'\'Phase\' Servitor','Servitor are Self contained Expert Systems used to radicaly alter the functionlity of a specific core system. These Systems are quite large but being self contained they connect to the ship though a Dedicated interface node without any disruption to the ships power and computer systems.   ',1,5,0,1,NULL,0.0000,0,NULL,0),(19461,314,'Blaque Voucher','This is a candidate voucher for Mentas Blaque, used to determine the biggest supporters of this particular candidate for selecting candidate emissaries.',1,0.5,0,1,NULL,0.0000,1,754,0),(19462,314,'Foiritan Voucher','This is a candidate voucher for Souro Foiritan, used to determine the biggest supporters of this particular candidate for selecting candidate emissaries.',1,0.5,0,1,NULL,0.0000,1,754,0),(19463,314,'Autrech Voucher','This is a candidate voucher for Eman Autrech, used to determine the biggest supporters of this particular candidate for selecting candidate emissaries.',1,0.5,0,1,NULL,0.0000,1,754,0),(19466,498,'Regular Mercenary Navigator','Servitor are Self contained Expert Systems used to radicaly alter the functionlity of a specific core system. These Systems are quite large but being self contained they connect to the ship though a Dedicated interface node without any disruption to the ships power and computer systems.   ',1,5,0,1,NULL,0.0000,0,NULL,0),(19468,498,'\'Longbow\' Servitor','Servitor are Self contained Expert Systems used to radicaly alter the functionlity of a specific core system. These Systems are quite large but being self contained they connect to the ship though a Dedicated interface node without any disruption to the ships power and computer systems.   ',1,5,0,1,NULL,0.0000,0,NULL,0),(19470,311,'Intensive Reprocessing Array','An anchorable reprocessing array, able to take raw ores and process them into minerals. Has a lower reprocessing yield than fully upgraded outposts, but due to its mobile nature it is very valuable to frontier industrialists who operate light years away from the nearest permanent installation. This unit is for use in low and null security space only.',50000000,6000,200000,1,NULL,75000000.0000,1,482,0),(19487,494,'Angel Battlestation','This gigantic suprastructure is one of the military installations of the Angel pirate corporation. Even for its size, it has no commercial station services or docking bay to receive guests.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(19489,38,'Thukker Modified Medium Shield Extender','Increases the maximum strength of the shield.',0,10,0,1,NULL,114760.0000,0,NULL,0),(19491,46,'Thukker Modified 100MN Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Battleship class module',0,5,0,1,NULL,161280.0000,0,NULL,0),(19493,314,'Arms Cache','Personal weapons and armaments, used both for warfare and personal security.',2500,2,0,1,NULL,100.0000,1,NULL,0),(19500,747,'Zor\'s Custom Navigation Link','A neural Interface upgrade that boost the pilots skill in a specific area. This Navigation Link was created for the ruthless pirate commander, referred to as \'Zor\'.\r\r\n\r\r\n10% bonus to afterburner duration.',0,1,0,1,NULL,800000.0000,1,1490,0),(19501,494,'The Damsels Wimpy Prison','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19502,494,'The Damsels Wimpy Brothel','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19504,494,'Pirate Headquarters','Zazzmatazz\'s outpost headquarters is located in this jumble of structures and asteroid leftovers.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19505,319,'Guristas Starbase Control Tower','Originally designed by the Kaalakiota, the Caldari Control Tower blueprint was quickly obtained by the Guristas, through their agents within the State, to serve their own needs.',100000,1150,8850,1,1,0.0000,0,NULL,0),(19533,319,'Gas/Storage Silo - Pirate Extravaganza lvl 3_ MISSION','Built to withstand assault, these behemoths can each hold roughly 8.5 million m3 worth of materials.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19534,300,'High-grade Talisman Alpha','This ocular filter has been modified by Blood Raider scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,800000.0000,1,618,0),(19535,300,'High-grade Talisman Beta','This memory augmentation has been modified by Blood Raider scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Memory\r\r\n\r\r\nSecondary Effect: 2% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,800000.0000,1,619,0),(19536,300,'High-grade Talisman Gamma','This neural boost has been modified by Blood Raider scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,800000.0000,1,620,0),(19537,300,'High-grade Talisman Delta','This cybernetic subprocessor has been modified by Blood Raider scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 4% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,800000.0000,1,621,0),(19538,300,'High-grade Talisman Epsilon','This social adaptation chip has been modified by Blood Raider scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,800000.0000,1,622,0),(19539,300,'High-grade Talisman Omega','This implant does nothing in and of itself, but when used in conjunction with other Talisman implants it will boost their effect. \r\r\n\r\r\n50% bonus to the strength of all Talisman implant secondary effects.',0,1,0,1,NULL,800000.0000,1,1506,0),(19540,300,'High-grade Snake Alpha','This ocular filter has been modified by Serpentis scientists for use by their elite smugglers.\r\r\n\r\r\nPrimary Effect: +4 bonus to Perception\r\r\n\r\r\nSecondary Effect: 0.5% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,800000.0000,1,618,0),(19547,738,'Inherent Implants \'Noble\' Repair Systems RS-605','A neural Interface upgrade that boosts the pilot\'s skill in operating armor/hull repair modules.\r\r\n\r\r\n5% reduction in repair systems duration.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,0.0000,1,1514,0),(19548,738,'Inherent Implants \'Noble\' Remote Armor Repair Systems RA-705','A neural Interface upgrade that boosts the pilot\'s skill in the operation of remote armor repair systems.\r\r\n\r\r\n5% reduced capacitor need for remote armor repair system modules.',0,1,0,1,NULL,0.0000,1,1515,0),(19549,738,'Inherent Implants \'Noble\' Mechanic MC-805','A neural Interface upgrade that boosts the pilot\'s skill at maintaining the mechanical components and structural integrity of a spaceship.\r\r\n\r\r\n5% bonus to hull hp.',0,1,0,1,NULL,0.0000,1,1516,0),(19550,738,'Inherent Implants \'Noble\' Hull Upgrades HG-1005','A neural Interface upgrade that boosts the pilot\'s skill at maintaining their ship\'s midlevel defenses. \r\r\n\r\r\n5% bonus to armor hit points.',0,1,0,1,NULL,0.0000,1,1518,0),(19551,300,'High-grade Snake Beta','This memory augmentation has been modified by Serpentis scientists for use by their elite smugglers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Memory\r\r\n\r\r\nSecondary Effect: 0.625% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,800000.0000,1,619,0),(19553,300,'High-grade Snake Gamma','This neural boost  has been modified by Serpentis scientists for use by their elite smugglers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 0.75% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,800000.0000,1,620,0),(19554,300,'High-grade Snake Delta','This cybernetic subprocessor has been modified by Serpentis scientists for use by their elite smugglers.\r\r\n\r\r\nPrimary Effect: +4 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 0.875% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,800000.0000,1,621,0),(19555,300,'High-grade Snake Epsilon','This social adaptation chip has been modified by Serpentis scientists for use by their elite smugglers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 1% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,800000.0000,1,622,0),(19556,300,'High-grade Snake Omega','This implant does nothing in and of itself, but when used in conjunction with other Snake implants it will boost their effect. \r\r\n\r\r\n200% bonus to the strength of all Snake implant secondary effects.',0,1,0,1,NULL,800000.0000,1,1506,0),(19557,494,'Low-Tech Deadspace Energy Harvester','Containing only a handful of mechanical components, this simple wonder harvests energy from the system\'s sun by virtue of the unique EM refractive qualities in its scartate fabric.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19558,494,'Angel Radiating Telescope','This huge radio telescope contains fragile but advanced sensory equipment. A structure such as this has enormous capabilities in crunching survey data from nearby systems and constellations.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19559,494,'Habitation Module','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19560,494,'Deserted Starbase Storage Facility','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(19561,494,'Habitation Module','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19562,494,'Habitation Module','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19563,446,'CONCORD Customs Commander','This is a security vessel of the CONCORD Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',20000000,1080000,14000,1,8,0.0000,0,NULL,0),(19564,446,'CONCORD Customs Official','This is a security vessel of the CONCORD Customs force. It is patrolling this sector and will proactively scan bypassing vessels for illegal goods.\r\r\n\r\r\nThreat level: Very high',2040000,20400,160,1,8,0.0000,0,NULL,0),(19565,494,'Guristas Bunker_MISSION','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19582,314,'Guristas Research Data','These documents contain valuable technical data on Gurista ship technology.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19583,498,'Regular Mercenary Scout','Servitor are Self contained Expert Systems used to radicaly alter the functionlity of a specific core system. These Systems are quite large but being self contained they connect to the ship though a Dedicated interface node without any disruption to the ships power and computer systems.   ',1,5,0,1,NULL,0.0000,0,NULL,0),(19585,474,'Dewak\'s Level 1 Decoder','The feared prison warden Dewak is a master codemaker and built and programmed this cipher in his private lab. He distributes prison gate decoders only amongst his most trusted and highly paid officers.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19586,474,'Dewak\'s Level 2 Decoder','The feared prison warden Dewak is a master codemaker and built and programmed this second level cipher in his private lab. He distributes prison gate decoders only amongst his most trusted and highly paid officers.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19587,474,'Dewak\'s Level 3 Decoder','The feared prison warden Dewak is a master codemaker and built and programmed this third level cipher in his private lab. He distributes prison gate decoders only amongst his most trusted and highly paid officers.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19588,494,'Gas/Storage Silo','Built to withstand assault, these behemoths can each hold roughly 8.5 million m3 worth of materials.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19589,817,'Utori Kumesh','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',10700000,107000,850,1,1,0.0000,0,NULL,0),(19590,494,'Dewak\'s First Officer\'s HQ','It is through these headquarters that everyone heading for the inner deadspace pockets must go.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19591,496,'Dewak\'s Dot','Inside this container, Dewak regularly puts a new set of ciphers for the third acceleration gate in the Pith\'s Penal Complex. The keys are especially well guarded.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(19592,821,'\'Screaming\' Dewak Humfry','Dewak is a fiercely disciplined tactician. A veteran of Imperial navy battles, he acuired a taste for Sadistic oppression during cleanup operations of the 2nd Illinfrik insurgence, and went into business in the private sector. The Pith Guristas use Dewak\'s prison facilities manily to eliminate competition and also to extract knowledge from difficult \"business\" associates.',21000000,1040000,235,1,1,0.0000,0,NULL,0),(19593,319,'Imai Kenon\'s Corpse','Imai Kenon evidently met a painful death after his ship had been infested by rogue drones.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19594,498,'\'Dart\' Servitor','Servitor are Self contained Expert Systems used to radicaly alter the functionlity of a specific core system. These Systems are quite large but being self contained they connect to the ship though a Dedicated interface node without any disruption to the ships power and computer systems.   ',1,5,0,1,NULL,0.0000,0,NULL,0),(19620,821,'Drone Commandeered Battleship','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(19621,474,'Perimeter Descramble Code','This fractal generated descrambling code is used by local Rogue Drones as a way to secure access through the  acceleration gate. Once the code is used, the gate will remain open for a short period of time and the code will be rendered useless as a new security codeline will be automatically generated.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19622,494,'Starbase Storage Facility','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(19653,494,'Industrial Derelict','This Iteron V-class industrial has been left here by the former owner of the station, before the rogue drones took over the complex.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(19658,976,'Melted Snowball CVII','This snowball used to be bigger than your head. Now it is just a puddle of water. Onoes.',100,1,0,100,NULL,0.0000,1,1663,0),(19660,501,'Festival Launcher','An otherworldly glow emanates from this strange and outlandish-looking device. Its missile tubes look suspiciously capable of fitting a huge snowball, fireworks, and other festive ammunition.',0,20,5,1,NULL,0.0000,1,1663,0),(19662,817,'Jarkon Puman','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(19663,370,'Jarkon Puman\'s Tag','This brass tag carries the rank insignia equivalent of a sergeant within the Serpentis drug corporation. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,750,0),(19664,383,'Ammatar Point Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(19665,383,'Ammatar Light Missile Battery','This Light missile Sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(19666,383,'Ammatar Heavy Missile Battery','This Heavy missile Sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(19667,383,'Ammatar Cruise Missile Battery','This Cruise missile Sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(19668,383,'Tower Sentry Ammatar I','Ammatar tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(19669,383,'Tower Sentry Ammatar II','Ammatar tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(19670,383,'Tower Sentry Ammatar III','Ammatar tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(19671,319,'Ammatar Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19672,319,'Ammatar Cathedral','This impressive structure operates as a place for religious practice and the throne of a high ranking member within the clergy.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19673,319,'Ammatar Deadspace Tactical Unit','Tactical outposts serve as the first line of defense of the Ammatars against their Minmatar cousins.  The design of these Tactical Units come from the Amarr Empire, originally as a personal gift from the Emperor himself when the Ammatar nation was founded.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(19674,816,'Warlord Ixon Kruz','Warlord Ixon Kruz is an up-and-coming general within the Minmatar Fleet.  Known for his recklessness and defiance of authority, Ixon is not very popular among the leadership within the Republic, but has had a growing following amongst it\'s troops.',19000000,850000,600,1,2,0.0000,0,NULL,0),(19675,409,'Ixon Kruz\'s Insignia','The insignia of the Minmatar Warlord Ixon Kruz.',0.1,0.1,0,1,2,0.0000,1,NULL,0),(19676,817,'Ixon Reaver','The Ixon Reavers are the personal guard ships of Warlord Ixon Kruz of the Minmatar Republic.  Known for their ferocity in combat and otherwise, Minmatar Reavers are feared even amongst their own people.',10900000,109000,120,1,2,0.0000,0,NULL,0),(19677,816,'Commander Dakin Gara','Commander Dakin Gara has, throughout the years, acquired a reputation as one of the most competent commanders in Caldari Navy history.  His swift and fearless decision-making prowess and level-headedness in combat situations have carved for him a reputation sure to someday pass into legend.',19000000,1080000,665,1,1,0.0000,0,NULL,0),(19678,409,'Dakin Gara\'s Insignia','The insignia of the Caldari Commander, Dakin Gara.',0.1,0.1,0,1,1,0.0000,1,NULL,0),(19679,816,'High Priest Karmone Tizmer','Tizmer is a prominent member of the fanatical Cult of Catechization. Founded centuries ago by the Emperor to teach the scripts to heathens, the cult became more and more belligerent over time. Eventually they started hunting and killing those heathens or heretics not deemed worthy or capable of receiving the Holy Word. Today, they are still active under the protective wing of the Emperor and are mainly focused on the Blood Raiders, whom cult members consider to be their ultimate nemeses and have vowed to eradicate fully.',19000000,1150000,675,1,4,0.0000,0,NULL,0),(19680,409,'Karmone Tizmer\'s Insignia','The insignia of the High Priest, Karmone Tizmer.',0.1,0.1,0,1,4,0.0000,1,NULL,0),(19681,817,'Hunter Malbreth','This is a bounty hunter.  These freelancers can be of any race and come from all walks of life, sometimes they have mercenaries aiding them, but they usually work solo.  Normally, unless sent to kill you, they will leave you alone.  Threat level: Deadly',10900000,109000,120,1,4,0.0000,0,NULL,0),(19683,816,'Commander Genom Tara','Commander Genom Tara was a decorated Navy squad leader for 10 years before earning the rank of Commander.  He built up quite a reputation for himself on the Ammatar frontier, and was renowned for his bravery on the battlefield.  Sadly however, the past few years have not been kind on Genom.  His Amarrian wife was murdered, along with their children, by Minmatar Freedom Fighters, and soon after his closest friend within the Navy shared the same fate.  This seems to have driven the unfortunate Commander insane.  With his most loyal men by his side, he disobeyed direct orders from the Ammatar government to withdraw from the secret base he was stationed on and instead has been using it as a base of operations to launch attacks on nearby Minmatar settlements, especially keen on sniffing out Minmatar Freedom Fighters for the slaughter.  \r\r\n',19000000,1150000,675,1,4,0.0000,0,NULL,0),(19684,738,'Inherent Implants \'Noble\' Repair Proficiency RP-903','A neural Interface upgrade for analyzing and repairing starship damage.\r\r\n\r\r\n3% bonus to repair system repair amount.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,0.0000,1,1517,0),(19685,738,'Inherent Implants \'Noble\' Repair Proficiency RP-905','A neural Interface upgrade for analyzing and repairing starship damage.\r\r\n\r\r\n5% bonus to repair system repair amount.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,0.0000,1,1517,0),(19686,742,'Eifyr and Co. \'Gunslinger\' Motion Prediction MR-705','An Eifyr and Co. gunnery hardwiring designed to enhance turret tracking.\r\r\n\r\r\n5% bonus to turret tracking speed.',0,1,0,1,NULL,0.0000,1,1499,0),(19687,742,'Eifyr and Co. \'Gunslinger\' Surgical Strike SS-905','An Eifyr and Co. gunnery hardwiring designed to enhance skill with all turrets.\r\r\n\r\r\n5% bonus to all turret damages.',0,1,0,1,NULL,0.0000,1,1501,0),(19688,742,'Eifyr and Co. \'Gunslinger\' Large Projectile Turret LP-1005','An Eifyr and Co. gunnery hardwiring designed to enhance skill with large projectile turrets.\r\r\n\r\r\n5% bonus to large projectile turret damage.',0,1,0,1,NULL,0.0000,1,1502,0),(19689,742,'Eifyr and Co. \'Gunslinger\' Medium Projectile Turret MP-805','An Eifyr and Co. gunnery hardwiring designed to enhance skill with medium projectile turrets.\r\r\n\r\r\n5% bonus to medium projectile turret damage.',0,1,0,1,NULL,0.0000,1,1500,0),(19690,742,'Eifyr and Co. \'Gunslinger\' Small Projectile Turret SP-605','An Eifyr and Co. gunnery hardwiring designed to enhance skill with small projectile turrets.\r\r\n\r\r\n5% bonus to small projectile turret damage.',0,1,0,1,NULL,0.0000,1,1498,0),(19691,742,'Inherent Implants \'Lancer\' Small Energy Turret SE-605','An Inherent Implants gunnery hardwiring designed to enhance skill with small energy turrets.\r\r\n\r\r\n5% bonus to small energy turret damage.',0,1,0,1,NULL,0.0000,1,1498,0),(19692,742,'Inherent Implants \'Lancer\' Controlled Bursts CB-705','An Inherent Implants gunnery hardwiring designed to enhance turret energy management.\r\r\n\r\r\n5% reduction in all turret capacitor need.',0,1,0,1,NULL,0.0000,1,1499,0),(19693,742,'Inherent Implants \'Lancer\' Gunnery RF-905','An Inherent Implants gunnery hardwiring designed to enhance turret rate of fire.\r\r\n\r\r\n5% bonus to all turret rate of fire.',0,1,0,1,NULL,0.0000,1,1501,0),(19694,742,'Inherent Implants \'Lancer\' Large Energy Turret LE-1005','An Inherent Implants gunnery hardwiring designed to enhance skill with large energy turrets.\r\r\n\r\r\n5% bonus to large energy turret damage.',0,1,0,1,NULL,0.0000,1,1502,0),(19695,742,'Inherent Implants \'Lancer\' Medium Energy Turret ME-805','An Inherent Implants gunnery hardwiring designed to enhance skill with medium energy turrets.\r\r\n\r\r\n5% bonus to medium energy turret damage.',0,1,0,1,NULL,0.0000,1,1500,0),(19696,742,'Zainou \'Deadeye\' Sharpshooter ST-905','A Zainou gunnery hardwiring designed to enhance optimal range.\r\r\n\r\r\n5% bonus to turret optimal range.',0,1,0,1,NULL,0.0000,1,1501,0),(19697,742,'Zainou \'Deadeye\' Trajectory Analysis TA-705','A Zainou gunnery hardwiring designed to enhance falloff range.\r\r\n\r\r\n5% bonus to turret falloff.',0,1,0,1,NULL,0.0000,1,1499,0),(19698,742,'Zainou \'Deadeye\' Large Hybrid Turret LH-1005','A Zainou gunnery hardwiring designed to enhance skill with large hybrid turrets.\r\r\n\r\r\n5% bonus to large hybrid turret damage.',0,1,0,1,NULL,0.0000,1,1502,0),(19699,742,'Zainou \'Deadeye\' Medium Hybrid Turret MH-805','A Zainou gunnery hardwiring designed to enhance skill with medium hybrid turrets.\r\r\n\r\r\n5% bonus to medium hybrid turret damage.',0,1,0,1,NULL,0.0000,1,1500,0),(19700,742,'Zainou \'Deadeye\' Small Hybrid Turret SH-605','A Zainou gunnery hardwiring designed to enhance skill with small hybrid turrets.\r\r\n\r\r\n5% bonus to small hybrid turret damage.',0,1,0,1,NULL,0.0000,1,1498,0),(19701,821,'Swarm Parasite Worker','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(19702,474,'Repository Descramble Code','This fractal generated descrambling code is used by local Rogue Drones as a way to secure access through the  acceleration gate. Once the code is used, the gate will remain open for a short period of time and the code will be rendered useless as a new security codeline will be automatically generated.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19703,495,'Swarm Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(19704,821,'Supreme Hive Defender','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(19705,474,'Outgrowth Hive Entrance Code','This fractal generated descrambling code is used by local Rogue Drones as a way to secure access through the  acceleration gate. Once the code is used, the gate will remain open for a short period of time and the code will be rendered useless as a new security codeline will be automatically generated.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19706,310,'Celestial Beacon II','Fitted with a power flash-battery, this beacon sends out signals throughout the entire solar system.',1,1,0,1,NULL,0.0000,0,NULL,0),(19707,495,'Outgrowth Strain Mother','This gargantuan mother drone holds the central CPU, controlling the rogue drones throughout the sector. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(19708,494,'Metal Scraps In Storage','This storage silo is being used as a dump for unwanted material from a nearby habitation.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(19711,319,'AstroFarm','An astrofarm.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19712,319,'HumanFarm','The human farm is for farming humans.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19713,227,'Argon Gas Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19714,494,'Habitation Module','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19715,494,'Habitation Module','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19716,494,'Habitation Module','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19719,257,'Transport Ships','Skill for operation of Transport Ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,30000000.0000,1,377,0),(19720,485,'Revelation','The Revelation represents the pinnacle of Amarrian military technology.  Maintaining their proud tradition of producing the strongest armor plating to be found anywhere, the Empire\'s engineers outdid themselves in creating what is arguably the most resilient dreadnought in existence.\r\r\n\r\r\nAdded to that, the Revelation\'s ability to fire capital beams makes its position on the battlefield a unique one.  When extended sieges are the order of the day, this is the ship you call in.',1237500000,18500000,2175,1,4,2479301962.0000,1,762,0),(19721,537,'Revelation Blueprint',' ',0,0.01,0,1,NULL,2000000000.0000,1,783,0),(19722,485,'Naglfar','The Naglfar is based on a Matari design believed to date back to the earliest annals of antiquity.  While the exact evolution of memes informing its figure is unclear, the same distinctive vertical monolith form has shown up time and time again in the wind-scattered remnants of Matari legend.\r\r\n\r\r\nBoasting an impressive versatility in firepower options, the Naglfar is capable of holding its own against opponents of all sizes and shapes.  While its defenses don\'t go to extremes as herculean as those of its counterparts, the uniformity of resilience - coupled with the sheer amount of devastation it can dish out - make this beast an invaluable addition to any fleet.\r\r\n\r\r\n',1127500000,15500000,2900,1,2,2465892518.0000,1,765,0),(19723,537,'Naglfar Blueprint',' ',0,0.01,0,1,NULL,1850000000.0000,1,786,0),(19724,485,'Moros','Of all the dreadnoughts currently in existence, the imposing Moros possesses a tremendous capacity to fend off garguantuan hostiles while still posing a valid threat to any and all larger-scale threats on the battlefield. By virtue of its protean array of point defense capabilities, and its terrifying ability to unleash rapid and thoroughly devastating amounts of destruction on the battlefield, the Moros is single-handedly capable of turning the tide in a fleet battle.',1292500000,17550000,2550,1,8,2515543002.0000,1,764,0),(19725,537,'Moros Blueprint',' ',0,0.01,0,1,NULL,1900000000.0000,1,785,0),(19726,485,'Phoenix','In terms of Caldari design philosophy, the Phoenix is a chip off the old block.  With a heavily tweaked missile interface, targeting arrays of surpassing quality and the most advanced shield systems to be found anywhere, it is considered the strongest long-range installation attacker out there.\r\r\n\r\r\nWhile its shield boosting actuators allow the Phoenix, when properly equipped, to withstand tremendous punishment over a short duration, its defenses are not likely to hold up against sustained attack over longer periods.  With a strong supplementary force, however, few things in existence rival this vessel\'s pure annihilative force.',1320000000,16250000,2750,1,1,2451853460.0000,1,763,0),(19727,537,'Phoenix Blueprint',' ',0,0.01,0,1,NULL,1950000000.0000,1,784,0),(19728,502,'Deadspace Signature','A cosmic signature.',0,1,0,1,NULL,0.0000,0,NULL,0),(19729,319,'Gallente Bunker UDI','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,4,0.0000,0,NULL,0),(19730,314,'Communications Logs','A stack of encrypted communications logs.  Valuable intelligence data in the right hands.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19731,821,'Sansha Corpse Collector','Jokingly named after his secondary occupation, the check-in officer is used to clean up the mess pilots leave in his complex after being blown to smithereens.',21000000,100100,235,1,4,0.0000,0,NULL,0),(19732,474,'Sansha Supply Pit Passcard','This security passcard is manufactured by Sansha\'s Nation and allows the user to unlock a specific acceleration gate to the lower level of the war supply complex. The gate will remain open for a short period of time and the securitycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19737,621,'Sansha\'s Tyrant Elite','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(19738,494,'Subspace Data Miner','This huge radio telescope contains fragile but advanced sensory equipment. A structure such as this has enormous capabilities in crunching survey data from nearby systems and constellations.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19739,506,'Cruise Missile Launcher II','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.35,1,NULL,784728.0000,1,643,0),(19740,136,'Cruise Missile Launcher II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(19742,494,'Infested station ruins','To speed up the construction process of rogue drone structures, certain strains of drones have been known to salvage the ruins of their defeated enemies, using them either as a base or to slowly dissolve them into their desired final shape.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19743,319,'Extremely Powerful EM Forcefield','A reinforced antimatter generator powered by muonal crystals, creating a perfect circle of electro-magnetic radiance penetrable only by a coordinated attack from the strongest armaments.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19744,28,'Sigil','The Sigil is a recent ship from Viziam based on an old slave transport design.',11000000,230000,2100,1,4,1031756.0000,1,85,0),(19745,108,'Sigil Blueprint',' ',0,0.01,0,1,NULL,4977500.0000,1,285,0),(19746,227,'Dust Storm Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19747,227,'Lightning Storm Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19748,227,'Ethereal Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19749,227,'Celestial Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19750,227,'Infernal Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19751,227,'Icefield Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19752,227,'Krypton Gas Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19753,227,'Toxic Cloud Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19754,227,'Radon Gas Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19755,227,'Turbulent Storm Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19756,227,'Xenon Gas Environment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(19757,15,'Research Outpost','test',0,1,0,1,2,0.0000,0,NULL,0),(19758,307,'Caldari Research Outpost Platform',' ',0,750000,7500000,1,NULL,28146875000.0000,1,1864,0),(19759,272,'Long Distance Jamming','Skill at the long-range operation of electronic warfare systems. 10% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors, Tracking Links, Remote Sensor Boosters and Target Painters per skill level.',0,0.01,0,1,NULL,200000.0000,1,367,0),(19760,272,'Frequency Modulation','Advanced understanding of signal waves. 10% bonus to falloff for ECM, Remote Sensor Dampeners, Tracking Disruptors, Remote Tracking Computers, Remote Sensor Boosters and Target Painters per skill level.',0,0.01,0,1,4,160000.0000,1,367,0),(19761,272,'Signal Dispersion','Skill at the operation of target jamming equipment. 5% bonus to strength of all ECM jammers per skill level.',0,0.01,0,1,NULL,1000000.0000,1,367,0),(19765,306,'Warehouse_MISSION','This is a standard storage facility.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(19766,272,'Signal Suppression','Skill at the operation of remote sensor dampers.  5% bonus to remote sensor dampers\' scan resolution and targeting range suppression per skill level.',0,0.01,0,1,NULL,800000.0000,1,367,0),(19767,272,'Turret Destabilization','Advanced understanding of tracking disruption technology. 5% bonus to Tracking Disruptor modules\' tracking speed, optimal range and falloff disruption per skill level.',0,0.01,0,1,NULL,400000.0000,1,367,0),(19768,817,'Mercenary Corporal','This is a mercenary corporal.  These freelancers will do almost anything for the highest bidder. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(19769,817,'Mercenary Lieutenant','This is a mercenary lieutenant.  These freelancers will do almost anything for the highest bidder. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(19794,306,'Cruise Missile Storage','This is a supply storage for large missiles.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(19795,494,'Radio Telescope','This huge telescope contains fragile but advanced sensory equipment.  Its scanning range is huge, and it is able to detect almost any moving object in the solar system it\'s deployed in at an astoundingly fast rate.  Due to the advantage it gives in combat, use of this prototype outside national militaries has been banned by most governments.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(19806,379,'Target Painter II','A targeting subsystem that projects an electronic \"Tag\" on the target thus making it easier to target and Hit. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized. ',0,5,0,1,NULL,168674.0000,1,757,0),(19807,504,'Target Painter II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(19808,379,'Partial Weapon Navigation','A targeting subsystem that projects a electronic \"Tag\" on the target thus making it easier to target and Hit. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized. ',0,5,0,1,NULL,366.0000,1,757,0),(19809,504,'Partial Weapon Navigation Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(19810,379,'Peripheral Weapon Navigation Diameter','A targeting subsystem that projects a electronic \"Tag\" on the target thus making it easier to target and Hit. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized. ',0,5,0,1,NULL,366.0000,1,757,0),(19811,504,'Peripheral Weapon Navigation Diameter Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(19812,379,'Parallel Weapon Navigation Transmitter','A targeting subsystem that projects a electronic \"Tag\" on the target thus making it easier to target and Hit. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized. ',0,5,0,1,NULL,366.0000,1,757,0),(19813,504,'Parallel Weapon Navigation Transmitter Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(19814,379,'Phased Weapon Navigation Array Generation Extron','A targeting subsystem that projects a electronic \"Tag\" on the target thus making it easier to target and Hit. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized. ',0,5,0,1,NULL,366.0000,1,757,0),(19815,504,'Phased Weapon Navigation Array Generation Extron Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(19921,272,'Target Painting','Skill at using target painters. 5% less capacitor need for target painters per skill level.',0,0.01,0,1,NULL,90000.0000,1,367,0),(19922,272,'Signature Focusing','Advanced understanding of target painting technology. 5% bonus to target painter modules\' signature radius multiplier per skill level.',0,0.01,0,1,NULL,600000.0000,1,367,0),(19923,201,'Induced Ion Field ECM I','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors. ',0,5,0,1,NULL,20000.0000,1,715,0),(19925,201,'Compulsive Ion Field ECM I','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors. ',0,5,0,1,NULL,20000.0000,1,715,0),(19927,201,'\'Hypnos\' Ion Field ECM I','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors. ',0,5,0,1,NULL,20000.0000,1,715,0),(19929,201,'Induced Multispectral ECM I','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,29696.0000,1,719,0),(19931,201,'Compulsive Multispectral ECM I','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,29696.0000,1,719,0),(19933,201,'\'Hypnos\' Multispectral ECM I','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,29696.0000,1,719,0),(19935,201,'Languid Phase Inversion ECM I','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',0,5,0,1,NULL,20000.0000,1,716,0),(19937,201,'Halting Phase Inversion ECM I','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',0,5,0,1,NULL,20000.0000,1,716,0),(19939,201,'Enfeebling Phase Inversion ECM I','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',0,5,0,1,NULL,20000.0000,1,716,0),(19942,201,'FZ-3a Disruptive Spatial Destabilizer ECM','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',0,5,0,1,NULL,20000.0000,1,717,0),(19944,201,'CZ-4 Concussive Spatial Destabilizer ECM','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',0,5,0,1,NULL,20000.0000,1,717,0),(19946,201,'BZ-5 Neutralizing Spatial Destabilizer ECM','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',0,5,0,1,NULL,20000.0000,1,717,0),(19948,201,'\'Gloom\' White Noise ECM','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',0,5,0,1,NULL,20000.0000,1,718,0),(19950,201,'\'Shade\' White Noise ECM','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',0,5,0,1,NULL,20000.0000,1,718,0),(19952,201,'\'Umbra\' White Noise ECM','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',0,5,0,1,NULL,20000.0000,1,718,0),(19954,474,'Soran\'s Passkey','Markings indicate that Soran\'s Passkey will activate two Acceleration Gates. One is marked as a check-gate which will leave the key intact, while the other one is some highly encrypted Accleration Gate called \"Station Ultima\". That gate will seemingly destroy the key and unlock the gate to a single ship.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(19955,495,'\'True Power\' Assembly Security HQ','The headquarters of the True Power security headquarters have been fitted with huge citadel torpedo batteries, a long range stasis web generators and powerful long-range sensors.',1000,1000,1000,1,4,0.0000,0,NULL,0),(19957,494,'Centus Reprocessing Station','A harvesting factory for collecting moon minerals.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(19960,496,'Special Products','This container is securely guarded.',10000,2750,2700,1,NULL,0.0000,0,NULL,0),(19961,495,'Station Ultima','The famed Station Ultima houses secret development projects and production. The most high ranking leaders of Sansha\'s Nation are rumoured to meet here from time to time.',1000,1000,1000,1,4,0.0000,0,NULL,0),(19962,85,'Shadow Iron Charge S','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.01,0.0025,0,100,NULL,222.0000,1,993,0),(19964,85,'Shadow Tungsten Charge S','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.01,0.0025,0,100,NULL,332.0000,1,993,0),(19966,85,'Shadow Iridium Charge S','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.01,0.0025,0,100,NULL,428.0000,1,993,0),(19968,85,'Shadow Lead Charge S','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.01,0.0025,0,100,NULL,524.0000,1,993,0),(19970,83,'Arch Angel Carbonized Lead S','This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,222.0000,1,989,0),(19972,83,'Arch Angel Nuclear S','Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,332.0000,1,989,0),(19974,83,'Arch Angel Proton S','Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,428.0000,1,989,0),(19976,83,'Arch Angel Depleted Uranium S','Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',0.01,0.0025,0,100,NULL,524.0000,1,989,0),(19978,86,'Sanshas Radio S','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3008.0000,1,997,0),(19980,86,'Sanshas Microwave S','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2000.0000,1,997,0),(19982,86,'Sanshas Infrared S','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1128.0000,1,997,0),(19984,86,'Sanshas Standard S','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1358.0000,1,997,0),(19986,83,'Arch Angel Titanium Sabot S','This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.0025,0,100,NULL,660.0000,1,989,0),(19988,83,'Arch Angel Fusion S','The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.0025,0,100,NULL,732.0000,1,989,0),(19990,83,'Arch Angel Phased Plasma S','This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range. ',1,0.0025,0,100,NULL,848.0000,1,989,0),(19992,83,'Arch Angel EMP S','A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.0025,0,100,NULL,1056.0000,1,989,0),(19994,83,'Arch Angel Carbonized Lead M','This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.0125,0,100,NULL,848.0000,1,988,0),(19995,165,'Arch Angel Carbonized Lead M Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(19996,83,'Arch Angel Nuclear M','Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.0125,0,100,NULL,1328.0000,1,988,0),(19998,83,'Arch Angel Proton M','Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.0125,0,100,NULL,1830.0000,1,988,0),(20000,83,'Arch Angel Depleted Uranium M','Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.0125,0,100,NULL,2236.0000,1,988,0),(20002,83,'Arch Angel Titanium Sabot M','This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.0125,0,100,NULL,2608.0000,1,988,0),(20003,165,'Arch Angel Titanium Sabot M Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20004,83,'Arch Angel Fusion M','The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,3054.0000,1,988,0),(20006,83,'Arch Angel Phased Plasma M','This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,3544.0000,1,988,0),(20008,83,'Arch Angel EMP M','A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,4458.0000,1,988,0),(20010,86,'Sanshas Radio M','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,31062.0000,1,996,0),(20012,86,'Sanshas Microwave M','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,20192.0000,1,996,0),(20014,86,'Sanshas Infrared M','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,10192.0000,1,996,0),(20016,86,'Sanshas Standard M','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,12736.0000,1,996,0),(20018,86,'Sanshas Radio L','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,336522.0000,1,995,0),(20020,86,'Sanshas Microwave L','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,218720.0000,1,995,0),(20022,86,'Sanshas Infrared L','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,108552.0000,1,995,0),(20024,86,'Sanshas Standard L','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,141320.0000,1,995,0),(20026,86,'Sanshas Radio XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3336522.0000,1,1007,0),(20028,86,'Sanshas Microwave XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2218720.0000,1,1007,0),(20030,86,'Sanshas Infrared XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1108552.0000,1,1007,0),(20032,86,'Sanshas Standard XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1391864.0000,1,1007,0),(20034,85,'Shadow Thorium Charge S','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.05,0.0025,0,100,NULL,660.0000,1,993,0),(20036,85,'Shadow Uranium Charge S','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.05,0.0025,0,100,NULL,778.0000,1,993,0),(20038,85,'Shadow Plutonium Charge S','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.05,0.0025,0,100,NULL,848.0000,1,993,0),(20040,85,'Shadow Antimatter Charge S','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.05,0.0025,0,100,NULL,1056.0000,1,993,0),(20043,85,'Shadow Iron Charge M','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.1,0.0125,0,100,NULL,848.0000,1,992,0),(20045,85,'Shadow Tungsten Charge M','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.1,0.0125,0,100,NULL,1208.0000,1,992,0),(20047,85,'Shadow Iridium Charge M','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.1,0.0125,0,100,NULL,1664.0000,1,992,0),(20049,85,'Shadow Lead Charge M','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.1,0.0125,0,100,NULL,1832.0000,1,992,0),(20051,85,'Shadow Thorium Charge M','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.5,0.0125,0,100,NULL,2436.0000,1,992,0),(20053,85,'Shadow Uranium Charge M','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.5,0.0125,0,100,NULL,3042.0000,1,992,0),(20055,85,'Shadow Plutonium Charge M','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.5,0.0125,0,100,NULL,3588.0000,1,992,0),(20057,85,'Shadow Antimatter Charge M','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.5,0.0125,0,100,NULL,4458.0000,1,992,0),(20059,365,'Amarr Control Tower Medium','The Amarr have always been fond of majestic and intimidating constructions. Their Control Towers do not deviate from that tradition and are truly big and powerful structures, intended more for preservation of territorial interests than commercial benefits.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Energy Sentry Optimal Range\r\r\n25% bonus to Energy Sentry Damage\r\r\n50% bonus to Silo Cargo Capacity',200000000,4000,70000,1,4,200000000.0000,1,478,0),(20060,365,'Amarr Control Tower Small','The Amarr have always been fond of majestic and intimidating constructions. Their Control Towers do not deviate from that tradition and are truly big and powerful structures, intended more for preservation of territorial interests than commercial benefits.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Energy Sentry Optimal Range\r\r\n25% bonus to Energy Sentry Damage\r\r\n50% bonus to Silo Cargo Capacity',200000000,2000,35000,1,4,100000000.0000,1,478,0),(20061,365,'Caldari Control Tower Medium','At first the Caldari Control Towers were manufactured by Kaalakiota, but since they focused their efforts mostly on other, more profitable installations, they soon lost the contract and the Sukuuvestaa corporation took over the Control Towers\' development and production.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Missile Battery Rate of Fire\r\r\n50% bonus to Missile Velocity\r\r\n-75% bonus to Electronic Warfare Battery Target Cycling Speed',200000000,4000,70000,1,1,200000000.0000,1,478,0),(20062,365,'Caldari Control Tower Small','At first the Caldari Control Towers were manufactured by Kaalakiota, but since they focused their efforts mostly on other, more profitable installations, they soon lost the contract and the Sukuuvestaa corporation took over the Control Towers\' development and production.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Missile Battery Rate of Fire\r\r\n50% bonus to Missile Velocity\r\r\n-75% bonus to Electronic Warfare Battery Target Cycling Speed',200000000,2000,35000,1,1,100000000.0000,1,478,0),(20063,365,'Gallente Control Tower Medium','Gallente Control Towers are more pleasing to the eye than they are strong or powerful. They have above average electronic countermeasures, average CPU output, and decent power output compared to towers from the other races, but are quite lacking in sophisticated defenses.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Hybrid Sentry Damage\r\r\n100% bonus to Silo Cargo Capacity',200000000,4000,70000,1,8,200000000.0000,1,478,0),(20064,365,'Gallente Control Tower Small','Gallente Control Towers are more pleasing to the eye than they are strong or powerful. They have above average electronic countermeasures, average CPU output, and decent power output compared to towers from the other races, but are quite lacking in sophisticated defenses.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Hybrid Sentry Damage\r\r\n100% bonus to Silo Cargo Capacity',200000000,2000,35000,1,8,100000000.0000,1,478,0),(20065,365,'Minmatar Control Tower Medium','The Matari aren\'t really that high-tech, preferring speed rather than firepower or involved technology. Unfortunately that doesn\'t apply very well to stationary objects, much to the liking of the Amarr Empire.  \r\r\n\r\r\nAmarrians call it a scrapheap of epic proportions. But don\'t underestimate these structures. Minmatar commanders usually have the last laugh when it comes to combat.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Projectile Sentry Optimal Range\r\r\n50% bonus to Projectile Sentry Fall Off Range\r\r\n25% bonus to Projectile Sentry RoF',200000000,4000,70000,1,2,200000000.0000,1,478,0),(20066,365,'Minmatar Control Tower Small','The Matari aren\'t really that high-tech, preferring speed rather than firepower or involved technology. Unfortunately that doesn\'t apply very well to stationary objects, much to the liking of the Amarr Empire.  \r\r\n\r\r\nAmarrians call it a scrapheap of epic proportions. But don\'t underestimate these structures. Minmatar commanders usually have the last laugh when it comes to combat.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Projectile Sentry Optimal Range\r\r\n50% bonus to Projectile Sentry Fall Off Range\r\r\n25% bonus to Projectile Sentry RoF',200000000,2000,35000,1,2,100000000.0000,1,478,0),(20069,316,'Armored Warfare Link - Damage Control I','Reduces the capacitor need of the fleet\'s personal and targeted armor repair systems.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,225005.0000,1,1634,0),(20070,316,'Skirmish Warfare Link - Evasive Maneuvers I','Lowers the signature radius of ships in the fleet.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,196333.0000,1,1637,0),(20077,496,'Main Supply Storage','Of the various supplies to fuel Sansha\'s Nation\'s warfare that are stored in this deadspace pocket, this one is the most securely guarded.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(20078,821,'True Creation\'s Park Overseer','The overseer of this morbid production park is a legendary commander. Formerly known as Dufus Andanin he ran True Creation\'s cybernetics division before being assigned this post.',21000000,100100,235,1,4,0.0000,0,NULL,0),(20079,821,'Effotber\'s Transit Overseer','The pilot of this ship, Daggot Velash, reports directly to Skomener Effotber who is the head of True Creation\'s storage facilities. The ship\'s armor is heavily modified.',21000000,100100,235,1,4,0.0000,0,NULL,0),(20080,821,'Overseer Skomener Effotber','This battleship is in Skomener Effotber\'s possession. Being one of True Creation\'s top employees he equips his command ships with the best modules, shield and armor repair systems he has access to.',21000000,100100,235,1,4,0.0000,0,NULL,0),(20102,494,'Guristas War Installation','This gigantic suprastructure is one of the military installations of the Guristas pirate corporation. Even for its size it has no commercial station services or docking bays to receive guests.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(20103,474,'Product Park Passcard','This security passcard is manufactured by Sansha\'s Nation and allows the user to unlock a specific acceleration gate to the lower level of the war supply complex. The gate will remain open for a short period of time and the securitycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20104,474,'Creations Central Pass','This cipher unlocks the acceleration into the Centus Creations pocket of the sansha war supply complex. The gate will remain open to anyone for a short period of time and using the cipher will cause it to self destruct, so use wisely.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20105,474,'\'True Creations\' Manufacture Passcard','This security passcard is manufactured by Sansha\'s Nation and allows the user to unlock the last acceleration gate of the war supply complex. The gate will remain open for a short period of time and the securitycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20108,356,'Gold Sculpture Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20110,530,'Sleeper Foundation Block','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1902,0),(20113,333,'Datacore - Jove Tech 1',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(20114,333,'Datacore - Propulsion Subsystems Engineering',' ',1,0.1,0,1,4,0.0000,1,1880,0),(20115,333,'Datacore - Engineering Subsystems Engineering',' ',1,0.1,0,1,4,0.0000,1,1880,0),(20116,333,'Datacore - Electronic Subsystems Engineering',' ',1,0.1,0,1,4,0.0000,1,1880,0),(20117,333,'Datacore - Advanced Starship Engineering ',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(20121,300,'High-grade Crystal Alpha','This ocular filter has been modified by Guristas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +4 bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,800000.0000,1,618,0),(20124,316,'Siege Warfare Link - Active Shielding I','Increases the speed of the fleet\'s shield boosters and decreases the duration of shield transporters. Will not affect Capital-sized personal shield boosters.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,225005.0000,1,1636,0),(20125,906,'Curse','Built to represent the last word in electronic warfare, combat recon ships have onboard facilities designed to maximize the effectiveness of electronic countermeasure modules of all kinds.  Filling a role next to their class counterpart, the heavy assault cruiser, combat recon ships are the state of the art when it comes to anti-support support.  They are also devastating adversaries in smaller skirmishes, possessing strong defensive capabilities in addition to their electronic superiority.\r\r\n\r\r\nDeveloper:  Khanid Innovation\r\r\n\r\r\nIn addition to robust electronics systems, the Khanid Kingdom\'s ships possess advanced armor alloys capable of withstanding a great deal of punishment. Generally eschewing the use of turrets, they tend to gear their vessels more towards close-range missile combat.',11810000,120000,345,1,4,48575396.0000,1,827,0),(20126,106,'Curse Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,900,0),(20127,505,'Stealth Bombers Fake Skill','Fake Skill to give the Stealth Bombers bonuses only to Cruise Missile Launchers.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20128,86,'Civilian Pulse Crystal','Modulates the beam of a civilian laser weapons into the visible light spectrum. ',1,1,0,1,NULL,0.0000,0,NULL,0),(20130,86,'Civilian Autocannon Ammo','Standard ammo used in civilian autocannons. ',1,1,0,1,NULL,0.0000,0,NULL,0),(20132,86,'Civilian Railgun Charge','Standard charges used in civilian railguns. ',1,1,0,1,NULL,0.0000,0,NULL,0),(20134,86,'Civilian Blaster Charge','Standard charge used in civilian blasters. ',1,1,0,1,NULL,0.0000,0,NULL,0),(20138,771,'Heavy Assault Missile Launcher I','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,0.75,1,NULL,41700.0000,1,974,0),(20157,300,'High-grade Crystal Beta','This memory augmentation has been modified by Guristas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Memory\r\r\n\r\r\nSecondary Effect: 2% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,800000.0000,1,619,0),(20158,300,'High-grade Crystal Gamma','This neural boost has been modified by Guristas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +4 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,800000.0000,1,620,0),(20159,300,'High-grade Crystal Delta','This cybernetic subprocessor has been modified by Guristas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 4% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,800000.0000,1,621,0),(20160,300,'High-grade Crystal Epsilon','This social adaptation chip has been modified by Guristas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,800000.0000,1,622,0),(20161,300,'High-grade Crystal Omega','This implant does nothing in and of itself, but when used in conjunction with other Crystal implants it will boost their effect. \r\r\n\r\r\n50% bonus to the strength of all Crystal implant secondary effects.\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,800000.0000,1,1506,0),(20162,494,'Asteroid Colony','Highly vulnerable, but economically extremely feasible, asteroid factories are one of the major boons of the expanding space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20163,683,'Minmatar Miner','The Burst is a small and fast cargo vessel. It can easily be used as a small-time miner, but requires some crunching assistance for large-scale mining operations.',1350000,17100,225,1,2,0.0000,0,NULL,0),(20164,474,'Drazin\'s Keycard','This is a chaos-logic keycard. It had been issued to a pirate by the name of Drazin Jaruk. It will open the acceleration gate for a short time and then self-destruct.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20165,319,'Asteroid Prime Colony_MISSION lvl 3','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20166,494,'Habitation Module','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20171,333,'Datacore - Hydromagnetic Physics','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of hydromagnetic physics.',1,0.1,0,1,4,0.0000,1,1880,0),(20172,333,'Datacore - Minmatar Starship Engineering','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of Matari starship engineering.',1,0.1,0,1,4,0.0000,1,1880,0),(20173,821,'Serpentis Major','This is one of the Serpentis\' best and brightest.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(20174,821,'Serpentis Deadspace Sergeant','Watching and waiting, the Serpentis Deadspace Sergeant keeps a watchful eye on all that goes on in the Beta Hangars.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(20175,438,'Simple Reactor Array','An arena for various different substances to mix and match. The Simple Reactor Array is where chemical processes take place that can turn a simple element into a complex composite, and thus plays an important part in the harnessing of moon minerals.\r\r\n\r\r\nNote: the Simple Reactor Array is capable of running only simple reactions.',100000000,4000,1,1,NULL,12500000.0000,1,490,0),(20176,438,'Academy','An arena for various different substances to mix and match.  The Reactor Array is where chemical processes take place that can turn a simple element into a complex composite, and thus plays an important part in the harnessing of moon minerals.\r\r\n\r\r\nThe Simple Reactor Array will only run at half speed on a Medium Control Tower, and may only contain Simple Reactions.',100000000,4000,1,1,NULL,0.0000,0,NULL,0),(20177,319,'Asteroid Deadspace Mining Colony','Where geographical conditions allow, outposts such as this one are a good way of increasing the effectiveness of deep-space mining operations.',0,1,0,1,NULL,0.0000,0,NULL,0),(20182,319,'Secured Drone Bunker','This large metal bunker is thoroughly infested with rogue drones.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20183,513,'Providence','Even though characteristically last in the race to create a working prototype of new technology, the Empire\'s engineers spared no effort in bringing the Providence into the world.  While the massive potential for profit from the capsuleer market is said to have been what eventually made the stolid Empire decide to involve themselves in the freighter business, their brainchild is by no means the runt of the litter; the Providence is one of the sturdiest freighters out there.\r\r\n\r\r\n',900000000,18500000,435000,1,4,1150783822.0000,1,767,0),(20184,525,'Providence Blueprint',' ',0,0.01,0,1,NULL,1900000000.0000,1,788,0),(20185,513,'Charon','As the makers of the Charon, the Caldari State are generally credited with pioneering the freighter class.  Recognizing the need for a massive transport vehicle as deep space installations constantly increase in number, they set about making the ultimate in efficient mass transport - and were soon followed by the other empires.\r\r\n\r\r\nRegardless, the Charon still stands out as the benchmark by which the other freighters were measured.  Its massive size and titanic cargo hold are rivalled by none.',960000000,16250000,465000,1,1,1131632216.0000,1,768,0),(20186,525,'Charon Blueprint',' ',0,0.01,0,1,NULL,2000000000.0000,1,789,0),(20187,513,'Obelisk','The Obelisk was designed by the Federation in response to the Caldari State\'s Charon freighter.  Possessing similar characteristics but placing a greater emphasis on resilience, this massive juggernaut represents the latest, and arguably finest, step in Gallente transport technology.\r\r\n\r\r\n',940000000,17550000,440000,1,8,1149698992.0000,1,769,0),(20188,525,'Obelisk Blueprint',' ',0,0.01,0,1,NULL,1950000000.0000,1,790,0),(20189,513,'Fenrir','Third in line to jump on the freighter bandwagon, the Republic decided early in the design process to focus on a balance between all ship systems.  True to form, their creation is comparatively lightweight - though lightweight is certainly not a term easily applicable to this giant.\r\r\n\r\r\n',820000000,15500000,435000,1,2,1139211390.0000,1,770,0),(20190,525,'Fenrir Blueprint',' ',0,0.01,0,1,NULL,1850000000.0000,1,791,0),(20196,494,'Blood Raider Chapel','This decorated structure serves as a place for religious practice.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20197,353,'QA Shield Extender','This module does not exist.',0,1,0,1,NULL,12474.0000,0,NULL,0),(20199,201,'Dread Guristas ECM Multispectral Jammer','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,29696.0000,1,719,0),(20201,201,'Kaikka\'s Modified ECM Multispectral Jammer','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,29696.0000,1,719,0),(20203,201,'Thon\'s Modified ECM Multispectral Jammer','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,29696.0000,1,719,0),(20205,201,'Vepas\' Modified ECM Multispectral Jammer','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,29696.0000,1,719,0),(20207,201,'Estamel\'s Modified ECM Multispectral Jammer','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,29696.0000,1,719,0),(20209,256,'Rocket Specialization','Specialist training in the operation of advanced rocket launchers. 2% bonus per level to the rate of fire of modules requiring Rocket Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,1000000.0000,1,373,0),(20210,256,'Light Missile Specialization','Specialist training in the operation of advanced light missile launchers and arrays. 2% bonus per level to the rate of fire of modules requiring Light Missile Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,1000000.0000,1,373,0),(20211,256,'Heavy Missile Specialization','Specialist training in the operation of advanced heavy missile launchers. 2% bonus per level to the rate of fire of modules requiring Heavy Missile Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,3000000.0000,1,373,0),(20212,256,'Cruise Missile Specialization','Specialist training in the operation of advanced cruise missile launchers. 2% bonus per level to the rate of fire of modules requiring Cruise Missile Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,373,0),(20213,256,'Torpedo Specialization','Specialist training in the operation of advanced siege launchers. 2% bonus per level to the rate of fire of modules requiring Torpedo Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,9000000.0000,1,373,0),(20214,202,'Extra Radar ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,25000.0000,1,729,0),(20216,202,'Incremental Radar ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,25000.0000,1,729,0),(20218,202,'Conjunctive Radar ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,729,0),(20219,131,'Conjunctive Radar ECCM Scanning Array I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20220,202,'Extra Ladar ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,25000.0000,1,726,0),(20222,202,'Incremental Ladar ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,25000.0000,1,726,0),(20224,202,'Conjunctive Ladar ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,726,0),(20225,131,'Conjunctive Ladar ECCM Scanning Array I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20226,202,'Extra Gravimetric ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,25000.0000,1,725,0),(20228,202,'Incremental Gravimetric ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,25000.0000,1,725,0),(20230,202,'Conjunctive Gravimetric ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,725,0),(20231,131,'Conjunctive Gravimetric ECCM Scanning Array I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20232,202,'Extra Magnetometric ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,25000.0000,1,727,0),(20234,202,'Incremental Magnetometric ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,25000.0000,1,727,0),(20236,202,'Conjunctive Magnetometric ECCM Scanning Array I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,727,0),(20237,131,'Conjunctive Magnetometric ECCM Scanning Array I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20238,203,'Secure Gravimetric Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,720,0),(20239,347,'Secure Gravimetric Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20240,203,'Shielded Gravimetric Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,720,0),(20241,347,'Shielded Gravimetric Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20242,203,'Warded Gravimetric Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,720,0),(20243,347,'Warded Gravimetric Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20244,203,'Secure Ladar Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,721,0),(20245,347,'Secure Ladar Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20246,203,'Shielded Ladar Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,721,0),(20247,347,'Shielded Ladar Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20248,203,'Warded Ladar Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,721,0),(20249,347,'Warded Ladar Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20250,203,'Secure Magnetometric Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,723,0),(20251,347,'Secure Magnetometric Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20252,203,'Shielded Magnetometric Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,723,0),(20253,347,'Shielded Magnetometric Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20254,203,'Warded Magnetometric Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,723,0),(20255,347,'Warded Magnetometric Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20260,203,'Secure Radar Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,722,0),(20261,347,'Secure Radar Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20262,203,'Shielded Radar Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,722,0),(20263,347,'Shielded Radar Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20264,203,'Warded Radar Backup Cluster I','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,722,0),(20265,347,'Warded Radar Backup Cluster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20279,817,'Rogue Pirate Raider','This is a rogue pirate vessel.  Rogue pirates are not part of any specific faction, or at least not officially. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(20280,515,'Siege Module I','An electronic interface designed to augment and enhance a dreadnought\'s siege warfare abilities. Through a series of electromagnetic polarity field shifts, the siege module diverts energy from the ship\'s propulsion and warp systems to lend additional power to its offensive and defensive capabilities.\r\r\n\r\r\nThis results in a tremendous increase in damage, as well as a greatly increased rate of defensive self-sustenance. Due to the ionic field created by the siege module, remote effects like warp scrambling et al. will not affect the ship while in siege mode.\r\r\n\r\r\nThis also means that friendly remote effects will not work while in siege mode either. In addition, the lack of power to locomotion systems means that neither standard propulsion nor warp travel are available to the ship nor are you allowed to dock until out of siege mode.\r\r\n\r\r\nNote: A siege module requires Strontium clathrates to run and operate effectively. Only one siege module can be fitted to a dreadnought class ship. The amount of shield boosting gained from the Siege Module is subject to a stacking penalty when used with other similar modules that affect the same attribute on the ship.',1,4000,0,1,NULL,66169610.0000,1,801,0),(20281,516,'Siege Module I Blueprint',' ',0,0.01,0,1,NULL,522349680.0000,1,343,0),(20282,494,'Storage Silo','Built to withstand assault, these behemoths can each hold roughly 8.5 million m3 worth of materials.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20283,494,'Storage Silo','Built to withstand assault, these behemoths can each hold roughly 8.5 million m3 worth of materials.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20284,494,'Storage Silo','Built to withstand assault, these behemoths can each hold roughly 8.5 million m3 worth of materials.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20285,494,'Storage Silo','Built to withstand assault, these behemoths can each hold roughly 8.5 million m3 worth of materials.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20306,772,'Mjolnir Heavy Assault Missile','An EMP warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,3776.0000,1,971,0),(20307,772,'Scourge Heavy Assault Missile','A kinetic warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,2680.0000,1,971,0),(20308,772,'Inferno Heavy Assault Missile','A plasma warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,3176.0000,1,971,0),(20312,256,'Guided Missile Precision','Skill at precision missile homing. Proficiency at this skill increases the accuracy of a fired missile\'s exact point of impact, resulting in greater damage to small targets.  5% decrease per level in factor of signature radius for all missile explosions.',0,0.01,0,1,NULL,500000.0000,1,373,0),(20314,256,'Target Navigation Prediction','Proficiency at optimizing a missile\'s flight path to negate the effects of a target\'s speed upon the explosion\'s impact. 10% decrease per level in factor of target\'s velocity for all missiles.',0,0.01,0,1,NULL,60000.0000,1,373,0),(20315,256,'Warhead Upgrades','Proficiency at upgrading missile warheads with deadlier payloads. 2% bonus to all missile damage per skill level.',0,0.01,0,1,NULL,1000000.0000,1,373,0),(20324,818,'COSMOS Caldari B1',' ',1300000,18000,120,1,1,0.0000,0,NULL,0),(20325,494,'Serpentis Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20326,494,'Guristas Starbase Control Tower','Originally designed by the Kaalakiota, the Caldari Control Tower blueprint was quickly obtained by the Guristas, through their agents within the State, to serve their own needs.',100000,1150,8850,1,1,0.0000,0,NULL,0),(20327,255,'Capital Energy Turret','Operation of capital energy turrets. 5% Bonus to capital energy turret damage per level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,15000000.0000,1,364,0),(20328,314,'Insorum','Insorum (Insorzapine bisulfate) is a reactive mutagen binder, a compound whose active chemical responds dynamically to mutagens in the body.  This gives it tremendous healing properties for those afflicted with specific diseases, but, it is believed, also makes it an extremely dangerous genetic toxin for those in otherwise good health.',5,0.2,0,1,NULL,0.0000,1,NULL,0),(20329,494,'Radio Telescope','This huge Communication Tower contains fragile but advanced sensory equipment. A structure such as this has enormous capabilities in crunching survey data from nearby systems and constellations, as well as communicating over enormous distances.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20330,667,'Imperial Navy Jakar','This is a top-class battleship for the Amarr Empire.  Usually at the head of their fleets, the Jakar\'s are feared all through-out the galaxy. Threat level: Deadly',20500000,1150000,235,1,4,0.0000,0,NULL,0),(20333,706,'Republic Fleet Darkana','This is a top-class battleship of the Minmatar Fleet.  The Darkana\'s are usually at the head of their fleet, and are reputed to have been the driving force behind many glorious Minmatar victories over the Amarr armadas. Threat level: Deadly',19000000,1080000,120,1,2,0.0000,0,NULL,0),(20334,674,'Caldari Navy Temura','This is a top-class battleship of the Caldari Navy.   Threat level: Deadly',20500000,1080000,235,1,1,0.0000,0,NULL,0),(20335,680,'Federation Navy Orion','This is a top-class battleship of the Federation Navy.  Threat level: Deadly',19000000,1140000,480,1,8,0.0000,0,NULL,0),(20342,257,'Advanced Spaceship Command','The advanced operation of spaceships. Grants a 5% Bonus per skill level to the agility of ships requiring Advanced Spaceship Command. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,50000000.0000,1,377,0),(20343,329,'50mm Steel Plates II','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,47780.0000,0,NULL,0),(20344,349,'50mm Steel Plates II Blueprint',' ',0,0.01,0,1,4,0.0000,0,NULL,0),(20345,329,'100mm Steel Plates II','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,127470.0000,1,1672,0),(20346,349,'100mm Steel Plates II Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(20347,329,'200mm Steel Plates II','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,305492.0000,1,1673,0),(20348,349,'200mm Steel Plates II Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(20349,329,'400mm Steel Plates II','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,602666.0000,1,1674,0),(20350,349,'400mm Steel Plates II Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(20351,329,'800mm Steel Plates II','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,4,1272072.0000,1,1675,0),(20352,349,'800mm Steel Plates II Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(20353,329,'1600mm Steel Plates II','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,4,2440280.0000,1,1676,0),(20354,349,'1600mm Steel Plates II Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(20358,738,'Numon Family Heirloom','A neural Interface upgrade that boosts the pilot\'s skill in a specific area.  This implant is an old heirloom of the Numon family, which has sole manufacturing rights of this implant.  \r\r\n\r\r\n7% reduction in repair systems duration.\r\r\n\r\r\nNote: Has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,0.0000,1,1514,0),(20359,816,'Kazar Numon','Kazar Numon is part of House Numon, an ancient and noble family with the Empire.  Fiercly loyal to House Sarum.  Threat level: Deadly',19000000,1150000,620,1,4,0.0000,0,NULL,0),(20362,314,'Foiritan Sculpture',' ',0,1,0,1,NULL,0.0000,1,NULL,0),(20363,817,'Sukuuvestaa Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(20364,517,'Cosmos Condor','A Condor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20367,341,'Smugglers Mask I','This singnature scrambler has been modified to mask the cargo hold of the ship making it harder to detect contraband.',0,10,0,1,NULL,366.0000,0,NULL,0),(20368,120,'Smugglers Mask I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(20369,517,'Cosmos Incursus','An Incursus piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(20370,816,'Whelan Machorin','This is a top-class battleship of the Caldari Navy, being piloted by the high-profile Caldari military agent, Whelan Machorin.   Threat level: Deadly',19000000,1080000,235,1,1,0.0000,0,NULL,0),(20371,746,'Whelan Machorin\'s Ballistic Smartlink','A neural Interface upgrade that boost the pilots skill in a specific area.\r\r\n\r\r\n5% bonus to all missile launcher rate of fire.',0,1,0,1,NULL,0.0000,1,1497,0),(20372,409,'Whelan Machorin\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,1,0.0000,1,NULL,0),(20373,816,'General \'Buck\' Turgidson','This runaway general is wanted by both the Amarr Empire and Minmatar Republic.',19000000,1150000,235,1,4,0.0000,0,NULL,0),(20374,409,'\'Buck\' Turgidson\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,0.0000,1,NULL,0),(20375,314,'Whelan Machorin\'s Head','This is the head of the Caldari Agent, Whelan Machorin, in all its flabby, balding glory.  As it is not connected to his body at present it quite lacks the prestige it has grown accustomed to and, judging by the expression on its face, it\'s not at all content with this fact.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20376,517,'Cosmos Heron','A Heron piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20377,517,'Cosmos Merlin','A Merlin piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20378,517,'Cosmos Probe','A Probe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(20379,517,'Cosmos Buzzard','A Buzzard piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20380,517,'Cosmos Crow','A Crow piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20381,517,'Erudin Hanka\'s Harpy','A Harpy piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20382,517,'Cosmos Hawk','A Hawk piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20383,517,'Cosmos Raptor','A Raptor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20384,517,'Cosmos Cormorant','A Cormorant piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20385,517,'Cosmos Ferox','A Ferox piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20386,517,'Cosmos Badger','A Badger piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20387,517,'Cosmos Badger Mark II','A Badger Mark II piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20388,517,'Cosmos Blackbird','A Blackbird piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20389,517,'Cosmos Caracal','A Caracal piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20390,517,'Cosmos Moa','A Moa piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20391,517,'Cosmos Osprey','An Osprey piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20392,517,'Cosmos Raven','A Raven piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20393,517,'Cosmos Bustard','A Bustard piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20394,517,'Cosmos Capsule','An agent in a pod.',0,0,0,1,NULL,0.0000,0,NULL,0),(20405,316,'Information Warfare Link - Recon Operation I','Increases range of modules requiring Electronic Warfare, Sensor Linking, Target Painting or Weapon Disruption for all ships in the fleet.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,225005.0000,1,1635,0),(20406,316,'Information Warfare Link - Electronic Superiority I','Boosts the strength of the fleet\'s electronic warfare modules.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,225005.0000,1,1635,0),(20408,316,'Skirmish Warfare Link - Rapid Deployment I','Increases the speed of the fleet\'s afterburner and microwarpdrive modules.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems.\r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,225005.0000,1,1637,0),(20409,316,'Armored Warfare Link - Passive Defense I','Grants a bonus to the fleet\'s armor resistances.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,225005.0000,1,1634,0),(20410,333,'Datacore - Gallentean Starship Engineering','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of Gallentean starship engineering.',1,0.1,0,1,4,0.0000,1,1880,0),(20411,333,'Datacore - High Energy Physics','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of high energy physics.',1,0.1,0,1,4,0.0000,1,1880,0),(20412,333,'Datacore - Plasma Physics','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of plasma physics.',1,0.1,0,1,4,0.0000,1,1880,0),(20413,333,'Datacore - Laser Physics','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of laser physics.',1,0.1,0,1,4,0.0000,1,1880,0),(20414,333,'Datacore - Quantum Physics','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of quantum physics.',1,0.1,0,1,4,0.0000,1,1880,0),(20415,333,'Datacore - Molecular Engineering','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of molecular engineering.',1,0.1,0,1,4,0.0000,1,1880,0),(20416,333,'Datacore - Nanite Engineering','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of nanite engineering.',1,0.1,0,1,4,0.0000,1,1880,0),(20417,333,'Datacore - Electromagnetic Physics','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of electromagnetic physics.',1,0.1,0,1,4,0.0000,1,1880,0),(20418,333,'Datacore - Electronic Engineering','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of electronic engineering.',1,0.1,0,1,4,0.0000,1,1880,0),(20419,333,'Datacore - Graviton Physics','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of graviton physics.',1,0.1,0,1,4,0.0000,1,1880,0),(20420,333,'Datacore - Rocket Science','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of rocket science.',1,0.1,0,1,4,0.0000,1,1880,0),(20421,333,'Datacore - Amarrian Starship Engineering','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of Amarrian starship engineering.',1,0.1,0,1,4,0.0000,1,1880,0),(20422,332,'Data Interface - Talocan Weapon Systems',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(20423,333,'Datacore - Nuclear Physics','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of nuclear physics.',1,0.1,0,1,4,0.0000,1,1880,0),(20424,333,'Datacore - Mechanical Engineering','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of mechanical engineering.',1,0.1,0,1,4,0.0000,1,1880,0),(20425,333,'Datacore - Offensive Subsystems Engineering',' ',1,0.1,0,1,4,0.0000,1,1880,0),(20426,716,'Data Interface - Basic','This portable interface permits its user to course through the electronic datastream, hunting down the stray bits of information necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed.',1,1,0,1,NULL,0.0000,0,NULL,0),(20431,428,'Black Morphite','An extremely dense but flexible alloy of Morphite that seems to be a common component in most Talocan technology. Although the process of creating Black Morphite is somewhat understood it still requires huge amounts of ingrediences to synthesize in usable quantities.  ',100000,0.01,0,1,NULL,250000.0000,0,NULL,0),(20432,436,'Black Morphite Reaction',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(20433,270,'Talocan Technology','Basic understanding of interfacing with Talocan technology.\r\r\n\r\r\nThe Talocan were masters of Spatial manipulation and Hypereuclidean Mathematics.\r\r\n\r\r\nAllows the rudimentary use of Talocan components in the creation of advanced technology, even though the scientific theories behind them remain a mystery.',0,0.01,0,1,NULL,0.0000,1,375,0),(20434,526,'Terran Broken Datachips - Weaponry','These ancient data storage devices are severly damaged but it might still possible to extract some valable data from them.    ',1e35,40,0,250,NULL,0.0000,1,NULL,0),(20435,816,'Yaekun Ogdin','A powerful leader amongst the Freedom Fighters, Yaekun Ogdin is a fighter to be reckoned with.  He grew up as a slave amongst the Amarr, but was rescued and later trained by the Minmatar Fleet in space combat.  After he retired from the Fleet, he vowed to spend every last moment of his life working for the Freedom Fighters and their noble goal. Threat level: Deadly',19000000,920000,625,1,2,0.0000,0,NULL,0),(20438,816,'Faramon Mundan','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(20439,816,'Hoborak Moon','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(20440,816,'Rachen Mysuna','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,22000000,235,1,1,0.0000,0,NULL,0),(20441,816,'Xevni Jipon','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(20442,816,'Paon Tay','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,22000000,235,1,1,0.0000,0,NULL,0),(20443,742,'Ogdin\'s Eye Coordination Enhancer','Improved ability at hitting fast moving targets.\r\r\n\r\r\n6% bonus to turrets tracking speed. ',0,1,0,1,NULL,0.0000,1,1499,0),(20444,53,'Dual Giga Pulse Laser I','One of the largest weapons currently in existence, this massive laser is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',40000,4000,1,1,NULL,61450528.0000,1,774,0),(20445,133,'Dual Giga Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,43006260.0000,1,794,0),(20446,53,'Dual Giga Beam Laser I','One of the largest weapons currently in existence, this massive laser is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',40000,4000,1,1,NULL,68359026.0000,1,773,0),(20447,133,'Dual Giga Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,48404274.0000,1,794,0),(20448,74,'Dual 1000mm Railgun I','One of the largest weapons currently in existence, this massive railgun is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',40000,4000,5,1,NULL,65222582.0000,1,772,0),(20449,154,'Dual 1000mm Railgun I Blueprint',' ',0,0.01,0,1,NULL,46052412.0000,1,792,0),(20450,74,'Ion Siege Blaster Cannon I','One of the largest weapons currently in existence, this massive blaster is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',40000,4000,10,1,NULL,50073494.0000,1,771,0),(20451,154,'Ion Siege Blaster Cannon I Blueprint',' ',0,0.01,0,1,NULL,36286548.0000,1,792,0),(20452,55,'6x2500mm Repeating Cannon I','One of the largest weapons currently in existence, this massive autocannon is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,4000,10,1,NULL,45303166.0000,1,776,0),(20453,135,'6x2500mm Repeating Cannon I Blueprint',' ',0,0.01,0,1,NULL,32694870.0000,1,793,0),(20454,55,'Quad 3500mm Siege Artillery I','One of the largest weapons currently in existence, this massive artillery cannon is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.\r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',750,4000,5,1,NULL,52484034.0000,1,775,0),(20455,135,'Quad 3500mm Siege Artillery I Blueprint',' ',0,0.01,0,1,NULL,37692954.0000,1,793,0),(20456,474,'Alpha Keycard','This security passcard is manufactured by the Minmatar Fleet and allows the user to unlock a specific acceleration gate to another sector. The gate will remain open for a short period of time and the keycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20457,474,'Beta Keycard','This security passcard is manufactured by the Minmatar Fleet and allows the user to unlock a specific acceleration gate to another sector. The gate will remain open for a short period of time and the keycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20458,474,'Gamma Keycard','This security passcard is manufactured by the Minmatar Fleet and allows the user to unlock a specific acceleration gate to another sector. The gate will remain open for a short period of time and the keycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20459,706,'Republic Fleet Darkana_Alpha','This is a top-class battleship of the Minmatar Fleet.  The Darkana\'s are usually at the head of their fleet, and are reputed to have been the driving force behind many glorious Minmatar victories over the Amarr armadas. Threat level: Deadly',19000000,1080000,120,1,2,0.0000,0,NULL,0),(20460,706,'Republic Fleet Darkana_Beta','This is a top-class battleship of the Minmatar Fleet.  The Darkana\'s are usually at the head of their fleet, and are reputed to have been the driving force behind many glorious Minmatar victories over the Amarr armadas. Threat level: Deadly',19000000,1080000,120,1,2,0.0000,0,NULL,0),(20461,706,'Republic Fleet Darkana_Gamma','This is a top-class battleship of the Minmatar Fleet.  The Darkana\'s are usually at the head of their fleet, and are reputed to have been the driving force behind many glorious Minmatar victories over the Amarr armadas. Threat level: Deadly',19000000,1080000,120,1,2,0.0000,0,NULL,0),(20462,520,'COSMOS Caldari Arrogator','This is a hostile pirate vessel. Threat level: Very low',1500100,15001,45,1,1,0.0000,0,NULL,0),(20463,520,'COSMOS Caldari Assassin','This is a hostile pirate vessel. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(20464,520,'COSMOS Caldari Death Dealer','This is a hostile pirate vessel. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(20465,520,'COSMOS Caldari Demolisher','This is a hostile pirate vessel. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(20466,520,'COSMOS Caldari Despoiler','This is a hostile pirate vessel. Threat level: Significant',2040000,20400,100,1,1,0.0000,0,NULL,0),(20467,520,'COSMOS Caldari Destructor','This is a hostile pirate vessel. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(20468,520,'COSMOS Caldari Eliminator','This is a hostile pirate vessel. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(20469,520,'COSMOS Caldari Imputor','This is a hostile pirate vessel. Threat level: Low',1612000,16120,80,1,1,0.0000,0,NULL,0),(20470,520,'COSMOS Caldari Infiltrator','This is a hostile pirate vessel. Threat level: Moderate',2025000,20250,235,1,1,0.0000,0,NULL,0),(20471,520,'COSMOS Caldari Invader','This is a hostile pirate vessel. Threat level: Moderate',2025000,20250,65,1,1,0.0000,0,NULL,0),(20472,520,'COSMOS Caldari Nihilist','This is a hostile pirate vessel. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(20473,520,'COSMOS Caldari Plunderer','This is a hostile pirate vessel. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(20474,520,'COSMOS Caldari Saboteur','This is a hostile pirate vessel. Threat level: Significant',2040000,20400,235,1,1,0.0000,0,NULL,0),(20475,520,'COSMOS Caldari Wrecker','This is a hostile pirate vessel. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(20476,521,'Drifter Spur','This spur is used as a method of identification.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20477,521,'Bandit Spur','This spur is used as a method of identification.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20478,521,'Marauder Spur','This spur is used as a method of identification.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20479,521,'Outlaw Spur','This spur is used as a method of identification.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20480,521,'Gunslinger Spur','This spur is used as a method of identification.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20481,521,'Desperado Spur','This spur is used as a method of identification.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20482,522,'COSMOS Caldari Annihilator','This is a hostile pirate vessel. Threat level: Deadly',9200000,92000,235,1,1,0.0000,0,NULL,0),(20483,522,'COSMOS Caldari Ascriber','This is a hostile pirate vessel. Threat level: Deadly',9600000,96000,450,1,1,0.0000,0,NULL,0),(20484,522,'COSMOS Caldari Eraser','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(20485,522,'COSMOS Caldari Inferno','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(20486,522,'COSMOS Caldari Mortifier','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(20487,522,'COSMOS Caldari Nullifier','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(20488,522,'COSMOS Caldari Silencer','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(20489,522,'COSMOS Caldari Terrorist','This is a hostile pirate vessel. Threat level: Extreme',10700000,107000,850,1,1,0.0000,0,NULL,0),(20490,523,'COSMOS Caldari Conquistador','This is a hostile pirate vessel. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(20491,523,'COSMOS Caldari Destroyer','This is a hostile pirate vessel. Threat level: Deadly',22000000,1080000,235,1,1,0.0000,0,NULL,0),(20492,523,'COSMOS Caldari Extinguisher','This is a hostile pirate vessel. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(20493,523,'COSMOS Caldari Usurper','This is a hostile pirate vessel. Threat level: Deadly',19000000,22000000,235,1,1,0.0000,0,NULL,0),(20494,258,'Armored Warfare','Basic proficiency at coordinating armored warfare. Grants a 2% bonus to fleet members\' armor hit points per skill level. <br>Note: The fleet bonus only works if you are the assigned fleet booster and fleet members are in space within the same solar system.',0,0.01,0,1,NULL,100000.0000,1,370,0),(20495,258,'Information Warfare','Basic proficiency at coordinating information warfare. Grants a 2% bonus to fleet members\' targeting range per skill level. <br>Note: The fleet bonus only works if you are the assigned fleet booster and fleet members are in space within the same solar system.',0,0.01,0,1,NULL,100000.0000,1,370,0),(20498,300,'High-grade Halo Alpha','This ocular filter has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +4 Bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(20499,300,'High-grade Slave Alpha','This ocular filter has been modified by Sanshas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% bonus to armor HP\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(20500,300,'High-grade Halo Beta','This memory augmentation has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +4 Bonus to Memory\r\r\n\r\r\nSecondary Effect: 1.25% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(20501,300,'High-grade Slave Beta','This memory augmentation has been modified by Sanshas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Memory\r\r\n\r\r\nSecondary Effect: 2% bonus to armor HP\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(20502,300,'High-grade Halo Delta','This cybernetic subprocessor has been modified by Angel scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 Bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 1.5% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(20503,300,'High-grade Slave Delta','This cybernetic subprocessor has been modified by Sanshas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 4% bonus to armor HP\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(20504,300,'High-grade Halo Epsilon','This social adaptation chip has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +4 Bonus to Charisma\r\r\n\r\r\nSecondary Effect: 2% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(20505,300,'High-grade Slave Epsilon','This social adaptation chip has been modified by Sanshas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to armor HP\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(20506,300,'High-grade Halo Gamma','This neural boost has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +4 Bonus to Willpower\r\r\n\r\r\nSecondary Effect: 1.75% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(20507,300,'High-grade Slave Gamma','This neural boost  has been modified by Sanshas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to armor HP\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(20508,300,'High-grade Halo Omega','This implant does nothing in and of itself, but when used in conjunction with other Halo implants it will boost their effect.\r\r\n\r\r\n50% bonus to the strength of all Halo implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(20509,300,'High-grade Slave Omega','This implant does nothing in and of itself, but when used in conjunction with other Slave implants it will boost their effect. \r\r\n\r\r\n50% bonus to the strength of all Slave implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(20510,284,'Potent Viral Agent','The causative agent of an infectious disease, the viral agent is a parasite with a noncellular structure composed mainly of nucleic acid within a protein coat.',100,0.5,0,1,NULL,0.0000,1,NULL,0),(20514,316,'Siege Warfare Link - Shield Harmonizing I','Boosts all shield resistances for the fleet\'s ships.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,225005.0000,1,1636,0),(20517,474,'Private Citizen Tsuna\'s Passcard','This keycard belongs to private citizen Tsuna Qayse.  Illegal possession of this object will result in a severe fine and at least 1 year of jail time.\r\r\n\r\r\n- CONCORD Security',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20520,517,'Turu\'s Harpy','A Harpy piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20521,517,'Helkelen\'s Blackbird','A Blackbird piloted by an agent.\r\r\n\r\r\nMissions:\r\r\n\r\r\n<b>Difficulty Rating: Grade 7</b>\r\r\n\r\r\n<i>Warning:  An industrial, as well as a combat ship, is recommended</i> \r\r\n',0,0,0,1,1,0.0000,0,NULL,0),(20523,494,'Habitation Module - Tsuna\'s Science Labs','This mobile habitation module contains Tsuna Qayse\'s science laboratory.  Highly toxic chemicals on board, entry is strictly prohibited without proper authorization.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(20524,257,'Amarr Freighter','Skill at operating Amarr freighters.  \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,75000000.0000,1,377,0),(20525,257,'Amarr Dreadnought','Skill at operating Amarr dreadnoughts.  \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,100000000.0000,1,377,0),(20526,257,'Caldari Freighter','Skill at operating Caldari freighters.  \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,75000000.0000,1,377,0),(20527,257,'Gallente Freighter','Skill at operating Gallente freighters. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,75000000.0000,1,377,0),(20528,257,'Minmatar Freighter','Skill at operating Minmatar freighters. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,75000000.0000,1,377,0),(20529,517,'Ariato\'s Condor','A Condor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20530,257,'Caldari Dreadnought','Skill at operating Caldari dreadnoughts.  \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,100000000.0000,1,377,0),(20531,257,'Gallente Dreadnought','Skill at operating Gallente dreadnoughts. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,100000000.0000,1,377,0),(20532,257,'Minmatar Dreadnought','Skill at operating Minmatar dreadnoughts. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,100000000.0000,1,377,0),(20533,257,'Capital Ships','Skill for the operation of capital ships. Grants a 5% bonus per skill level to the agility of ships requiring the Capital Ships skill. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,400000000.0000,1,377,0),(20534,517,'Awazhen\'s Moa','A Moa piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20535,517,'Hatamei\'s Cormorant','A Cormorant piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20536,517,'Sakkaro\'s Badger','A Badger piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20537,517,'Makachi\'s Probe','A Probe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(20538,517,'Mottoya\'s Crow','A Crow piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20539,524,'Citadel Torpedo Launcher I','The size of a small cruiser, this massive launcher is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.',0,4000,4.5,1,NULL,65222582.0000,1,777,0),(20540,136,'Citadel Torpedo Launcher I Blueprint',' ',0,0.01,0,1,NULL,54371388.0000,1,340,0),(20541,314,'Drill Parts','These large containers are fitted with a password-protected security lock.  These particular containers are filled with spare parts needed to build a drill used for drilling through rock and ice sheets.',1000,100,0,1,NULL,0.0000,1,NULL,0),(20542,494,'Lephny\'s Mining Post','Where geographical conditions allow, outposts such as this one are a good way of increasing the effectiveness of deep-space mining operations.',0,1,0,1,NULL,0.0000,0,NULL,0),(20545,816,'Markus Ikmani','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(20546,409,'Markus\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,1,0.0000,1,NULL,0),(20547,817,'Ratei Jezzor','This is a fighter for the Mordus Legion. It is protecting the assets of the Mordus Legion and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(20548,409,'Ratei\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,1,0.0000,1,NULL,0),(20549,533,'Manchura Todaki','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(20550,370,'Manchura\'s Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Guristas pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20551,314,'Manchura\'s Logs','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(20552,533,'Wei Todaki_','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(20554,283,'Wei Todaki','A veteran pilot of a Guristas cruiser.  Married to Manchura Todaki.',80,1,0,1,NULL,0.0000,1,NULL,0),(20555,76,'Small \'Siesta\' Capacitor Booster','Provides a quick injection of power into the capacitor.',0,5,12,1,NULL,20010.0000,1,699,0),(20556,156,'Small \'Siesta\' Capacitor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20557,76,'Medium \'Gattotte\' Capacitor Booster','Provides a quick injection of power into the capacitor.',0,10,32,1,NULL,40356.0000,1,700,0),(20558,156,'Medium \'Gattotte\' Capacitor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20559,76,'Heavy \'Brave\' Capacitor Booster','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,78242.0000,1,701,0),(20560,156,'Heavy \'Brave\' Capacitor Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20561,330,'Prototype \'Poncho\' Cloaking Device I','This prototype of an advanced cloaking mechanism was one of the last major technological breakthroughs to come out of Crielere Labs. Although it does work it is not really a finished product and has some serious drawbacks, most notably the fact that the module creates high sensor disruption while fitted and can not operate unless at minimum velocity.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,1168066.0000,1,675,0),(20562,401,'Prototype \'Poncho\' Cloaking Device I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20563,330,'\'Smokescreen\' Covert Ops Cloaking Device II','A very specialized piece of technology, the covert ops cloak is designed for use in tandem with specific covert ops vessels. Although it could theoretically work on other ships, its spatial distortion field is so unstable that trying to compensate for its fluctuations will overwhelm non-specialized computing hardware.\r\r\n\r\r\nNote: This particular module is advanced enough that it allows a ship to warp while cloaked. However, fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,1966080.0000,1,675,0),(20564,401,'\'Smokescreen\' Covert Ops Cloaking Device II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20565,330,'Improved \'Guise\' Cloaking Device II','An Improved Cloaking device based on the Crielere Labs prototype. It performs better and allows for faster movement while cloaked.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,983040.0000,1,675,0),(20566,401,'Improved \'Guise\' Cloaking Device II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20567,285,'\'Dyad\' Co-Processor I','Increases CPU output.',0,5,0,1,NULL,16428.0000,1,676,0),(20568,346,'\'Dyad\' Co-Processor I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20569,285,'\'Deuce\' Co-Processor I','Increases CPU output.',0,5,0,1,NULL,16428.0000,1,676,0),(20570,346,'\'Deuce\' Co-Processor I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20573,201,'\'Marshall\' Ion Field Projector','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors. ',0,5,0,1,NULL,29504.0000,1,715,0),(20574,130,'\'Marshall\' Ion Field Projector Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20575,201,'\'Gambler\' Phase Inverter','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',0,5,0,1,NULL,29504.0000,1,716,0),(20576,130,'\'Gambler\' Phase Inverter Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20577,201,'\'Plunderer\' Spatial Destabilizer','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',0,5,0,1,NULL,29504.0000,1,717,0),(20578,130,'\'Plunderer\' Spatial Destabilizer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20579,201,'\'Heist\' White Noise Generator','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',0,5,0,1,NULL,29504.0000,1,718,0),(20580,130,'\'Heist\' White Noise Generator Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20581,80,'\'Ghost\' ECM Burst','Emits random electronic bursts which have a chance of momentarily disrupting target locks on ships within range.\r\r\n\r\r\nGiven the unstable nature of the bursts and the amount of internal shielding needed to ensure they do not affect their own point of origin, only battleship-class vessels can use this module to its fullest extent. \r\r\n\r\r\nNote: Only one module of this type can be activated at the same time.',5000,5,0,1,NULL,71572.0000,1,678,0),(20582,160,'\'Ghost\' ECM Burst Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20587,74,'150mm \'Musket\' Railgun','This is a standard long-range railgun designed for frigates. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.1,1,NULL,20306.0000,1,564,0),(20588,154,'150mm \'Musket\' Railgun Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20589,74,'250mm \'Flintlock\' Railgun','Cruiser-sized large barrel turret. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,0.5,1,NULL,166754.0000,1,565,0),(20590,154,'250mm \'Flintlock\' Railgun Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20591,74,'425mm \'Popper\' Railgun','This large battleship-sized weapon packs quite a punch. Railguns use magnetic rails to fire solid chunks of matter at hypersonic speed. The accurate range of railguns is very good, but due to technical limitations it cannot use onboard guidance. This results in a fairly rapid drop in accuracy at extreme ranges. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,1,1,NULL,2015232.0000,1,566,0),(20592,154,'425mm \'Popper\' Railgun Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20593,507,'\'Balefire\' Rocket Launcher','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.1875,1,NULL,3336.0000,1,639,0),(20594,136,'\'Balefire\' Rocket Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20595,509,'\'Gallows\' Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.795,1,NULL,6670.0000,1,640,0),(20596,136,'\'Gallows\' Light Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20597,511,'\'Pickaxe\' Rapid Light Missile Launcher','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.3,1,NULL,9792.0000,1,641,0),(20598,136,'\'Pickaxe\' Rapid Light Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20599,510,'\'Undertaker\' Heavy Missile Launcher','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,0.9,1,NULL,33348.0000,1,642,0),(20600,136,'\'Undertaker\' Heavy Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20601,506,'\'Noose\' Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1,1,NULL,167472.0000,1,643,0),(20602,136,'\'Noose\' Cruise Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20603,508,'\'Barrage\' Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,1.5,1,NULL,204004.0000,1,644,0),(20604,136,'\'Barrage\' Torpedo Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20605,295,'\'Whiskey\' Explosive Deflection Amplifier','Boosts the explosive resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1690,0),(20606,296,'\'Whiskey\' Explosive Deflection Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20607,295,'\'High Noon\' Thermic Dissipation Amplifier','Boosts the thermal resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1688,0),(20608,296,'\'High Noon\' Thermic Dissipation Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20609,295,'\'Cactus\' Modified Kinetic Deflection Amplifier','Boosts the kinetic resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1689,0),(20610,296,'\'Cactus\' Modified Kinetic Deflection Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20611,295,'\'Prospector\' EM Ward Amplifier','Boosts the EM resistance of the shield.<br><br>Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,20828.0000,1,1691,0),(20612,296,'\'Prospector\' EM Ward Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20613,338,'\'Glycerine\' Shield Boost Amplifier','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,531040.0000,1,613,0),(20614,360,'\'Glycerine\' Shield Boost Amplifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20617,40,'Small \'Settler\' Shield Booster','Expends energy to provide a quick boost in shield strength.',0,5,0,1,NULL,10118.0000,1,609,0),(20618,120,'Small \'Settler\' Shield Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20619,40,'Medium \'Lone Ranger\' Shield Booster','Expends energy to provide a quick boost in shield strength.',0,10,0,1,NULL,40472.0000,1,610,0),(20620,120,'Medium \'Lone Ranger\' Shield Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20621,40,'Large \'Outlaw\' Shield Booster','Expends energy to provide a quick boost in shield strength.',0,25,0,1,NULL,161888.0000,1,611,0),(20622,120,'Large \'Outlaw\' Shield Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20623,40,'X-Large \'Locomotive\' Shield Booster','Expends energy to provide a quick boost in shield strength.',0,50,0,1,NULL,883072.0000,1,612,0),(20624,120,'X-Large \'Locomotive\' Shield Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20625,38,'Small \'Wolf\' Shield Extender','Increases the maximum strength of the shield.',0,5,0,1,NULL,5320.0000,1,605,0),(20626,118,'Small \'Wolf\' Shield Extender Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20627,38,'Small \'Trapper\' Shield Extender','Increases the maximum strength of the shield.',0,2.5,0,1,4,2222.0000,1,605,0),(20628,118,'Small \'Trapper\' Shield Extender Blueprint',' ',0,0.01,0,1,4,0.0000,0,NULL,0),(20629,38,'Medium \'Canyon\' Shield Extender','Increases the maximum strength of the shield.',0,10,0,1,NULL,13924.0000,1,606,0),(20630,118,'Medium \'Canyon\' Shield Extender Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20631,38,'Large \'Sheriff\' Shield Extender','Increases the maximum strength of the shield.',0,20,0,1,NULL,34710.0000,1,608,0),(20632,118,'Large \'Sheriff\' Shield Extender Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20633,77,'\'Nugget\' Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br> Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,NULL,83310.0000,1,1693,0),(20634,157,'\'Nugget\' Kinetic Deflection Field Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20635,77,'\'Desert Heat\' Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,5,0,1,NULL,83310.0000,1,1692,0),(20636,157,'\'Desert Heat\' Thermic Dissipation Field Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20637,77,'\'Posse\' Adaptive Invulnerability Field','Boosts shield resistance against all damage types.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,NULL,83310.0000,1,1696,0),(20638,157,'\'Posse\' Adaptive Invulnerability Field Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20639,77,'\'Poacher\' EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,NULL,83310.0000,1,1695,0),(20640,157,'\'Poacher\' EM Ward Field Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20641,77,'\'Snake Eyes\' Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,5,0,1,NULL,83310.0000,1,1694,0),(20642,157,'\'Snake Eyes\' Explosive Deflection Field Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(20643,517,'Poyri\'s Harpy','A Harpy piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20644,517,'Niemenen\'s Capsule','An agent in a pod.',0,0,0,1,NULL,0.0000,0,NULL,0),(20645,517,'Kirku\'s Heron','A Heron piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20646,517,'Arkimo\'s Hawk','A Hawk piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20647,517,'Riutta\'s Ferox','A Ferox piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20648,517,'Taihti\'s Raven','A Raven piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20649,517,'Kanji\'s Caracal','A Caracal piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20650,517,'Jitainen\'s Probe','A Probe piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 1</b> \r\r\n\r\r\n<i>Warning: Being able to mine is recommended.</i> ',0,0,0,1,2,0.0000,0,NULL,0),(20651,517,'Tuuri\'s Raptor','A Raptor piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 3.5</b> ',0,0,0,1,1,0.0000,0,NULL,0),(20652,517,'Urigamu\'s Crow','A Crow piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5</b> \r\r\n\r\r\n<i>Warning: An industrial, as well as a combat ship, is recommended</i> ',0,0,0,1,1,0.0000,0,NULL,0),(20653,517,'Sayto\'s Badger Mark II','A Badger Mark II piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20654,517,'Setala\'s Blackbird','A Blackbird piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 4</b> ',0,0,0,1,1,0.0000,0,NULL,0),(20655,517,'Hekkiren\'s Badger','A Badger piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20656,517,'Ikonen\'s Buzzard','A Buzzard piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20657,517,'Hochi\'s Badger Mark II','A Badger Mark II piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20658,517,'Saturi\'s Bustard','A Bustard piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20659,517,'Etsuya\'s Merlin','A Merlin piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20660,517,'Rost\'s Ferox','A Ferox piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20661,517,'Aikato\'s Probe','A Probe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(20662,517,'Dechien\'s Heron','A Heron piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20663,517,'Tekkurs\'s Crow','A Crow piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20664,517,'Tanaka\'s Raptor','A Raptor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20665,517,'Anekoji\'s Osprey','An Osprey piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20666,517,'Gojivi\'s Bustard','A Bustard piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20667,517,'Gorgoz\'s Raptor','A Raptor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20668,517,'Opainen\'s Cormorant','A Cormorant piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20669,517,'Pihrava\'s Condor','A Condor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20670,517,'Nakamuta\'s Incursus','An Incursus piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(20671,517,'Katori\'s Cormorant','A Cormorant piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20672,517,'Suruki\'s Hawk','A Hawk piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20673,517,'Yama\'s Moa','A Moa piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20674,517,'Adakita\'s Caracal','A Caracal piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20675,517,'Nobayashi\'s Incursus','An Incursus piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(20676,517,'Karpela\'s Ferox','A Ferox piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20677,517,'Rahkamo\'s Buzzard','A Buzzard piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20678,517,'Nissiken\'s Condor','A Condor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20679,517,'Sirkya\'s Cormorant','A Cormorant piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20680,517,'Rati\'s Moa','A Moa piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20681,517,'Eskaila\'s Raven','A Raven piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20682,517,'Aurio\'s Incursus','An Incursus piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(20683,517,'Michi\'s Heron','A Heron piloted by an agent.\r\r\n\r\r\nMissions:\r\r\n\r\r\n<b>Difficulty Rating: Grade 8</b>',0,0,0,1,1,0.0000,0,NULL,0),(20684,517,'Utrainen\'s Merlin','A Merlin piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5</b> ',0,0,0,1,1,0.0000,0,NULL,0),(20685,517,'Otalen\'s Caracal','A Caracal piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20686,517,'Nikainen\'s Moa','A Moa piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5.5</b> \r\r\n\r\r\n<i>Warning: An industrial, as well as a combat ship, is recommended</i> ',0,0,0,1,1,0.0000,0,NULL,0),(20687,517,'Raytio\'s Badger Mark II','A Badger Mark II piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5.5</b> \r\r\n',0,0,0,1,1,0.0000,0,NULL,0),(20688,517,'Magye\'s Bustard','A Bustard piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5</b> ',0,0,0,1,1,0.0000,0,NULL,0),(20689,517,'Koronen\'s Raptor','A Raptor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20690,517,'Ahti\'s Osprey','An Osprey piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 7.5</b> \r\r\n',0,0,0,1,1,0.0000,0,NULL,0),(20691,517,'Watanen\'s Heron','A Heron piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5.5</b> \r\r\n',0,0,0,1,1,0.0000,0,NULL,0),(20692,517,'Oshima\'s Crow','A Crow piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20693,517,'Fujimo\'s Caracal','A Caracal piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 7</b> \r\r\n\r\r\n<i>Warning: An industrial, as well as a combat ship, is recommended</i> ',0,0,0,1,1,0.0000,0,NULL,0),(20694,517,'Kubona\'s Merlin','A Merlin piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<i>Mini-Profession related</i> \r\r\n',0,0,0,1,1,0.0000,0,NULL,0),(20695,517,'Kanerva\'s Condor','A Condor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20696,517,'Tazaki\'s Buzzard','A Buzzard piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5.5</b> ',0,0,0,1,1,0.0000,0,NULL,0),(20697,517,'Aura\'s Osprey','An Osprey piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 6</b> ',0,0,0,1,1,0.0000,0,NULL,0),(20698,517,'Sagimoro\'s Blackbird','A Blackbird piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20699,517,'Wakomi\'s Raven','A Raven piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(20700,1229,'Michi\'s Excavation Augmentor','A neural Interface upgrade that boosts the pilot\'s skill in a specific area.\r\r\n\r\r\n5% bonus to mining yield of mining lasers.',0,1,0,1,NULL,21504.0000,1,1769,0),(20701,62,'Capital Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the ship.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',500,4000,0,1,4,66169610.0000,1,1052,0),(20702,142,'Capital Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,47022756.0000,1,1536,0),(20703,40,'Capital Shield Booster I','Expends energy to provide a quick boost in shield strength.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',0,4000,0,1,4,72505546.0000,1,778,0),(20704,120,'Capital Shield Booster I Blueprint',' ',0,0.01,0,1,NULL,51002322.0000,1,1552,0),(20713,526,'Utrainen\'s Employment Voucher','This employment voucher has been signed by Kochi Utrainen.',1,1,0,1,NULL,0.0000,1,NULL,0),(20714,817,'Lephny\'s Mining Boat','Jorek Lephny owns this mining boat, fitted with top-class mining equipment.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(20715,283,'Jorek Lephny',' ',80,1,0,1,NULL,0.0000,1,NULL,0),(20716,297,'Vendor','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',102000000,1020000,3000,1,1,0.0000,0,NULL,0),(20717,297,'Bursar','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3800,1,2,0.0000,0,NULL,0),(20718,297,'Auctioneer','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3600,1,4,0.0000,0,NULL,0),(20719,297,'Marketeer','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',110500000,1105000,4000,1,8,0.0000,0,NULL,0),(20721,83,'Arch Angel Carbonized Lead L','This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.025,0,100,NULL,2210.0000,1,987,0),(20723,83,'Arch Angel Nuclear L','Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.025,0,100,NULL,3184.0000,1,987,0),(20725,83,'Arch Angel Proton L','Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.025,0,100,NULL,4446.0000,1,987,0),(20727,83,'Arch Angel Depleted Uranium L','Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',0.01,0.025,0,100,NULL,5556.0000,1,987,0),(20729,83,'Arch Angel Titanium Sabot L','This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.025,0,100,NULL,6656.0000,1,987,0),(20731,83,'Arch Angel Fusion L','The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.\r\r\n',1,0.025,0,100,NULL,7776.0000,1,987,0),(20733,83,'Arch Angel Phased Plasma L','This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,8850.0000,1,987,0),(20735,83,'Arch Angel EMP L','A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,11132.0000,1,987,0),(20737,83,'Arch Angel Carbonized Lead XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,22210.0000,1,1006,0),(20739,83,'Arch Angel Depleted Uranium XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.125,0,100,NULL,55556.0000,1,1006,0),(20741,83,'Arch Angel EMP XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,111132.0000,1,1006,0),(20743,83,'Arch Angel Fusion XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,77776.0000,1,1006,0),(20745,83,'Arch Angel Nuclear XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts.  Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,33184.0000,1,1006,0),(20747,83,'Arch Angel Phased Plasma XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,88850.0000,1,1006,0),(20749,83,'Arch Angel Proton XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,44446.0000,1,1006,0),(20751,83,'Arch Angel Titanium Sabot XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation flechettes that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.125,0,100,NULL,66656.0000,1,1006,0),(20753,83,'Domination Carbonized Lead S','This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,222.0000,1,989,0),(20755,83,'Domination Nuclear S','Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,332.0000,1,989,0),(20757,83,'Domination Proton S','Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,428.0000,1,989,0),(20759,83,'Domination Depleted Uranium S','Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',0.01,0.0025,0,100,NULL,524.0000,1,989,0),(20761,83,'Domination Titanium Sabot S','This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',0.01,0.0025,0,100,NULL,660.0000,1,989,0),(20763,83,'Domination Fusion S','The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,732.0000,1,989,0),(20765,83,'Domination Phased Plasma S','This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range. ',0.01,0.0025,0,100,NULL,848.0000,1,989,0),(20767,83,'Domination EMP S','A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,1056.0000,1,989,0),(20769,83,'Domination Carbonized Lead M','This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.0125,0,100,NULL,848.0000,1,988,0),(20771,83,'Domination Nuclear M','Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.0125,0,100,NULL,1328.0000,1,988,0),(20773,83,'Domination Proton M','Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.0125,0,100,NULL,1830.0000,1,988,0),(20775,83,'Domination Depleted Uranium M','Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.0125,0,100,NULL,2236.0000,1,988,0),(20777,83,'Domination Titanium Sabot M','This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.0125,0,100,NULL,2608.0000,1,988,0),(20779,83,'Domination Fusion M','The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,3054.0000,1,988,0),(20781,83,'Domination Phased Plasma M','This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range. ',1,0.0125,0,100,NULL,3544.0000,1,988,0),(20783,83,'Domination EMP M','A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,4458.0000,1,988,0),(20785,83,'Domination Carbonized Lead L','This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.025,0,100,NULL,2210.0000,1,987,0),(20787,83,'Domination Nuclear L','Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.025,0,100,NULL,3184.0000,1,987,0),(20789,83,'Domination Proton L','Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.025,0,100,NULL,4446.0000,1,987,0),(20791,83,'Domination Depleted Uranium L','Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.025,0,100,NULL,5556.0000,1,987,0),(20793,83,'Domination Titanium Sabot L','This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.025,0,100,NULL,6656.0000,1,987,0),(20795,83,'Domination Fusion L','The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,7776.0000,1,987,0),(20797,83,'Domination Phased Plasma L','This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,8850.0000,1,987,0),(20799,83,'Domination EMP L','A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,11132.0000,1,987,0),(20801,83,'Domination Carbonized Lead XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,22210.0000,1,1006,0),(20803,83,'Domination Depleted Uranium XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.125,0,100,NULL,55556.0000,1,1006,0),(20805,83,'Domination EMP XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,111132.0000,1,1006,0),(20807,83,'Domination Fusion XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,77776.0000,1,1006,0),(20809,83,'Domination Nuclear XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts.  Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,33184.0000,1,1006,0),(20811,83,'Domination Phased Plasma XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,88850.0000,1,1006,0),(20813,83,'Domination Proton XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,44446.0000,1,1006,0),(20815,83,'Domination Titanium Sabot XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation flechettes that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.125,0,100,NULL,66656.0000,1,1006,0),(20817,86,'Sanshas Ultraviolet S','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1628.0000,1,997,0),(20819,86,'Sanshas Xray S','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2532.0000,1,997,0),(20821,86,'Sanshas Gamma S','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3508.0000,1,997,0),(20823,86,'Sanshas Multifrequency S','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4000.0000,1,997,0),(20825,86,'Sanshas Ultraviolet M','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,15648.0000,1,996,0),(20827,86,'Sanshas Xray M','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,26064.0000,1,996,0),(20829,86,'Sanshas Gamma M','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,35160.0000,1,996,0),(20831,86,'Sanshas Multifrequency M','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,40072.0000,1,996,0),(20833,86,'Sanshas Ultraviolet L','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,166464.0000,1,995,0),(20835,86,'Sanshas Xray L','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,279152.0000,1,995,0),(20837,86,'Sanshas Gamma L','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,385880.0000,1,995,0),(20839,86,'Sanshas Multifrequency L','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,443296.0000,1,995,0),(20841,86,'Sanshas Ultraviolet XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1666464.0000,1,1007,0),(20843,86,'Sanshas Xray XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2779152.0000,1,1007,0),(20845,86,'Sanshas Gamma XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3885880.0000,1,1007,0),(20847,86,'Sanshas Multifrequency XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nRandomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4443296.0000,1,1007,0),(20849,86,'True Sanshas Radio S','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3008.0000,1,997,0),(20851,86,'True Sanshas Microwave S','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2000.0000,1,997,0),(20853,86,'True Sanshas Infrared S','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1128.0000,1,997,0),(20855,86,'True Sanshas Standard S','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1358.0000,1,997,0),(20857,86,'True Sanshas Ultraviolet S','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1628.0000,1,997,0),(20859,86,'True Sanshas Xray S','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2532.0000,1,997,0),(20861,86,'True Sanshas Gamma S','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3508.0000,1,997,0),(20863,86,'True Sanshas Multifrequency S','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4000.0000,1,997,0),(20865,86,'True Sanshas Radio M','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,31062.0000,1,996,0),(20867,86,'True Sanshas Microwave M','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,20192.0000,1,996,0),(20869,86,'True Sanshas Infrared M','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,10192.0000,1,996,0),(20871,86,'True Sanshas Standard M','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,12736.0000,1,996,0),(20873,86,'True Sanshas Ultraviolet M','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,15648.0000,1,996,0),(20875,86,'True Sanshas Xray M','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,26064.0000,1,996,0),(20877,86,'True Sanshas Gamma M','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,35160.0000,1,996,0),(20879,86,'True Sanshas Multifrequency M','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,40072.0000,1,996,0),(20881,86,'True Sanshas Radio L','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,336522.0000,1,995,0),(20883,86,'True Sanshas Microwave L','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,218720.0000,1,995,0),(20885,86,'True Sanshas Infrared L','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,108552.0000,1,995,0),(20887,86,'True Sanshas Standard L','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,141320.0000,1,995,0),(20889,86,'True Sanshas Ultraviolet L','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,166464.0000,1,995,0),(20891,86,'True Sanshas Xray L','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,279152.0000,1,995,0),(20893,86,'True Sanshas Gamma L','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,385880.0000,1,995,0),(20895,86,'True Sanshas Multifrequency L','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,443296.0000,1,995,0),(20897,86,'True Sanshas Radio XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3336522.0000,1,1007,0),(20899,86,'True Sanshas Microwave XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2218720.0000,1,1007,0),(20901,86,'True Sanshas Infrared XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1108552.0000,1,1007,0),(20903,86,'True Sanshas Standard XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1391864.0000,1,1007,0),(20905,86,'True Sanshas Ultraviolet XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1666464.0000,1,1007,0),(20907,86,'True Sanshas Xray XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2779152.0000,1,1007,0),(20909,86,'True Sanshas Gamma XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3885880.0000,1,1007,0),(20911,86,'True Sanshas Multifrequency XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nRandomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4443296.0000,1,1007,0),(20913,85,'Shadow Iron Charge L','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.01,0.025,0,100,NULL,2210.0000,1,991,0),(20915,85,'Shadow Tungsten Charge L','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.01,0.025,0,100,NULL,3184.0000,1,991,0),(20917,85,'Shadow Iridium Charge L','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.01,0.025,0,100,NULL,4446.0000,1,991,0),(20919,85,'Shadow Lead Charge L','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.01,0.025,0,100,NULL,5556.0000,1,991,0),(20921,85,'Shadow Thorium Charge L','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.05,0.025,0,100,NULL,6656.0000,1,991,0),(20923,85,'Shadow Uranium Charge L','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.05,0.025,0,100,NULL,7776.0000,1,991,0),(20925,85,'Shadow Plutonium Charge L','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.05,0.025,0,100,NULL,8850.0000,1,991,0),(20927,85,'Shadow Antimatter Charge L','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.05,0.025,0,100,NULL,11132.0000,1,991,0),(20929,85,'Shadow Antimatter Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.1,0.125,0,100,NULL,111132.0000,1,1004,0),(20931,85,'Shadow Iridium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.1,0.125,0,100,NULL,44446.0000,1,1004,0),(20933,85,'Shadow Iron Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.1,0.125,0,100,NULL,22210.0000,1,1004,0),(20935,85,'Shadow Lead Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.1,0.125,0,100,NULL,55556.0000,1,1004,0),(20937,85,'Shadow Plutonium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.5,0.125,0,100,NULL,88850.0000,1,1004,0),(20939,85,'Shadow Thorium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.5,0.125,0,100,NULL,66656.0000,1,1004,0),(20941,85,'Shadow Tungsten Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.5,0.125,0,100,NULL,33184.0000,1,1004,0),(20943,85,'Shadow Uranium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.5,0.125,0,100,NULL,77776.0000,1,1004,0),(20945,85,'Guardian Iron Charge S','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.01,0.0025,0,100,NULL,222.0000,1,993,0),(20947,85,'Guardian Tungsten Charge S','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.01,0.0025,0,100,NULL,332.0000,1,993,0),(20949,85,'Guardian Iridium Charge S','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.01,0.0025,0,100,NULL,428.0000,1,993,0),(20951,85,'Guardian Lead Charge S','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.01,0.0025,0,100,NULL,524.0000,1,993,0),(20953,85,'Guardian Thorium Charge S','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.01,0.0025,0,100,NULL,660.0000,1,993,0),(20955,85,'Guardian Uranium Charge S','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.01,0.0025,0,100,NULL,778.0000,1,993,0),(20957,85,'Guardian Plutonium Charge S','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.01,0.0025,0,100,NULL,848.0000,1,993,0),(20959,85,'Guardian Antimatter Charge S','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,1056.0000,1,993,0),(20961,85,'Guardian Iron Charge M','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.05,0.0125,0,100,NULL,848.0000,1,992,0),(20963,85,'Guardian Tungsten Charge M','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.05,0.0125,0,100,NULL,1208.0000,1,992,0),(20965,85,'Guardian Iridium Charge M','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.05,0.0125,0,100,NULL,1664.0000,1,992,0),(20967,85,'Guardian Lead Charge M','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.05,0.0125,0,100,NULL,1832.0000,1,992,0),(20969,85,'Guardian Thorium Charge M','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.05,0.0125,0,100,NULL,2436.0000,1,992,0),(20971,85,'Guardian Uranium Charge M','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.05,0.0125,0,100,NULL,3042.0000,1,992,0),(20973,85,'Guardian Plutonium Charge M','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.05,0.0125,0,100,NULL,3588.0000,1,992,0),(20975,85,'Guardian Antimatter Charge M','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.05,0.0125,0,100,NULL,4458.0000,1,992,0),(20977,85,'Guardian Iron Charge L','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.1,0.025,0,100,NULL,2210.0000,1,991,0),(20979,85,'Guardian Tungsten Charge L','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.1,0.025,0,100,NULL,3184.0000,1,991,0),(20981,85,'Guardian Iridium Charge L','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.1,0.025,0,100,NULL,4446.0000,1,991,0),(20983,85,'Guardian Lead Charge L','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.1,0.025,0,100,NULL,5556.0000,1,991,0),(20985,85,'Guardian Thorium Charge L','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.1,0.025,0,100,NULL,6656.0000,1,991,0),(20987,85,'Guardian Uranium Charge L','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.1,0.025,0,100,NULL,7776.0000,1,991,0),(20989,85,'Guardian Plutonium Charge L','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.1,0.025,0,100,NULL,8850.0000,1,991,0),(20991,85,'Guardian Antimatter Charge L','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.1,0.025,0,100,NULL,11132.0000,1,991,0),(20993,85,'Guardian Antimatter Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.5,0.125,0,100,NULL,111132.0000,1,1004,0),(20995,85,'Guardian Iridium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.5,0.125,0,100,NULL,44446.0000,1,1004,0),(20997,85,'Guardian Iron Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.5,0.125,0,100,NULL,22210.0000,1,1004,0),(20999,85,'Guardian Lead Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.5,0.125,0,100,NULL,55556.0000,1,1004,0),(21001,85,'Guardian Plutonium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.5,0.125,0,100,NULL,88850.0000,1,1004,0),(21003,85,'Guardian Thorium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.5,0.125,0,100,NULL,66656.0000,1,1004,0),(21005,85,'Guardian Tungsten Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.5,0.125,0,100,NULL,33184.0000,1,1004,0),(21007,85,'Guardian Uranium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.5,0.125,0,100,NULL,77776.0000,1,1004,0),(21009,873,'Capital Propulsion Engine','A centralized propulsion engine designed to send power to a capital ship\'s thrusters, propelling the behemoth forward.',10000,10000,0,1,NULL,8820596.0000,1,781,0),(21010,915,'Capital Propulsion Engine Blueprint',' ',0,0.01,0,1,NULL,1253962000.0000,1,796,0),(21011,873,'Capital Turret Hardpoint','A turret hardpoint fitting, engineered to allow extra-large weapon turrets to fit on capital.',10000,10000,0,1,NULL,10601488.0000,1,781,0),(21012,915,'Capital Turret Hardpoint Blueprint',' ',0,0.01,0,1,NULL,1462602000.0000,1,796,0),(21013,873,'Capital Sensor Cluster','A vast bank of sensor equipment designed for use with capital ships.',10000,10000,0,1,NULL,8584638.0000,1,781,0),(21014,915,'Capital Sensor Cluster Blueprint',' ',0,0.01,0,1,NULL,1202763200.0000,1,796,0),(21017,873,'Capital Armor Plates','Gigantic sheets of reinforced armor plating, manufactured for the construction of capital ships.',10000,10000,0,1,NULL,9114842.0000,1,781,0),(21018,915,'Capital Armor Plates Blueprint',' ',0,0.01,0,1,NULL,1291210800.0000,1,796,0),(21019,873,'Capital Capacitor Battery','A multiple-thousand kilojoule capacitor battery, engineered for use in capital ships.',10000,10000,0,1,NULL,8194538.0000,1,781,0),(21020,915,'Capital Capacitor Battery Blueprint',' ',0,0.01,0,1,NULL,1146936000.0000,1,796,0),(21021,873,'Capital Power Generator','A gigantic hulk of machinery, designed to give life to a capital ship\'s power core.',10000,10000,0,1,2,9671186.0000,1,781,0),(21022,915,'Capital Power Generator Blueprint',' ',0,0.01,0,1,NULL,1360063200.0000,1,796,0),(21023,873,'Capital Shield Emitter','A modular unit designed to create a vast electromagnetic shield around capital ships.',10000,10000,0,1,NULL,9336104.0000,1,781,0),(21024,915,'Capital Shield Emitter Blueprint',' ',0,0.01,0,1,NULL,1306728000.0000,1,796,0),(21025,873,'Capital Jump Drive','A massive hulk of machinery designed to propel a capital vessel through vast tracts of space, allowing it to make its way between systems without the use of a stargate.',10000,10000,0,1,NULL,11990024.0000,1,781,0),(21026,915,'Capital Jump Drive Blueprint',' ',0,0.01,0,1,NULL,1663964800.0000,1,796,0),(21027,873,'Capital Cargo Bay','Sheets of massive metal which link together to form a multiple-thousand-cubic meter cargo bay, for insertion into capital ships.',10000,10000,0,1,NULL,5184252.0000,1,781,0),(21028,915,'Capital Cargo Bay Blueprint',' ',0,0.01,0,1,NULL,833702400.0000,1,796,0),(21029,873,'Capital Drone Bay','Sheets of massive metal which link together to form a fully functional drone bay, for insertion into capital ships.',10000,10000,0,1,NULL,6051254.0000,1,781,0),(21030,915,'Capital Drone Bay Blueprint',' ',0,0.01,0,1,NULL,872279600.0000,1,796,0),(21035,873,'Capital Computer System','Onboard electronic interfaces and data banks, required for the operation of capital ships.',10000,10000,0,1,NULL,8701416.0000,1,781,0),(21036,915,'Capital Computer System Blueprint',' ',0,0.01,0,1,NULL,1228398800.0000,1,796,0),(21037,873,'Capital Construction Parts','Various mechanical and electronic parts for the construction of capital ships.',10000,10000,0,1,NULL,7009160.0000,1,781,0),(21038,915,'Capital Construction Parts Blueprint',' ',0,0.01,0,1,NULL,1005494000.0000,1,796,0),(21039,873,'Capital Siege Array','An electronic interface responsible for rerouting a dreadnought\'s energy from its propulsion systems towards its defensive and offensive systems.',10000,10000,0,1,NULL,11252764.0000,1,781,0),(21040,915,'Capital Siege Array Blueprint',' ',0,0.01,0,1,NULL,1543366400.0000,1,796,0),(21041,873,'Capital Launcher Hardpoint','A launcher hardpoint fitting, engineered to allow citadel-class missile launchers to fit on capital ships.',10000,10000,0,1,NULL,10028794.0000,1,781,0),(21042,915,'Capital Launcher Hardpoint Blueprint',' ',0,0.01,0,1,NULL,1393368000.0000,1,796,0),(21043,526,'Ancient Treasure Map','An ancient and partly decayed treasure map, with the name \'Otitoh\' scribbled next to a picture of a crudely drawn solarsystem.  A big X marks one of the moons.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21044,526,'Pistols','Semi-automatic small arms used for personal protection and skirmish warfare.',2500,2,0,1,NULL,0.0000,1,NULL,0),(21046,526,'Nugoeihuvi Transaction Logs','These reports hold information on recent transactions of prop small arms between the Nugoeihuvi corporation and the Sukuuvestaa corporation, as well as evidence that the props aren\'t what they appear to be.',1,1,0,1,NULL,0.0000,1,NULL,0),(21047,472,'Oshima\'s System Scanner','A very old system scanner prototype.  Far too big and cumbersome to be worth anything in today\'s markets.',0,800,0,1,NULL,0.0000,0,NULL,0),(21048,474,'Kepheur\'s Keycard','This is a chaos-logic keycard. It had been issued to a pirate by the name of Drazin Jaruk. It will open the acceleration gate for a short time and then self-destruct.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21049,533,'Tao Pai Motow','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21052,306,'Old Storage Container','The wrecked container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21053,526,'Kepheur\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the long deceased Gallente entrepreneur, Kepheur Buquet.  ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21054,526,'Crude Sculpture','A crude, but old, sculpture of a Gallente citizen.',100,5,0,1,NULL,355552.0000,1,NULL,0),(21055,356,'Crude Sculpture Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(21056,533,'Tara Buquet','A direct descendant of the late Gallente entrepreneur Kepheur Buquet. Threat level: Deadly',12000000,112000,265,1,8,0.0000,0,NULL,0),(21057,409,'Tara\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,1,0.0000,1,NULL,0),(21058,523,'COSMOS Caldari Non-Pirate Battleship 4','This is a security vessel.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(21059,1209,'Shield Compensation','Improved skill for regulating energy flow to shields. 2% less capacitor need for shield boosters per skill level.\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,0.01,0,1,NULL,120000.0000,1,1747,0),(21060,520,'COSMOS Caldari Non-Pirate Frigate Elite 4','This is a security vessel.',1650000,16500,235,1,1,0.0000,0,NULL,0),(21061,533,'Makele Kordonii','A nefarious Minmatar pirate who was sent to the Okkelen constellation by the Angel Cartel to wreck havoc.  Leads a band of Caldari bandits. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(21062,370,'Makele\'s Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Angel Cartel pirate organization. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21063,533,'Zvarin Karsha_','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(21064,283,'Zvarin Karsha','A friendly peddler who operates in Otitoh.',90,3,0,1,NULL,0.0000,1,NULL,0),(21065,533,'Ryoke Laika','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21066,283,'Ryoke Laika','A Guristas pilot.',80,1,0,1,NULL,0.0000,1,NULL,0),(21067,526,'Ryoke Laika\'s Head','This is the head of Ryoke Laika, a veteran Guristas pilot.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21068,533,'Sheriff Togany_','The Sheriff of Otitoh.',10100000,101000,235,1,1,0.0000,0,NULL,0),(21070,283,'Sheriff Togany','The Sheriff of Otitoh.',80,1,0,1,NULL,0.0000,1,NULL,0),(21071,256,'Rapid Launch','Proficiency at rapid missile launcher firing. 3% bonus to missile launcher rate of fire per level.',0,0.01,0,1,NULL,40000.0000,1,373,0),(21073,530,'Sleeper Split Cables','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1902,0),(21074,735,'Talocan Sketch Books',' ',1,1,0,1,NULL,0.0000,1,1903,0),(21075,530,'Talocan Molecule Binder','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1903,0),(21076,528,'Talocan Stasis Inverter',' ',1,0.1,0,1,NULL,0.0000,1,1903,0),(21077,735,'Talocan Info Shards',' ',1,1,0,1,NULL,0.0000,1,1903,0),(21078,530,'Talocan Reflective Sheets','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1903,0),(21079,528,'Talocan Perpetual Clock',' ',1,0.1,0,1,NULL,0.0000,1,1903,0),(21080,528,'Talocan Solid Atomizer',' ',1,0.1,0,1,NULL,0.0000,1,1903,0),(21081,530,'Talocan Mechanical Gears','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1903,0),(21082,528,'Talocan System Interface Unit',' ',1,0.1,0,1,NULL,0.0000,1,1903,0),(21084,735,'Talocan Mathematical Schematics',' ',1,1,0,1,NULL,0.0000,1,1903,0),(21085,735,'Talocan Automation Accounts',' ',1,1,0,1,NULL,0.0000,1,1903,0),(21086,530,'Talocan Partition Plates','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1903,0),(21087,735,'Talocan Intricate Formulas',' ',1,1,0,1,NULL,0.0000,1,1903,0),(21088,528,'Talocan Stasis Deflector',' ',1,0.1,0,1,NULL,0.0000,1,1903,0),(21089,530,'Talocan Ignition Device','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1903,0),(21090,533,'Bai Tarziiki','This is a hostile outlaw. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21091,526,'Bai\'s Corpse','A Caldari bandit.',80,1,0,1,NULL,0.0000,1,NULL,0),(21092,533,'Motani Ihura','This is an agent working for the Hyasyoda corporation. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21094,310,'Cynosural Field I','A precise frequency energy field, used as a target beacon for jumpdrives.',1,5,0,1,NULL,32136.0000,0,NULL,0),(21095,532,'Cynosural Field I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(21096,658,'Cynosural Field Generator I','Generates a cynosural field for capital ship jump drives to lock on to.\r\r\n',0,50,0,1,NULL,6410500.0000,1,1641,0),(21097,31,'Goru\'s Shuttle','Goru Nikainen\'s Shuttle.',1600000,5000,10,1,1,5556.0000,1,1631,0),(21098,111,'Goru\'s Shuttle Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(21099,306,'Kazka Loot Container','The enclosed flotsam drifts quietly in space, closely monitored by the infamous pirate gang in Okkelen, the Kazka Bandits.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(21101,533,'RabaRaba ChooChoo','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21103,533,'Jakon Tooka','The Amarrian outlaw, Jakon Tooka, is an old member of the Blood Raider cult who decided to settle in Otitoh.  He was welcomed with open arms by the local bandit groups, and is currently a feared gang leader within the Kazka Bandits, a loosely knit outlaw organization within the Okkelen constellation. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(21104,370,'Jakon\'s Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21105,517,'Cosmos Bellicose','A Bellicose piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21106,517,'Cosmos Bestower','A Bestower piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(21107,517,'Cosmos Claw','A Claw piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21108,517,'Cosmos Executioner','An Executioner piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(21109,517,'Cosmos Hoarder','A Hoarder piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21110,517,'Cosmos Hound','A Hound piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21111,517,'Cosmos Mammoth','A Mammoth piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21112,517,'Cosmos Maulus','A Maulus piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(21113,517,'Cosmos Navitas','A Navitas piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(21114,517,'Cosmos Omen','An Omen piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(21115,517,'Cosmos Retribution','A Retribution piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(21116,517,'Cosmos Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21117,517,'Cosmos Rupture','A Rupture piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21118,517,'Cosmos Scythe','A Scythe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21119,517,'Cosmos Stiletto','A Stiletto piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21120,517,'Cosmos Tempest','A Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21121,517,'Cosmos Thrasher','A Thrasher piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21122,517,'Cosmos Vagabond','A Vagabond piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21123,517,'Cosmos Vigil','A Vigil piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21124,517,'Cosmos Wolf','A Wolf piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21125,517,'Cosmos Wreathe','A Wreathe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21126,526,'Raytio Family Supplies','These crates contain property of the Raytio family.',100,10,0,1,NULL,0.0000,1,NULL,0),(21127,534,'Payo Ming','An ex-member of the Mordu\'s Legion, Payo was banished from all Caldari territories for \'causing civil unrest and engaging in illegal activities\'.  He has always maintained his innocence, and claimed that he was simply a political target to feed the Mordu\'s propaganda machine.  His supporters within the Legion managed to smuggle him out before his arrest, and he has been running from the law ever since.  Finally, after realizing his sentance would not be revoked, he joined up with the Kazka Bandits, an outlaw organization in the Okkelen constellation with close ties to the Guristas Pirates.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(21128,522,'COSMOS Magye Eraser','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21129,522,'COSMOS Magye Silencer','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21130,520,'COSMOS Magye Death Dealer','This is a hostile pirate vessel. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(21131,520,'COSMOS Magye Wrecker','This is a hostile pirate vessel. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(21132,517,'Burkur\'s Vigil','A Vigil piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21133,517,'Mork\'s Probe','A Probe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21134,517,'Kersos\' Thrasher','A Thrasher piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21135,517,'Rakken\'s Claw','A Claw piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21136,517,'Pokkolen\'s Wreathe','A Wreathe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21137,517,'Hekken\'s Condor','A Condor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(21138,517,'Nitrut\'s Vigil','A Vigil piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 4.5</b> ',0,0,0,1,2,0.0000,0,NULL,0),(21139,517,'Takson\'s Wreathe','A Wreathe piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 1</b> \r\r\n\r\r\n<i>Warning: An industrial is recommended</i> ',0,0,0,1,2,0.0000,0,NULL,0),(21140,517,'Rochet\'s Incursus','An Incursus piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 1</b> \r\r\n\r\r\n<i>Warning: An industrial is recommended</i> ',0,0,0,1,8,0.0000,0,NULL,0),(21141,517,'Darrchien\'s Navitas','A Navitas piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(21142,517,'Stokk\'s Claw','A Claw piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21143,517,'Rikkiryo\'s Heron','A Heron piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(21144,517,'Hatram\'s Executioner','An Executioner piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(21145,517,'Nitrus\' Vigil','A Vigil piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21146,517,'Ouche\'s Navitas','A Navitas piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(21147,517,'Bokh\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21148,517,'Karkinen\'s Cormorant','A Cormorant piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(21149,517,'Sakt\'s Stiletto','A Stiletto piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21150,517,'Sarbaert\'s Hound','A Hound piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21151,517,'Tekrawhol\'s Rupture','A Rupture piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21152,517,'Tromkurt\'s Vagabond','A Vagabond piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21153,517,'Rugaert\'s Vigil','A Vigil piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21154,517,'Asshala\'s Retribution','A Retribution piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(21155,517,'Horkund\'s Scythe','A Scythe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21156,517,'Korten\'s Vagabond','A Vagabond piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21157,517,'Patrenn\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21158,517,'Tikrest\'s Rupture','A Rupture piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21159,517,'Ucham\'s Omen','An Omen piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(21160,517,'Sharum\'s Maulus','A Maulus piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(21161,715,'Kutill\'s Hoarder','A Hoarder piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 6</b> ',0,0,0,1,2,0.0000,0,NULL,0),(21162,517,'Mothrus\'s Bellicose','A Bellicose piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5.5</b> ',0,0,0,1,2,0.0000,0,NULL,0),(21163,517,'Maertigor\'s Wreathe','A Wreathe piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<i>Mini-Profession related</i> \r\r\n',0,0,0,1,2,0.0000,0,NULL,0),(21164,517,'Ristiger\'s Bellicose','A Bellicose piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5</b> \r\r\n',0,0,0,1,2,0.0000,0,NULL,0),(21165,517,'Frain\'s Blackbird','A Blackbird piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 7.5</b> ',0,0,0,1,1,0.0000,0,NULL,0),(21166,517,'Karadom\'s Mammoth','A Mammoth piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 7.5</b> ',0,0,0,1,2,0.0000,0,NULL,0),(21167,517,'Robaerger\'s Scythe','A Scythe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21168,517,'Torsont\'s Bellicose','A Bellicose piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21169,517,'Jogmundt\'s Probe','A Probe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21170,517,'Hakkars\' Wolf','A Wolf piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21171,517,'Murchor\'s Tempest','A Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21172,517,'Ossiam\'s Retribution','A Retribution piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(21173,517,'Quereg\'s Omen','An Omen piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(21174,517,'Kverkinn\'s Stiletto','A Stiletto piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21175,517,'Namian\'s Retribution','A Retribution piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(21176,517,'Tyrfin\'s Rupture','A Rupture piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21177,517,'Spitek\'s Bellicose','A Bellicose piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21178,517,'Gurmurkur\'s Vagabond','A Vagabond piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21179,517,'Verkort\'s Scythe','A Scythe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(21180,526,'Illian\'s Passcard','This security passcard is manufactured by the Minmatar Fleet and allows the user to unlock a specific acceleration gate to another sector. The gate will remain open for a short period of time and the keycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21181,534,'Illian Gara','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(21194,86,'Blood Radio S','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3008.0000,1,997,0),(21196,86,'Blood Microwave S','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2000.0000,1,997,0),(21198,86,'Blood Infrared S','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1128.0000,1,997,0),(21200,86,'Blood Standard S','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1358.0000,1,997,0),(21202,86,'Blood Ultraviolet S','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1628.0000,1,997,0),(21204,86,'Blood Xray S','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2532.0000,1,997,0),(21206,86,'Blood Gamma S','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3508.0000,1,997,0),(21208,86,'Blood Multifrequency S','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4000.0000,1,997,0),(21210,86,'Blood Microwave M','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,20192.0000,1,996,0),(21212,86,'Blood Infrared M','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,10192.0000,1,996,0),(21214,86,'Blood Standard M','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,12736.0000,1,996,0),(21216,86,'Blood Ultraviolet M','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,15648.0000,1,996,0),(21218,86,'Blood Xray M','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,26064.0000,1,996,0),(21220,86,'Blood Gamma M','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,35160.0000,1,996,0),(21222,86,'Blood Multifrequency M','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,40072.0000,1,996,0),(21224,86,'Blood Radio L','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,336522.0000,1,995,0),(21226,86,'Blood Microwave L','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,218720.0000,1,995,0),(21228,86,'Blood Infrared L','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,108552.0000,1,995,0),(21230,86,'Blood Standard L','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,141320.0000,1,995,0),(21232,86,'Blood Ultraviolet L','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,166464.0000,1,995,0),(21234,86,'Blood Xray L','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,279152.0000,1,995,0),(21236,86,'Blood Gamma L','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,385880.0000,1,995,0),(21238,86,'Blood Multifrequency L','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.\r\r\n',1,1,0,1,NULL,443296.0000,1,995,0),(21240,86,'Blood Radio XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3336522.0000,1,1007,0),(21242,86,'Blood Microwave XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2218720.0000,1,1007,0),(21244,86,'Blood Infrared XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1108552.0000,1,1007,0),(21246,86,'Blood Standard XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the visible light spectrum. \r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1391864.0000,1,1007,0),(21248,86,'Blood Ultraviolet XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1666464.0000,1,1007,0),(21250,86,'Blood Xray XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2779152.0000,1,1007,0),(21252,86,'Blood Gamma XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3885880.0000,1,1007,0),(21254,86,'Blood Multifrequency XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nRandomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4443296.0000,1,1007,0),(21256,86,'Dark Blood Radio S','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3008.0000,1,997,0),(21258,86,'Dark Blood Microwave S','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2000.0000,1,997,0),(21260,86,'Dark Blood Infrared S','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1128.0000,1,997,0),(21262,86,'Dark Blood Standard S','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1358.0000,1,997,0),(21264,86,'Dark Blood Ultraviolet S','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1628.0000,1,997,0),(21266,86,'Dark Blood Xray S','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2532.0000,1,997,0),(21268,86,'Dark Blood Gamma S','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3508.0000,1,997,0),(21270,86,'Dark Blood Multifrequency S','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4000.0000,1,997,0),(21272,86,'Dark Blood Radio M','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,31062.0000,1,996,0),(21274,86,'Dark Blood Microwave M','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,20192.0000,1,996,0),(21276,86,'Dark Blood Infrared M','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,10192.0000,1,996,0),(21278,86,'Dark Blood Standard M','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,12736.0000,1,996,0),(21280,86,'Dark Blood Ultraviolet M','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,15648.0000,1,996,0),(21282,86,'Dark Blood Xray M','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,26064.0000,1,996,0),(21284,86,'Dark Blood Gamma M','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,35160.0000,1,996,0),(21286,86,'Dark Blood Multifrequency M','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,40072.0000,1,996,0),(21288,86,'Dark Blood Radio L','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,336522.0000,1,995,0),(21290,86,'Dark Blood Microwave L','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,218720.0000,1,995,0),(21292,86,'Dark Blood Infrared L','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,108552.0000,1,995,0),(21294,86,'Dark Blood Standard L','Modulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,141320.0000,1,995,0),(21296,86,'Dark Blood Ultraviolet L','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,166464.0000,1,995,0),(21298,86,'Dark Blood Xray L','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,279152.0000,1,995,0),(21300,86,'Dark Blood Gamma L','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,385880.0000,1,995,0),(21302,86,'Dark Blood Multifrequency L','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,443296.0000,1,995,0),(21304,86,'Dark Blood Radio XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3336522.0000,1,1007,0),(21306,86,'Dark Blood Microwave XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2218720.0000,1,1007,0),(21308,86,'Dark Blood Infrared XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1108552.0000,1,1007,0),(21310,86,'Dark Blood Standard XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the visible light spectrum.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1391864.0000,1,1007,0),(21312,86,'Dark Blood Ultraviolet XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1666464.0000,1,1007,0),(21314,86,'Dark Blood Xray XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2779152.0000,1,1007,0),(21316,86,'Dark Blood Gamma XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nModulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3885880.0000,1,1007,0),(21318,86,'Dark Blood Multifrequency XL','Extra Large Frequency Crystal. Can be used only by starbase defense batteries and capital ships like dreadnoughts. \r\r\n\r\r\nRandomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4443296.0000,1,1007,0),(21320,85,'Guristas Iron Charge S','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.01,0.0025,0,100,NULL,222.0000,1,993,0),(21322,85,'Guristas Tungsten Charge S','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.01,0.0025,0,100,NULL,332.0000,1,993,0),(21324,85,'Guristas Iridium Charge S','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.01,0.0025,0,100,NULL,428.0000,1,993,0),(21326,85,'Guristas Lead Charge S','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.01,0.0025,0,100,NULL,524.0000,1,993,0),(21328,85,'Guristas Thorium Charge S','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.05,0.0025,0,100,NULL,660.0000,1,993,0),(21330,85,'Guristas Uranium Charge S','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.05,0.0025,0,100,NULL,778.0000,1,993,0),(21332,85,'Guristas Plutonium Charge S','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.05,0.0025,0,100,NULL,848.0000,1,993,0),(21334,85,'Guristas Antimatter Charge S','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.05,0.0025,0,100,NULL,1056.0000,1,993,0),(21335,167,'Guristas Antimatter Charge S Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(21336,85,'Guristas Iron Charge M','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.1,0.0125,0,100,NULL,848.0000,1,992,0),(21338,85,'Guristas Tungsten Charge M','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.1,0.0125,0,100,NULL,1208.0000,1,992,0),(21340,85,'Guristas Iridium Charge M','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.1,0.0125,0,100,NULL,1664.0000,1,992,0),(21342,85,'Guristas Lead Charge M','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.1,0.0125,0,100,NULL,1832.0000,1,992,0),(21344,85,'Guristas Thorium Charge M','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.5,0.0125,0,100,NULL,2436.0000,1,992,0),(21346,85,'Guristas Uranium Charge M','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.5,0.0125,0,100,NULL,3042.0000,1,992,0),(21348,85,'Guristas Plutonium Charge M','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.5,0.0125,0,100,NULL,3588.0000,1,992,0),(21350,85,'Guristas Antimatter Charge M','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.5,0.0125,0,100,NULL,4458.0000,1,992,0),(21352,85,'Guristas Iron Charge L','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.01,0.025,0,100,NULL,2210.0000,1,991,0),(21354,85,'Guristas Tungsten Charge L','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.01,0.025,0,100,NULL,3184.0000,1,991,0),(21356,85,'Guristas Iridium Charge L','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.01,0.025,0,100,NULL,4446.0000,1,991,0),(21358,85,'Guristas Lead Charge L','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.01,0.025,0,100,NULL,5556.0000,1,991,0),(21360,85,'Guristas Thorium Charge L','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.05,0.025,0,100,NULL,6656.0000,1,991,0),(21362,85,'Guristas Uranium Charge L','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.05,0.025,0,100,NULL,7776.0000,1,991,0),(21364,85,'Guristas Plutonium Charge L','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.05,0.025,0,100,NULL,8850.0000,1,991,0),(21366,85,'Guristas Antimatter Charge L','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.05,0.025,0,100,NULL,11132.0000,1,991,0),(21368,85,'Guristas Antimatter Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.1,0.125,0,100,NULL,111132.0000,1,1004,0),(21370,85,'Guristas Iridium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.1,0.125,0,100,NULL,44446.0000,1,1004,0),(21372,85,'Guristas Iron Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.1,0.125,0,100,NULL,22210.0000,1,1004,0),(21374,85,'Guristas Lead Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.1,0.125,0,100,NULL,55556.0000,1,1004,0),(21376,85,'Guristas Plutonium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.5,0.125,0,100,NULL,88850.0000,1,1004,0),(21378,85,'Guristas Thorium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.5,0.125,0,100,NULL,66656.0000,1,1004,0),(21380,85,'Guristas Tungsten Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.5,0.125,0,100,NULL,33184.0000,1,1004,0),(21382,85,'Guristas Uranium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.5,0.125,0,100,NULL,77776.0000,1,1004,0),(21384,85,'Dread Guristas Iron Charge S','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.01,0.0025,0,100,NULL,222.0000,1,993,0),(21386,85,'Dread Guristas Tungsten Charge S','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.01,0.0025,0,100,NULL,332.0000,1,993,0),(21388,85,'Dread Guristas Iridium Charge S','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.01,0.0025,0,100,NULL,428.0000,1,993,0),(21390,85,'Dread Guristas Lead Charge S','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.01,0.0025,0,100,NULL,524.0000,1,993,0),(21392,85,'Dread Guristas Thorium Charge S','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.01,0.0025,0,100,NULL,660.0000,1,993,0),(21394,85,'Dread Guristas Uranium Charge S','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.01,0.0025,0,100,NULL,778.0000,1,993,0),(21396,85,'Dread Guristas Plutonium Charge S','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.01,0.0025,0,100,NULL,848.0000,1,993,0),(21398,85,'Dread Guristas Antimatter Charge S','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,1056.0000,1,993,0),(21400,85,'Dread Guristas Iron Charge M','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.05,0.0125,0,100,NULL,848.0000,1,992,0),(21402,85,'Dread Guristas Tungsten Charge M','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.05,0.0125,0,100,NULL,1208.0000,1,992,0),(21404,85,'Dread Guristas Iridium Charge M','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.05,0.0125,0,100,NULL,1664.0000,1,992,0),(21406,85,'Dread Guristas Lead Charge M','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.05,0.0125,0,100,NULL,1832.0000,1,992,0),(21408,85,'Dread Guristas Thorium Charge M','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.05,0.0125,0,100,NULL,2436.0000,1,992,0),(21410,85,'Dread Guristas Uranium Charge M','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.05,0.0125,0,100,NULL,3042.0000,1,992,0),(21412,85,'Dread Guristas Plutonium Charge M','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.05,0.0125,0,100,NULL,3588.0000,1,992,0),(21414,85,'Dread Guristas Antimatter Charge M','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.05,0.0125,0,100,NULL,4458.0000,1,992,0),(21416,85,'Dread Guristas Iron Charge L','Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.1,0.025,0,100,NULL,2210.0000,1,991,0),(21418,85,'Dread Guristas Tungsten Charge L','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.1,0.025,0,100,NULL,3184.0000,1,991,0),(21420,85,'Dread Guristas Iridium Charge L','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.1,0.025,0,100,NULL,4446.0000,1,991,0),(21422,85,'Dread Guristas Lead Charge L','Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.1,0.025,0,100,NULL,5556.0000,1,991,0),(21424,85,'Dread Guristas Thorium Charge L','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.1,0.025,0,100,NULL,6656.0000,1,991,0),(21426,85,'Dread Guristas Uranium Charge L','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.1,0.025,0,100,NULL,7776.0000,1,991,0),(21428,85,'Dread Guristas Plutonium Charge L','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.1,0.025,0,100,NULL,8850.0000,1,991,0),(21430,85,'Dread Guristas Antimatter Charge L','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.1,0.025,0,100,NULL,11132.0000,1,991,0),(21432,85,'Dread Guristas Antimatter Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.5,0.125,0,100,NULL,111132.0000,1,1004,0),(21434,85,'Dread Guristas Iridium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.5,0.125,0,100,NULL,44446.0000,1,1004,0),(21436,85,'Dread Guristas Iron Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of iron atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.5,0.125,0,100,NULL,22210.0000,1,1004,0),(21438,85,'Dread Guristas Lead Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of lead atoms suspended in a plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.5,0.125,0,100,NULL,55556.0000,1,1004,0),(21440,85,'Dread Guristas Plutonium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.5,0.125,0,100,NULL,88850.0000,1,1004,0),(21442,85,'Dread Guristas Thorium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.5,0.125,0,100,NULL,66656.0000,1,1004,0),(21444,85,'Dread Guristas Tungsten Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.5,0.125,0,100,NULL,33184.0000,1,1004,0),(21446,85,'Dread Guristas Uranium Charge XL','Extra Large Hybrid Charge. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.5,0.125,0,100,NULL,77776.0000,1,1004,0),(21448,534,'Gatti Zhara','A wealthy land-owner in Otomainen.  Owns a powerful battleship.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(21449,526,'Gatti\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the Caldari entrepreneur, Gatti Zhara.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21450,86,'Blood Radio M','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,31062.0000,1,996,0),(21452,534,'Pata Wakiro','This is a hostile pirate vessel. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(21453,526,'Pata Wakiro\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the Kazka Bandit Lord Pata Wakiro.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21454,526,'Moa Parts','These crates contain parts needed to build a Moa cruiser.',128000,30,0,1,NULL,0.0000,1,NULL,0),(21459,494,'COSMOS Storage Silo','A Lai Dai storage silo. Overtaken by Guristas forces, the Guristas are now using this structure to store valuables weapons and equipment.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(21460,526,'Nugoeihuvi Rifles','These rifles belong to the Nugoeihuvi corporation.',1,5,0,1,NULL,0.0000,1,NULL,0),(21461,526,'Wiyrkomi Rifles','These rifles belong to the Wiyrkomi Corporation.',1,5,0,1,NULL,0.0000,1,NULL,0),(21462,526,'Propel Dynamics Reports','These encoded reports may mean little to the untrained eye, but can prove valuable to the relevant institution.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21463,526,'Excavation Equipment','Excavation Equipment.',2000,1,0,1,NULL,0.0000,1,NULL,0),(21464,526,'Rifles','Laser rifles, used both for warfare and personal security.',2500,2,0,1,NULL,0.0000,1,NULL,0),(21465,526,'Ancient Weapon','Excavated by the Wiyrkomi Corporation, many factions seek to gain hold of these weapons. They are rumoured to contain abilities previously unknown to the empires.',2500,2,0,1,NULL,0.0000,1,NULL,0),(21466,283,'Miner','A sturdy miner.',100,3,0,1,NULL,0.0000,1,NULL,0),(21467,283,'Spy','A captured spy.',100,3,0,1,NULL,0.0000,1,NULL,0),(21468,526,'Counterfeit Credits','Counterfeit money confiscated from bandits.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(21469,526,'Bag of Counterfeit Credits','Counterfeit money confiscated from bandits.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(21470,46,'1MN Analog Booster Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,7104.0000,1,542,0),(21471,126,'1MN Analog Booster Afterburner Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21472,46,'10MN Analog Booster Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,4,35804.0000,1,542,0),(21473,126,'10MN Analog Booster Afterburner Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(21474,46,'100MN Analog Booster Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,4,189896.0000,1,542,0),(21475,126,'100MN Analog Booster Afterburner Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(21476,46,'5MN Digital Booster Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,4,34998.0000,1,131,0),(21477,126,'5MN Digital Booster Microwarpdrive Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(21478,46,'50MN Digital Booster Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,4,192086.0000,1,131,0),(21479,126,'50MN Digital Booster Microwarpdrive Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(21480,46,'500MN Digital Booster Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,4,1076506.0000,1,131,0),(21481,126,'500MN Digital Booster Rockets Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(21482,367,'Ballistic \'Purge\' Targeting System I','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,85006.0000,1,645,0),(21483,400,'Ballistic \'Purge\' Targeting System I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21484,367,'\'Full Duplex\' Ballistic Targeting System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,85006.0000,1,645,0),(21485,400,'\'Full Duplex\' Ballistic Targeting System Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21486,59,'\'Kindred\' Stabilization Actuator I','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,30626.0000,1,646,0),(21487,139,'\'Kindred\' Stabilization Actuator I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21488,59,'Monophonic Stabilization Actuator I','Gives a bonus to the speed and damage of projectile turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,30626.0000,1,646,0),(21489,139,'Monophonic Stabilization Actuator I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21490,527,'Zarkona Mirei\'s Worm','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(21491,764,'Synthetic Hull Conversion Overdrive Injector','This monster unit vastly increases engine power at the expense of cargo capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,5,0,1,4,27772.0000,1,1087,0),(21492,158,'Synthetic Hull Conversion Overdrive Injector Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(21493,765,'Limited Expanded \'Archiver\' Cargo','Increases cargo hold capacity.',50,5,0,1,4,1792.0000,1,1197,0),(21494,158,'Limited Expanded \'Archiver\' Cargo Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(21495,527,'Dry River Gangmember','This is a hostile pirate vessel. Threat level: Moderate',2025000,20250,65,1,1,0.0000,0,NULL,0),(21496,78,'Synthetic Hull Conversion Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,4,13888.0000,1,1195,0),(21497,158,'Synthetic Hull Conversion Reinforced Bulkheads Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(21498,762,'Synthetic Hull Conversion Inertia Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,4,6036.0000,1,1086,0),(21499,158,'Synthetic Hull Conversion Inertia Stabilizers Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(21500,763,'Synthetic Hull Conversion Nanofiber Structure','Replaces some of the heavier structure components with lighter, but more fragile material. Increases ship\'s velocity and improves maneuverability at the expense of hull strength.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',100,5,0,1,4,1792.0000,1,1196,0),(21501,158,'Synthetic Hull Conversion Nanofiber Structure Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(21502,283,'Zarkona Mirei','A veteran pilot of a Guristas elite frigate.',80,1,0,1,NULL,0.0000,1,NULL,0),(21503,527,'Dry River Gangleader','This is a hostile pirate vessel. Threat level: Significant',2040000,20400,235,1,1,0.0000,0,NULL,0),(21504,63,'Small \'Integrative\' Hull Repair Unit','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,5,0,1,NULL,55556.0000,1,1053,0),(21505,143,'Small \'Integrative\' Hull Repair Unit Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21506,63,'Medium \'Integrative\' Hull Repair Unit','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,10,0,1,NULL,220806.0000,1,1054,0),(21507,143,'Medium \'Integrative\' Hull Repair Unit Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21508,63,'Large \'Integrative\' Hull Repair Unit','Makes use of nano-assembler technology in order to repair damage done to the structure.',1000,50,0,1,NULL,631556.0000,1,1055,0),(21509,143,'Large \'Integrative\' Hull Repair Unit Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21510,52,'Process-Interruptive Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,47476.0000,1,1935,0),(21511,132,'Process-Interruptive Warp Disruptor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21512,52,'\'Delineative\' Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,47476.0000,1,1936,0),(21513,132,'\'Delineative\' Warp Scrambler Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21514,526,'Doctored Arrivals & Departures Logs','These Arrivals & Departures logs have been carefully falsified and are ready for insertion into a particular station\'s data banks.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21515,533,'The Duke','This is a hostile pirate vessel. Threat level: Extreme',10700000,107000,850,1,1,0.0000,0,NULL,0),(21516,526,'Cheri Mirei\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the villain, Cheri Mirei.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21517,526,'Parts of Printing Machine','Broken and bent pieces of a printing machine used to create counterfeit credits. If you look closely enough, you can see traces of blood smeared over some of the parts. Undoubtedly that of the printers hired by the Dry River gang. Let\'s hope the knowledge for creating this bad money died with them.',1000,1,0,1,NULL,0.0000,1,NULL,0),(21518,527,'Dry River Guardian','This is a hostile pirate vessel. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(21519,494,'Dry River Warehouse','Warehouse used by the Dry River gang for unknown purposes. It is guarded by several gang members.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(21520,526,'Guristas Outlaw Dogtag','This tag was carried by a Guristas outlaw inhabiting the Okkelen constellation.',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(21521,203,'Gravimetric Firewall','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,720,0),(21522,347,'Gravimetric Firewall Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21523,203,'Ladar Firewall','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,721,0),(21524,347,'Ladar Firewall Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21525,203,'Magnetometric Firewall','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,723,0),(21526,347,'Magnetometric Firewall Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21527,203,'Multi Sensor Firewall','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,20,0,1,NULL,27772.0000,1,724,0),(21528,347,'Multi Sensor Firewall Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21529,203,'RADAR Firewall','A backup system which operates in conjunction with the main array. Reduces the ship\'s vulnerability to jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,13884.0000,1,722,0),(21530,347,'RADAR Firewall Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21531,526,'Barbed Wire Scanner','A prototype scanner that can be easily linked into a scanner array to get a full and detailed coverage of the area under surveillance.',2500,2,0,1,NULL,0.0000,1,NULL,0),(21532,72,'Micro Degenerative Concussion Bomb I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',10,5,0,1,NULL,50000.0000,1,380,0),(21534,72,'Small Degenerative Concussion Bomb I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,2.5,0,1,NULL,25854.0000,1,382,0),(21535,152,'Small Degenerative Concussion Bomb I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21536,72,'Medium Degenerative Concussion Bomb I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,10,0,1,NULL,168302.0000,1,383,0),(21537,152,'Medium Degenerative Concussion Bomb I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21538,72,'Large Degenerative Concussion Bomb I','Radiates an omnidirectional pulse from the ship that causes explosive damage to surrounding vessels.',100,50,0,1,NULL,348310.0000,1,381,0),(21539,152,'Large Degenerative Concussion Bomb I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21540,379,'\'Inception\' Target Painter I','A targeting subsystem that projects a electronic \"Tag\" on the target thus making it easier to target and Hit. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized. ',0,5,0,1,NULL,51464.0000,1,757,0),(21541,504,'\'Inception\' Target Painter I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21542,507,'N-1 Neon Type Rocket Bay','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.1875,1,NULL,3336.0000,1,639,0),(21543,136,'N-1 Neon Type Rocket Bay Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21544,526,'Broken Bug Device','A small bug device that can be planted on ships to intercept transmissions and relay them to a third person. This one is broken and can\'t relay anything, though it can still store data. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21545,55,'200mm Light \'Jolt\' Autocannon I','A powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.3,1,NULL,9958.0000,1,574,0),(21546,135,'200mm Light \'Jolt\' Autocannon I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21547,55,'250mm Light \'Jolt\' Artillery I','This artillery is one of the most powerful weapons that can be mounted on a frigate. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.1,1,NULL,13320.0000,1,577,0),(21548,135,'250mm Light \'Jolt\' Artillery I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21549,55,'280mm \'Jolt\' Artillery I','Rocket-assisted artillery projectiles designed for long-range combat. It is the most powerful projectile weapon able to be fitted onto frigates. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',500,5,0.05,1,NULL,20306.0000,1,577,0),(21550,135,'280mm \'Jolt\' Artillery I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21551,55,'425mm Medium \'Jolt\' Autocannon I','The 425mm is a behemoth that will inflict severe damage on most cruisers and frigates in short-range battles. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',1000,10,1.5,1,NULL,99930.0000,1,575,0),(21552,135,'425mm Medium \'Jolt\' Autocannon I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21553,55,'650mm Medium \'Jolt\' Artillery I','A powerful long-range cannon. One of the most damaging weapons mountable on a cruiser. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',125,10,0.5,1,NULL,133234.0000,1,578,0),(21554,135,'650mm Medium \'Jolt\' Artillery I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21555,55,'720mm \'Jolt\' Artillery I','This 720mm rocket-assisted howitzer is designed for long-range bombardment. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',50,10,0.25,1,NULL,166754.0000,1,578,0),(21556,135,'720mm \'Jolt\' Artillery I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21557,55,'800mm Heavy \'Jolt\' Repeating Cannon I','A two-barreled, intermediate-range, powerful cannon capable of causing tremendous damage. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',75,20,3,1,NULL,1116734.0000,1,576,0),(21558,135,'800mm Heavy \'Jolt\' Repeating Cannon I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21559,55,'1200mm Heavy \'Jolt\' Artillery I','One of the most powerful projectile cannons a battleship can equip. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,1,1,NULL,1568334.0000,1,579,0),(21560,135,'1200mm Heavy \'Jolt\' Artillery I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21561,55,'1400mm \'Jolt\' Artillery I','The ultimate artillery cannon. It hurls death and destruction over incredible distances. \r\r\n\r\r\nMust be loaded with any of the following projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, or Titanium Sabot.',2000,20,0.5,1,NULL,2015232.0000,1,579,0),(21562,135,'1400mm \'Jolt\' Artillery I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21563,527,'Dyklan Harrikar','This is the ship of Deklan Harrikar, a pirate, a scoundrel and a thief.',2025000,20250,235,1,1,0.0000,0,NULL,0),(21564,281,'Milk','Milk. New, fresh and cold.',400,0.5,0,1,NULL,0.0000,1,NULL,0),(21565,526,'Guristas Outlaw Leader Insignia','This insignia was carried by a Guristas Outlaw Leader. They can be found in the Okkelen constellation.',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(21566,526,'Impregnable Safe','A safe for use in banks and other financial establishments that handle lot of money. Guaranteed to be absolutely, totally and eternally impregnable to any and all kinds of assaults and infringements.',1000,120,0,1,NULL,0.0000,1,NULL,0),(21567,526,'Powdered Cubensis','This highly hallucinogenic powder is believed to be one of the primary causes of spirituality in humans.  Needless to say, it is reviled and feared in every industrialized part of the universe.',800,1,0,1,NULL,0.0000,1,NULL,0),(21568,732,'Sleeper Data Interface Protocol',' ',1,1,0,1,NULL,0.0000,1,1902,0),(21569,732,'Sleeper Profound Research Notes',' ',1,1,0,1,NULL,0.0000,1,1902,0),(21570,732,'Sleeper Manuscripts',' ',1,1,0,1,NULL,0.0000,1,1902,0),(21571,732,'Sleeper Technical Schematics',' ',1,1,0,1,NULL,0.0000,1,1902,0),(21572,732,'Sleeper Data Crystals',' ',1,1,0,1,NULL,0.0000,1,1902,0),(21573,731,'Esoteric Process','These are clever tips to improve the quality of Caldari blueprints received through invention.<br><br>Probability Multiplier: +10% <br>Max. Run Modifier: N/A <br>Material Efficiency Modifier: +3 <br>Time Efficiency Modifier: +6',1,1,0,1,NULL,0.0000,1,NULL,0),(21574,731,'Esoteric Accelerant','Rough outlines for a revolutionary new manufacture technique that improve the time efficiency of Caldari invention jobs considerably.<br><br>Probability Multiplier: +20% <br>Max. Run Modifier: +1 <br>Material Efficiency Modifier: +2 <br>Time Efficiency Modifier: +10',1,1,0,1,NULL,0.0000,1,NULL,0),(21575,731,'Esoteric Symmetry','Solid, if uninspiring, invention techniques, ideal for standard Caldari invention tasks.<br><br>Probability Multiplier: N/A <br>Max. Run Modifier: +2 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: +8',1,1,0,1,NULL,0.0000,1,NULL,0),(21576,731,'Esoteric Augmentation','Intriguing decryptor that will improve the number of runs of any invented Caldari blueprints a great deal.<br><br>Probability Multiplier: -40% <br>Max. Run Modifier: +9 <br>Material Efficiency Modifier: -2 <br>Time Efficiency Modifier: +2',1,1,0,1,NULL,0.0000,1,NULL,0),(21577,731,'Esoteric Attainment','The decryptor offers invaluable safe-guards to improve the chance of a successful Caldari invention immensely. Use this when you\'ve got to get it right.<br><br>Probability Multiplier: +80% <br>Max. Run Modifier: +4 <br>Material Efficiency Modifier: -1 <br>Time Efficiency Modifier: +4',1,1,0,1,NULL,0.0000,1,NULL,0),(21579,729,'Cryptic Process','This decryptor gives insightful information into the nature of Minmatar invention jobs, but lacks inspirational touches.<br><br>Probability Multiplier: +10% <br>Max. Run Modifier: N/A <br>Material Efficiency Modifier: +3 <br>Time Efficiency Modifier: +6',1,1,0,1,NULL,0.0000,1,NULL,0),(21580,729,'Cryptic Accelerant','The scientific jargon contained herein could cause mental meltdowns, but if you can extract anything of use it\'s great for Minmatar invention jobs. <br><br>Probability Multiplier: +20% <br>Max. Run Modifier: +1 <br>Material Efficiency Modifier: +2 <br>Time Efficiency Modifier: +10',1,1,0,1,NULL,0.0000,1,NULL,0),(21581,729,'Cryptic Symmetry','As long as you can decipher the theories there is some good common sense stuff in here that can give all around benefits to Minmatar invention jobs.<br><br>Probability Multiplier: N/A <br>Max. Run Modifier: +2 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: +8',1,1,0,1,NULL,0.0000,1,NULL,0),(21582,729,'Cryptic Augmentation','If you can assimilate these ideas into a Minmatar invention job it could greatly multiply your output runs.<br><br>Probability Multiplier: -40% <br>Max. Run Modifier: +9 <br>Material Efficiency Modifier: -2 <br>Time Efficiency Modifier: +2',1,1,0,1,NULL,0.0000,1,NULL,0),(21583,729,'Cryptic Attainment','Solid instructions that even an idiot can follow that improve your probability of a successful Minmatar invention job immensely. <br><br>Probability Multiplier: +80% <br>Max. Run Modifier: +4 <br>Material Efficiency Modifier: -1 <br>Time Efficiency Modifier: +4',1,1,0,1,NULL,0.0000,1,NULL,0),(21584,530,'Sleeper Micro Circuits','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1902,0),(21585,530,'Sleeper Cryo Batteries','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1902,0),(21586,530,'Sleeper Virtual Energizer','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1902,0),(21587,530,'Electronic Link','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1900,0),(21588,530,'Spare Parts','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1900,0),(21589,530,'Power Couplings','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1900,0),(21590,530,'Armor Blocks','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1900,0),(21591,530,'Computer Chips','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1900,0),(21592,530,'Electric Conduit','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,32,0.0000,1,1898,0),(21593,530,'Mechanic Parts','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,32,0.0000,1,1898,0),(21594,530,'Energy Cells','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1898,0),(21595,530,'Construction Alloy','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1898,0),(21596,530,'Data Processor','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1898,0),(21597,533,'Wolf Skarkert','A peddler of illicit substances.',10100000,101000,235,1,1,0.0000,0,NULL,0),(21598,517,'Guristas Prison','An agent resides in here.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 7.5</b> \r\r\n\r\r\n<i>Warning:  Industrial and combat ship recommended</i>',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(21600,494,'Officers Quarters','Guristas Officer\'s Quarters.  Equipped with a high tech EM forcefield.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(21601,526,'Myrkai\'s Data Chip','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21602,526,'Jakon\'s Head','This is the head of Jakon Tooka, a Blood Raider mercenary in league with the Kazka Bandits.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21603,275,'Cynosural Field Theory','Skill at creating effective cynosural fields. 10% reduction in liquid ozone consumption for module activation per skill level.  \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,10000000.0000,1,374,0),(21604,532,'Cynosural Field Generator I Blueprint',' ',0,0.01,0,1,NULL,31372640.0000,1,799,0),(21606,738,'Inherent Implants \'Noble\' Hull Upgrades HG-1008','A neural Interface upgrade that boosts the pilot\'s skill at maintaining their ship\'s midlevel defenses.\r\r\n\r\r\n8% bonus to armor hit points.',0,1,0,1,NULL,0.0000,1,1518,0),(21607,526,'Liberation Elixir','Made of the finest wahoo-root, gunpowder and crushed cubensis, this wondrous concoction can cure most every ill known to man, from the common cold to the Jovian disease to the spiritless drudgery of everyday life.  Step right up!',5,0.2,0,1,NULL,0.0000,1,NULL,0),(21608,226,'Astro Farm','The empty hull of an astro farm. Though it was abandoned long ago it\'s still in good shape. Maybe one day an adventurous farmer will take up residence here.',0,0,0,1,NULL,0.0000,0,NULL,0),(21609,226,'Dysfunctional Solar Harvester','A huge solar harvester once linked to the nearby astro farm. It has been out of order for many years.',0,0,0,1,NULL,0.0000,0,NULL,0),(21610,275,'Jump Fuel Conservation','Skill at regulating energy flow to the jump drive. 10% reduction in isotope consumption amount for jump drive operation per light year per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,20000000.0000,1,374,0),(21611,275,'Jump Drive Calibration','Advanced skill at using Jump Drives. 20% increase in maximum jump range per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,30000000.0000,1,374,0),(21612,526,'Dynamite Crate','A crate of the finest TNT money can buy. Guaranteed to blow even the largest of problems into smithereens.',1000,80,0,1,NULL,0.0000,1,NULL,0),(21613,526,'Safe-Deposit Box Owner List','This highly confidential document lists the owner of each safe-deposit box in the vault on the State and Region Bank station in Vahunomi.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21614,526,'Plan to Crack Impregnable Safe','Criminals have a knack for always being one step ahead of those trying to outsmart them. If it wasn\'t for the extra-long screws used to fasten the \'Lifetime Warranty\' sign on the back, it really would be an Impregnable Safe.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21615,526,'Pakkori\'s Hat','This is an extremely ugly wide-rimmed hat that once adorned the head of one Uchi Pakkori. The burn marks and blood smears don\'t improve the looks.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21616,526,'Nugoeihuvi Dogtag','This dogtag was carried by an officer of the Nugoeihuvi corporation. Strangely it has the Guristas emblem on it.',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(21617,494,'Barricaded Warehouse','This barricaded warehouse is the hiding place of Uchi Pakkori, employee of Caldari Funds Unlimited.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(21618,527,'Hired Gunman','This is a hostile pirate vessel. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(21619,526,'Wiretap Plant','A potted plant with a wiretap device cleverly hidden in the dirt.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21620,526,'Assistant\'s Keychain','This is the keychain of an assistant bank manager for the State and Region Bank in Vahunomi. It can be used to access to outer security vault in the bank.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21621,527,'Kazka Eunuch','This is a hostile pirate vessel. Threat level: Significant',2040000,20400,100,1,1,0.0000,0,NULL,0),(21622,494,'Kazka Brothel','A brothel operated by the Kazka Bandits. As sleazy as they come. Frilly petticoats are the pet fetishes here.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(21623,526,'Nugoeihuvi Station Schematics','Encoded station schematics for the Nugoeihuvi corporation. If decoded correctly, could this be decoded and used by someone else than Nugoeihuvi?',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21624,314,'Encoded Lai Dai Reports','If decoded correctly, these reports will show the locations of ancient monuments and relics.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21625,526,'Kusan Niemenen\'s Missile Launcher','Only Kusan Niemenen knows how to fit this strange missile launcher.',3000,2,0,1,NULL,0.0000,1,NULL,0),(21626,370,'Propel Dynamics Dogtag','This dogtag was carried by an officer of Propel Dynamics. Strangely it has the Guristas emblem on it.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21627,494,'Gas/Storage Silo','Built to withstand assault, these behemoths can each hold roughly 8.5 million m3 worth of materials.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(21628,31,'Guristas Shuttle','Caldari Shuttle registered to the Guristas organization.',1600000,5000,10,1,1,5556.0000,1,1631,0),(21629,111,'Guristas Shuttle Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(21630,533,'Bounty Hunter Drukhar','This is a ruthless bounty hunter, out for whatever blood is mandated by his contracts.  Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21631,283,'Construction Workers','Construction Workers',100,3,0,1,NULL,0.0000,1,NULL,0),(21632,526,'Construction Tools','Tools used in various construction projects.',10,10,0,1,NULL,58624.0000,1,NULL,0),(21633,306,'Urigamu_Warehouse_MISSION','This is a standard storage facility.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(21634,526,'Secret Garage Coordinates','A data chip containing the location of a secret garage operated by the local bandits.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21635,494,'Rent-A-Dream Pleasure Gardens','This Gallentean pleasure resort sports various activities open for guests, including casinos, baths, escort booths and three domes of simulated tropical paradise for maximum bliss.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(21636,527,'Sefo Caraton','A wealthy Gallente entrepreneur, who has just recently expanded his business to the Caldari territories.',10900000,109000,120,1,8,0.0000,0,NULL,0),(21637,526,'Data Chip Decoder','A decoder to unlock information stored on an encoded data chip. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21638,100,'Vespa II','Medium Scout Drone',5000,10,0,1,1,145750.0000,1,838,0),(21639,176,'Vespa II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21640,100,'Valkyrie II','Medium Scout Drone',5000,10,0,1,2,140736.0000,1,838,0),(21641,176,'Valkyrie II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(21642,15,'Caldari Research Outpost',' ',0,1,0,1,1,1683617576.0000,0,NULL,0),(21643,533,'Guristas Outlaw','This is a hostile pirate vessel. Threat level: Deadly',9200000,92000,235,1,1,0.0000,0,NULL,0),(21644,15,'Amarr Factory Outpost',' ',0,1,0,1,4,1702171823.0000,0,NULL,0),(21645,15,'Gallente Administrative Outpost',' ',0,1,0,1,8,1403018549.0000,0,NULL,0),(21646,15,'Minmatar Service Outpost',' ',0,1,0,1,2,1983932072.0000,0,NULL,0),(21647,533,'Guristas Robber','This is a hostile pirate vessel. Threat level: Deadly',9600000,96000,450,1,1,0.0000,0,NULL,0),(21648,533,'Guristas Maniac','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21649,533,'Nugoeihuvi Excavator','This is a hostile pirate vessel. Threat level: Deadly',9200000,92000,235,1,1,0.0000,0,NULL,0),(21650,533,'Nugoeihuvi Propagandist','This is a hostile vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21651,533,'Propel Dynamics Excavator','This is a hostile vessel. Threat level: Deadly',9600000,96000,450,1,1,0.0000,0,NULL,0),(21652,533,'Propel Dynamics Propagandist','This is a hostile vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21653,527,'Nugoeihuvi Defender','This is a hostile vessel. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(21654,527,'Nugoeihuvi Miner','This is a hostile vessel. Threat level: Very low',1500100,15001,45,1,1,0.0000,0,NULL,0),(21655,527,'Propel Dynamics Miner','This is a pirate vessel. Threat level: Very low',1500100,15001,45,1,1,0.0000,0,NULL,0),(21656,527,'Propel Dynamics Defender','This is a hostile vessel. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(21657,527,'Guristas Propagandist','This is a hostile vessel. Threat level: Very low',1500100,15001,45,1,1,0.0000,0,NULL,0),(21658,527,'Guristas Defender','This is a hostile pirate vessel. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(21659,226,'Dirty Bandit Shipyard','A shipyard, or garage, operated by those on the flashy side of the law (no, not the cops).',0,0,0,1,NULL,0.0000,0,NULL,0),(21660,527,'Bandit Mechanic','This is a hostile pirate vessel. Threat level: Moderate',2025000,20250,65,1,1,0.0000,0,NULL,0),(21661,526,'Spiked Quafe','Quafe is the name of the most popular soft drink in the universe, manufactured by a Gallentean company bearing the same name. Like so many soft drinks, it was initially intended as a medicine for indigestion and tender stomachs, but the refreshing effects of the drink appealed to everyone and the drink quickly became tremendously popular. Quafe is one of the best recognized brands in the whole EVE universe and can be found in every corner of it.\r\r\n\r\r\nThis is a spiked version of the popular soft drink. Keep out of reach of children. ',500,0.1,0,1,NULL,0.0000,1,NULL,0),(21662,306,'Radio_Telescope_MISSION','This is a radio telescope used for scouting nearby territory',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(21663,526,'Scanner Data I','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21664,526,'Scanner Data II','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21665,526,'Scanner Data III','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21666,255,'Capital Hybrid Turret','Operation of capital hybrid turrets. 5% Bonus to capital hybrid turret damage per level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,15000000.0000,1,364,0),(21667,255,'Capital Projectile Turret','Operation of capital projectile turrets. 5% Bonus to capital projectile turret damage per level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,15000000.0000,1,364,0),(21668,256,'Citadel Torpedoes','Skill at the handling and firing of citadel torpedoes. 5% bonus to citadel torpedo damage per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,15000000.0000,1,373,0),(21669,526,'Guristas Communications Logs','This salvaged data from a destroyed Guristas vessel contains an audio record of all communications between the pilot and his commanding officers for the last month.',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(21670,533,'Quao Kale','A Guristas Pirate envoy to the Kazka Bandits. Threat level: Deadly',9600000,96000,450,1,1,0.0000,0,NULL,0),(21671,526,'Guristas Patrol Routes','This encoded data from a destroyed Guristas vessel reveals the current patrol routes used by the Guristas in the Okkelen constellation.',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(21672,283,'Quao Kale','A Guristas pilot.',80,1,0,1,NULL,0.0000,1,NULL,0),(21675,533,'Zaphiria Oddin','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21676,526,'Jedon Hekkiren\'s Belongings','This container is filled with expensive jewelry and platinum bars.  Belongs to the wealthy Caldari banker, Jedon Hekkiren.',1000,50,0,1,NULL,0.0000,1,NULL,0),(21677,526,'Hakkuran Brother\'s Remains','The remain of the Hakkuran brothers, who died at the hands of Guristas Pirates while transporting a shipment through Otomainen.',80,1,0,1,NULL,0.0000,1,NULL,0),(21678,1207,'Talocan Debris Fragment','This Floating piece of debris looks like it might be of some value to the right person   ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21679,1207,'Talocan Debris Part','This Floating piece of debris looks like it might be of some value to the right person   ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21680,1207,'Talocan Debris Segment','This Floating piece of debris looks like it might be of some value to the right person   ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21681,1207,'Talocan Debris Heap','This Floating piece of debris looks like it might be of some value to the right person   ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21683,1207,'Basic Guristas Vault','A Guristas security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21684,1207,'Standard Guristas Vault','A Guristas security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21685,1207,'Fortified Guristas Vault','A Guristas security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21686,1207,'Secure Guristas Vault','A Guristas security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21688,1207,'Sleeper Debris Fragment','This Floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21689,1207,'Sleeper Debris Part','This Floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21690,1207,'Sleeper Debris Segment','This Floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21691,1207,'Sleeper Debris Heap','This Floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21693,1207,'Basic Angel Vault','An Angel  stasis security Vault . Nearly impossible to destroy but perhaps it is possible to bypass its security ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21694,1207,'Standard Angel Vault','An Angel  stasis security Vault . Nearly impossible to destroy but perhaps it is possible to bypass its security ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21695,1207,'Fortified Angel Vault','An Angel  stasis security Vault . Nearly impossible to destroy but perhaps it is possible to bypass its security ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21696,1207,'Secure Angel Vault','An Angel stasis security Vault . Nearly impossible to destroy but perhaps it is possible to bypass its security ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21698,306,'Angel Network Node','This Tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interestin information from its mainframe',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21699,306,'Angel Network Hub','This Tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interestin information from its mainframe',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21700,306,'Angel Network Nucleus','This Tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interestin information from its mainframe',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21701,306,'Angel Network Nexus','This Tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interestin information from its mainframe',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21703,306,'Guristas Network Node','This Tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interesting information from its mainframe',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21704,306,'Guristas Network Hub','This Tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interestin information from its mainframe',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21705,306,'Guristas Network Nucleus','This Tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interestin information from its mainframe',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21706,306,'Guristas Network Nexus','This Tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interestin information from its mainframe',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21708,1207,'Sleeper Data Log','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21709,1207,'Sleeper Data Registry','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21710,1207,'Sleeper Data Transcript','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21711,1207,'Sleeper Data Records','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21713,1207,'Talocan Data Log','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21714,1207,'Talocan Data Registry','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21715,1207,'Talocan Data Transcript','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21716,1207,'Talocan Data Records','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21718,1217,'Hacking','Proficiency at breaking into guarded computer systems. Required skill for the use of Data Analyzer modules.\r\r\n\r\r\nGives +10 Virus Coherence per level.',0,0.01,0,1,NULL,100000.0000,1,1110,0),(21719,528,'Sleeper Hyperbooster',' ',1,0.1,0,1,NULL,0.0000,1,1902,0),(21720,528,'Sleeper Thermal Regulator',' ',1,0.1,0,1,NULL,0.0000,1,1902,0),(21721,528,'Sleeper Heat Nullifying Coil',' ',1,0.1,0,1,NULL,0.0000,1,1902,0),(21722,528,'Sleeper Nanite Cluster',' ',1,0.1,0,1,NULL,0.0000,1,1902,0),(21723,528,'Sleeper Reintegration Control',' ',1,0.1,0,1,NULL,0.0000,1,1902,0),(21724,528,'Guristas Heavy Weapon Console',' ',1,0.1,0,1,NULL,0.0000,1,1900,0),(21725,528,'Guristas Medium Weapon Console',' ',1,0.1,0,1,NULL,0.0000,1,1900,0),(21726,528,'Guristas Light Weapon Console',' ',1,0.1,0,1,NULL,0.0000,1,1900,0),(21727,528,'Guristas Gravity Focuser',' ',1,0.1,0,1,NULL,0.0000,1,1900,0),(21728,528,'Guristas Graviton Hardening',' ',1,0.1,0,1,NULL,0.0000,1,1900,0),(21729,528,'Angel Advanced Trigger Mechanism',' ',1,0.1,0,1,NULL,0.0000,1,1898,0),(21730,528,'Angel Standard Trigger Mechanism',' ',1,0.1,0,1,NULL,0.0000,1,1898,0),(21731,528,'Angel Simple Trigger Mechanism',' ',1,0.1,0,1,NULL,0.0000,1,1898,0),(21732,528,'Angel Spatial Analyzer',' ',1,0.1,0,1,NULL,0.0000,1,1898,0),(21733,528,'Angel Dynamic Calibrator',' ',1,0.1,0,1,NULL,0.0000,1,1898,0),(21734,283,'Cattle','Cattle are domestic animals raised for home use or for profit, whether it be for their meat or dairy products.',900,1,0,1,NULL,0.0000,1,NULL,0),(21735,534,'Loki Machedo','A mercenary of Minmatar Sebiestor origin.  Loki fled the Republic after being sentenced to death by tribal elders for murder and theft.  Eventually settling in the Okkelen constellation, where he joined up with a gang of bandits referring to themselves as the Kazka. Threat level: Deadly.',19000000,980000,235,1,2,0.0000,0,NULL,0),(21736,526,'Loki\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the Kazka prison guard, Loki Machedo.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21739,526,'Shady Acres Deed','This is a deed for a small piece of area in the shady acres territory. The owner of this deed is permitted to construct astro farms in that area.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21740,85,'Caldari Navy Antimatter Charge L','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.1,0.025,0,100,NULL,11132.0000,1,991,0),(21742,526,'Black Mask','This mask was carried by a Guristas outlaw inhabiting the Okkelen constellation.',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(21743,283,'Nakyo Fukoren','Fiance of Chichiro Rati.',80,1,0,1,NULL,0.0000,1,NULL,0),(21744,383,'Siege Artillery Sentry','Siege Artillery Sentry',1000,1000,1000,1,8,0.0000,0,NULL,0),(21745,383,'Siege Autocannon Sentry','Siege Autocannon Sentry',1000,1000,1000,1,8,0.0000,0,NULL,0),(21746,383,'Siege Beam Laser Sentry','Siege Beam Laser Sentry',1000,1000,1000,1,4,0.0000,0,NULL,0),(21747,383,'Siege Pulse Laser Sentry','Siege Pulse Laser Sentry',1000,1000,1000,1,8,0.0000,0,NULL,0),(21748,383,'Siege Railgun Sentry','Siege Railgun Sentry',1000,1000,1000,1,8,0.0000,0,NULL,0),(21749,383,'Siege Blaster Sentry','Siege Blaster Sentry',1000,1000,1000,1,8,0.0000,0,NULL,0),(21754,523,'COSMOS Minmatar Commander','This is a hostile pirate vessel. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(21755,523,'COSMOS Minmatar Gist General','This is a hostile pirate vessel. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(21756,523,'COSMOS Minmatar Gist Seraphim','This is a hostile pirate vessel. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(21757,523,'COSMOS Minmatar Warlord','This is a hostile pirate vessel. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(21758,522,'COSMOS Minmatar Angel','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(21759,522,'COSMOS Minmatar Liquidator','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(21760,522,'COSMOS Minmatar Marauder','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,1400,1,2,0.0000,0,NULL,0),(21762,522,'COSMOS Minmatar Predator','This is a hostile pirate vessel. Threat level: Extreme',9900000,99000,120,1,2,0.0000,0,NULL,0),(21763,522,'COSMOS Minmatar Angel Centurion','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(21764,522,'COSMOS Minmatar Angel Legionnaire','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(21765,522,'COSMOS Minmatar Angel Scout','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(21766,522,'COSMOS Minmatar Depredator','This is a hostile pirate vessel. Threat level: Extreme',9900000,99000,1900,1,2,0.0000,0,NULL,0),(21767,520,'COSMOS Minmatar Hijacker','This is a hostile pirate vessel. Threat level: Very low',2112000,21120,100,1,2,0.0000,0,NULL,0),(21768,520,'COSMOS Minmatar Impaler','This is a hostile pirate vessel. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(21769,520,'COSMOS Minmatar Hunter','This is a hostile pirate vessel. Threat level: Very high',1910000,19100,80,1,2,0.0000,0,NULL,0),(21770,520,'COSMOS Minmatar Nomad','This is a hostile pirate vessel. Threat level: Significant',1750000,17500,180,1,2,0.0000,0,NULL,0),(21771,520,'COSMOS Minmatar Outlaw','This is a hostile pirate vessel. Threat level: Moderate',1740000,17400,220,1,2,0.0000,0,NULL,0),(21772,520,'COSMOS Minmatar Raider','This is a hostile pirate vessel. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(21773,520,'COSMOS Minmatar Rogue','This is a hostile pirate vessel. Threat level: Low',2250000,22500,75,1,2,0.0000,0,NULL,0),(21774,520,'COSMOS Minmatar Ruffian','This is a hostile pirate vessel. Threat level: Significant',1766000,17660,120,1,2,0.0000,0,NULL,0),(21775,520,'COSMOS Minmatar Thug','This is a hostile pirate vessel. Threat level: Moderate',2600500,26005,120,1,2,0.0000,0,NULL,0),(21776,520,'COSMOS Minmatar Non-Pirate Elite Frigate','An elite Jaguar-class assault frigate, designed by Thukker Mix',1125000,17400,120,1,2,0.0000,0,NULL,0),(21777,523,'COSMOS Minmatar Non-Pirate Battleship',' ',19000000,1080000,120,1,2,0.0000,0,NULL,0),(21778,522,'COSMOS Minmatar Non-Pirate Cruiser',' ',11500000,96000,300,1,2,0.0000,0,NULL,0),(21779,520,'COSMOS Minmatar Arch Ambusher','This is a hostile pirate vessel. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(21780,520,'COSMOS Minmatar Arch Hunter','This is a hostile pirate vessel. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(21781,520,'COSMOS Minmatar Arch Impaler','This is a hostile pirate vessel. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(21782,520,'COSMOS Minmatar Arch Raider','This is a hostile pirate vessel. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(21783,526,'Unassembled Hybrid Weapons','Hybrid weapon parts waiting to be assembled into fully functional equipment.',1,5,0,1,NULL,0.0000,1,NULL,0),(21784,526,'Hybrid Weapon Assembly Instructions','A set of manuals containing instructions on how to assemble hybrid weapons out of component parts.',1,0.5,0,1,NULL,0.0000,1,NULL,0),(21786,533,'Nugoeihuvi Operative','According to your information, this is an operative of the Nugoeihuvi corporation.  He is currently conducting what appears to be an illegal arms deal.',10100000,101000,235,1,1,0.0000,0,NULL,0),(21787,533,'Arms Dealer Incognito','An unidentified arms dealer, here to peddle his wares to the highest bidder.',10100000,101000,235,1,1,0.0000,0,NULL,0),(21788,534,'Bandit Arms Dealer','This is a hostile pirate vessel. Threat level: Deadly',22000000,1080000,235,1,1,0.0000,0,NULL,0),(21789,270,'Sleeper Technology','Basic understanding of interfacing with Sleeper technology.\r\r\n\r\r\nThe Sleepers were masters of virtual reality, neural interfacing and cryotechnology.\r\r\n\r\r\nAllows the rudimentary use of Sleeper components in the creation of advanced technology, even though the scientific theories behind them remain a mystery.',0,0.01,0,1,NULL,0.0000,1,375,0),(21790,270,'Caldari Encryption Methods','Understanding of the data encryption methods used by the Caldari State and its allies.',0,0.01,0,1,NULL,0.0000,1,375,0),(21791,270,'Minmatar Encryption Methods','Understanding of the data encryption methods used by the Minmatar Republic and its allies.',0,0.01,0,1,NULL,0.0000,1,375,0),(21792,534,'Bandit Jailor','This is a hostile pirate vessel. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(21793,526,'Pansya\'s Head','This is the head of Sanku Pansya, a ruthless gang leader.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21794,534,'Sanku Pansya','This is a hostile pirate vessel. Threat level: Deadly',19000000,22000000,235,1,1,0.0000,0,NULL,0),(21795,534,'Pansya\'s Bodyguard','This is a hostile pirate vessel. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(21796,534,'Black Mask Bandit','This is a hostile pirate vessel. Threat level: Deadly',19000000,22000000,235,1,1,0.0000,0,NULL,0),(21797,226,'Arena','Executions Mon-Sat at High Noon. Closed Sundays. Hang\'em High T-Shirts for sale in the back. Ask for Wendy.',0,0,0,1,4,0.0000,0,NULL,0),(21798,226,'Hillside Gambling Hall','Dice, cards, races, Splinterz, roulette for the ladies. Formal attire except for strip-kani.',0,0,0,1,1,0.0000,0,NULL,0),(21799,226,'Pleasure Hub','A pleasure house of questionable honor. Whether it\'s outrageous, dirty, lethal or just merely illegal, you\'re bound to find it here.',0,0,0,1,8,0.0000,0,NULL,0),(21800,526,'EMP Charge Components','A standard-looking shipment of electronic entertainment equipment, inside which are hidden components of a high-powered electromagnetic charge.',1000,1,0,1,NULL,0.0000,1,NULL,0),(21801,526,'Firewater','High quality moonshine. Inhaling causes uninhibited behavior, loss of muscle motor skills and similar hilarity.',2500,0.2,0,1,NULL,0.0000,1,NULL,0),(21802,1209,'Capital Shield Operation','Operation of capital shield boosters and other shield modules. 2% reduction in capacitor need for capital shield boosters per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,25000000.0000,1,1747,0),(21803,1210,'Capital Repair Systems','Operation of capital armor/hull repair modules. 5% reduction in capital repair systems duration per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,17500000.0000,1,1745,0),(21804,526,'Rotgut','A potent mixture used to increase the intoxication effects of alcohol. ',5,0.2,0,1,NULL,0.0000,1,NULL,0),(21807,226,'Fortified Caldari Junction','A junction connecting two things, like A to B.',0,0,0,1,4,0.0000,0,NULL,0),(21808,521,'Punk ID Slice','ID slice is an identification tag injected into the body with nano-bots. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21809,521,'Hacker ID Slice','ID slice is an identification tag injected into the body with nano-bots. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21810,521,'Spy ID Slice','ID slice is an identification tag injected into the body with nano-bots. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21811,521,'Sniper ID Slice','ID slice is an identification tag injected into the body with nano-bots. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21812,521,'Ninja ID Slice','ID slice is an identification tag injected into the body with nano-bots. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21813,521,'Mikado ID Slice','ID slice is an identification tag injected into the body with nano-bots. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21814,802,'Elite Drone Parasite','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(21815,886,'Elite Drone AI','A tiny chip with a modified silicon-extract wafer forming the base for an integrated circuit. The chip stores the code for the elite drone\'s artificial intelligence. ',0.01,0.01,0,1,4,0.0000,1,1906,0),(21816,43,'Tairei\'s Modified Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,23750.0000,1,665,0),(21817,43,'Raysere\'s Modified Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,23750.0000,1,665,0),(21818,43,'Ahremen\'s Modified Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,23750.0000,1,665,0),(21819,43,'Draclira\'s Modified Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,23750.0000,1,665,0),(21820,226,'Fortified Gallente Outpost','Equally equipped for scientific observation and entertainment of all sorts, these multi-purpose structures, while not quite big enough to be classified as stations, nonetheless see quite a bit of use by both tourists and professionals. ',0,0,0,1,8,0.0000,0,NULL,0),(21821,226,'Habitation Brothel','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities. ',0,0,0,1,4,0.0000,0,NULL,0),(21822,226,'Habitation Prison','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities. ',0,0,0,1,4,0.0000,0,NULL,0),(21823,226,'Residential Habitation Module','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',0,0,0,1,NULL,0.0000,0,NULL,0),(21824,226,'Habitation Pleasure Hub','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities. ',0,0,0,1,4,0.0000,0,NULL,0),(21825,226,'Habitation Casino','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities. ',0,0,0,1,4,0.0000,0,NULL,0),(21826,226,'Habitation Police Dpt','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities. ',0,0,0,1,4,0.0000,0,NULL,0),(21827,226,'Habitation Roadhouse','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities. ',0,0,0,1,4,0.0000,0,NULL,0),(21828,226,'Habitation Drughouse','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities. ',0,0,0,1,4,0.0000,0,NULL,0),(21829,226,'Indestructible Landing Pad','This outpost has a docking pad designed to receive and process large shipments of cargo. ',0,0,0,1,NULL,0.0000,0,NULL,0),(21830,226,'Fortified Minmatar Wall','A wall. Go figure.',0,0,0,1,4,0.0000,0,NULL,0),(21831,226,'Fortified Minmatar Fence','A fence. Sheep.',0,0,0,1,4,0.0000,0,NULL,0),(21832,226,'Fortified Minmatar Junction','A junction. Blind date.',0,0,0,1,4,0.0000,0,NULL,0),(21833,226,'Fortified Minmatar Lookout','A lookout. Look out.',0,0,0,1,4,0.0000,0,NULL,0),(21834,226,'Fortified Minmatar Barrier','A barrier. Tune in, turn up, keep out.',0,0,0,1,4,0.0000,0,NULL,0),(21835,226,'Fortified Minmatar Bunker','A bunker. Beware.',0,0,0,1,4,0.0000,0,NULL,0),(21836,226,'Fortified Minmatar Barricade','A barricade. No, it\'s not a snake.',0,0,0,1,4,0.0000,0,NULL,0),(21837,226,'Fortified Minmatar Battery','A battery. Juicy.',0,0,0,1,4,0.0000,0,NULL,0),(21838,226,'Fortified Minmatar Elevator','An elevator. Going down?',0,0,0,1,4,0.0000,0,NULL,0),(21839,474,'Training Complex Passkey','This security passkey is made by CONCORD and placed aboard one of the automated pirate vessels in the training complex CONCORD designed. It will open up an Acceleration Gate which will remain open for a short period of time and render the passkey unusable afterwards.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21840,677,'Gallente Miner','The Atron is a hard nugget with an advanced power conduit system, but little space for cargo. Although the Atron is a good harvester when it comes to mining, its main ability is as a combat vessel.  It is sometimes used by the Gallente Navy and is generally considered an expendable low-cost craft.  Threat level: Moderate',1200000,22500,125,1,8,0.0000,0,NULL,0),(21841,54,'Gallente Mining Laser','Basic mining laser. Extracts common ore quickly, but has difficulty with the more rare types.',0,5,0,1,NULL,9272.0000,1,1039,0),(21843,517,'Cosmos Iteron Mark III','An Iteron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(21844,517,'Barou Lardoss','An Iteron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(21845,185,'Automated Coreli Training Vessel','This is a captured frigate from the Core deadspace division of the Serpentis Corporation. It has been modified by CONCORD to serve as target practice for pilots fresh out of the Flight Academy.',2450000,24500,60,1,8,0.0000,0,NULL,0),(21846,185,'Automated Gisti Training Vessel','This is a captured frigate from the Gisti deadspace division of the Angel Cartel. It has been modified by CONCORD to serve as target practice for pilots fresh out of the Flight Academy.',2450000,24500,60,1,2,0.0000,0,NULL,0),(21847,185,'Automated Corpii Training Vessel','This is a captured frigate from the Corpus deadspace division of the Blood Raider pirates. It has been modified by CONCORD to serve as target practice for pilots fresh out of the Flight Academy.',2450000,24500,60,1,4,0.0000,0,NULL,0),(21848,185,'Automated Pithi Training Vessel','This is a captured frigate from the Pith deadspace division of the Guristas Pirates. It has been modified by CONCORD to serve as target practice for pilots fresh out of the Flight Academy.',2450000,24500,60,1,1,0.0000,0,NULL,0),(21849,185,'Automated Centii Training Vessel','This is a captured frigate from the Centus deadspace pirates of Sansha\'s Nation. It has been modified by CONCORD to serve as target practice for pilots fresh out of the Flight Academy.',2450000,24500,60,1,4,0.0000,0,NULL,0),(21850,283,'Infected Refugees','When wars and epidemics break out, people flee from their homes, forming massive temporary migrations. These innocent civilans are the victims of chemical warfare.',400,1,0,1,NULL,0.0000,1,NULL,0),(21851,526,'Formula for Septicemic Agent','This is a chemistry formula for creating an extremely potent viral agent, using materials readily available on the market.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21852,526,'Sample of Septicemic Agent','The causative agent of an infectious disease. The septicemic bacterial infection is extremely dangerous. Lethality: 99.9%. Known treatments: None.',100,0.5,0,1,NULL,0.0000,1,NULL,0),(21853,62,'Civilian Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,136.0000,1,1049,0),(21854,142,'Civilian Armor Repairer Blueprint',' ',0,0.01,0,1,4,0.0000,1,1536,0),(21855,765,'Civilian Expanded Cargohold','Increases cargo hold capacity.',50,5,0,1,NULL,244.0000,1,1197,0),(21856,158,'Civilian Expanded Cargohold Blueprint',' ',0,0.01,0,1,4,0.0000,1,335,0),(21857,46,'1MN Civilian Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,5,0,1,4,134.0000,1,542,0),(21858,126,'1MN Civilian Afterburner Blueprint',' ',0,0.01,0,1,4,0.0000,1,1525,0),(21859,533,'Cybertron','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(21860,816,'Gregory Lerma','This is a fighter-ship belonging to the CONCORD Army.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',19000000,1080000,235,1,NULL,0.0000,0,NULL,0),(21861,494,'General Lafema','This Bestower-class industrial is currently undergoing maintenance.  Although an excellent military tactician, Lafema is not known for his bravery in combat, rather opting to fly in a heavily armored industrial behind the scene while his men do the fighting.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(21862,409,'Karo Zulak\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,1,0.0000,1,NULL,0),(21867,772,'Nova Heavy Assault Missile','A nuclear warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,2166.0000,1,971,0),(21868,166,'Nova Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,600000.0000,1,975,0),(21877,526,'Okham\'s Head','This is the head of Jihar Okham, an Amarrian peddler of information. It\'s so full of implants that it\'s liable to set off every metal detector in a 5 mile radius.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21878,526,'Cracked Keycard','This is an ancient keycard used to access the old nefantar base in this complex. It needs to be repaired to be usable.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21879,474,'Repaired Keycard','This is a keycard used to enter the inner most room in a complex in the Traun system. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21880,526,'Transputer Orb','Strange artifact of unknown origin. It emanates unorthodox energy signals, but its purpose is not readily discernable.',2500,2,0,1,NULL,0.0000,1,NULL,0),(21881,533,'Jihar Okham','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(21882,533,'Okham\'s Cyber Thrall','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(21883,226,'Elemental Base','The base of some strange artifact from long-forgotten times.',0,0,0,1,NULL,0.0000,0,NULL,0),(21884,494,'Old Nefantar Bunker','A small bunker, dating from the time the system was still in the hands of the Nefantar tribe. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(21885,526,'Caldari Navy Convoy Disposition File','This file contains detailed information on the size, strength and numbers of the vessels in Caldari Navy Convoy AR06248-E.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21886,534,'The Black Viper','This is a hostile pirate vessel. It has thief and scoundrel written all over it. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(21887,533,'Nefantar Pilgrim','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,4,0.0000,0,NULL,0),(21888,744,'Siege Warfare Mindlink','This advanced interface link drastically improves a commander\'s siege warfare ability by directly linking to the active shield systems of all ships in the fleet. \r\r\n\r\r\n25% increase to the command bonus of Siege Warfare Link modules.\r\r\n\r\r\nReplaces Siege Warfare skill bonus with fixed 15% shield HP bonus.',0,1,0,1,NULL,0.0000,1,1505,0),(21889,744,'Information Warfare Mindlink','This advanced interface link drastically improves a commander\'s information warfare ability by directly linking to the sensor arrays of all ships in the fleet.\r\r\n\r\r\n25% increase to the command bonus of Information Warfare Link modules.\r\r\n\r\r\nReplaces Information Warfare skill bonus with fixed 15% targeting range bonus.',0,1,0,1,NULL,0.0000,1,1505,0),(21890,744,'Skirmish Warfare Mindlink','This advanced interface link drastically improves a commander\'s skirmish warfare ability by directly linking to the navigation systems of all ships in the fleet. \r\r\n\r\r\n25% increase to the command bonus of Skirmish Warfare Link modules.\r\r\n\r\r\nReplaces Skirmish Warfare skill bonus with fixed 15% agility bonus.',0,1,0,1,NULL,0.0000,1,1505,0),(21891,306,'Kutill\'s Storage Bin','The wrecked container drifts silently amongst the stars.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(21892,526,'Hacker\'s Keycard','Key to gain entry to the Maru headquarters in Ani.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21893,526,'Kutill\'s Data Chip','This data chip contains the code for a hacker-program developed by Dagras Kutill to infiltrate the Brutor Y.976 computer mainframe in Barkrik.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21894,83,'Republic Fleet EMP L','Large Projectile Ammo. A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,11132.0000,1,987,0),(21896,83,'Republic Fleet EMP M','Medium Projectile Ammo. A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,4458.0000,1,988,0),(21898,83,'Republic Fleet EMP S','Small projectile Ammo. A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,1056.0000,1,989,0),(21900,83,'Republic Fleet EMP XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. A new technology, this highly advanced ammunition emits a focused EM pulse. Very potent against shields.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,111132.0000,1,1006,0),(21902,83,'Republic Fleet Fusion L','Large Projectile Ammo. The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,7776.0000,1,987,0),(21904,83,'Republic Fleet Fusion M','Medium Projectile Ammo. The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,3054.0000,1,988,0),(21906,83,'Republic Fleet Fusion S','Small Projectile Ammo. The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,732.0000,1,989,0),(21908,83,'Republic Fleet Fusion XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. The destructive power of a fusion warhead is superior to most other projectile warheads available, although it has problems penetrating heavy shield systems.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,77776.0000,1,1006,0),(21910,83,'Republic Fleet Nuclear L','Large Projectile Ammo. Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.025,0,100,NULL,3184.0000,1,987,0),(21912,83,'Republic Fleet Nuclear M','Medium Projectile Ammo. Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.05,0.0125,0,100,NULL,1328.0000,1,988,0),(21914,83,'Republic Fleet Nuclear S','Small Projectile Ammo. Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,332.0000,1,989,0),(21916,83,'Republic Fleet Nuclear XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts.  Nuclear weapons are considered by most races to be crude and primitive. However, the Minmatar still favor them over more sophisticated weapons due to the abundance of materials for plutonium production in Minmatar space.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,33184.0000,1,1006,0),(21918,83,'Republic Fleet Phased Plasma L','Large Projectile Ammo. This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.025,0,100,NULL,8850.0000,1,987,0),(21920,83,'Republic Fleet Phased Plasma XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.125,0,100,NULL,88850.0000,1,1006,0),(21922,83,'Republic Fleet Phased Plasma M','Medium Projectile Ammo. This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',1,0.0125,0,100,NULL,3544.0000,1,988,0),(21924,83,'Republic Fleet Phased Plasma S','Small Projectile Ammo. This ammo uses a similar plasma containment core as hybrid charges except that it is mounted in a standard cannon shell.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,848.0000,1,989,0),(21926,83,'Republic Fleet Proton L','Large Projectile Ammo. Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.025,0,100,NULL,4446.0000,1,987,0),(21928,83,'Republic Fleet Proton M','Medium Projectile Ammo. Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.0125,0,100,NULL,1830.0000,1,988,0),(21930,526,'Sealed Case of GI Paradise Missiles','A crate of GI Paradise Cruise missiles courtesy of the Minmatar Republic.',1,250,0,1,NULL,0.0000,1,NULL,0),(21931,83,'Republic Fleet Proton S','Small Projectile Ammo. Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,428.0000,1,989,0),(21933,83,'Republic Fleet Proton XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Emits a focused, high intensity proton burst upon impact. Fairly effective vs. both shields and armor.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,44446.0000,1,1006,0),(21935,83,'Republic Fleet Titanium Sabot L','Large Projectile Ammo. This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.025,0,100,NULL,6656.0000,1,987,0),(21937,83,'Republic Fleet Titanium Sabot M','Medium Projectile Ammo. This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.0125,0,100,NULL,2608.0000,1,988,0),(21939,83,'Republic Fleet Titanium Sabot S','Small Projectile Ammo. This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation fletchets that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',0.01,0.0025,0,100,NULL,660.0000,1,989,0),(21941,83,'Republic Fleet Titanium Sabot XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This is among the most feared ammunition around. It has excellent penetration. Once the ship\'s outer layer is penetrated, the core explodes, spraying the interior with a cloud of fragmentation flechettes that cause considerable damage to the vulnerable interior structure.\r\r\n\r\r\n20% increased tracking speed.',1,0.125,0,100,NULL,66656.0000,1,1006,0),(21943,535,'Amarr Factory Outpost Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,1,1912,0),(21944,535,'Caldari Research Outpost Platform Blueprint',' ',0,0.01,0,1,NULL,1750000000.0000,1,1912,0),(21945,535,'Gallente Administrative Outpost Platform Blueprint',' ',0,0.01,0,1,NULL,2000000000.0000,1,1912,0),(21946,535,'Minmatar Service Outpost Platform Blueprint',' ',0,0.01,0,1,NULL,1250000000.0000,1,1912,0),(21947,536,'Station Construction Parts','Assorted parts of metal, textiles, composite fabrics and miscellaneous machinery - the basic building blocks for the assembly and operation of a space outpost.',10000,100000,0,1,NULL,22500000.0000,1,1865,0),(21948,447,'Station Construction Parts Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21949,536,'Station Hangar Array','Components for the construction of individualized ship and module hangars in space outposts.',10000,100000,0,1,NULL,39375000.0000,1,1865,0),(21950,447,'Station Hangar Array Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21951,536,'Station Storage Bay','One of the myriad construction components required for the building of space outposts.',10000,100000,0,1,NULL,22500000.0000,1,1865,0),(21952,447,'Station Storage Bay Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21953,536,'Station Laboratory','Construction materials and research tools for space outpost laboratories.',10000,100000,0,1,NULL,90000000.0000,1,1865,0),(21954,447,'Station Laboratory Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21955,536,'Station Factory','Materials required for the construction of factory facilities in a space outpost.',10000,100000,0,1,NULL,84375000.0000,1,1865,0),(21956,447,'Station Factory Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21957,536,'Station Repair Facility','Lathes, grinders, riveting machines, uncoilers, and various other pieces of machinery required for the operation of an outpost repair facility.',10000,100000,0,1,NULL,95625000.0000,1,1865,0),(21958,447,'Station Repair Facility Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21959,536,'Station Reprocessing Plant','Parts required for the construction of a space outpost materials refinery.',10000,100000,0,1,NULL,95625000.0000,1,1865,0),(21960,447,'Station Reprocessing Plant Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21961,536,'Station Docking Bay','Mechanical components required for the construction of an outpost docking bay.',10000,100000,0,1,NULL,84375000.0000,1,1865,0),(21962,447,'Station Docking Bay Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21963,536,'Station Market Network','Market access electronics and secure storage facilities of market goods for space outposts.',10000,100000,0,1,NULL,142500000.0000,1,1865,0),(21964,447,'Station Market Network Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21965,536,'Station Medical Center','Medicine, anaesthetics, surgical supplies and complete cloning facilities for space outposts.',10000,100000,0,1,NULL,56250000.0000,1,1865,0),(21966,447,'Station Medical Center Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21967,536,'Station Office Center','Materials for the construction of dozens of offices, as well as computer systems and supplies needed for their day-to-day running.',10000,100000,0,1,NULL,88750000.0000,1,1865,0),(21968,447,'Station Office Center Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21969,536,'Station Mission Network','A computerized interface allowing people to barter goods and services with the outpost acting as centralized broker and data bank.',10000,100000,0,1,NULL,72500000.0000,1,1865,0),(21970,447,'Station Mission Network Blueprint',' ',0,0.01,0,1,NULL,200000000.0000,1,1913,0),(21971,526,'Broken ComLink Scanner','A hi-tech surveillance equipment capable of breaking into secure communication lines and listen in on the chatter. It\'s broken beyond repair.',2500,2,0,1,NULL,0.0000,1,NULL,0),(21972,533,'Machul Mu\'Shabba','No information available.',11500000,96000,300,1,2,0.0000,0,NULL,0),(21973,526,'Machul\'s Head','This is the head of Machul Mu\'shabba, a mercenary in employment of the Brutor Tribe.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(21974,562,'Outlaw Arrogator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',1500100,15001,45,1,1,0.0000,0,NULL,0),(21975,562,'Outlaw Imputor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',1612000,16120,80,1,1,0.0000,0,NULL,0),(21976,562,'Outlaw Infiltrator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2025000,20250,235,1,1,0.0000,0,NULL,0),(21977,562,'Outlaw Invader','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2025000,20250,65,1,1,0.0000,0,NULL,0),(21978,562,'Outlaw Despoiler','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2040000,20400,100,1,1,0.0000,0,NULL,0),(21979,562,'Outlaw Saboteur','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2040000,20400,235,1,1,0.0000,0,NULL,0),(21980,562,'Outlaw Plunderer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(21981,562,'Outlaw Wrecker','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(21982,562,'Outlaw Destructor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(21983,562,'Outlaw Demolisher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(21984,561,'Gunslinger Silencer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',10700000,107000,850,1,1,0.0000,0,NULL,0),(21985,561,'Gunslinger Ascriber','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',9600000,96000,450,1,1,0.0000,0,NULL,0),(21986,561,'Gunslinger Killer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',9200000,92000,235,1,1,0.0000,0,NULL,0),(21987,561,'Gunslinger Murderer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(21988,800,'Ace Arrogator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1500100,15001,45,1,1,0.0000,0,NULL,0),(21989,800,'Ace Imputor','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1612000,16120,80,1,1,0.0000,0,NULL,0),(21990,800,'Ace Infiltrator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',2025000,20250,235,1,1,0.0000,0,NULL,0),(21991,800,'Ace Invader','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',2025000,20250,65,1,1,0.0000,0,NULL,0),(21992,800,'Ace Despoiler','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',2040000,20400,100,1,1,0.0000,0,NULL,0),(21993,800,'Ace Saboteur','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',2040000,20400,235,1,1,0.0000,0,NULL,0),(21994,800,'Ace Plunderer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1970000,19700,125,1,1,0.0000,0,NULL,0),(21995,800,'Ace Wrecker','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1650000,16500,130,1,1,0.0000,0,NULL,0),(21996,800,'Ace Destructor','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1970000,19700,235,1,1,0.0000,0,NULL,0),(21997,800,'Ace Demolisher','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1650000,16500,235,1,1,0.0000,0,NULL,0),(21998,798,'Deuce Silencer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10700000,107000,850,1,1,0.0000,0,NULL,0),(21999,798,'Deuce Ascriber','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',9600000,96000,450,1,1,0.0000,0,NULL,0),(22000,798,'Deuce Killer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',9200000,92000,235,1,1,0.0000,0,NULL,0),(22001,563,'Bandit Gatherer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(22002,563,'Bandit Ferrier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1970000,19700,235,1,1,0.0000,0,NULL,0),(22003,563,'Bandit Loader','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(22004,563,'Bandit Courier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(22005,550,'Cyber Hijacker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2112000,21120,100,1,2,0.0000,0,NULL,0),(22006,550,'Cyber Rogue','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Low',2250000,22500,75,1,2,0.0000,0,NULL,0),(22007,550,'Cyber Outlaw','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',1740000,17400,220,1,2,0.0000,0,NULL,0),(22008,550,'Cyber Thug','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2600500,26005,120,1,2,0.0000,0,NULL,0),(22009,550,'Cyber Ruffian','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',1766000,17660,120,1,2,0.0000,0,NULL,0),(22010,550,'Cyber Nomad','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',1750000,17500,180,1,2,0.0000,0,NULL,0),(22011,550,'Cyber Ambusher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1910000,19100,120,1,2,0.0000,0,NULL,0),(22012,550,'Cyber Raider','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(22013,550,'Cyber Hunter','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1910000,19100,80,1,2,0.0000,0,NULL,0),(22014,550,'Cyber Impaler','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22015,789,'Psycho Hijacker','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',2112000,21120,100,1,2,0.0000,0,NULL,0),(22016,789,'Psycho Rogue','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',2250000,22500,75,1,2,0.0000,0,NULL,0),(22017,789,'Psycho Outlaw','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1740000,17400,220,1,2,0.0000,0,NULL,0),(22018,789,'Psycho Thug','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',2600500,26005,120,1,2,0.0000,0,NULL,0),(22019,789,'Psycho Ruffian','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1766000,17660,120,1,2,0.0000,0,NULL,0),(22020,789,'Psycho Nomad','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1750000,17500,180,1,2,0.0000,0,NULL,0),(22021,789,'Psycho Ambusher','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1910000,19100,120,1,2,0.0000,0,NULL,0),(22022,789,'Psycho Raider','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1645000,16450,110,1,2,0.0000,0,NULL,0),(22023,789,'Psycho Hunter','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1910000,19100,80,1,2,0.0000,0,NULL,0),(22024,789,'Psycho Impaler','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1645000,16450,120,1,2,0.0000,0,NULL,0),(22025,554,'Degenerate Harvester','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1910000,19100,120,1,2,0.0000,0,NULL,0),(22026,554,'Degenerate Gatherer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(22027,554,'Degenerate Ferrier','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1910000,19100,80,1,2,0.0000,0,NULL,0),(22028,554,'Degenerate Loader','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22029,563,'Bandit Harvester','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1970000,19700,125,1,1,0.0000,0,NULL,0),(22030,526,'Destroyed ComLink Scanner','A small fragment of a ComLink Scanner. It is unusable and too badly damaged to be really discernable.',2500,2,0,1,NULL,0.0000,1,NULL,0),(22031,494,'ComLink Scanner','This piece of equipment emanates waves from its built-in broadcasting beacon. It is fitted with a small shield module and appears to be coated with a thin layer of armored plates. This modified version sends out bursts of high-frequency waves.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22032,306,'Podded Pilot','The remains of a pod. The remains of the dead pilot are still inside.',10000,1200,1400,1,NULL,0.0000,0,NULL,0),(22033,526,'Republic Pilot','The remains of a Republic Fleet pilot.',80,1,0,1,NULL,0.0000,1,NULL,0),(22035,526,'Body Bag','A standard issue body bag. It is occupied.',80,1,0,1,NULL,0.0000,1,NULL,0),(22036,526,'Republic Fleet Deserter','The remains of a Republic Fleet pilot that deserted.',80,1,0,1,NULL,0.0000,1,NULL,0),(22037,526,'Republic Repair Kit','Hi tech electronic gadgets and tools. Those with enough knowledge can fix just about anything with one of these.',1000,1,0,1,NULL,0.0000,1,NULL,0),(22038,526,'Norak Pakkul\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the rebel rouser Norak Pakkul.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22039,494,'Hiding Hole','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22040,534,'Republic Deserter','This is a hostile pirate vessel. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22041,534,'Norak Pakkul','This is a hostile pirate vessel. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22042,533,'Pakkul\'s Thugs','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22043,255,'Tactical Weapon Reconfiguration','Skill at the operation of siege modules. 25-unit reduction in strontium clathrate consumption amount for module activation per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,25000000.0000,1,364,0),(22044,526,'Vat of Aqua Regia Acid','A fuming yellowish liquid made by combining hydrochloric acid and nitric acid. Extremely corrosive. Often used as an ingredient in chemical weapons. ',100,500,0,1,NULL,0.0000,1,NULL,0),(22045,526,'Remains of Thukker Pest','Smoldering remains of a Thukker pirate.',80,1,0,1,NULL,0.0000,1,NULL,0),(22046,526,'DNA Samples of Republic Commandos','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis is a batch of DNAs taken from the remains of several Republic Special Forces troopers.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22047,494,'Special Forces Command Post','Outfitted with makeshift sensor arrays and second-hand tactical data analysis equipment, these outposts will, to anyone not in the know, look like useless scrapyards.  Which is exactly what the Matari would have you think.\r\r\n\r\r\nThis particular one is being used by several Republic commandos trying to lay low.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(22048,534,'Thukker Nomad Chief','This is a hostile pirate vessel. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22049,526,'REF Insignia','This insignia marks the bearer as a member of the Republic Expeditionary Force in the Ani constellation.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22052,533,'REF Pilot','This pilot is a member of the Republic Expeditionary Force.',11500000,96000,300,1,2,0.0000,0,NULL,0),(22053,185,'Automated Centii Keyholder','This is a captured frigate from the Centus deadspace pirates of Sansha\'s Nation. It has been modified by CONCORD to serve as target practice for pilots fresh out of the Flight Academy. Judging by its name, it should carry some kind of key for the gate.',2450000,24500,60,1,4,0.0000,0,NULL,0),(22054,526,'Thukker Loot','Mangled loot scavenged from old Nefantar bases.',10,10,0,1,NULL,58624.0000,1,NULL,0),(22055,526,'Motherload Bomb','Huge, homemade bomb. Looks lethal.',1000,380,0,1,NULL,0.0000,1,NULL,0),(22056,526,'Rebel Biomass','A mass of congealed blood and ripped intestines that look very much like it once belonged to a human.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22057,533,'Roaming Rebel','Rebel on a cruiser. Might have cause too, hard to tell.',11500000,96000,300,1,2,0.0000,0,NULL,0),(22058,533,'Thukker Scavenger','Thukker nomad out scavenging. Looks very efficient.',11500000,96000,300,1,2,0.0000,0,NULL,0),(22059,494,'Small Rebel Base','A small bunker, there for accommodation and increased mobility of troops and other personnel. This one holds several Minmatar freedom fighters.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22060,526,'Frozen Livers','These cryogenic storage containers are used to transfer body-parts without risk of decay.',100,10,0,1,NULL,0.0000,1,NULL,0),(22061,306,'Ship Wreckage','The mangled wreck floats motionless in space, surrounded with a field of scorched debris.',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(22062,526,'Mangled Corpses','These mangled corpses belong to a group of Gallente tourists who seem to have been killed by an explosion aboard their craft.',80,1,0,1,NULL,0.0000,1,NULL,0),(22063,526,'Empty Data Chip','An empty data chip, marked as being owned by Dagras Kutill.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22064,226,'Indestructible Radio Telescope','This huge radio telescope contains fragile but advanced sensory equipment. A structure such as this has enormous capabilities in crunching survey data from nearby systems and constellations.',0,100000000,0,1,NULL,0.0000,0,NULL,0),(22067,283,'Ambassador Hugo Farin','An official ambassador of the Minmatar Republic.',130,3,0,1,NULL,0.0000,1,NULL,0),(22068,306,'Amarr Workers\' Quarters','This is where the workers on the plantation which are of Amarrian descent reside while off-duty.  This is also where guests stay, regardless of race.',100000,100000000,8850,1,NULL,0.0000,0,NULL,0),(22069,283,'Inspector Layna Whizon','An official ambassador of the Minmatar Republic.',70,2,0,1,NULL,0.0000,1,NULL,0),(22072,306,'Ship Wreckage2','The mangled wreck floats motionless in space, surrounded with a field of scorched debris.',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(22073,526,'Bono Zakan Corpse','The corpse of a Sebiestor agent, working for the Minmatar Republic.',80,1,0,1,NULL,0.0000,1,NULL,0),(22074,526,'Gist Database Codes','These complicated data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.',1,1,0,1,NULL,0.0000,1,NULL,0),(22075,534,'Arrak Nutan','The Gist Overseer of their stronghold within Hjoramold.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22076,533,'Huriki Vunau','An inauspicious cruiser pilot.',10100000,101000,235,1,1,0.0000,0,NULL,0),(22077,526,'Encoded Gurista Intelligence Dossier','Encoded information for Gurista strike forces.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22078,526,'Modified Laser Rifles','Laser rifles, used both for warfare and personal security.',2500,2,0,1,NULL,0.0000,1,NULL,0),(22079,534,'Kael Nutan','This is a hostile pirate vessel. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22080,526,'TX-890 Polytextile Fabric','This extremely tough and durable synthetic fabric is specially manufactured by Nugoeihuvi for use in some of their more extreme entertainment material.',200,1,0,1,NULL,0.0000,1,NULL,0),(22081,517,'Frain\'s Rupture','A Rupture piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22082,533,'Jerpam Hollek','A double agent who needs to be neutralized. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(22083,526,'Jerpam Hollek\'s Head','This is the head of the villainous double agent, Jerpam Hollek.  It doesn\'t look like it\'s going to be talking any time soon.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22084,306,'Ship Carcass','The mangled wreck floats motionless in space, surrounded with a field of scorched debris.',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(22085,283,'Injured Slaves','Slavery has always been a questionable industry, favored by the Amarr Empire and detested by the Gallente Federation.',200,3,0,1,NULL,0.0000,1,NULL,0),(22086,816,'Freedom Command Ship','The Tempest battleship can become a real behemoth when fully equipped.\r\r\nThreat level: Deadly',19000000,850000,600,1,2,0.0000,0,NULL,0),(22087,526,'Ancient Vherokior Medallion','This medallion was once worn by the leaders of the Vherokior tribe, as a symbol of their superiority over other members of the community.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(22088,533,'Roark','An ex-miner and inveterate gambler who has no idea how to treat a lady.  Needs to be taught a lesson.',9200000,92000,235,1,1,0.0000,0,NULL,0),(22089,283,'Lucia Deep','A dazzling beauty with a mischievous gleam in her eye.',60,0.1,0,1,NULL,0.0000,1,NULL,0),(22091,533,'Sleeban Iratur','The owner and proprietor of the \"Red Roid\" establishment, this not-so-gentleman is a prime example of why human beings should preferably not mate with other species.',9600000,96000,450,1,1,0.0000,0,NULL,0),(22092,527,'Honim Iratur','A sniveling toad with little to offer humanity.',1650000,16500,130,1,1,0.0000,0,NULL,0),(22093,527,'Umeld Iratur','A worthless toad with little to offer humanity.',1650000,16500,130,1,1,0.0000,0,NULL,0),(22094,533,'Garp Soolim','This man, sir, is a liar and a cheat.',9200000,92000,235,1,1,0.0000,0,NULL,0),(22095,521,'Garp Soolim\'s ID Tag','This is the ID tag of one Garp Soolim.',0.1,0.1,0,1,8,0.0000,1,NULL,0),(22096,526,'Hraldar\'s Sculpture','Bronze Sculpture of the long deceased Minmatar general, Hraldar.',100,5,0,1,NULL,2000.0000,1,NULL,0),(22097,534,'Bazeri Palen','Bazeri is one of the leaders of the Maru Rebels.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22098,494,'Bastion Museum','The Bastion Museum holds various old relics gathered from the days of Nefantar rule in this sector.  ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22099,526,'Telligman\'s Stone',' ',10000,180,0,1,NULL,0.0000,1,NULL,0),(22100,526,'Namian\'s Artifacts','These crates contain artifacts of the Ni-Kunni treasure hunter, Sydri Namian.',100,10,0,1,NULL,0.0000,1,NULL,0),(22101,526,'ST 58 Memory Chip','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22102,526,'ST 59 Memory Chip','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22103,526,'ST 60 Memory Chip','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22104,533,'ST 60','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22105,533,'ST 59','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22106,527,'ST 58','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22107,300,'Mid-grade Crystal Alpha','This ocular filter has been modified by Guristas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,618,0),(22108,300,'Mid-grade Crystal Beta','This memory augmentation has been modified by Guristas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,619,0),(22109,300,'Mid-grade Crystal Delta','This cybernetic subprocessor has been modified by Guristas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,621,0),(22110,300,'Mid-grade Crystal Epsilon','This social adaptation chip has been modified by Guristas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,622,0),(22111,300,'Mid-grade Crystal Gamma','This neural boost has been modified by Guristas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,620,0),(22112,300,'Mid-grade Crystal Omega','This implant does nothing in and of itself, but when used in conjunction with other Crystal implants it will boost their effect. \r\r\n\r\r\n25% bonus to the strength of all Crystal implant secondary effects.\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,1506,0),(22113,300,'Mid-grade Halo Alpha','This ocular filter has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 Bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(22114,300,'Mid-grade Halo Beta','This memory augmentation has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 Bonus to Memory\r\r\n\r\r\nSecondary Effect: 1.25% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(22115,300,'Mid-grade Halo Delta','This cybernetic subprocessor has been modified by Angel scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 Bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 1.5% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(22116,300,'Mid-grade Halo Epsilon','This social adaptation chip has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 Bonus to Charisma\r\r\n\r\r\nSecondary Effect: 2% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(22117,300,'Mid-grade Halo Gamma','This neural boost has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 Bonus to Willpower\r\r\n\r\r\nSecondary Effect: 1.75% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(22118,300,'Mid-grade Halo Omega','This implant does nothing in and of itself, but when used in conjunction with other Halo implants it will boost their effect.\r\r\n\r\r\n25% bonus to the strength of all Halo implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(22119,300,'Mid-grade Slave Alpha','This ocular filter has been modified by Sanshas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% bonus to armor HP\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(22120,300,'Mid-grade Slave Beta','This memory augmentation has been modified by Sansha scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Memory\r\r\n\r\r\nSecondary Effect: 2% bonus to armor HP\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(22121,300,'Mid-grade Slave Delta','This cybernetic subprocessor has been modified by Sanshas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 4% bonus to armor HP\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(22122,300,'Mid-grade Slave Epsilon','This social adaption chip has been modified by Sanshas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to armor HP\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(22123,300,'Mid-grade Slave Gamma','This neural boost  has been modified by Sanshas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to armor HP\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(22124,300,'Mid-grade Slave Omega','This implant does nothing in and of itself, but when used in conjunction with other Slave implants it will boost their effect. \r\r\n\r\r\n25% bonus to the strength of all Slave implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(22125,300,'Mid-grade Snake Alpha','This ocular filter has been modified by Serpentis scientists for use by their elite smugglers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Perception\r\r\n\r\r\nSecondary Effect: 0.5% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(22126,300,'Mid-grade Snake Beta','This memory augmentation has been modified by Serpentis scientists for use by their elite smugglers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Memory\r\r\n\r\r\nSecondary Effect: 0.625% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(22127,300,'Mid-grade Snake Delta','This cybernetic subprocessor has been modified by Serpentis scientists for use by their elite smugglers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 0.875% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(22128,300,'Mid-grade Snake Epsilon','This social adaption chip has been modified by Serpentis scientists for use by their elite smugglers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 1% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(22129,300,'Mid-grade Snake Gamma','This neural boost  has been modified by Serpentis scientists for use by their elite smugglers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 0.75% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(22130,300,'Mid-grade Snake Omega','This implant does nothing in and of itself, but when used in conjunction with other Snake implants it will boost their effect. \r\r\n\r\r\n150% bonus to the strength of all Snake implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(22131,300,'Mid-grade Talisman Alpha','This ocular filter has been modified by Blood Raider scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(22133,300,'Mid-grade Talisman Beta','This memory augmentation has been modified by Blood Raider scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Memory\r\r\n\r\r\nSecondary Effect: 2% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(22134,300,'Mid-grade Talisman Delta','This cybernetic subprocessor has been modified by Blood Raider scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 4% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(22135,300,'Mid-grade Talisman Epsilon','This social adaption chip has been modified by Blood Raider scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(22136,300,'Mid-grade Talisman Gamma','This neural boost has been modified by Blood Raider scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(22137,300,'Mid-grade Talisman Omega','This implant does nothing in and of itself, but when used in conjunction with other Talisman implants it will boost their effect. \r\r\n\r\r\n25% bonus to the strength of all Talisman implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(22138,306,'Minmatar Prison_Mission','This rat-infested prison is being closely guarded by Maru personnel.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22139,283,'Kardimo Palettan','A member of Ekdit Spitek\'s census gathering team.',80,3,0,1,NULL,0.0000,1,NULL,0),(22140,526,'Tri-Vitoc','The Tri-Vitoc is an offshoot of the infamous Vitoc drug used by the Amarrians to control their most precious slaves. Yet, Tri-Vitoc is not an Amarrian design, but a Gallentean one, a futile attempt at developing an antidote for Vitoc. Tri-Vitoc has much the same effects as normal Vitoc, but is also known to heighten the senses, even to the point of causing hallucinations.',800,0.5,0,1,NULL,0.0000,1,NULL,0),(22141,526,'Finger Bone','Finger bone, taken from the body of a pirate.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22142,526,'Prophecy Virus','The latest doomsday prophecies of the Blind Muse in a plug-and-play format.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22143,283,'Freed Pet Slaves','These former pet slaves have been cleansed of their Vitoc dependency. But the trauma of what they had to endure while in captivity still haunts them.',400,1,0,1,NULL,0.0000,1,NULL,0),(22144,526,'Sadry Damoklet\'s Head','Decapitated head of Sadry Damoklet, an Amarrian Holder of such notorious perversity that he was exiled from the Empire. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22145,494,'Refitted Bestower','This Bestower-class industrial is currently undergoing maintenance. This particular vessel has been greatly modified and set up as a covert pleasure barge.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(22146,526,'Forged Waypoint Logs','Logs made to look like official imperial documents giving certain waypoint settings.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22148,803,'Searcher Drone_MISSION Spawn','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22149,526,'Searcher Drone\'s Memory Chip','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22150,306,'Ship Wreckage3','The mangled wreck floats motionless in space, surrounded with a field of scorched debris.',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(22151,526,'Yttora\'s Corpse','The corpse of an Urban Management census taker.',80,1,0,1,NULL,0.0000,1,NULL,0),(22152,526,'ID Card Generator','Generates fake ID\'s for those who wish to avoid detection by CONCORD.',2500,2,0,1,NULL,0.0000,1,NULL,0),(22153,534,'Ketta Tommin','This is a commander of the Maru Rebels.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22154,534,'Choiji the Vanquisher','One of the most feared combatants in this part of the world, Choiji is rumored to be the cousin of legendary pirate leader Korako \"The Rabbit\" Kosakami.  Many a hero has fallen to this bandit\'s deadly cannons. Threat level: Extreme',19000000,22000000,235,1,1,0.0000,0,NULL,0),(22155,526,'Sispur\'s Security Camera Logs','These security camera digital recordings date back a few weeks, mainly portraying the coming and goings of personnel on Sispur\'s Estate.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22156,494,'Sispur Estate Control Tower','The Matari aren\'t really that high-tech, preferring speed rather then firepower or involved technology. Unfortunately that doesn\'t apply very well to stationary objects, much to the liking of the Amarr Empire.\r\r\n\r\r\nAmarrians call it a scrapheap of epic proportions. But don\'t underestimate these structures. Minmatar commanders usually have the last laugh when it comes to combat.',100000,1150,8850,1,2,0.0000,0,NULL,0),(22157,474,'Sispur Estate Keycard','This keycard will activate the acceleration gate leading into Sispur\'s Estate.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22158,494,'Damaged Portal','Part of a mysterious portal that has long since malfunctioned.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22159,526,'Mysterious Portal Parts','Parts from a mysterious portal built by an unknown entity long ago. Looks human made, though.',1000,1,0,1,NULL,0.0000,1,NULL,0),(22160,533,'Famon Gurch','Famon is a well known peddler of contraband goods within the Republic. ',10900000,109000,120,1,2,0.0000,0,NULL,0),(22161,494,'Gisti Repair Station','This is an Angel operated repair unit charged with cleaning and fixing the old citadel.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(22162,526,'Runic Tablet','This tablet is covered in intricate runic signs, totally beyond comprehension. It looks sinister, though.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22163,526,'Patrenn\'s Stash','This crate contains a backup of Sifor Patrenn\'s research material. ',100,300,0,1,NULL,0.0000,1,NULL,0),(22164,526,'Navy Issue Amplifier','An electronic device that generates and amplifies a carrier wave, modulates it with a meaningful signal derived from speech or other sources, and radiates the resulting signal from an antenna.',2500,200,0,1,NULL,0.0000,1,NULL,0),(22165,526,'Custom-made Antenna','A huge antenna designed for use in zero gravity.',2500,200,0,1,NULL,0.0000,1,NULL,0),(22166,526,'Portable Power Generator','Small generator capable of powering up a small space installation.',1500,10,0,1,NULL,0.0000,1,NULL,0),(22167,526,'Broken Science Equipment','Left-over equipment from this abandoned research lab. It\'s badly damaged and probably contaminated.',2000,1,0,1,NULL,0.0000,1,NULL,0),(22168,306,'Republic Navy Container','The bolted container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,2750,2700,1,NULL,0.0000,0,NULL,0),(22171,533,'Angel Scavenger','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22172,273,'TEST Drone Skill','This skill currently has no effect.',0,0.01,0,1,4,0.0000,0,NULL,0),(22173,283,'The Infiltrator','A mysterious figure of Minmatar ancestry.',80,1,0,1,NULL,0.0000,1,NULL,0),(22174,526,'Blue Box','Small, sealed box. A single socket connects it to the outside world.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22175,538,'Data Analyzer I','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,51464.0000,1,1718,0),(22176,917,'Data Analyzer I Blueprint',' ',0,0.01,0,1,NULL,332640.0000,1,1809,0),(22177,538,'Relic Analyzer I','An archaeology system used to analyze and search ancient ruins. ',0,5,0,1,NULL,51464.0000,1,1718,0),(22178,917,'Relic Analyzer I Blueprint',' ',0,0.01,0,1,NULL,332640.0000,1,1809,0),(22179,517,'Apheta Zenakon\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22180,517,'Hakno Lekan\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22181,517,'Jachael Menson\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22182,494,'Barou Lardoss\'s Iteron','This a Iteron V-class industrial.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(22184,494,'Gallente Miner','The Atron is a hard nugget with an advanced power conduit system, but little space for cargo. Although the Atron is a good harvester when it comes to mining, its main ability is as a combat vessel.  It is sometimes used by the Gallente Navy and is generally considered an expendable low-cost craft.',1200000,22500,500,1,8,0.0000,0,NULL,0),(22185,517,'Cosmos Tristan','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(22186,517,'Wenda Lamort','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(22187,517,'Jaak Rozake','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(22188,517,'Beteux Maron','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(22189,517,'Cosmos Punisher','A Punisher piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(22190,517,'Demi Lazerus\'s Punisher','A Punisher piloted by an agent.',1425000,28600,135,1,4,0.0000,0,NULL,0),(22191,517,'Nikmar Jyran\'s Punisher','A Punisher piloted by an agent.',1425000,28600,135,1,4,0.0000,0,NULL,0),(22192,517,'Taspar Zolankor\'s Punisher','A Punisher piloted by an agent.',1425000,28600,135,1,4,0.0000,0,NULL,0),(22193,517,'Cosmos Kestrel','A Kestrel piloted by an agent.',1700000,19700,305,1,1,0.0000,0,NULL,0),(22194,521,'Minmatar Republic Narcotic Officer\'s Tag','This tag belonged to a narcotics officer working for the Minmatar Republic. These can often be found working in the Ani constellation, trying to uncover the secrets of the various drug-cartels working there.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(22195,517,'Peeta Waikon\'s Kestrel','A Kestrel piloted by an agent.',1700000,19700,305,1,1,0.0000,0,NULL,0),(22196,517,'Rokuza Taman\'s Kestrel','A Kestrel piloted by an agent.',1700000,19700,305,1,1,0.0000,0,NULL,0),(22197,517,'Vaktan Sido\'s Kestrel','A Kestrel piloted by an agent.',1700000,19700,305,1,1,0.0000,0,NULL,0),(22201,474,'Uni-Dimensional Algorithm Code','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22203,521,'Angel Drug Addict Tag','This tag was carried by an Angel Cartel drug addict.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(22204,521,'Red Hammer\'s Personal Effects','These are the personal effects of a drug addict who goes by the nickname Red Hammer.',25,10,0,1,NULL,0.0000,1,NULL,0),(22205,526,'Godun Sakt\'s Diamond Drill','This Diamond Drill belongs to a man named Godun Sakt. Stored in a small box to avoid damage, this item is extremely valuable in the right hands.',25,10,0,1,NULL,0.0000,1,NULL,0),(22206,526,'Blood Sample','A blood sample given by one of the infected people inhabiting the Ani constellation. Avoid coming close or you might catch the disease yourself.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22207,526,'Analyzed Blood Sample','This blood sample is infected with the deadly Alobe virus.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22208,283,'Prostitute','An individual who provides sexual services in exchange for currency.',50,1,0,1,NULL,0.0000,1,NULL,0),(22209,283,'Refugee','A person who has fled from their home because of war, political oppression or religious persecution.',60,3,0,1,NULL,0.0000,1,NULL,0),(22210,283,'Cloned SOE officer','This is the clone of an officer who previously worked for the Sisters of Eve. It has a strange mind-controlling implant inserted.',80,1,0,1,NULL,0.0000,1,NULL,0),(22211,526,'Angel Cartel Computer Hardware','Modified, overclocked and hacked are the trademarks of the Angel Cartel hardware designers. These components are superior to most other computer systems.',2500,2,0,1,NULL,0.0000,1,NULL,0),(22214,526,'Godun Sakt\'s Questionable Holoreel','What is on this holoreel? Only its owner, Godun Sakt, can tell.',100,0.5,0,1,NULL,0.0000,1,NULL,0),(22217,526,'Strange Construction Blocks','These construction blocks feel lighter than normal. Perhaps they are hollow on the inside?',10000,4,0,1,NULL,0.0000,1,NULL,0),(22218,526,'Drug Delivery Package','These illegal substances are encased in a special magnetically sealed container so the Empire\'s security forces cannot detect them.',25,10,0,1,NULL,0.0000,1,NULL,0),(22219,526,'Replacement Laboratory Equipment','These basic elements of all electronic hardware are sought out by those who require spare parts in their hardware. These specific parts are intended for repair and maintenance of a laboratory.',1000,1,0,1,NULL,0.0000,1,NULL,0),(22220,526,'Mind-Altering Drugs','Inhaling this once can make a person\'s brain unable to function like it should. One becomes submissive to others and some even lose the will to live. Most addicts end up committing suicide.',1.4,1,0,1,NULL,0.0000,1,NULL,0),(22221,517,'Cosmos Scorpion','A Scorpion piloted by an agent.',115000000,1040000,550,1,1,0.0000,0,NULL,0),(22222,314,'Classified Report - Station Defenses','These encoded reports may mean little to the untrained eye, but can prove valuable to the relevant institution.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22223,306,'Guristas Officer\'s Quarters Mission Spy Stash','The highest ranking personnel within this deadspace pocket reside here.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22225,1207,'Sleeper Data Storage','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(22226,1207,'Sleeper Debris Piece','This floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(22227,316,'Armored Warfare Link - Rapid Repair I','Increases the speed of the fleet\'s personal and targeted armor repair systems.\r\r\nWill not affect Capital-sized personal repair modules.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,225005.0000,1,1634,0),(22228,316,'Siege Warfare Link - Shield Efficiency I','Reduces the capacitor need of the fleet\'s shield boosters and shield transporters.\r\r\n\r\r\nWarfare links are dedicated fleet command systems designed for use on battlecruisers and advanced command class ships.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNotes: The Fleet bonus only works if you are the assigned fleet booster. This module cannot activate inside a starbase forcefield.',0,60,0,1,NULL,225005.0000,1,1636,0),(22229,464,'Ice Harvester II','A unit used to extract valuable materials from ice asteroids. Used on Mining barges and Exhumers.',0,5,0,1,NULL,6478646.0000,1,1038,0),(22230,490,'Ice Harvester II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22231,526,'Recruitment Center Data Log','These data logs contain information on the comings and goings of all new recruits stationed in Fluekele, as well as messages sent to and from the control tower in the recruitment center.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22232,494,'Angel Information Center','This station is a center of information for the Angel Cartel. Here, they store and filter all the data gathered by their agents throughout the constellation. It also acts as a place of recreation and relaxation for all cartel members in the area.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(22233,533,'Vanir Makono','This is a Thukker Tribe envoy to the Angel Cartel base in Inder.',10900000,109000,120,1,2,0.0000,0,NULL,0),(22234,526,'Vanir Makono\'s DNA','A DNA sample taken from the Thukker Tribe pirate, Vanir Makono.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22235,534,'Red Hammer','This drug-addict goes by the name of Red Hammer, he is wanted by various factions.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22236,527,'Angel Drug Addict','This is a hostile pirate vessel. Threat level: Very high',1910000,19100,80,1,2,0.0000,0,NULL,0),(22237,533,'Angel Thief','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22238,534,'Minmatar Republic Narcotics Officer 3rd Rank','This is a narcotics officer working for the Minmatar Republic.',19000000,1080000,120,1,2,0.0000,0,NULL,0),(22239,533,'Minmatar Republic Narcotics Officer 2nd Rank','This is an undercover narcotics officer working for the Minmatar Republic.',9900000,99000,1900,1,2,0.0000,0,NULL,0),(22240,527,'Minmatar Republic Narcotics Officer 1st Rank','This is an undercover narcotics officer working for the Minmatar Republic.',1645000,16450,110,1,2,0.0000,0,NULL,0),(22241,494,'Deserted Nefantar Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. Deserted years ago by the Nefantar tribe, this bunker is now used as storage by the Angel Cartel.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22242,268,'Capital Ship Construction','Skill required for the manufacturing of standard and advanced capital ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,75000000.0000,1,369,0),(22246,534,'Minmatar Republic Narcotics Deputy','This is an undercover narcotics officer working for the Minmatar Republic.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22247,306,'Nefantar Debris II','This Floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more',10000,27500,2700,1,4,0.0000,0,NULL,0),(22248,526,'Ancient Nefantar Sculpture',' ',100,5,0,1,NULL,2000.0000,1,NULL,0),(22249,526,'Lagaster Malotoff\'s Tag','This Angel Cartel insignia may prove valuable if turned in at the proper authorities.',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(22250,533,'Lagaster Malotoff','This is the commander of the Gist fleet in the Minmatar Military Depot. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22253,533,'Rekker Malkun','The Maller is the largest cruiser class used by the Amarrians. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches. In the Amarr Imperial Navy, the Maller is commonly used as the spearhead for large military operations.',12750000,118000,280,1,4,0.0000,0,NULL,0),(22254,526,'Rekker\'s Keycard','This security passcard is manufactured by the Minmatar Fleet and allows the user to unlock a specific acceleration gate to another sector. The gate will remain open for a short period of time and the keycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22255,520,'COSMOS Amarr Seeker',' ',2820000,24398,235,1,4,0.0000,0,NULL,0),(22256,520,'COSMOS Amarr Collector',' ',2810000,28100,135,1,4,0.0000,0,NULL,0),(22257,520,'COSMOS Amarr Engraver',' ',2810000,28100,315,1,4,0.0000,0,NULL,0),(22258,520,'COSMOS Amarr Archon',' ',2860000,28600,235,1,4,0.0000,0,NULL,0),(22259,520,'COSMOS Amarr Templar',' ',2860000,28600,235,1,4,0.0000,0,NULL,0),(22260,520,'COSMOS Amarr Shade','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(22261,520,'COSMOS Amarr Phantom','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(22262,522,'COSMOS Amarr Arch Engraver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',12000000,120000,450,1,4,0.0000,0,NULL,0),(22263,522,'COSMOS Amarr Revenant','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(22264,522,'COSMOS Amarr Arch Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(22265,522,'COSMOS Amarr Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(22266,523,'COSMOS Amarr Shadow Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(22267,523,'COSMOS Amarr Dark Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(22268,523,'COSMOS Amarr Harbinger','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(22269,523,'COSMOS Amarr Patriarch','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(22270,520,'COSMOS Amarr Gamma II Support Frigate',' ',1050000,28100,235,1,4,0.0000,0,NULL,0),(22271,523,'COSMOS Amarr Jakar',' ',19000000,1150000,235,1,4,0.0000,0,NULL,0),(22272,522,'COSMOS Amarr Maller',' ',12750000,118000,280,1,4,0.0000,0,NULL,0),(22273,534,'Kurzon General',' ',19000000,1150000,235,1,4,0.0000,0,NULL,0),(22276,534,'Kyan Magdesh',' ',21000000,1040000,235,1,1,0.0000,0,NULL,0),(22277,526,'Kyan Magdesh\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the Mordu\'s mercenary, Kyan Magdesh.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22280,803,'COSMOS Strain Matriarch Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22281,803,'COSMOS Strain Domination Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22282,803,'COSMOS Strain Spearhead Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22283,803,'COSMOS Viral Infector Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22284,805,'COSMOS Marauder Drone',' ',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22285,805,'COSMOS Ripper Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: High',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22288,526,'Angel Cartel Scanner Data','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22289,494,'Scanner Tower','This huge telescope contains fragile but advanced sensory equipment. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22291,367,'Ballistic Control System II','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,360976.0000,1,645,0),(22292,400,'Ballistic Control System II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22293,1207,'Talocan Data Storage','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(22294,1207,'Talocan Debris Piece','This Floating piece of debris looks like it might be of some value to the right person   ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(22295,474,'Ancient Ciphering Totem','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22296,15,'Blood Raider Logistics Outpost',' ',0,0,0,1,4,0.0000,0,NULL,0),(22297,15,'Blood Raider Military Outpost',' ',0,0,0,1,4,0.0000,0,NULL,0),(22298,15,'Blood Raider Trading Outpost',' ',0,0,0,1,4,0.0000,0,NULL,0),(22299,532,'Armored Warfare Link - Damage Control I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22300,532,'Armored Warfare Link - Passive Defense I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22301,532,'Armored Warfare Link - Rapid Repair I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22302,532,'Command Processor I Blueprint',' ',0,0.01,0,1,NULL,1796640.0000,1,799,0),(22303,532,'Information Warfare Link - Electronic Superiority I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22304,532,'Information Warfare Link - Recon Operation I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22305,532,'Information Warfare Link - Sensor Integrity I Blueprint',' ',0,0.01,0,1,NULL,1476280.0000,1,799,0),(22306,532,'Siege Warfare Link - Shield Harmonizing I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22307,532,'Siege Warfare Link - Active Shielding I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22308,532,'Siege Warfare Link - Shield Efficiency I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22309,532,'Skirmish Warfare Link - Evasive Maneuvers I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22310,532,'Skirmish Warfare Link - Interdiction Maneuvers I Blueprint',' ',0,0.01,0,1,NULL,1476280.0000,1,799,0),(22311,532,'Skirmish Warfare Link - Rapid Deployment I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22315,526,'Encoded RSS Brief','This encoded brief may mean little to the untrained eye, but can prove valuable to the relevant institution.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22316,527,'Nanom Basskel','Nanom Basskel, human trafficker and lady of the night.',10900000,109000,120,1,4,0.0000,0,NULL,0),(22317,526,'Nanom Basskel\'s Ship Logs','Logs providing information about the location of an illegal slave trading hideout.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22318,306,'Angel Hardware Storage','This is where the Angel Cartel stores its computer hardware.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(22319,517,'Viljanen\'s Heron','A Heron piloted by an agent.\r\r\n\r\r\nMissions:\r\r\n\r\r\n<i>Mini-Profession related</i>\r\r\n',0,0,0,1,1,0.0000,0,NULL,0),(22320,494,'Brothel','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22321,283,'Grace Tarsis','Grace Tarsis is a tremendously skilled martial artist.',50,1,0,1,NULL,0.0000,1,NULL,0),(22322,533,'Gerno Babalu',' ',11500000,96000,300,1,2,0.0000,0,NULL,0),(22324,816,'Draben Kuvakei','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(22325,538,'\'Daemon\' Data Analyzer I','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,51464.0000,1,NULL,0),(22326,917,'\'Daemon\' Data Analyzer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22327,538,'\'Codex\' Data Analyzer I','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,51464.0000,1,NULL,0),(22328,917,'\'Codex\' Data Analyzer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22329,538,'\'Alpha\' Data Analyzer I','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,51464.0000,1,NULL,0),(22330,917,'\'Alpha\' Data Analyzer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22331,538,'\'Libram\' Data Analyzer I','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,51464.0000,1,NULL,0),(22332,917,'\'Libram\' Data Analyzer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22333,538,'Talocan Data Analyzer I','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,33264.0000,1,NULL,0),(22335,538,'Sleeper Data Analyzer I','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,33264.0000,1,NULL,0),(22337,538,'Terran Data Analyzer I','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,33264.0000,1,NULL,0),(22339,538,'Tetrimon Data Analyzer I','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,33264.0000,1,NULL,0),(22343,306,'Nefantar Debris I','This damaged hunk of machinery could once have been a part of a powerplant or relay station.',10000,27500,2700,1,4,0.0000,0,NULL,0),(22390,517,'Nikmar Jyran\'s Retribution','A Retribution piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(22391,517,'Taspar Zolankor\'s Retribution','A Retribution piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(22428,898,'Redeemer','Black Ops battleships are designed for infiltration and espionage behind enemy lines. With the use of a jump drive and portal generator, they are capable of making a special type of jump portal usable only by covert ops vessels. This enables them to stealthily plant reconnaissance and espionage forces in enemy territory. For the final word in clandestine maneuvers, look no further.\r\r\n\r\r\nDeveloper: Viziam \r\r\n\r\r\nViziam ships are quite possibly the most durable ships money can buy. Their armor is second to none and that, combined with superior shields, makes them hard nuts to crack. Of course this does mean they are rather slow and possess somewhat more limited weapons and electronics options.',150300000,486000,700,1,4,449830704.0000,1,1076,0),(22429,107,'Redeemer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22430,898,'Sin','Black Ops battleships are designed for infiltration and espionage behind enemy lines. With the use of a jump drive and portal generator, they are capable of making a special type of jump portal usable only by covert ops vessels. This enables them to stealthily plant reconnaissance and espionage forces in enemy territory. For the final word in clandestine maneuvers, look no further.\r\r\n\r\r\nDeveloper: CreoDron\r\r\n\r\r\nAs the largest drone developer and manufacturer in space, CreoDron has a vested interest in drone carriers. While sacrificing relatively little in the way of defensive capability, the Sin can chew its way through surprisingly strong opponents - provided, of course, that the pilot uses top-of-the-line CreoDron drones.\r\r\n',141700000,454500,700,1,8,418778546.0000,1,1078,0),(22431,107,'Sin Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22436,898,'Widow','Black Ops battleships are designed for infiltration and espionage behind enemy lines. With the use of a jump drive and portal generator, they are capable of making a special type of jump portal usable only by covert ops vessels. This enables them to stealthily plant reconnaissance and espionage forces in enemy territory. For the final word in clandestine maneuvers, look no further.\r\r\n\r\r\nDeveloper: Kaalakiota \r\r\nAs befits one of the largest weapons manufacturers in the known world, Kaalakiota\'s ships are very combat focused. Favoring the traditional Caldari combat strategy, they are designed around a substantial number of weapons systems, especially missile launchers. However, they have rather weak armor and structure, relying more on shields for protection.',151100000,468000,650,1,1,384949840.0000,1,1077,0),(22437,107,'Widow Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22440,898,'Panther','Black Ops battleships are designed for infiltration and espionage behind enemy lines. With the use of a jump drive and portal generator, they are capable of making a special type of jump portal usable only by covert ops vessels. This enables them to stealthily plant reconnaissance and espionage forces in enemy territory. For the final word in clandestine maneuvers, look no further.\r\r\n\r\r\nDeveloper: Thukker Mix \r\r\n\r\r\nThe Thukkers generally favor speed and offensive power over defensive capability. While many of them could be said to lack technological innovation, Thukker Mix vessels are invariably the swiftest and most agile of their kind.',148800000,414000,725,1,2,377113480.0000,1,1079,0),(22441,107,'Panther Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22442,540,'Eos','Command ships are engineered specifically to wreak havoc on a battlefield of many.  Sporting advanced command module interfaces, these vessels are more than capable of turning the tide in large engagements. Command ships represent the ultimate in warfare link efficiency; the boosts they give their comrades in combat make them indispensable assets to any well-rounded fleet.\r\r\n\r\r\nDeveloper: CreoDron\r\r\n\r\r\nAs the largest drone developer and manufacturer in space, CreoDron has a vested interest in drone carriers.  While sacrificing relatively little in the way of defensive capability, the Eos can chew its way through surprisingly strong opponents - provided, of course, that the pilot uses top-of-the-line CreoDron drones.',13000000,270000,400,1,8,120718336.0000,1,831,0),(22443,489,'Eos Blueprint',' ',0,0.01,0,1,NULL,599156000.0000,1,898,0),(22444,540,'Sleipnir','Command ships are engineered specifically to wreak havoc on a battlefield of many.  Sporting advanced command module interfaces, these vessels are more than capable of turning the tide in large engagements. Command ships represent the ultimate in warfare link efficiency; the boosts they give their comrades in combat make them indispensable assets to any well-rounded fleet.\r\r\n\r\r\nDeveloper: Boundless Creation\r\r\n\r\r\nBoundless Creation\'s ships are based on the Brutor tribe\'s philosophy of warfare: simply fit as much firepower onto your ship as possible.  Defense systems and electronics arrays therefore tend to take a back seat to sheer annihilative potential.',12800000,216000,475,1,2,122101940.0000,1,834,0),(22445,489,'Sleipnir Blueprint',' ',0,0.01,0,1,NULL,536736000.0000,1,899,0),(22446,540,'Vulture','Command ships are engineered specifically to wreak havoc on a battlefield of many.  Sporting advanced command module interfaces, these vessels are more than capable of turning the tide in large engagements. Command ships represent the ultimate in warfare link efficiency; the boosts they give their comrades in combat make them indispensable assets to any well-rounded fleet.\r\r\n\r\r\nDeveloper: Ishukone\r\r\n\r\r\nMost of the recent designs off their assembly line have provided for a combination that the Ishukone name is becoming known for: great long-range capabilities and shield systems unmatched anywhere else.',14000000,252000,400,1,1,120840494.0000,1,828,0),(22447,489,'Vulture Blueprint',' ',0,0.01,0,1,NULL,571826000.0000,1,897,0),(22448,540,'Absolution','Command ships are engineered specifically to wreak havoc on a battlefield of many.  Sporting advanced command module interfaces, these vessels are more than capable of turning the tide in large engagements. Command ships represent the ultimate in warfare link efficiency; the boosts they give their comrades in combat make them indispensable assets to any well-rounded fleet.\r\r\n\r\r\nDeveloper: Carthum Conglomerate\r\r\n\r\r\nCarthum ships are the very embodiment of the Amarrian warfare philosophy. Possessing sturdy armor and advanced weapons systems, they provide a nice mix of offense and defense. On the other hand, their electronics and shield systems tend to be rather limited.  ',13300000,234000,375,1,4,118747598.0000,1,825,0),(22449,489,'Absolution Blueprint',' ',0,0.01,0,1,NULL,569536000.0000,1,896,0),(22452,541,'Heretic','Interdictors are destroyer-sized vessels built to fill a single important tactical niche: the breaching of enemy warp tunnels.  Capable of launching warp-disrupting interdiction spheres, interdictors are of great value in locations of strategic importance where enemy movement must be restricted.  Additionally, much like their destroyer-class progenitors, they are well-suited to offensive strikes against frigate-sized craft.\r\r\n\r\r\nDeveloper: Khanid Innovations\r\r\n\r\r\nIn addition to robust electronics systems, the Khanid Kingdom\'s ships possess advanced armor alloys capable of withstanding a great deal of punishment. Generally eschewing the use of turrets, they tend to gear their vessels more towards close-range missile combat.\r\r\n\r\r\n',1300000,47000,380,1,4,10259890.0000,1,826,0),(22453,487,'Heretic Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,892,0),(22456,541,'Sabre','Interdictors are destroyer-sized vessels built to fill a single important tactical niche: the breaching of enemy warp tunnels.  Capable of launching warp-disrupting interdiction spheres, interdictors are of great value in locations of strategic importance where enemy movement must be restricted.  Additionally, much like their destroyer-class progenitors, they are well-suited to offensive strikes against frigate-sized craft.\r\r\n\r\r\nDeveloper: Core Complexion\r\r\n\r\r\nCore Complexion\'s ships are unusual in that they favor electronics and defense over the \"lots of guns\" approach traditionally favored by the Minmatar.   \r\r\n',1285000,43000,400,1,2,10055040.0000,1,835,0),(22457,487,'Sabre Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,895,0),(22460,541,'Eris','Interdictors are destroyer-sized vessels built to fill a single important tactical niche: the breaching of enemy warp tunnels.  Capable of launching warp-disrupting interdiction spheres, interdictors are of great value in locations of strategic importance where enemy movement must be restricted.  Additionally, much like their destroyer-class progenitors, they are well-suited to offensive strikes against frigate-sized craft.\r\r\n\r\r\nDeveloper: Roden Shipyards\r\r\n\r\r\nUnlike most Gallente ship manufacturers, Roden Shipyards tend to favor missiles over drones and their ships generally possess stronger armor.  Their electronics capacity, however, tends to be weaker than that of their competitors\'.\r\r\n\r\r\n',1200000,55000,400,1,8,10129096.0000,1,832,0),(22461,487,'Eris Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,894,0),(22464,541,'Flycatcher','Interdictors are destroyer-sized vessels built to fill a single important tactical niche: the breaching of enemy warp tunnels.  Capable of launching warp-disrupting interdiction spheres, interdictors are of great value in locations of strategic importance where enemy movement must be restricted.  Additionally, much like their destroyer-class progenitors, they are well-suited to offensive strikes against frigate-sized craft.\r\r\n\r\r\nDeveloper: Kaalakiota\r\r\n\r\r\nAs befits one of the largest weapons manufacturers in the known world, Kaalakiota\'s ships are very combat focused. Favoring the traditional Caldari combat strategy, they are designed around a substantial number of weapons systems, especially missile launchers. However, they have rather weak armor and structure, relying more on shields for protection.\r\r\n',1350000,52000,450,1,1,10163076.0000,1,829,0),(22465,487,'Flycatcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,893,0),(22466,540,'Astarte','Command ships are engineered specifically to wreak havoc on a battlefield of many.  Sporting advanced command module interfaces, these vessels are more than capable of turning the tide in large engagements. Command ships represent the ultimate in warfare link efficiency; the boosts they give their comrades in combat make them indispensable assets to any well-rounded fleet.\r\r\n\r\r\nDeveloper: Duvolle Labs\r\r\n\r\r\nDuvolle Labs manufactures sturdy ships with a good mix of offensive and defensive capabilities. Since the company is one of New Eden\'s foremost manufacturers of particle blasters, its ships tend to favor turrets and thus have somewhat higher power output than normal.',12300000,270000,400,1,8,117860286.0000,1,831,0),(22467,489,'Astarte Blueprint',' ',0,0.01,0,1,NULL,590626000.0000,1,898,0),(22468,540,'Claymore','Command ships are engineered specifically to wreak havoc on a battlefield of many.  Sporting advanced command module interfaces, these vessels are more than capable of turning the tide in large engagements. Command ships represent the ultimate in warfare link efficiency; the boosts they give their comrades in combat make them indispensable assets to any well-rounded fleet.\r\r\n\r\r\nDeveloper: Core Complexion Inc.\r\r\n\r\r\nCore Complexion\'s ships are unusual in that they favor electronics and defense over the \"lots of guns\" approach traditionally favored by the Minmatar.   ',12500000,216000,575,1,2,126867874.0000,1,834,0),(22469,489,'Claymore Blueprint',' ',0,0.01,0,1,NULL,513546000.0000,1,899,0),(22470,540,'Nighthawk','Command ships are engineered specifically to wreak havoc on a battlefield of many.  Sporting advanced command module interfaces, these vessels are more than capable of turning the tide in large engagements. Command ships represent the ultimate in warfare link efficiency; the boosts they give their comrades in combat make them indispensable assets to any well-rounded fleet.\r\r\n\r\r\nDeveloper: Kaalakiota\r\r\n\r\r\nAs befits one of the largest weapons manufacturers in the known world, Kaalakiota\'s ships are very combat focused. Favoring the traditional Caldari combat strategy, they are designed around a substantial number of weapons systems, especially missile launchers. However, they have rather weak armor and structure, relying more on shields for protection.\r\r\n',14810000,252000,700,1,1,117963816.0000,1,828,0),(22471,489,'Nighthawk Blueprint',' ',0,0.01,0,1,NULL,585336000.0000,1,897,0),(22474,540,'Damnation','Command ships are engineered specifically to wreak havoc on a battlefield of many.  Sporting advanced command module interfaces, these vessels are more than capable of turning the tide in large engagements. Command ships represent the ultimate in warfare link efficiency; the boosts they give their comrades in combat make them indispensable assets to any well-rounded fleet.\r\r\n\r\r\nDeveloper: Khanid Innovation\r\r\n\r\r\nIn addition to robust electronics systems, the Khanid Kingdom\'s ships possess advanced armor alloys capable of withstanding a great deal of punishment. Generally eschewing the use of turrets, they tend to gear their vessels more towards close-range missile combat.',13500000,234000,645,1,4,116752524.0000,1,825,0),(22475,489,'Damnation Blueprint',' ',0,0.01,0,1,NULL,589866000.0000,1,896,0),(22476,52,'Warp Prohibitor I','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,47476.0000,0,NULL,0),(22477,132,'Warp Prohibitor I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(22494,526,'Utrainen\'s Reports','These encoded reports may mean little to the untrained eye, but can prove valuable to the relevant institution.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22534,1229,'Inherent Implants \'Highwall\' Mining MX-1003','A neural Interface upgrade that boosts the pilot\'s skill at mining.\r\r\n\r\r\n3% bonus to mining yield.',0,1,0,1,NULL,21504.0000,1,1767,0),(22535,1229,'Inherent Implants \'Highwall\' Mining MX-1005','A neural Interface upgrade that boosts the pilot\'s skill at mining.\r\r\n\r\r\n5% bonus to mining yield.',0,1,0,1,NULL,21504.0000,1,1767,0),(22536,258,'Mining Foreman','Basic proficiency at coordinating mining operations. Grants a 2% bonus to fleet members\' mining yield per level.<br>Note: The fleet bonus only works if you are the assigned fleet booster and fleet members are in space within the same solar system',0,0.01,0,1,NULL,75000.0000,1,370,0),(22537,78,'Ore compression thingie','Increases cargo hold capacity.',50,5,0,1,NULL,1664.0000,0,NULL,0),(22541,273,'Mining Drone Specialization','Advanced proficiency at controlling mining drones. 3% Bonus to mining drone yield.',0,0.01,0,1,NULL,2000000.0000,0,NULL,0),(22542,546,'Mining Laser Upgrade I','Increases the yield on mining lasers, but causes them to use up more CPU.',1,5,0,1,NULL,40456.0000,1,935,0),(22543,1139,'Mining Laser Upgrade I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,937,0),(22544,543,'Hulk','The exhumer is the second generation of mining vessels created by <a href=showinfo:30//500014>ORE</a>. Exhumers, like their mining barge cousins, were each created to excel at a specific function, the Hulk\'s being mining yield and mining laser range. The additional yield comes at a price, as the Hulk has weaker defenses and a smaller ore bay than the other exhumers.\r\r\nExhumers are equipped with electronic subsystems specifically designed to accommodate Strip Mining and Ice Harvesting modules.',30000000,200000,350,1,128,82502106.0000,1,874,0),(22545,477,'Hulk Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,904,0),(22546,543,'Skiff','The exhumer is the second generation of mining vessels created by <a href=showinfo:30//500014>ORE</a>. Exhumers, like their mining barge cousins, were each created to excel at a specific function, the Skiff\'s being durability and self-defense. Advanced shielding and drone control systems make the Skiff the toughest mining ship in the cluster. With that in mind, the designers could only make space to fit one mining or ice harvesting module. To mitigate the effect this would have on its mining output, they came up with a unique loading system that allows this one module to work with vastly increased efficiency.\r\r\nExhumers are equipped with electronic subsystems specifically designed to accommodate Strip Mining and Ice Harvesting modules.',10000000,100000,350,1,128,57749552.0000,1,874,0),(22547,477,'Skiff Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,904,0),(22548,543,'Mackinaw','The exhumer is the second generation of mining vessels created by <a href=showinfo:30//500014>ORE</a>. Exhumers, like their mining barge cousins, were each created to excel at a specific function, the Mackinaw\'s being storage. A massive ore hold allows the Mackinaw to operate for extended periods without requiring as much support as other exhumers.\r\r\nExhumers are equipped with electronic subsystems specifically designed to accommodate Strip Mining and Ice Harvesting modules.',20000000,150000,450,1,128,70158750.0000,1,874,0),(22549,477,'Mackinaw Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,904,0),(22551,257,'Exhumers','Skill for the operation of Exhumers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,28000000.0000,1,377,0),(22552,258,'Mining Director','Advanced proficiency at group mining. Boosts the effectiveness of mining foreman link modules by 20% per skill level.',0,0.01,0,1,NULL,400000.0000,1,370,0),(22553,316,'Mining Foreman Link - Harvester Capacitor Efficiency I','Decreases the capacitor need of mining lasers, gas harvesters and ice harvesters.\r\r\n\r\r\nForeman Links are dedicated mining operation systems designed to assist foremen in coordinating their operations.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNote: The Fleet bonus only works if you are the assigned fleet booster.',0,60,0,1,NULL,225005.0000,1,1638,0),(22554,532,'Mining Foreman Link - Harvester Capacitor Efficiency I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22555,316,'Mining Foreman Link - Mining Laser Field Enhancement I','Increases the range of the fleet\'s mining lasers, gas harvesters, ice harvesters and survey scanners.\r\r\n\r\r\nForeman Links are dedicated mining operation systems designed to assist foremen in coordinating their operations.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNote: The Fleet bonus only works if you are the assigned fleet booster.',0,60,0,1,NULL,225005.0000,1,1638,0),(22556,532,'Mining Foreman Link - Mining Laser Field Enhancement I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22557,316,'Mining Foreman Link - Laser Optimization I','Decreases mining laser, gas harvester and ice harvester duration.\r\r\n\r\r\nForeman Links are dedicated mining operation systems designed to assist foremen in coordinating their operations.\r\r\n\r\r\nWhile only one of these units can normally be operated at any given time, certain advanced units allow the use of multiple systems. \r\r\n\r\r\nNote: The Fleet bonus only works if you are the assigned fleet booster.',0,60,0,1,NULL,225005.0000,1,1638,0),(22558,532,'Mining Foreman Link - Laser Optimization I Blueprint',' ',0,0.01,0,1,NULL,1732280.0000,1,799,0),(22559,744,'Mining Foreman Mindlink','This advanced interface link drastically improves a commander\'s Mining Foreman ability by directly linking to the mining laser interfaces of all ships in the fleet.\r\r\n\r\r\n25% increase to the command bonus of Mining Foreman Link modules.\r\r\n\r\r\nReplaces Mining Foreman skill bonus with fixed 15% mining yield bonus.\r\r\n',0,1,0,1,NULL,0.0000,1,1505,0),(22564,507,'True Sansha Rocket Launcher','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.2531,1,NULL,3000.0000,1,639,0),(22565,509,'True Sansha Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.9,1,1,3000.0000,1,640,0),(22566,511,'True Sansha Rapid Light Missile Launcher','Launcher for cruisers intended to counter fast frigates, can only be fitted with regular light missiles.',0,10,0.315,1,1,4224.0000,1,641,0),(22567,510,'True Sansha Heavy Missile Launcher','Designed for long engagements between medium sized ships. Slow firing rate, but makes up for it with a large missile capacity.',0,10,1.23,1,1,14996.0000,1,642,0),(22568,506,'True Sansha Cruise Missile Launcher','A battleship mounted launcher used for long range standoffs with other battleships, but less suitable for bombardment of deployed structures. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships. ',0,20,1.35,1,NULL,99996.0000,1,643,0),(22569,508,'True Sansha Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2,1,1,20580.0000,1,644,0),(22570,1229,'Inherent Implants \'Yeti\' Ice Harvesting IH-1003','A neural Interface upgrade that boosts the pilot\'s skill at mining ice.\r\r\n\r\r\n3% decrease in ice harvester cycle time.',0,1,0,1,NULL,21504.0000,1,1767,0),(22571,1229,'Inherent Implants \'Yeti\' Ice Harvesting IH-1005','A neural Interface upgrade that boosts the pilot\'s skill at mining ice.\r\r\n\r\r\n5% decrease in ice harvester cycle time.',0,1,0,1,NULL,21504.0000,1,1767,0),(22572,544,'Praetor EV-900','Energy Neutralizer Drone',3000,25,0,1,4,88424.0000,1,843,0),(22573,1142,'Praetor EV-900 Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,1,1586,0),(22574,545,'Warp Scrambling Drone','Warp Scrambling Drone',3000,5,1200,1,NULL,2000.0000,0,NULL,0),(22576,546,'Ice Harvester Upgrade I','Decreases the cycle time on Ice Harvester but causes them to use up more CPU.',1,5,0,1,NULL,40456.0000,1,935,0),(22577,1139,'Ice Harvester Upgrade I Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,937,0),(22578,1218,'Mining Upgrades','Skill at using mining upgrades. 5% reduction per skill level in CPU penalty of mining upgrade modules.',0,0.01,0,1,NULL,80000.0000,1,1323,0),(22609,546,'Erin Mining Laser Upgrade','Increases the yield on mining lasers, but causes them to use up more CPU.',1,5,0,1,4,24960.0000,0,NULL,0),(22611,546,'Elara Restrained Mining Laser Upgrade','Increases the yield on mining lasers, but causes them to use up more CPU.',1,5,0,1,4,24960.0000,1,935,0),(22613,546,'\'Carpo\' Mining Laser Upgrade','Increases the yield on mining lasers, but causes them to use up more CPU.',1,5,0,1,4,24960.0000,1,935,0),(22615,546,'\'Aoede\' Mining Laser Upgrade','Increases the yield on mining lasers, but causes them to use up more CPU.',1,5,0,1,4,24960.0000,1,935,0),(22617,546,'Crisium Ice Harvester Upgrade','Decreases the cycle time on Ice Harvester but causes them to use up more CPU.',1,5,0,1,4,24960.0000,0,NULL,0),(22619,546,'Frigoris Restrained Ice Harvester Upgrade','Decreases the cycle time on Ice Harvester but causes them to use up more CPU.',1,5,0,1,4,24960.0000,1,935,0),(22621,546,'\'Anguis\' Ice Harvester Upgrade','Decreases the cycle time on Ice Harvester but causes them to use up more CPU.',1,5,0,1,4,24960.0000,1,935,0),(22623,546,'\'Ingenii\' Ice Harvester Upgrade','Decreases the cycle time on Ice Harvester but causes them to use up more CPU.',1,5,0,1,4,24960.0000,1,935,0),(22625,517,'Kaiko Maina (Merlin)','A Merlin piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(22629,517,'Emma Tharkin (MOA)','A Moa piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(22630,517,'Zoun Makui (Scorpion)','A Scorpion piloted by an agent.',115000000,1040000,550,1,1,0.0000,0,NULL,0),(22631,517,'Mutama Czeik\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22632,517,'Thora Desto\'s Rupture','A Rupture piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22633,517,'Makor Desto\'s Tempest','A Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22634,438,'Medium Biochemical Reactor Array','An arena for various different substances to mix and match. The Biochemical Reactor Array is where biochemical processes take place that can turn a simple element into a complex chemical.\r\r\n\r\r\nThe Medium Biochemical Reactor array may only contain simple biochemical reactions.',100000000,4000,1,1,NULL,12500000.0000,1,490,0),(22635,517,'Jordan Usquen\'s Tristan','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(22636,517,'Cosmos Celestis','A Celestis piloted by an agent.',12500000,116000,320,1,8,0.0000,0,NULL,0),(22637,517,'Babalu Wrezka\'s Celestis','A Celestis piloted by an agent.',12500000,116000,320,1,8,0.0000,0,NULL,0),(22638,517,'Cosmos Dominix','A Dominix piloted by an agent.',105000000,1010000,600,1,8,0.0000,0,NULL,0),(22639,517,'Timmothy Sawyr\'s Dominix','A Dominix piloted by an agent.',105000000,1010000,600,1,8,0.0000,0,NULL,0),(22640,517,'Mandor Neek\'s Punisher','An Punisher piloted by an agent.',1425000,28600,135,1,4,0.0000,0,NULL,0),(22641,517,'Jeeta Neek\'s Omen','An Omen piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(22642,517,'Cosmos Armageddon','An Armageddon piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(22643,517,'Zaestra Kuramor\'s Armageddon','An Armageddon piloted by an agent.',110000000,1100000,600,1,4,0.0000,0,NULL,0),(22644,517,'Skami Zarton\'s Dramiel','A Dramiel piloted by an agent.',1645000,27289,130,1,2,0.0000,0,NULL,0),(22645,517,'Numa Fashit\'s Cynabal','A Cynabal piloted by an agent.',10100000,101000,250,1,2,0.0000,0,NULL,0),(22646,517,'Kardimo Menka Machariel','A Machariel piloted by an agent.',110000000,1080000,665,1,2,0.0000,0,NULL,0),(22647,517,'Pol Pat\'s Rattlesnake','A Rattlesnake piloted by an agent.',110000000,1080000,665,1,1,0.0000,0,NULL,0),(22648,517,'Jakuzi Makar\'s Gila','A Gila piloted by an agent.',10100000,101000,250,1,1,0.0000,0,NULL,0),(22649,517,'Ippana Maltyr\'s Worm','A Worm piloted by an agent.',2140000,16500,130,1,1,0.0000,0,NULL,0),(22650,517,'Jaquon Jalibar\'s Daredevil','A Daredevil piloted by an agent.',1330000,26500,140,1,2,0.0000,0,NULL,0),(22651,517,'Luthetion Preque\'s Vigilant','A Vigilant piloted by an agent.',10100000,101000,250,1,8,0.0000,0,NULL,0),(22652,517,'Hara Lafleur\'s Vindicator','A Vindicator piloted by an agent.',110000000,1080000,665,1,8,0.0000,0,NULL,0),(22653,517,'Miguel Maktar\'s Succubus','A Succubus piloted by an agent.',2860000,28600,135,1,4,0.0000,0,NULL,0),(22654,517,'Karhoum Ykta\'s Phantasm','A Phantasm piloted by an agent.',10100000,101000,250,1,4,0.0000,0,NULL,0),(22655,517,'Ophana Zett\'s Nightmare','A Nightmare piloted by an agent.',110000000,1080000,665,1,4,0.0000,0,NULL,0),(22656,517,'Farak Kali\'s Cruor','An Cruor piloted by an agent.',2860000,28600,135,1,4,0.0000,0,NULL,0),(22657,517,'Unnaya Mafir\'s Ashimmu','An Ashimmu piloted by an agent.',12000000,118000,280,1,4,0.0000,0,NULL,0),(22658,517,'Sari Arkhi\'s Bhaalgorn','A Bhaalgorn piloted by an agent.',107500000,1150000,675,1,4,0.0000,0,NULL,0),(22661,520,'COSMOS Gallente Mercenary',' ',2250000,22500,125,1,8,0.0000,0,NULL,0),(22662,520,'COSMOS Gallente Patroller',' ',2250000,22500,235,1,8,0.0000,0,NULL,0),(22663,520,'COSMOS Gallente Sentinel',' ',2950000,29500,235,1,8,0.0000,0,NULL,0),(22664,520,'COSMOS Gallente Defender',' ',2300000,23000,235,1,8,0.0000,0,NULL,0),(22665,520,'COSMOS Gallente Soldier',' ',2650000,26500,235,1,8,0.0000,0,NULL,0),(22666,520,'COSMOS Gallente Elite Frigate','An elite frigate of the Serpentis',2650000,26500,140,1,8,0.0000,0,NULL,0),(22667,522,'COSMOS Gallente Drug Baron',' ',11600000,116000,900,1,8,0.0000,0,NULL,0),(22668,522,'COSMOS Gallente Chief Protector',' ',11200000,112000,480,1,8,0.0000,0,NULL,0),(22669,522,'COSMOS Gallente Sentry','\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(22670,522,'COSMOS Gallente Captain',' ',11200000,112000,480,1,8,0.0000,0,NULL,0),(22671,523,'COSMOS Gallente Enforcer',' ',17500000,1140000,480,1,8,0.0000,0,NULL,0),(22672,523,'COSMOS Gallente Commodore',' ',17500000,1140000,480,1,8,0.0000,0,NULL,0),(22673,520,'COSMOS Gallente Non-Pirate Elite Frigate','An elite Ares-class interceptor, designed by Roden Shipyards',2650000,26500,140,1,8,0.0000,0,NULL,0),(22674,522,'COSMOS Gallente Non-Pirate Cruiser','The Thorax-class cruisers are the latest combat ships commissioned by the Federation. In the few times it has seen action since its christening, it has performed admirably. The hordes of combat drones it carries allow it to strike against unwary opponents far away and to easily fight many opponents at the same time. Threat level: Deadly',11280000,112000,265,1,8,0.0000,0,NULL,0),(22675,523,'COSMOS Gallente Non-Pirate Battleship','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.\r\r\n  Threat level: Deadly',19000000,1140000,675,1,8,0.0000,0,NULL,0),(22676,522,'COSMOS Pleasure Cruiser','A large pleasure cruiser, built for casual exploration of space while the inhabitants indulge themselves in various luxuries.',13075000,115000,3200,1,8,0.0000,0,NULL,0),(22677,517,'Cosmos Atron','An Atron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(22678,517,'Cosmos Imicus','An Imicus piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(22679,517,'Cosmos Helios','A Helios piloted by an agent.',1700000,19700,305,1,8,0.0000,0,NULL,0),(22680,517,'Cosmos Nemesis','A Nemesis piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(22681,517,'Cosmos Enyo','An Enyo piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(22682,517,'Cosmos Catalyst','A Catalyst piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(22683,517,'Cosmos Thorax','A Thorax piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(22685,517,'Cosmos Vexor','A Vexor piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(22686,517,'Cosmos Megathron','A Megathron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(22693,517,'Madibe Arnadi\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22694,517,'Tori Aman\'s Punisher','A Punisher piloted by an agent.',1425000,28600,135,1,4,0.0000,0,NULL,0),(22695,517,'Hakkuna Baille\'s Thorax','A Thorax piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(22696,517,'Testo Hrinz\'s Merlin','A Merlin piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(22699,517,'Zaknar Cente\'s Tristan','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(22700,517,'Bakkla Viftuin\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22701,526,'Minmatar Bluechip','\'Bluechip\' is a name for the data chips which store valuable information on what happened shortly before a structure, normally a space structure, has been destroyed.  Introduced by Gallantean mining corporations after they endured numerous inexplicable losses of their mining barges in deep space, the Bluechip has become universally used due to its incredible survivability.  \r\r\n\r\r\nIf the Bluechip survives an explosion or crash, researchers can usually quickly determine the cause of the accident.  ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22704,494,'General Minas Iksan','Minas Iksan is a vetern war hero of the Amarr Empire.  He led the fleet that defeated the largest Blood Raider armada ever to attack an Amarrian settlement eight years ago. His credentials also include over 40 years of dedicated service to the Imperial Navy. Born of Royalty, his place as a commander of the military was quickly established upon his entrance into the Imperial Academy.\r\n\r\nMinas now leads the Amarr/Ammatar/Khanid/Caldari campaign against the Minmatar and their allies in Audesder.',1125000000,18500000,7250,1,4,0.0000,0,NULL,0),(22705,526,'Minas\'s Voucher','This voucher was given to all recruitment officers by General Minas Iksan.  Any mercenary with one of these vouchers who is well regarded by the Amarr Empire should speak with Minas Iksan for possible employment.',1,1,0,1,NULL,0.0000,1,NULL,0),(22706,677,'Gallente Spy Drone','This fragile high-tech drone is frequently used in Gallente espionage missions.',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22707,526,'Oggiin Kalda\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the Minmatar collaberator, Oggiin Kalda.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22708,283,'Amarrian Spy','A spy working for the Amarr Empire.',80,1,0,1,NULL,0.0000,1,NULL,0),(22709,494,'Minmatar Starbase Control Tower','The Matari aren\'t really that high-tech, preferring speed rather than firepower or involved technology. Unfortunately that doesn\'t apply very well to stationary objects, much to the liking of the Amarr Empire.\r\r\n\r\r\nAmarrians call it a scrapheap of epic proportions. But don\'t underestimate these structures. Minmatar commanders usually have the last laugh when it comes to combat.',100000,1150,8850,1,2,0.0000,0,NULL,0),(22710,494,'Minmatar Command Post','Outfitted with makeshift sensor arrays and second-hand tactical data analysis equipment, these outposts will, to anyone not in the know, look like useless scrapyards.  Which is exactly what the Matari would have you think.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(22711,319,'Extremely Powerful EM Forcefield_2','A reinforced antimatter generator powered by muonal crystals, creating a perfect circle of electro-magnetic radiance penetrable only by a coordinated attack from the strongest armaments.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22712,319,'Republic Fleet Naglfar - Under Construction','This mighty behemoth of a ship is currently under construction.  Only the last few touches of polish remain before it is ready for test flight.',1025000000,15500000,10250,1,2,0.0000,0,NULL,0),(22713,545,'10mn webscramblifying Drone','Warp Scrambling Drone',3000,5,1200,1,NULL,2000.0000,0,NULL,0),(22715,783,'Republic Special Ops Field Enhancer - Gamma','This image processor implanted in the parietal lobe grants a +4 bonus to one\'s Willpower and a 5% bonus to the ship\'s maximum speed.',0,1,0,1,NULL,0.0000,1,620,0),(22716,821,'General Matar Pol','The Tempest battleship can become a real behemoth when fully equipped.\r\r\nThreat level: Deadly',21000000,850000,600,1,2,0.0000,0,NULL,0),(22718,319,'Minas Iksan\'s Revelation_old','General Minas Iksan is the highest ranking officer of the Amarr forces and their allies stationed in Kenobanala.  His responsibility is to see to it that the \'Tyrion incident\' is resolved, and to lead his armada into Audesder should it come to all-out-war.\r\r\n\r\r\nMinas commands a Revelation.  It represents the pinnacle of Amarrian military technology.  Maintaining their proud tradition of producing the strongest armor plating to be found anywhere, the Empire\'s engineers outdid themselves in creating what is arguably the most resilient dreadnought in existence.\r\r\n\r\r\nAdded to that, the Revelation\'s ability to fire capital beams makes its position on the battlefield a unique one.  When extended sieges are the order of the day, this is the ship you call in.',1125000000,18500000,7250,1,4,0.0000,0,NULL,0),(22719,517,'Minas Iksan\'s Control Tower','General Minas Iksan is the highest ranking officer of the Amarr forces and their allies stationed in Kenobanala.  His responsibility is to see to it that the \'Tyrion incident\' is resolved, and to lead his armada into Audesder should it come to all-out-war.\r\r\n\r\r\nMinas commands a Revelation, which is currently undergoing maintenance.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 8.5</b> ',100000,100000000,10000,1,4,0.0000,0,NULL,0),(22725,494,'Oggiin Kalda\'s Residence','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22726,517,'Oggiin Kalda\'s Maller','A Maller piloted by an agent.',12750000,118000,280,1,4,0.0000,0,NULL,0),(22728,306,'Minmatar Bunker_Alliance Barracks','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22729,803,'Strain Domination Drone Replica','Rogue drones are hi-tech drones that have the ability to manufacture themselves. These drones are however simply a replica of known rogue drone types, created by the Amarr military .  These drone replicas are simply configured to patrol this small asteroid field and defend themselves if neccessary.  They are in essence powerful training drones.',100000,60,1200,1,NULL,0.0000,0,NULL,0),(22730,314,'Amarr Training Certification Results','These complicated data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.',1,1,0,1,NULL,0.0000,1,NULL,0),(22734,517,'Krard Wengalill\'s Punisher','A Punisher piloted by an agent.',1425000,28600,135,1,4,0.0000,0,NULL,0),(22735,517,'Nuo Tuotura\'s Kestrel','A Kestrel piloted by an agent.',1700000,19700,305,1,1,0.0000,0,NULL,0),(22736,517,'Zama Fedas\'s Khanid Punisher','A Punisher piloted by an agent.',1425000,28600,135,1,4,0.0000,0,NULL,0),(22737,517,'Ison Tiadala\'s Tempest','A Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22738,526,'Ison\'s Voucher','This voucher was given to all recruitment officers by Warlord Ison Tiadala.  Any mercenary with one of these vouchers who is well regarded by the Minmatar Republic should speak with Ison Tiadala for possible employment.',1,1,0,1,NULL,0.0000,1,NULL,0),(22739,494,'Caldari Broadcasting Unit','This broadcasting unit is being used by the Caldari military to send messages of propoganda to the Minmatar alliance, aimed at lowering morale and causing dissent amongst the army.  Quite a common tactic amongst the Caldari.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22740,526,'Caldari P.A. Keycard','Key to gain entry to the Caldari Broadcasting unit in Audesder.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22741,526,'Caldari P.A. Keycard Replica','Key to gain entry to the Caldari Broadcasting unit in Audesder.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22742,319,'Asteroid Construct Minor','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22743,319,'Asteroid Colony Minor','Highly vulnerable, but economically extremely feasible, asteroid factories are one of the major boons of the expanding space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22744,319,'Asteroid Micro-Colony Minor','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22750,494,'Kameira Quarters','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22751,526,'Khanid Ext Keycard',' ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22752,283,'Khanid Commander',' ',90,1,0,1,NULL,0.0000,1,NULL,0),(22753,691,'Khanid Kazmaar_2','The legendary Khanid Kazmaar is reserved for the leaders within the Khanid Royalty.  Few have witnessed its awesome majesty, as it is only used on special occasions.',19000000,1150000,235,1,4,0.0000,0,NULL,0),(22754,526,'Gallente Intelligence Data Recorder','A data recorder used by the Gallente Navy Intelligence division.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22755,306,'Army Quarters','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22756,526,'Khanid Commander Keycard',' ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(22757,494,'Scanner Post','This piece of equipment emanates waves from its built-in broadcasting beacon. It is fitted with a small shield module and appears to be coated with a thin layer of armored plates.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22758,319,'Revelation - Under Construction','The Revelation represents the pinnacle of Amarrian military technology.  Maintaining their proud tradition of producing the strongest armor plating to be found anywhere, the Empire\'s engineers outdid themselves in creating what is arguably the most resilient dreadnought in existence.\r\r\n\r\r\nThis particular Revelation is currently in the last stages of the construction process.',1125000000,18500000,7250,1,4,0.0000,0,NULL,0),(22759,821,'Baron Haztari Arkhi','Designed by master starship engineers and constructed in the royal shipyards of the Emperor himself, the imperial issue of the dreaded Apocalypse battleship is held in awe throughout the Empire. Given only as an award to those who have demonstrated their fealty to the Emperor in a most exemplary way, it is considered a huge honor to command, let alone own, one of these majestic and powerful battleships. ',17500000,1150000,675,1,4,0.0000,0,NULL,0),(22760,783,'Imperial Special Ops Field Enhancer - Standard','This image processor implanted in the occipital lobe grants a +4 bonus to a character\'s Perception. Also grants a +5% bonus to your ship\'s armor.',0,1,0,1,NULL,0.0000,1,618,0),(22761,257,'Recon Ships','Skill for the operation of Recon Ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,32000000.0000,1,377,0),(22762,517,'Ison Tiadala\'s Naglfar','Ison Tiadala is the leader of the Minmatar and Gallente army stationed in Audesder.  Her assignment is to defend the solarsystem from any enemy incursions.  She was ordered by the Republic, as were hundreds of thousands of other military personnel, to relocate herself to Audesder due to the volatile political situation in the region.\r\r\n\r\r\nIson is a veteran on the battlefield, despite her relatively young age.  Displaying remarkable ability as a field commander, she quickly rose up in the military ranks of the Minmatar Republic.  She commands a mighty Naglfar dreadnought, which is feared in all corners of the galaxy.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 8.5</b> ',1025000000,15500000,10250,1,2,0.0000,0,NULL,0),(22763,517,'Fassara Nazarut\'s Slicer','A Slicer piloted by an agent.',1810000,16500,130,1,4,0.0000,0,NULL,0),(22764,314,'Minmatar Training Certification Results','These complicated data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.',1,1,0,1,NULL,0.0000,1,NULL,0),(22765,640,'Heavy Shield Maintenance Bot I','Shield Maintenance Drone',3000,25,0,1,NULL,111114.0000,1,842,0),(22766,1144,'Heavy Shield Maintenance Bot I Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1030,0),(22767,517,'Wirdar Erazako\'s Firetail','A Firetail piloted by an agent.',2140000,16500,130,1,2,0.0000,0,NULL,0),(22768,517,'Daemire Adamia\'s Tristan','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(22769,517,'Aville Ancare\'s Comet','A Comet piloted by an agent.',2040000,26500,140,1,8,0.0000,0,NULL,0),(22770,517,'Rasnik\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22771,517,'Akoto\'s Kestrel','A Kestrel piloted by an agent.',1700000,19700,305,1,1,0.0000,0,NULL,0),(22772,517,'Rikkolen\'s Heron','A Heron piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(22773,517,'Arkiso\'s Hawk','A Hawk piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(22774,517,'Rekkai\'s Moa','A Moa piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(22775,517,'Hokoru\'s Blackbird','A Blackbird piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(22778,548,'Warp Disrupt Probe','Deployed from an Interdiction Sphere Launcher fitted to an Interdictor this probe prevents warping from within its area of effect.',1,5,0,2,NULL,73876.0000,1,1201,0),(22779,486,'Warp Disrupt Probe Blueprint',' ',0,0.01,0,1,NULL,2344200.0000,1,1529,0),(22780,549,'Fighter Uno','Fighter drone for carriers',12000,5000,0,1,NULL,106788.0000,0,NULL,0),(22781,176,'Fighter Uno Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(22782,589,'Interdiction Sphere Launcher I','Built for use with interdictor-class vessels, this launcher produces a warp disruption sphere capable of pulling passing vessels out of warp.\r\r\n\r\r\nLimited to one per ship.',0,50,15,1,NULL,3259222.0000,1,1937,0),(22783,136,'Interdiction Sphere Launcher I Blueprint',' ',0,0.01,0,1,NULL,17328680.0000,1,1940,0),(22788,283,'Amarr Reporter',' ',80,2,0,1,NULL,0.0000,1,NULL,0),(22789,705,'Minmatar Transport Ship_2','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',89000000,890000,2000,1,2,0.0000,0,NULL,0),(22791,306,'Ship Wreckage4','The mangled wreck floats motionless in space, surrounded with a field of scorched debris.',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(22792,283,'Amarrian Agent','An agent working for the Amarr Empire.',1000,2,0,1,NULL,0.0000,1,NULL,0),(22793,526,'Amarr Corpse','The corpse of someone with Amarrian ancestry.',80,1,0,1,NULL,0.0000,1,NULL,0),(22794,494,'Habitation Module','A local prison facility.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(22795,526,'Gallente Corpse','The corpse of someone with Gallentean ancestry.',80,1,0,1,NULL,0.0000,1,NULL,0),(22796,283,'Gallente Reporter','A reporter working for The Scope.',1000,2,0,1,NULL,0.0000,1,NULL,0),(22797,498,'Independent Shielding','Servitor are Self contained Expert Systems used to radicaly alter the functionlity of a specific core system. These Systems are quite large but being self contained they connect to the ship though a Dedicated interface node without any disruption to the ships power and computer systems.   ',1,5,0,1,NULL,0.0000,0,NULL,0),(22799,306,'Ship Wreckage5','The mangled wreck floats motionless in space, surrounded with a field of scorched debris.',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(22800,673,'Caldari Military Transport','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',96000000,960000,2300,1,1,0.0000,0,NULL,0),(22801,283,'Amarr Light Marines','When war breaks out, the demand for transporting military personnel on site can exceed the grasp of the military organization. In these cases, the aid from non-military spacecrafts is often needed.',1000,2,0,1,NULL,0.0000,1,NULL,0),(22802,283,'Gallente Light Marines','When war breaks out, the demand for transporting military personnel on site can exceed the grasp of the military organization. In these cases, the aid from non-military spacecrafts is often needed.',1000,2,0,1,NULL,0.0000,1,NULL,0),(22803,283,'Minmatar Light Marines','When war breaks out, the demand for transporting military personnel on site can exceed the grasp of the military organization. In these cases, the aid from non-military spacecrafts is often needed.',1000,2,0,1,NULL,0.0000,1,NULL,0),(22804,283,'Caldari Light Marines','When war breaks out, the demand for transporting military personnel on site can exceed the grasp of the military organization. In these cases, the aid from non-military spacecrafts is often needed.',1000,2,0,1,NULL,0.0000,1,NULL,0),(22806,1210,'EM Armor Compensation','5% bonus to EM resistance per level for Armor Coatings and Energized Platings',0,0.01,0,1,NULL,120000.0000,1,1745,0),(22807,1210,'Explosive Armor Compensation','5% bonus to explosive resistance per level for Armor Coatings and Energized Platings',0,0.01,0,1,NULL,120000.0000,1,1745,0),(22808,1210,'Kinetic Armor Compensation','5% bonus to kinetic resistance per level for Armor Coatings and Energized Platings',0,0.01,0,1,NULL,120000.0000,1,1745,0),(22809,1210,'Thermic Armor Compensation','5% bonus to thermal resistance per level for Armor Coatings and Energized Platings',0,0.01,0,1,NULL,120000.0000,1,1745,0),(22812,575,'Angel Shatterer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22813,575,'Angel Defacer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22814,575,'Angel Haunter','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22815,575,'Angel Defiler','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22816,575,'Angel Seizer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22817,575,'Angel Trasher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22818,550,'Arch Angel Ruffian','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',1766000,17660,120,1,2,0.0000,0,NULL,0),(22819,550,'Arch Angel Nomad','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',1750000,17500,180,1,2,0.0000,0,NULL,0),(22820,551,'Angel Phalanx','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22821,551,'Angel Centurion','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22822,576,'Angel Legionnaire','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22823,576,'Angel Primus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22824,576,'Angel Tribuni','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22825,576,'Angel Praefectus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22826,576,'Angel Tribunus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22827,576,'Angel Legatus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22828,551,'Arch Angel Depredator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',9900000,99000,1900,1,2,0.0000,0,NULL,0),(22829,551,'Arch Angel Predator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',9900000,99000,120,1,2,0.0000,0,NULL,0),(22830,551,'Arch Angel Marauder','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22831,551,'Arch Angel Liquidator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22832,551,'Arch Angel Phalanx','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22833,551,'Arch Angel Centurion','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22834,550,'Arch Angel Ambusher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1910000,19100,120,1,2,0.0000,0,NULL,0),(22835,550,'Arch Angel Raider','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,2,0.0000,0,NULL,0),(22836,550,'Arch Angel Hunter','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1910000,19100,80,1,2,0.0000,0,NULL,0),(22837,550,'Arch Angel Impaler','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22838,552,'Angel Saint','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22839,552,'Angel Nephilim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22840,552,'Angel Malakim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22841,552,'Angel Throne','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22842,552,'Angel Cherubim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22843,552,'Angel Seraphim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22844,517,'Tagrina Angi\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(22845,517,'Kaeg Zkaen\'s Omen','An Omen piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(22847,283,'Minmatar Civilians','When war breaks out, the demand for transporting military personnel on site can exceed the grasp of the military organization. In these cases, the aid from non-military spacecrafts is often needed.',1000,5,0,1,NULL,0.0000,1,NULL,0),(22848,383,'Gallente Sentry Gun - Training','Gallente ion blaster cannon sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(22849,306,'Drifting Cask - Minmatar Training Facility','The worn container drifts quietly in space, waiting patiently to be pried open by a hungry looter.',10000,1200,1400,1,NULL,0.0000,0,NULL,0),(22852,659,'Hel','Inspired by a vicious scissor-toothed shark indigenous to old-world Matar, the Hel is widely viewed as a sign of a Republic out for blood.  Since the beginning of its development it has remained a project cloaked in secrecy, with precious few people aware of its progress and its capabilities, and its formal unveiling has come as a defiant slap in the face to many who formerly believed the Matari incapable of working at this scale of starship design.  \r\r\n\r\r\nWhatever comprises the soil of its roots, though, one thing is clear: from no-frills living quarters to grim, unadorned aesthetic, this ferocious behemoth has been designed for one purpose and one purpose only.\r\r\n\r\r\n Imagine a swarm of deadly hornets pouring from the devil\'s mouth.  Now imagine they have autocannons. \r\r\n<i>-Unknown Hel designer</i>\r\r\n\r\r\n',1409375000,51000000,1360,1,2,19741317508.0000,1,821,0),(22853,1013,'Hel Blueprint',' ',0,0.01,0,1,NULL,19000000000.0000,1,891,0),(22857,794,'Domination Shatterer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22858,794,'Domination Defacer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22859,794,'Domination Haunter','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22860,794,'Domination Defiler','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22861,794,'Domination Seizer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22862,794,'Domination Trasher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(22865,793,'Domination Legionnaire','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22866,793,'Domination Primus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22867,793,'Domination Tribuni','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22868,793,'Domination Praefectus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22869,793,'Domination Tribunus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22870,793,'Domination Legatus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(22871,848,'Domination Malakim','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22872,848,'Domination Throne','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22873,848,'Domination Cherubim','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22874,848,'Domination Seraphim','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(22875,315,'\'Aura\' Warp Core Stabilizer I','When installed this unit attempts to compensate for fluctuations and disruptions of the ship\'s warp core.',0,5,0,1,NULL,11116.0000,1,1088,0),(22876,342,'\'Aura\' Warp Core Stabilizer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22877,315,'\'Natura\' Warp Core Stabilizer I','When installed this unit attempts to compensate for fluctuations and disruptions of the ship\'s warp core.',0,5,0,1,NULL,11116.0000,1,1088,0),(22878,342,'\'Natura\' Warp Core Stabilizer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22879,326,'\'Pilfer\' Energized Adaptive Nano Membrane I','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,120202.0000,1,1686,0),(22880,163,'\'Pilfer\' Energized Adaptive Nano Membrane I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22881,326,'\'Moonshine\' Energized Thermic Membrane I','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1683,0),(22882,163,'\'Moonshine\' Energized Thermic Membrane I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22883,326,'\'Mafia\' Energized Kinetic Membrane I','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1685,0),(22884,163,'\'Mafia\' Energized Kinetic Membrane I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22885,341,'Stealth System I','Scrambles the signature of a ship preventing tracking systems from identifing the ships shape and thus reducing their effectiveness. ',0,10,0,1,NULL,366.0000,0,NULL,0),(22886,120,'Stealth System I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(22887,62,'\'Harmony\' Small Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,36788.0000,1,1049,0),(22888,142,'\'Harmony\' Small Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22889,62,'\'Meditation\' Medium Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,44214.0000,1,1050,0),(22890,142,'\'Meditation\' Medium Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22891,62,'\'Protest\' Large Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,NULL,88788.0000,1,1051,0),(22892,142,'\'Protest\' Large Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22893,60,'\'Gonzo\' Damage Control I','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,NULL,5372.0000,1,615,0),(22894,140,'\'Gonzo\' Damage Control I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22895,202,'\'Shady\' ECCM - Gravimetric I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,725,0),(22896,131,'\'Shady\' ECCM - Gravimetric I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22897,202,'\'Forger\' ECCM - Magnetometric I','A secondary electronic array that provides a significant boost to sensor strength for a short time. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27776.0000,1,727,0),(22898,131,'\'Forger\' ECCM - Magnetometric I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22899,74,'\'Corporate\' Light Electron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.5,1,NULL,8488.0000,1,561,0),(22900,154,'\'Corporate\' Light Electron Blaster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22901,74,'\'Dealer\' Light Ion Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.3,1,NULL,9958.0000,1,561,0),(22902,154,'\'Dealer\' Light Ion Blaster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22903,74,'\'Racket\' Light Neutron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',500,5,0.2,1,NULL,13320.0000,1,561,0),(22904,154,'\'Racket\' Light Neutron Blaster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(22905,74,'\'Slither\' Heavy Electron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,2.5,1,NULL,73954.0000,1,562,0),(22906,154,'\'Slither\' Heavy Electron Blaster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22907,74,'\'Hooligan\' Heavy Ion Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',1000,10,1.5,1,NULL,99930.0000,1,562,0),(22908,154,'\'Hooligan\' Heavy Ion Blaster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22909,74,'\'Hustler\' Heavy Neutron Blaster I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',100,10,1,1,NULL,133234.0000,1,562,0),(22910,154,'\'Hustler\' Heavy Neutron Blaster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22911,74,'\'Swindler\' Electron Blaster Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,5,1,NULL,683790.0000,1,563,0),(22912,154,'\'Swindler\' Electron Blaster Cannon I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22913,74,'\'Felon\' Ion Blaster Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,3,1,NULL,1116734.0000,1,563,0),(22914,154,'\'Felon\' Ion Blaster Cannon I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22915,74,'\'Underhand\' Neutron Blaster Cannon I','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nRequires hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium.',2000,20,2,1,NULL,1568334.0000,1,563,0),(22916,154,'\'Underhand\' Neutron Blaster Cannon I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22917,302,'\'Capitalist\' Magnetic Field Stabilizer I','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27772.0000,1,648,0),(22918,139,'\'Capitalist\' Magnetic Field Stabilizer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22919,302,'\'Monopoly\' Magnetic Field Stabilizer I','Grants a bonus to the firing rate and damage of hybrid turrets. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,27772.0000,1,648,0),(22920,139,'\'Monopoly\' Magnetic Field Stabilizer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22921,54,'\'Habitat\' Miner I','Basic mining laser. Extracts common ore quickly, but has difficulty with the more rare types.',0,5,0,1,NULL,10304.0000,1,NULL,0),(22922,134,'\'Habitat\' Miner I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(22923,54,'\'Wild\' Miner I','Basic mining laser. Extracts common ore quickly, but has difficulty with the more rare types.',0,5,0,1,NULL,10304.0000,1,NULL,0),(22924,134,'\'Wild\' Miner I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22925,289,'\'Bootleg\' ECCM Projector I','ECCM Projectors utilize a sophisticated system of electronics to fortify the sensor strengths of an allied ship allowing it to overcome jamming.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,44396.0000,1,686,0),(22926,131,'\'Bootleg\' ECCM Projector I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22927,213,'\'Economist\' Tracking Computer I','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,18282.0000,1,706,0),(22928,224,'\'Economist\' Tracking Computer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22929,213,'\'Marketeer\' Tracking Computer I','By predicting the trajectory of targets, it helps to boost the tracking speed and range of turrets. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,18282.0000,1,706,0),(22930,224,'\'Marketeer\' Tracking Computer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22931,291,'\'Distributor\' Tracking Disruptor I','Disrupts the turret range and tracking speed of the target ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,47656.0000,1,680,0),(22932,343,'\'Distributor\' Tracking Disruptor I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22933,291,'\'Investor\' Tracking Disruptor I','Disrupts the turret range and tracking speed of the target ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,47656.0000,1,680,0),(22934,343,'\'Investor\' Tracking Disruptor I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22935,209,'\'Tycoon\' Remote Tracking Computer','Establishes a fire control link with another ship, thereby boosting the turret range and tracking speed of that ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,33284.0000,1,708,0),(22936,345,'\'Tycoon\' Remote Tracking Computer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22937,209,'\'Enterprise\' Remote Tracking Computer','Establishes a fire control link with another ship, thereby boosting the turret range and tracking speed of that ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,33284.0000,1,708,0),(22938,345,'\'Enterprise\' Remote Tracking Computer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22939,290,'\'Boss\' Remote Sensor Booster','Can only be activated on targets to increase their scan resolutions and boost their targeting range.  This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,44396.0000,1,673,0),(22940,223,'\'Boss\' Remote Sensor Booster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22941,290,'\'Entrepreneur\' Remote Sensor Booster','Can only be activated on targets to increase their scan resolutions and boost their targeting range.  This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,44396.0000,1,673,0),(22942,223,'\'Entrepreneur\' Remote Sensor Booster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22943,208,'\'Broker\' Remote Sensor Dampener I','Reduces the range and speed of a targeted ship\'s sensors. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,55560.0000,1,679,0),(22944,223,'\'Broker\' Remote Sensor Dampener I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22945,208,'\'Executive\' Remote Sensor Dampener I','Reduces the range and speed of a targeted ship\'s sensors. This module can be loaded with scripts to increase its effectiveness in certain areas.  \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,55560.0000,1,679,0),(22946,223,'\'Executive\' Remote Sensor Dampener I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22947,325,'\'Beatnik\' Small Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,5528.0000,1,1059,0),(22948,350,'\'Beatnik\' Small Remote Armor Repairer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22949,325,'\'Love\' Medium Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,13860.0000,1,1058,0),(22950,350,'\'Love\' Medium Remote Armor Repairer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22951,325,'\'Pacifier\' Large Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,50,0,1,NULL,34716.0000,1,1057,0),(22952,350,'\'Pacifier\' Large Remote Armor Repairer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22953,766,'\'Cartel\' Power Diagnostic System I','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,14544.0000,1,658,0),(22954,137,'\'Cartel\' Power Diagnostic System I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(22961,85,'Federation Navy Antimatter Charge S','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,1056.0000,1,993,0),(22963,85,'Federation Navy Plutonium Charge S','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.01,0.0025,0,100,NULL,848.0000,1,993,0),(22965,85,'Federation Navy Uranium Charge S','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.01,0.0025,0,100,NULL,778.0000,1,993,0),(22967,85,'Federation Navy Thorium Charge S','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.01,0.0025,0,100,NULL,660.0000,1,993,0),(22969,85,'Federation Navy Lead Charge S','Consists of two components: a shell of titanium and a core of lead atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.01,0.0025,0,100,NULL,524.0000,1,993,0),(22971,85,'Federation Navy Iridium Charge S','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.01,0.0025,0,100,NULL,428.0000,1,993,0),(22973,85,'Federation Navy Tungsten Charge S','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.01,0.0025,0,100,NULL,332.0000,1,993,0),(22975,85,'Federation Navy Iron Charge S','Consists of two components: a shell of titanium and a core of iron atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.01,0.0025,0,100,NULL,222.0000,1,993,0),(22977,85,'Federation Navy Antimatter Charge M','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.05,0.0125,0,100,NULL,4458.0000,1,992,0),(22979,85,'Federation Navy Plutonium Charge M','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.05,0.0125,0,100,NULL,3588.0000,1,992,0),(22981,85,'Federation Navy Uranium Charge M','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.05,0.0125,0,100,NULL,3042.0000,1,992,0),(22983,85,'Federation Navy Thorium Charge M','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.05,0.0125,0,100,NULL,2436.0000,1,992,0),(22985,85,'Federation Navy Lead Charge M','Consists of two components: a shell of titanium and a core of lead atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.05,0.0125,0,100,NULL,1832.0000,1,992,0),(22987,85,'Federation Navy Iridium Charge M','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.05,0.0125,0,100,NULL,1664.0000,1,992,0),(22989,85,'Federation Navy Tungsten Charge M','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.05,0.0125,0,100,NULL,1208.0000,1,992,0),(22991,85,'Federation Navy Iron Charge M','Consists of two components: a shell of titanium and a core of iron atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.05,0.0125,0,100,NULL,848.0000,1,992,0),(22993,85,'Federation Navy Antimatter Charge L','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.1,0.025,0,100,NULL,11132.0000,1,991,0),(22995,85,'Federation Navy Plutonium Charge L','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.1,0.025,0,100,NULL,8850.0000,1,991,0),(22997,85,'Federation Navy Uranium Charge L','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.1,0.025,0,100,NULL,7776.0000,1,991,0),(22999,85,'Federation Navy Thorium Charge L','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.1,0.025,0,100,NULL,6656.0000,1,991,0),(23001,85,'Federation Navy Lead Charge L','Consists of two components: a shell of titanium and a core of lead atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.1,0.025,0,100,NULL,5556.0000,1,991,0),(23003,85,'Federation Navy Iridium Charge L','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.1,0.025,0,100,NULL,4446.0000,1,991,0),(23005,85,'Federation Navy Tungsten Charge L','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.1,0.025,0,100,NULL,3184.0000,1,991,0),(23007,85,'Federation Navy Iron Charge L','Consists of two components: a shell of titanium and a core of iron atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.1,0.025,0,100,NULL,2210.0000,1,991,0),(23009,85,'Caldari Navy Antimatter Charge S','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.01,0.0025,0,100,NULL,1056.0000,1,993,0),(23011,85,'Caldari Navy Plutonium Charge S','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.01,0.0025,0,100,NULL,848.0000,1,993,0),(23013,85,'Caldari Navy Uranium Charge S','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.01,0.0025,0,100,NULL,778.0000,1,993,0),(23015,85,'Caldari Navy Thorium Charge S','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.01,0.0025,0,100,NULL,660.0000,1,993,0),(23017,85,'Caldari Navy Lead Charge S','Consists of two components: a shell of titanium and a core of lead atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.01,0.0025,0,100,NULL,524.0000,1,993,0),(23019,85,'Caldari Navy Iridium Charge S','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.01,0.0025,0,100,NULL,428.0000,1,993,0),(23021,85,'Caldari Navy Tungsten Charge S','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.01,0.0025,0,100,NULL,332.0000,1,993,0),(23023,85,'Caldari Navy Iron Charge S','Consists of two components: a shell of titanium and a core of iron atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.01,0.0025,0,100,NULL,222.0000,1,993,0),(23025,85,'Caldari Navy Antimatter Charge M','Consists of two components: a shell of titanium and a core of antimatter atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced optimal range.',0.05,0.0125,0,100,NULL,4458.0000,1,992,0),(23027,85,'Caldari Navy Plutonium Charge M','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.05,0.0125,0,100,NULL,3588.0000,1,992,0),(23029,85,'Caldari Navy Uranium Charge M','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.05,0.0125,0,100,NULL,3042.0000,1,992,0),(23031,85,'Caldari Navy Thorium Charge M','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.05,0.0125,0,100,NULL,2436.0000,1,992,0),(23033,85,'Caldari Navy Lead Charge M','Consists of two components: a shell of titanium and a core of lead atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.05,0.0125,0,100,NULL,1832.0000,1,992,0),(23035,85,'Caldari Navy Iridium Charge M','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.05,0.0125,0,100,NULL,1664.0000,1,992,0),(23037,85,'Caldari Navy Tungsten Charge M','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.05,0.0125,0,100,NULL,1208.0000,1,992,0),(23039,85,'Caldari Navy Iron Charge M','Consists of two components: a shell of titanium and a core of iron atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.05,0.0125,0,100,NULL,848.0000,1,992,0),(23041,85,'Caldari Navy Plutonium Charge L','Consists of two components: a shell of titanium and a core of plutonium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n5% reduced capacitor need.',0.1,0.025,0,100,NULL,8850.0000,1,991,0),(23043,85,'Caldari Navy Uranium Charge L','Consists of two components: a shell of titanium and a core of uranium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n25% reduced optimal range.\r\r\n8% reduced capacitor need.',0.1,0.025,0,100,NULL,7776.0000,1,991,0),(23045,85,'Caldari Navy Thorium Charge L','Consists of two components: a shell of titanium and a core of thorium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n40% reduced capacitor need.',0.1,0.025,0,100,NULL,6656.0000,1,991,0),(23047,85,'Caldari Navy Lead Charge L','Consists of two components: a shell of titanium and a core of lead atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n50% reduced capacitor need.',0.1,0.025,0,100,NULL,5556.0000,1,991,0),(23049,85,'Caldari Navy Iridium Charge L','Consists of two components: a shell of titanium and a core of iridium atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n20% increased optimal range.\r\r\n24% reduced capacitor need.',0.1,0.025,0,100,NULL,4446.0000,1,991,0),(23051,85,'Caldari Navy Tungsten Charge L','Consists of two components: a shell of titanium and a core of tungsten atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n40% increased optimal range.\r\r\n27% reduced capacitor need.',0.1,0.025,0,100,NULL,3184.0000,1,991,0),(23053,85,'Caldari Navy Iron Charge L','Consists of two components: a shell of titanium and a core of iron atoms suspended in plasma state. Railguns launch the shell directly, while particle blasters pump the plasma into a cyclotron and process the plasma into a bolt that is then fired.\r\r\n\r\r\n60% increased optimal range.\r\r\n30% reduced capacitor need.',0.1,0.025,0,100,NULL,2210.0000,1,991,0),(23055,549,'Templar','Amarr Fighter Craft',12000,5000,0,1,4,32949844.0000,1,840,0),(23056,1146,'Templar Blueprint',' ',0,0.01,0,1,NULL,200473400.0000,1,1028,0),(23057,549,'Dragonfly','Caldari Fighter Craft',12000,5000,0,1,1,32969896.0000,1,840,0),(23058,1146,'Dragonfly Blueprint',' ',0,0.01,0,1,NULL,203363320.0000,1,1028,0),(23059,549,'Firbolg','Gallente Fighter Craft',12000,5000,0,1,8,34161452.0000,1,840,0),(23060,1146,'Firbolg Blueprint',' ',0,0.01,0,1,NULL,213949920.0000,1,1028,0),(23061,549,'Einherji','Minmatar Fighter Craft',12000,5000,0,1,2,32523136.0000,1,840,0),(23062,1146,'Einherji Blueprint',' ',0,0.01,0,1,NULL,200013400.0000,1,1028,0),(23063,517,'Opeau\'s Celestis','A Celestis piloted by an agent.',12500000,116000,320,1,8,0.0000,0,NULL,0),(23064,517,'Arghe\'s Megathron','A Megathron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(23065,517,'Estacan\'s Tristan','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(23066,517,'Gallot\'s Atron','An Atron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(23067,517,'Lamuette\'s Nemesis','A Nemesis piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(23068,517,'Ardillan\'s Maulus','A Maulus piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(23069,273,'Fighters','Allows operation of fighter craft. 20% increase in fighter damage per level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,50000000.0000,1,366,0),(23070,517,'Nortul\'s Probe','A Probe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(23071,86,'Imperial Navy Multifrequency S','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,4000.0000,1,997,0),(23072,168,'Imperial Navy Multifrequency S Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(23073,86,'Imperial Navy Gamma S','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3508.0000,1,997,0),(23075,86,'Imperial Navy Xray S','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2532.0000,1,997,0),(23077,86,'Imperial Navy Ultraviolet S','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1628.0000,1,997,0),(23079,86,'Imperial Navy Standard S','Modulates the beam of a laser weapon into the visible light spectrum. \r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,1358.0000,1,997,0),(23081,86,'Imperial Navy Infrared S','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,1128.0000,1,997,0),(23083,86,'Imperial Navy Microwave S','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,2000.0000,1,997,0),(23085,86,'Imperial Navy Radio S','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,3008.0000,1,997,0),(23087,270,'Amarr Encryption Methods','Understanding of the data encryption methods used by the Amarr Empire and its allies.',0,0.01,0,1,NULL,0.0000,1,375,0),(23088,517,'Angetyn\'s Iteron Mark III','An Iteron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(23089,86,'Imperial Navy Multifrequency M','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,40072.0000,1,996,0),(23091,86,'Imperial Navy Gamma M','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,35160.0000,1,996,0),(23093,86,'Imperial Navy Xray M','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,26064.0000,1,996,0),(23095,86,'Imperial Navy Ultraviolet M','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,15648.0000,1,996,0),(23097,86,'Imperial Navy Standard M','Modulates the beam of a laser weapon into the visible light spectrum. \r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,12736.0000,1,996,0),(23099,86,'Imperial Navy Infrared M','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,10192.0000,1,996,0),(23101,86,'Imperial Navy Microwave M','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,20192.0000,1,996,0),(23103,86,'Imperial Navy Radio M','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,31062.0000,1,996,0),(23105,86,'Imperial Navy Multifrequency L','Randomly cycles the laser through the entire spectrum. The greatly increased damage comes at the cost of a significant reduction in range.\r\r\n\r\r\nWith shorter range, Thermal damage increases and the overall damage output is increased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n50% reduced optimal range.',1,1,0,1,NULL,443296.0000,1,995,0),(23107,86,'Imperial Navy Gamma L','Modulates the beam of a laser weapon into the gamma frequencies. Greatly reduced range. Greatly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n37.5% reduced optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,385880.0000,1,995,0),(23109,86,'Imperial Navy Xray L','Modulates the beam of a laser weapon into the xray frequencies. Reduced range. Increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n25% reduced optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,279152.0000,1,995,0),(23111,86,'Imperial Navy Ultraviolet L','Modulates the beam of a laser weapon into the ultraviolet frequencies. Slightly reduced range. Slightly increased thermal damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n12.5% reduced optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,166464.0000,1,995,0),(23113,86,'Imperial Navy Standard L','Modulates the beam of a laser weapon into the visible light spectrum. \r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n45% reduced capacitor need.',1,1,0,1,NULL,141320.0000,1,995,0),(23115,86,'Imperial Navy Infrared L','Modulates the beam of a laser weapon into the infrared frequencies. Slightly improved range. Slightly increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n20% increased optimal range.\r\r\n35% reduced capacitor need.',1,1,0,1,NULL,108552.0000,1,995,0),(23117,86,'Imperial Navy Microwave L','Modulates the beam of a laser weapon into the microwave frequencies. Improved range. Increased EM damage.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n40% increased optimal range.\r\r\n25% reduced capacitor need.',1,1,0,1,NULL,218720.0000,1,995,0),(23119,86,'Imperial Navy Radio L','Modulates the beam of a laser weapon into the radio frequencies. Offers greatly improved range but significantly lower damage.\r\r\n\r\r\nWith longer range, EM damage increases although the overall damage output is decreased.\r\r\n\r\r\nThe delicate crystalline structures used in the manufacture of this advanced crystal degrade with use, eventually causing it to shatter.\r\r\n\r\r\n60% increased optimal range.\r\r\n15% reduced capacitor need.',1,1,0,1,NULL,336522.0000,1,995,0),(23121,270,'Gallente Encryption Methods','Understanding of the data encryption methods used by the Gallente Federation and its allies.',0,0.01,0,1,NULL,0.0000,1,375,0),(23122,517,'Rupptofs\' Scythe','A Scythe piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(23123,270,'Takmahl Technology','Basic understanding of interfacing with Takmahl technology.\r\r\n\r\r\nThe Takmahl nation excelled in cybernetics and bio-engineering.\r\r\n\r\r\nAllows the rudimentary use of Takmahl components in the creation of advanced technology, even though the scientific theories behind them remain a mystery.',0,0.01,0,1,NULL,0.0000,1,375,0),(23124,270,'Yan Jung Technology','Basic understanding of interfacing with Yan Jung technology.\r\r\n\r\r\nThe Yan Jung nation possessed advanced gravitronic technology and force field theories.\r\r\n\r\r\nAllows the rudimentary use of Yan Jung components in the creation of advanced technology, even though the scientific theories behind them remain a mystery.',0,0.01,0,1,NULL,0.0000,1,375,0),(23125,517,'Formur\'s Tempest','A Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(23126,517,'Amakkit\'s Thrasher','A Thrasher piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(23127,517,'Ameisoure\'s Enyo','An Enyo piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(23128,528,'Yan Jung Crystal Cylinder',' ',1,0.1,0,1,NULL,0.0000,1,1904,0),(23129,528,'Yan Jung Paradox Box',' ',1,0.1,0,1,NULL,0.0000,1,1904,0),(23130,528,'Yan Jung Thunder Kite',' ',1,0.1,0,1,NULL,0.0000,1,1904,0),(23131,528,'Yan Jung Void Machine',' ',1,0.1,0,1,NULL,0.0000,1,1904,0),(23132,528,'Yan Jung Tachyon Stetoscope',' ',1,0.1,0,1,NULL,0.0000,1,1904,0),(23133,528,'Takmahl Phrenic Appendix',' ',1,0.1,0,1,NULL,0.0000,1,1905,0),(23134,528,'Takmahl Dynamic Gauge',' ',1,0.1,0,1,NULL,0.0000,1,1905,0),(23135,528,'Takmahl Gyro Ballast',' ',1,0.1,0,1,NULL,0.0000,1,1905,0),(23136,528,'Takmahl Biodroid Controller',' ',1,0.1,0,1,NULL,0.0000,1,1905,0),(23137,528,'Takmahl Quantum Sphere',' ',1,0.1,0,1,NULL,0.0000,1,1905,0),(23138,530,'Yan Jung Null Shell','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1904,0),(23139,530,'Yan Jung Glass Scale','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1904,0),(23140,530,'Yan Jung Plenary Wire','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1904,0),(23141,530,'Yan Jung Silk Armor','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1904,0),(23142,530,'Yan Jung Nano Fabric','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1904,0),(23143,530,'Takmahl Diamond Rod','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1905,0),(23144,530,'Takmahl Cohere Cord','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1905,0),(23145,530,'Takmahl Solid Mox','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1905,0),(23146,530,'Takmahl Magnetic Slab','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1905,0),(23147,530,'Takmahl Tri-polished Lens','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,1,0,1,NULL,0.0000,1,1905,0),(23148,528,'Blood Raider Limited Ballistic Control',' ',1,0.1,0,1,NULL,0.0000,1,1899,0),(23149,528,'Blood Raider Regular Ballistic Control',' ',1,0.1,0,1,NULL,0.0000,1,1899,0),(23150,528,'Blood Raider Extreme Ballistic Control',' ',1,0.1,0,1,NULL,0.0000,1,1899,0),(23151,528,'Blood Raider Weapon Integration Unit',' ',1,0.1,0,1,NULL,0.0000,1,1899,0),(23152,528,'Blood Raider Power Redistributor',' ',1,0.1,0,1,NULL,0.0000,1,1899,0),(23153,528,'Serpentis Plain Target Guider',' ',1,0.1,0,1,NULL,0.0000,1,1901,0),(23154,528,'Serpentis Basic Target Guider',' ',1,0.1,0,1,NULL,0.0000,1,1901,0),(23155,528,'Serpentis Complex Target Guider',' ',1,0.1,0,1,NULL,0.0000,1,1901,0),(23156,528,'Serpentis 3D Scanner Gamut',' ',1,0.1,0,1,NULL,0.0000,1,1901,0),(23157,528,'Serpentis Multi-tasking Processor',' ',1,0.1,0,1,NULL,0.0000,1,1901,0),(23158,530,'Positron Cord','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1899,0),(23159,530,'Auxiliary Parts','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1899,0),(23160,530,'Force Cable','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1899,0),(23161,530,'Elemental Crux','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1899,0),(23162,530,'Analog Panel','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1899,0),(23163,530,'Current Amplifier','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1901,0),(23164,530,'Second-hand Parts','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1901,0),(23165,530,'Heat Depressor','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1901,0),(23166,530,'Internal Bulkhead','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1901,0),(23167,530,'Mainframe Bit','Alloys and special materials used in the manufacture of modules based on Ancient technology.',1,0.1,0,1,4,0.0000,1,1901,0),(23168,733,'Yan Jung Info Matrix',' ',1,1,0,1,NULL,0.0000,1,1904,0),(23169,733,'Yan Jung Vellum Etch',' ',1,1,0,1,NULL,0.0000,1,1904,0),(23170,733,'Yan Jung Trigonometric Laws',' ',1,1,0,1,NULL,0.0000,1,1904,0),(23171,733,'Yan Jung Semiotic Theory',' ',1,1,0,1,NULL,0.0000,1,1904,0),(23172,733,'Yan Jung Singularity Fact Sheet',' ',1,1,0,1,NULL,0.0000,1,1904,0),(23173,734,'Takmahl Binary Texts',' ',1,1,0,1,NULL,0.0000,1,1905,0),(23174,734,'Takmahl Fractal Sheet',' ',1,1,0,1,NULL,0.0000,1,1905,0),(23175,734,'Takmahl Centrifugal Primer',' ',1,1,0,1,NULL,0.0000,1,1905,0),(23176,734,'Takmahl Geometric Design',' ',1,1,0,1,NULL,0.0000,1,1905,0),(23177,734,'Takmahl Astral Treatment',' ',1,1,0,1,NULL,0.0000,1,1905,0),(23178,728,'Occult Process','Allows for almost paint-by-numbers Amarr invention tasks, at the cost of blueprint quality. <br><br>Probability Multiplier: +10% <br>Max. Run Modifier: N/A <br>Material Efficiency Modifier: +3 <br>Time Efficiency Modifier: +6',1,1,0,1,NULL,0.0000,1,NULL,0),(23179,728,'Occult Accelerant','Unexceptional texts mostly aimed at rookie researchers wishing to increase the time efficiency of Amarr invention jobs. <br><br>Probability Multiplier: +20% <br>Max. Run Modifier: +1 <br>Material Efficiency Modifier: +2 <br>Time Efficiency Modifier: +10',1,1,0,1,NULL,0.0000,1,NULL,0),(23180,728,'Occult Symmetry','This decryptor contains true and tested research methods regarding Amarr invention jobs with decent stats across the board.<br><br>Probability Multiplier: N/A  <br>Max. Run Modifier: +2 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: +8',1,1,0,1,NULL,0.0000,1,NULL,0),(23181,728,'Occult Augmentation','Clever research technique that allows for refolding of blueprint materials in Amarr invention jobs. While the number of runs is greatly increased the probability of invention is adversely effected. <br><br>Probability Multiplier: -40% <br>Max. Run Modifier: +9 <br>Material Efficiency Modifier: -2 <br>Time Efficiency Modifier: +2',1,1,0,1,NULL,0.0000,1,NULL,0),(23182,728,'Occult Attainment','Dynamic guidelines for Amarr invention jobs, increasing the chance of success and number of runs greatly at a slight cost to material efficiency.<br><br>Probability Multiplier: +80% <br>Max. Run Modifier: +4 <br>Material Efficiency Modifier: -1 <br>Time Efficiency Modifier: +4',1,1,0,1,NULL,0.0000,1,NULL,0),(23183,730,'Incognito Process','The data found here can be utilized to increase overall efficiency in Gallente invention jobs.<br><br>Probability Multiplier: +10% <br>Max. Run Modifier: N/A <br>Material Efficiency Modifier: +3 <br>Time Efficiency Modifier: +6',1,1,0,1,NULL,0.0000,1,NULL,0),(23184,730,'Incognito Accelerant','If used in Gallente invention jobs this decryptor reduces the production time considerably.<br><br>Probability Multiplier: +20% <br>Max. Run Modifier: +1 <br>Material Efficiency Modifier: +2 <br>Time Efficiency Modifier: +10',1,1,0,1,NULL,0.0000,1,NULL,0),(23185,730,'Incognito Symmetry','Adds an interesting twist to Gallente invention jobs, that might make it a tad harder, but give great benefits if you succeed.<br><br>Probability Multiplier: N/A <br>Max. Run Modifier: +2 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: +8',1,1,0,1,NULL,0.0000,1,NULL,0),(23186,730,'Incognito Augmentation','Complex mismatch of numbers that won\'t make Gallente invention jobs any easier, but the number of runs you get will be great.<br><br>Probability Multiplier: -40% <br>Max. Run Modifier: +9 <br>Material Efficiency Modifier: -2 <br>Time Efficiency Modifier: +2',1,1,0,1,NULL,0.0000,1,NULL,0),(23187,730,'Incognito Attainment','Comprehensive decryptor for Gallente, that gives one of the best benefit possible to the probability of a successful invention.<br><br>Probability Multiplier: +80% <br>Max. Run Modifier: +4 <br>Material Efficiency Modifier: -1 <br>Time Efficiency Modifier: +4',1,1,0,1,NULL,0.0000,1,NULL,0),(23188,1207,'Yan Jung Data Log','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23189,1207,'Yan Jung Data Registry','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23190,1207,'Yan Jung Data Transcript','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23191,1207,'Yan Jung Data Records','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23192,1207,'Takmahl Data Log','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23193,1207,'Takmahl Data Registry','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23194,1207,'Takmahl Data Transcript','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23195,1207,'Takmahl Data Records','This look like a ancient data storage device of unknown origin. Detailed analysis might reveal more',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23196,1207,'Yan Jung Debris Fragment','This floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23197,1207,'Yan Jung Debris Part','This floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23198,1207,'Yan Jung Debris Segment','This floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23199,1207,'Yan Jung Debris Heap','This floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23200,1207,'Takmahl Debris Fragment','This floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23201,1207,'Takmahl Debris Part','This floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23202,1207,'Takmahl Debris Segment','This floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23203,1207,'Takmahl Debris Heap','This floating piece of debris looks like it might be of some value to the right person. Detailed analysis might reveal more.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23204,1207,'Basic Blood Raider Vault','A Blood Raider stasis security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security. ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23205,1207,'Standard Blood Raider Vault','A Blood Raider stasis security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security. ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23206,1207,'Secure Blood Raider Vault','A Blood Raider stasis security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security. ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23207,1207,'Fortified Blood Raider Vault','A Blood Raider stasis security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security. ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23208,1207,'Basic Serpentis Vault','A Serpentis stasis security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security.  ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23209,1207,'Standard Serpentis Vault','A Serpentis stasis security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security. ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23210,1207,'Secure Serpentis Vault','A Serpentis stasis security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security. ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23211,1207,'Fortified Serpentis Vault','A Serpentis stasis security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security. ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23212,306,'Blood Raider Network Node','This tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interesting information from its mainframe.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23213,306,'Blood Raider Network Hub','This tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interesting information from its mainframe.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23214,306,'Blood Raider Network Nucleus','This tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interesting information from its mainframe.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23215,306,'Blood Raider Network Nexus','This tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interesting information from its mainframe.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23216,306,'Serpentis Network Node','This tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interesting information from its mainframe.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23217,306,'Serpentis Network Hub','This tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interesting information from its mainframe.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23218,306,'Serpentis Network Nucleus','This tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interesting information from its mainframe.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23219,306,'Serpentis Network Nexus','This tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interesting information from its mainframe.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(23220,306,'Disposal Unit','A discarded container filled with junk and other waste.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(23221,523,'COSMOS Amarr NON-Pirate Battleship',' ',19000000,1150000,235,1,4,0.0000,0,NULL,0),(23222,319,'Serpentis Barricade','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(23223,226,'Fortified Serpentis Barricade','A barricade. No, it\'s not a snake.',0,0,0,1,4,0.0000,0,NULL,0),(23224,226,'Fortified Serpentis Barrier','A barrier. Tune in, turn up, keep out.',0,0,0,1,4,0.0000,0,NULL,0),(23225,226,'Fortified Serpentis Battery','A battery. Juicy.',0,0,0,1,4,0.0000,0,NULL,0),(23226,226,'Fortified Serpentis Bunker','A bunker. Beware.',0,0,0,1,4,0.0000,0,NULL,0),(23227,226,'Fortified Gallente Elevator','An elevator.',0,0,0,1,4,0.0000,0,NULL,0),(23228,226,'Fortified Serpentis Fence','A fence. Sheep.',0,0,0,1,4,0.0000,0,NULL,0),(23229,226,'Fortified Serpentis Junction','A junction. Blind date.',0,0,0,1,4,0.0000,0,NULL,0),(23230,226,'Fortified Serpentis Lookout','A lookout. Look out.',0,0,0,1,4,0.0000,0,NULL,0),(23231,226,'Fortified Serpentis Wall','A wall. Go figure.',0,0,0,1,4,0.0000,0,NULL,0),(23232,517,'Karmane Ban\'s Blackbird','A Blackbird piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(23233,533,'Apte Donie',' ',11200000,112000,480,1,8,0.0000,0,NULL,0),(23234,526,'Azure Canyon Tourist Pass','This pass gets you into the Azure Canyon Tourist Resort, located in Colelie.',1,1,0,1,NULL,0.0000,1,NULL,0),(23235,533,'Daubs Louel','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(23236,474,'Black Market Entry Keycard','This keycard will activate the acceleration gate leading into the Black Market of Azure Canyon in Colelie.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23237,226,'Indestructible Freight Pad','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',0,0,0,1,NULL,0.0000,0,NULL,0),(23238,517,'Fam Kishemas\'s Punisher','A Punisher piloted by an agent.',1425000,28600,135,1,4,0.0000,0,NULL,0),(23239,517,'Esordik Mitt\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(23240,494,'Drug Storage Facility','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(23241,523,'Temko Megathron','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.\r\r\n  Threat level: Deadly',19000000,1140000,675,1,8,0.0000,0,NULL,0),(23242,520,'Temko Grunt',' ',2650000,26500,235,1,8,0.0000,0,NULL,0),(23243,520,'Temko Interceptor','This is a guardian of a corporation\'s agents.  Attacking this ship would be very foolhardy, and is most likely not required of you.',2650000,26500,140,1,8,0.0000,0,NULL,0),(23244,578,'Blood Bishop','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23245,577,'Blood Visionary','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23246,577,'Blood Converter','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23247,577,'Blood Templar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23248,577,'Blood Devoter','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23249,577,'Blood Friar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23250,577,'Blood Cleric','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23252,578,'Blood Seer','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23253,578,'Blood Shade','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23254,578,'Blood Fanatic','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23255,578,'Blood Phantom','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23256,578,'Blood Exorcist','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23257,555,'Blood Shadow Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23258,555,'Blood Dark Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23259,557,'Elder Blood Seeker','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2810000,28100,315,1,4,0.0000,0,NULL,0),(23260,557,'Elder Blood Collector','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2810000,28100,315,1,4,0.0000,0,NULL,0),(23261,557,'Elder Blood Raider','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23262,557,'Elder Blood Diviner','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23263,557,'Elder Blood Reaver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23264,557,'Elder Blood Engraver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23265,556,'Blood Archbishop','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23266,556,'Blood Harbinger','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23267,556,'Blood Monsignor','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23268,556,'Blood Cardinal','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23269,556,'Blood Patriarch','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23270,556,'Blood Pope','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23271,534,'Alarus Ekire','Alarus Ekire is the leader of the military arm of FON, Friends of Nature, a powerful environmental group that has often had spats with the law in the past.  FON has pooled all of its resources into ruining Wiyrkomi\'s plans of building massive power stations in the Algintal constellation.\r\r\n  Threat level: Deadly',19000000,1140000,675,1,8,0.0000,0,NULL,0),(23272,526,'Alarus Ekire\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,0.0000,1,NULL,0),(23273,526,'Drill',' ',1,5,0,1,NULL,0.0000,1,NULL,0),(23274,283,'Caldari Surveyor',' ',250,3,0,1,NULL,0.0000,1,NULL,0),(23275,522,'FON Cruiser 2',' ',11200000,112000,480,1,8,0.0000,0,NULL,0),(23276,522,'FON Cruiser 1',' ',11600000,116000,900,1,8,0.0000,0,NULL,0),(23277,520,'FON Frigate 1',' ',2250000,22500,125,1,8,0.0000,0,NULL,0),(23278,523,'FON Battleship_OLD',' ',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23279,523,'FON Battleship',' ',19000000,1010000,480,1,8,0.0000,0,NULL,0),(23280,520,'FON Frigate 2',' ',2650000,26500,235,1,8,0.0000,0,NULL,0),(23281,555,'Elder Blood Arch Reaver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23282,555,'Elder Blood Arch Engraver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23283,555,'Elder Blood Arch Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23284,555,'Elder Blood Arch Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23285,555,'Elder Blood Shadow Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23286,555,'Elder Blood Dark Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23287,796,'Dark Blood Visionary','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23288,796,'Dark Blood Converter','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23289,796,'Dark Blood Templar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23290,796,'Dark Blood Devoter','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23291,796,'Dark Blood Friar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23292,796,'Dark Blood Cleric','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23293,795,'Dark Blood Bishop','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(23294,795,'Dark Blood Seer','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(23295,795,'Dark Blood Shade','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(23296,795,'Dark Blood Fanatic','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(23297,795,'Dark Blood Phantom','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(23298,795,'Dark Blood Exorcist','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(23299,849,'Dark Blood Monsignor','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23300,849,'Dark Blood Cardinal','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23301,849,'Dark Blood Patriarch','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23302,849,'Dark Blood Pope','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23303,526,'Wiyrkomi Voucher',' ',1,1,0,1,NULL,0.0000,1,NULL,0),(23304,517,'Aakeo Oshaima\'s Blackbird','A Blackbird piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5.5</b> \r\r\n',0,0,0,1,1,0.0000,0,NULL,0),(23305,561,'Dire Guristas Silencer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23306,561,'Dire Guristas Ascriber','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23307,561,'Dire Guristas Mortifier','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23308,561,'Dire Guristas Inferno','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23309,561,'Dire Guristas Eraser','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23310,561,'Dire Guristas Abolisher','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23311,517,'Veko Tallaja\'s Scorpion','A Scorpion piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5</b> \r\r\n\r\r\n<i>Warning: This agent is connected to another mission chain</i> ',115000000,1040000,550,1,1,0.0000,0,NULL,0),(23312,579,'Guristas Nihilist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23313,579,'Guristas Anarchist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23314,579,'Guristas Renegade','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23315,579,'Guristas Guerilla','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23319,561,'Guristas Eraser','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23320,561,'Guristas Abolisher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23321,580,'Guristas Executor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23322,580,'Guristas Enforcer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23323,580,'Guristas Assaulter','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23324,580,'Guristas Assassin','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23325,580,'Guristas Death Dealer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23326,580,'Guristas Revolter','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23327,283,'Temko Mercenaries','Mercenaries working for the Gallente organization, Temko.',1000,5,0,1,NULL,0.0000,1,NULL,0),(23328,579,'Guristas Terrorist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23329,579,'Guristas Supremacist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23330,562,'Dire Guristas Despoiler','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',2040000,20400,100,1,1,0.0000,0,NULL,0),(23331,562,'Dire Guristas Saboteur','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',2040000,20400,100,1,1,0.0000,0,NULL,0),(23332,562,'Dire Guristas Plunderer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1970000,19700,125,1,1,0.0000,0,NULL,0),(23333,562,'Dire Guristas Wrecker','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1970000,19700,125,1,1,0.0000,0,NULL,0),(23334,562,'Dire Guristas Destructor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23335,562,'Dire Guristas Demolisher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23337,560,'Guristas Eliminator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(23338,560,'Guristas Exterminator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(23339,560,'Guristas Destroyer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(23340,560,'Guristas Conquistador','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(23341,560,'Guristas Massacrer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(23342,560,'Guristas Usurper','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(23343,799,'Dread Guristas Nihilist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23344,799,'Dread Guristas Anarchist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23345,799,'Dread Guristas Renegade','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23346,799,'Dread Guristas Guerilla','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23347,799,'Dread Guristas Terrorist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23348,799,'Dread Guristas Supremacist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23349,797,'Dread Guristas Executor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23350,797,'Dread Guristas Enforcer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23351,797,'Dread Guristas Assaulter','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23352,797,'Dread Guristas Assassin','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23353,797,'Dread Guristas Death Dealer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23354,797,'Dread Guristas Revolter','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23355,850,'Dread Guristas Destroyer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(23356,850,'Dread Guristas Conquistador','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(23357,850,'Dread Guristas Massacrer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(23358,850,'Dread Guristas Usurper','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(23359,306,'Serpentis Prison_Mission','This rat-infested prison owned by the Serpentis organization.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(23360,567,'Sansha\'s Loyal Savage','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2000000,20000,200,1,4,0.0000,0,NULL,0),(23361,567,'Sansha\'s Loyal Slavehunter','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2000000,20000,200,1,4,0.0000,0,NULL,0),(23362,567,'Sansha\'s Loyal Enslaver','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23363,567,'Sansha\'s Loyal Plague','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23364,567,'Sansha\'s Loyal Manslayer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23365,567,'Sansha\'s Loyal Butcher','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23366,566,'Sansha\'s Loyal Ravisher','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(23367,566,'Sansha\'s Loyal Ravager','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(23368,566,'Sansha\'s Loyal Mutilator','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(23369,566,'Sansha\'s Loyal Torturer','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(23370,566,'Sansha\'s Loyal Fiend','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(23371,566,'Sansha\'s Loyal Hellhound','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(23372,565,'Sansha\'s Plague Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23373,565,'Sansha\'s Beast Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23374,565,'Sansha\'s Overlord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23375,565,'Sansha\'s Dark Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23376,565,'Sansha\'s Dread Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23377,565,'Sansha\'s Tyrant','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23378,581,'Sansha\'s Misshape','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23379,581,'Sansha\'s Cannibal','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23381,566,'Sansha\'s Fiend','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23382,566,'Sansha\'s Hellhound','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23383,582,'Sansha\'s Phantasm','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23384,582,'Sansha\'s Specter','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23385,582,'Sansha\'s Wraith','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23386,582,'Sansha\'s Devil','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23387,582,'Sansha\'s Daemon','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23388,582,'Sansha\'s Behemoth','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23391,809,'True Sansha\'s Misshape','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23392,809,'True Sansha\'s Cannibal','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23394,807,'True Sansha\'s Phantasm','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23395,807,'True Sansha\'s Specter','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23396,807,'True Sansha\'s Wraith','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23397,807,'True Sansha\'s Devil','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23398,807,'True Sansha\'s Daemon','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23399,807,'True Sansha\'s Behemoth','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23400,851,'True Sansha\'s Overlord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23401,851,'True Sansha\'s Dark Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23402,851,'True Sansha\'s Dread Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23403,851,'True Sansha\'s Tyrant','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(23405,581,'Sansha\'s Devourer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23406,581,'Sansha\'s Abomination','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23407,581,'Sansha\'s Monster','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23408,581,'Sansha\'s Horror','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23409,809,'True Sansha\'s Devourer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23410,809,'True Sansha\'s Abomination','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23411,809,'True Sansha\'s Monster','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23412,809,'True Sansha\'s Horror','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23413,494,'Pend Insurance Storage Bin','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(23414,325,'\'Brotherhood\' Small Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,5528.0000,1,1059,0),(23415,350,'\'Brotherhood\' Small Remote Armor Repairer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23416,325,'\'Peace\' Large Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,50,0,1,NULL,5528.0000,1,1057,0),(23417,350,'\'Peace\' Large Remote Armor Repairer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23418,60,'\'Radical\' Damage Control I','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,NULL,5372.0000,1,615,0),(23419,140,'\'Radical\' Damage Control I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23420,526,'Veko Tallaja\'s Voucher','Veko Tallaja\'s sign of approval, intended for General Gara Kort.',1,1,0,1,NULL,0.0000,1,NULL,0),(23421,526,'Eule Vitrauze\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the Temko mercenary, Eule Vitrauze.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23422,533,'Eule Vitrauze','The Thorax-class cruisers are the latest combat ships commissioned by the Federation. In the few times it has seen action since its christening, it has performed admirably. The hordes of combat drones it carries allow it to strike against unwary opponents far away and to easily fight many opponents at the same time. Threat level: Deadly',12000000,112000,265,1,1,0.0000,0,NULL,0),(23423,583,'Serpentis Trooper','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23424,583,'Serpentis Soldier','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23425,583,'Serpentis Infantry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23426,583,'Serpentis Sentinel','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23427,583,'Serpentis Cannoneer','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23428,583,'Serpentis Artillery','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23429,572,'Guardian Watchman','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2950000,29500,235,1,8,0.0000,0,NULL,0),(23430,572,'Guardian Patroller','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2950000,29500,235,1,8,0.0000,0,NULL,0),(23431,572,'Guardian Guard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,60,1,8,0.0000,0,NULL,0),(23432,572,'Guardian Safeguard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,60,1,8,0.0000,0,NULL,0),(23434,572,'Guardian Defender','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,140,1,8,0.0000,0,NULL,0),(23435,572,'Guardian Protector','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,140,1,8,0.0000,0,NULL,0),(23436,571,'Serpentis Chief Infantry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23437,571,'Serpentis Chief Sentinel','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23438,584,'Serpentis Wing Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23439,584,'Serpentis Squad Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23440,584,'Serpentis Platoon Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23441,584,'Serpentis Captain','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23442,584,'Serpentis Captain Sentry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23443,584,'Serpentis High Captain','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23444,571,'Guardian Chief Scout','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23445,571,'Guardian Chief Spy','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23446,571,'Guardian Chief Defender','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23447,571,'Guardian Chief Protector','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23448,571,'Guardian Chief Infantry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23449,571,'Guardian Chief Sentinel','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23450,570,'Serpentis Flotilla Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23451,570,'Serpentis Vice Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23452,570,'Serpentis Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23453,570,'Serpentis High Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23454,570,'Serpentis Grand Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23455,570,'Serpentis Lord Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23456,517,'Gara Kort\'s Raven','Gara Kort is the leader of Wiyrkomi\'s military arm in Algintal.  He was sent here by Wiyrkomi\'s Peace Corps to wrest control of the deadspace areas purchased by Wiyrkomi from Serpentis control, as well as combat the increasingly hostile environmentalist organization, Friends of Nature.  He was also the Wiyrkomi agent who managed to strike a deal with the gallente mercenary group, Temko, which now serve under Wiyrkomi in Federation space.\r\r\n\r\r\n<b>Difficulty Rating: Grade 7</b> ',0,0,0,1,1,0.0000,0,NULL,0),(23457,813,'Shadow Serpentis Trooper','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23458,813,'Shadow Serpentis Soldier','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23459,813,'Shadow Serpentis Infantry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23460,813,'Shadow Serpentis Sentinel','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23461,813,'Shadow Serpentis Cannoneer','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23462,813,'Shadow Serpentis Artillery','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23463,811,'Shadow Serpentis Wing Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23464,811,'Shadow Serpentis Squad Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23465,811,'Shadow Serpentis Platoon Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23466,811,'Shadow Serpentis Captain','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23467,811,'Shadow Serpentis Captain Sentry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23468,811,'Shadow Serpentis High Captain','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23469,852,'Shadow Serpentis Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23470,852,'Shadow Serpentis High Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23471,852,'Shadow Serpentis Grand Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23472,852,'Shadow Serpentis Lord Admiral','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23473,639,'Wasp EC-900','Heavy ECM Drone',3000,25,0,1,1,74430.0000,1,841,0),(23474,1143,'Wasp EC-900 Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1029,0),(23475,804,'Shatter Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23476,804,'Ripper Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23477,804,'Shredder Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23478,804,'Predator Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23479,804,'Marauder Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23480,804,'Dismantler Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23481,805,'Strain Sunder Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23482,805,'Strain Raider Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23483,805,'Strain Hunter Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23484,805,'Strain Silverfish Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23485,805,'Strain Devilfish Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23486,805,'Strain Barracude Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23487,803,'Atomizer Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23488,803,'Nuker Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23489,801,'Siege Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23490,801,'Exterminator Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23491,803,'Strain Wrecker Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23492,803,'Strain Destructor Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23493,803,'Strain Disintegrator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23494,803,'Strain Bomber Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23495,803,'Strain Atomizer Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23496,803,'Strain Nuker Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23497,802,'Swarm Preserver Alvus','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(23498,802,'Spearhead Alvus','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(23499,802,'Domination Alvus','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(23500,802,'Supreme Alvus Parasite','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(23501,802,'Alvus Ruler','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(23502,802,'Alvus Creator','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(23503,802,'Patriarch Alvus','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(23504,802,'Matriarch Alvus','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(23505,802,'Alvus Queen','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(23506,639,'Ogre SD-900','Heavy Sensor Dampener Drone',3000,25,0,1,8,106788.0000,1,841,0),(23507,1143,'Ogre SD-900 Blueprint',' ',0,0.01,0,1,NULL,7000000.0000,1,1029,0),(23508,526,'Interview Transcripts','These encoded interview transcripts describe the trials and tribulations of daily life as a worker for the Wiyrkomi project in the Algintal constellation.',1,1,0,1,NULL,0.0000,1,NULL,0),(23509,283,'Scope Journalist','This is a Gallente journalist working for the Scope.  He is currently hot on the trail of a lead, as evidenced by his searching eyes and braced datapad.',100,5,0,1,NULL,0.0000,1,NULL,0),(23510,639,'Praetor TD-900','Heavy Tracking Disruptor Drone',3000,25,0,1,4,88424.0000,1,841,0),(23511,1143,'Praetor TD-900 Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,1,1029,0),(23512,639,'Berserker TP-900','Heavy Target Painter Drone',3000,25,0,1,2,51744.0000,1,841,0),(23513,1143,'Berserker TP-900 Blueprint',' ',0,0.01,0,1,NULL,4000000.0000,1,1029,0),(23514,494,'Elere Febre\'s Habitation module','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(23515,526,'Strange DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the habitation module of the Serpentis agent, Elere Febre.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23516,526,'Elere Febre\'s Data Log','A data log belonging to Elere Febre.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23517,526,'Salvaged Data Core','This data core came out of an alleged FON cruiser, part of a squad that staged a vicious attack on a mercenary outpost. It needs to be brought back to Pandon Ardillan immediately for thorough analysis.',2500,2,0,1,NULL,0.0000,1,NULL,0),(23518,526,'Ardillan\'s Dossier','This dossier represents the entirety of the data gathered by senior Scope journalist Pandon Ardillan about the Wiyrkomi operation in Algintal and FON\'s attempts to subvert it.  78 pages thick, and encoded in ways that would make a supercomputer cry.',1,1,0,1,NULL,0.0000,1,NULL,0),(23519,526,'FON Strike Scene Evidence','This data chip contains within it compelling evidence suggesting that the Wiyrkomi corporation has hired mercenaries to attack its own contracted mercenaries in an attempt to martyrize itself, thus subverting the Gallente public\'s opinion of their industrial operations in the Algintal system.  It should be taken to Preaux Gallot, FON activist at the Natura Seminary in Audaerne, right away.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23520,494,'Serpentis Stronghold','This gigantic station is one of the Serpentis military installations and a black jewel of the alliance between The Guardian Angels and The Serpentis Corporation. Even for its size, it has no commercial station services or docking bays to receive guests.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(23521,526,'Serpentis Transaction Log','These logs contain information on transactions between Serpentis agents and outsiders, such as drug and arms sales etc.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23522,494,'Asteroid Deadspace Mining Post','An outpost situated inside a massive asteroid.',0,1,0,1,NULL,0.0000,0,NULL,0),(23523,640,'Heavy Armor Maintenance Bot I','Armor Maintenance Drone',3000,25,0,1,NULL,111114.0000,1,842,0),(23524,1144,'Heavy Armor Maintenance Bot I Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1030,0),(23525,100,'Curator I','Sentry Drone',12000,25,0,1,4,229968.0000,1,911,0),(23526,176,'Curator I Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,1,1533,0),(23527,647,'Drone Link Augmentor I','Increases drone control range.',200,25,0,1,NULL,441720.0000,1,938,0),(23528,408,'Drone Link Augmentor I Blueprint',' ',0,0.01,0,1,NULL,2130000.0000,1,939,0),(23533,646,'Omnidirectional Tracking Link I','Improves the optimal range and tracking of all drones. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,18160.0000,1,938,0),(23534,408,'Omnidirectional Tracking Link I Blueprint',' ',0,0.01,0,1,NULL,99000.0000,1,939,0),(23535,226,'Huge Silvery White Stalagmite',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(23536,641,'Berserker SW-900','Heavy Webifier Drone\r\r\n\r\r\nBecause of the instability inherent in affixing large, ship-capable webifier equipment to a small, mobile, independently powered carrier such as a mobile drone, the manufacturer had to sacrifice certain aspects of the drone\'s infrastructure. As a result, the drone has a high signature radius, making it relatively easy to target and hit, and isn\'t sturdy enough to suffer more than a few blows to its carapace.',3000,25,0,1,2,51744.0000,1,843,0),(23537,1147,'Berserker SW-900 Blueprint',' ',0,0.01,0,1,NULL,4000000.0000,1,1586,0),(23538,526,'Store Goods','Crate of various store goods.',1000,80,0,1,NULL,0.0000,1,NULL,0),(23539,526,'Stolen Goods','A crate of various goods, all stolen. ',1000,80,0,1,NULL,0.0000,1,NULL,0),(23540,517,'Eron Hoyere\'s Catalyst','A Catalyst piloted by an agent.',1750000,55000,400,1,8,0.0000,0,NULL,0),(23541,526,'Shady Goods','Crate of various unidentifiable goods of shady origin.',1000,80,0,1,NULL,0.0000,1,NULL,0),(23542,526,'Surveillance Recordings','A data storage of secret communications caught by hi-tech surveillance equipment.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23543,526,'Spoiled Drugs','Drugs that have been damaged by coming into contact with dirty substances.',5,0.2,0,1,NULL,0.0000,1,NULL,0),(23544,526,'Sealed Container','Securily locked case with unknown ingredients.',500,50,0,1,NULL,0.0000,1,NULL,0),(23545,526,'Smuggler DNA','DNA of smugglers operating on the borders of Federation and Republic space.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23546,526,'ComLink Encoder/Decoder','A device used to encode and decode comlink messages.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23547,526,'Dolls','Very lifelike dolls for little girls.',50,1,0,1,NULL,0.0000,1,NULL,0),(23548,526,'Tampered Dolls','Very lifelike dolls for little girls. These have been filled with drugs to fool the police.',50,1,0,1,NULL,0.0000,1,NULL,0),(23549,526,'Smuggler Signet','Signet used by smugglers associated with the Angel Cartel.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23550,526,'Don Rico\'s Head','This is the head of Don Rico, a Serpentis druglord that grew too fond of his own goods.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23551,526,'FON Contact DNA','DNA from a member of the Friends of Nature (FON) organization.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23552,526,'FON Banner','Banner depicting the symbol of the Friends of Nature (FON) organization.',1,1,0,1,NULL,0.0000,1,NULL,0),(23553,226,'Pleasure Cruiser',' ',13075000,115000,1750,1,8,0.0000,0,NULL,0),(23554,526,'Trust Partners Business Card','The Trust Partners can be rather paranoid about who they deal with. They hand out business cards to pilots that have proven themselves for other Thukkers to know they can be trusted.',1,1,0,1,NULL,0.0000,1,NULL,0),(23555,526,'Ship logs','Ships logs that need to be \'doctored\' to pass custom inspection.',1,1,0,1,NULL,0.0000,1,NULL,0),(23556,526,'Warning Message','A message warning a Serpentis agent working with FON that Wiyrkomi is on to her.',1,1,0,1,NULL,0.0000,1,NULL,0),(23557,527,'Serpentis Junkie',' ',2250000,22500,125,1,8,0.0000,0,NULL,0),(23558,283,'Federal Intelligence Officer','An officer of the Gallente Federal Intelligence Office.',90,2,0,1,NULL,0.0000,1,NULL,0),(23559,100,'Warden I','Sentry Drone',12000,25,0,1,1,229968.0000,1,911,0),(23560,176,'Warden I Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,1,1533,0),(23561,100,'Garde I','Sentry Drone',12000,25,0,1,8,229968.0000,1,911,0),(23562,176,'Garde I Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,1,1533,0),(23563,100,'Bouncer I','Sentry Drone',12000,25,0,1,2,229968.0000,1,911,0),(23564,176,'Bouncer I Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,1,1533,0),(23565,517,'Ardoen Dasaner\'s Navitas','A Navitas piloted by an agent.\r\r\n\r\r\n<b>Difficulty Rating: Grade 4</b> ',0,0,0,1,8,0.0000,0,NULL,0),(23566,273,'Advanced Drone Avionics','This skill is required for the operation of Electronic Warfare Drones but also gives a bonus to the control range of all drones.\r\r\n\r\r\n3,000m bonus drone control range per level.',0,0.01,0,1,NULL,400000.0000,1,366,0),(23567,494,'Serpentis Narcotics Storage','A storage facility for contraband goods owned by the Serpentis.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(23571,319,'Wiyrkomi Storage','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(23572,306,'Wiyrkomi Warehouse','This is a standard storage facility.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(23573,526,'Wiyrkomi Data Chip','A data chip owned by the Wiyrkomi Corporation.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23593,494,'Wiyrkomi Surveillance Outpost','A small outpost operated by the Wiyrkomi mega-corporation brim-ful of the latest hi-tech surveillance and listening gadgets.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(23594,273,'Sentry Drone Interfacing','Skill at controlling sentry drones. 5% bonus to Sentry Drone damage per level.',0,0.01,0,1,NULL,450000.0000,1,366,0),(23595,306,'Scorched Container','A dented and damaged container from a destroyed smuggling vessel.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(23596,533,'Splinter Smuggler','Serpentis smuggler dreaming of making it big on his own.',11600000,116000,900,1,8,0.0000,0,NULL,0),(23597,526,'Serpentis Data Chip Decoder','A decoder to unlock information stored on an encoded data chip. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23598,533,'Pourpas Aunten',' ',11200000,112000,480,1,8,0.0000,0,NULL,0),(23599,273,'Propulsion Jamming Drone Interfacing','Specialization in the operation of advanced Amarr drones. 2% bonus to advanced Amarr drone damage per level.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(23600,494,'Runner\'s Relay Station','A small bunker crammed with sophisticated communication devices used by smuggler\'s and border runners to coordinate themselves.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(23601,533,'Maqeri Camcen','This is a hostile pirate vessel. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(23602,526,'Maqeri Camcen\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the Angel Cartel member, Maqeri Camcen.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23603,517,'Onreun Coen\'s Tristan','A Tristan piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 4.5</b> \r\r\n\r\r\n<i>Warning: A battlecruiser or smaller ship is required</i> ',1250000,26500,140,1,8,0.0000,0,NULL,0),(23604,526,'Isone Flosins\'s Corpse','The corpse of someone with Amarrian ancestry.',80,1,0,1,NULL,0.0000,1,NULL,0),(23605,526,'Isone Flosin\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the Roden Shipyard employee, Isone Flosin.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23606,273,'Drone Sharpshooting','Increases drone optimal range.',0,0.01,0,1,NULL,150000.0000,1,366,0),(23607,306,'Wreckage of Isone\'s Ship','The mangled wreck floats motionless in space, surrounded with a field of scorched debris.',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(23608,517,'Nilla Elermare\'s Shuttle','A Gallente shuttle piloted by an agent.',1600000,5000,10,1,8,0.0000,0,NULL,0),(23609,533,'Don Rico\'s Henchman','A close associate of the notorious Serpentis druglord Don Rico.',11200000,112000,480,1,8,0.0000,0,NULL,0),(23610,283,'Jark Makon','A pilot of a Serpentis ship.',80,1,0,1,NULL,0.0000,1,NULL,0),(23612,527,'Captain Jark Makon','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23613,517,'Aminn Flosin\'s Celestis','A Celestis piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5</b> \r\r\n',12500000,116000,320,1,8,0.0000,0,NULL,0),(23614,533,'Don Rico\'s Pleasure Yacht','A large pleasure cruiser, built for casual exploration of space while the inhabitants indulge themselves in various luxuries. This one has the renegade Serpentis druglord Don Rico aboard.',13075000,115000,3200,1,8,0.0000,0,NULL,0),(23615,226,'Asteroid Station - Dark and Spiky','Dark and ominous metal structures jut outwards from this crumbled asteroid. Scanners indicate a distant powersource far within the adamant rock.',0,0,0,1,NULL,0.0000,0,NULL,0),(23616,534,'FON Contact','Member of the Friends of Nature organization and the sole link between Elere Febre and FON.',19000000,1010000,480,1,8,0.0000,0,NULL,0),(23617,494,'FON Operation Station','Station operated by the FON environmental organization to protest the occupation of the Serpentis smugglers of the Skeleton Comet park.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(23618,273,'Drone Durability','Increases drone hit points. 5% bonus to drone shield, armor and hull hit points per level.',0,0.01,0,1,NULL,50000.0000,1,366,0),(23619,527,'Ansedon Blat','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23620,517,'Schabs Xalot\'s Iteron Mark III','An Iteron piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5</b> \r\r\n\r\r\n<i>Warning: The ability to mine and defend yourself against pirates is required</i> ',0,0,0,1,8,0.0000,0,NULL,0),(23621,526,'Onreun\'s Crash','This expensive booster is highly addictive and has been known to cause heart attacks and seizures.  This particular unit of crash is owned by Federal Intelligence Office, and will not be detected by customs officials.',5,0.2,0,1,NULL,0.0000,1,NULL,0),(23622,526,'Aggregated FON Data','This dossier represents the aggregated data FON activists have gathered on the clandestine affairs being conducted by the Wiyrkomi corporation in the Algintal constellation. Highly classified.',1,1,0,1,NULL,0.0000,1,NULL,0),(23623,534,'Maschteri Markan',' ',17500000,1140000,480,1,8,0.0000,0,NULL,0),(23624,409,'Maschteri Markan\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,0.0000,1,NULL,0),(23625,517,'Ampsin Achippon\'s Tristan','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(23626,526,'Raid Drone Command Chip','This is the command chip of the destroyed raid drone, revealing what commands it was acting under at the time of it\'s demise. It shows that the next target in line was a hive close to Moon 5 orbiting Parchanier VI.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23628,533,'Malfunctioned Pleasure Cruiser','A large pleasure cruiser, built for casual exploration of space while the inhabitants indulge themselves in various luxuries. This one seems to have a problem with its warp drive.',13075000,115000,3200,1,8,0.0000,0,NULL,0),(23629,526,'Fedo Blood','Sealed bags of thick plastic, filled with viscous dark fedo blood.',1,5,0,1,NULL,0.0000,1,NULL,0),(23630,526,'Unassembled Drills','These drills, are capable of causing more environmental devastation than you can shake an extremely large stick at with both hands.  And that\'s unassembled.',2000,12,0,1,NULL,0.0000,1,NULL,0),(23632,526,'Suho Tatanal\'s Investigation Dossier','These are the results of Suho Tatanal\'s investigation into the strange happenings in the Algintal constellation.',1,1,0,1,NULL,0.0000,1,NULL,0),(23633,526,'Preaux\'s Letter','This is an encoded, highly classified letter from Preaux Gallot, to be brought to Ystvia Lamuette at the Ebony Tower in Barmalie.',1,1,0,1,NULL,0.0000,1,NULL,0),(23634,526,'Colelian Spider Spruce','A rare evergreen, native to Colelie IX.',1,4,0,1,NULL,0.0000,1,NULL,0),(23635,526,'Aortal Purifier','This hefty piece of medical equipment is necessary for transfusions to be possible in patients with certain rare blood diseases.',1000,1,50,1,NULL,0.0000,1,NULL,0),(23636,517,'Bartezo Maphante\'s Omen','An Omen piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 6.5</b> ',0,0,0,1,4,0.0000,0,NULL,0),(23637,517,'Manel Kador\'s Apocalypse','An Apocalypse piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5.5</b> \r\r\n\r\r\n<i>Warning:  This agent is a link in another mission chain.</i>',107500000,1150000,675,1,4,0.0000,0,NULL,0),(23638,551,'Arch Angel Smasher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',9900000,99000,120,1,2,0.0000,0,NULL,0),(23639,551,'Arch Angel Crusher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',9900000,99000,120,1,2,0.0000,0,NULL,0),(23640,551,'Arch Angel Breaker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',9900000,99000,120,1,2,0.0000,0,NULL,0),(23641,551,'Arch Angel Defeater','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',9900000,99000,120,1,2,0.0000,0,NULL,0),(23642,494,'Amarr Battlestation','This gigantic military installation is the pride of the Imperial Navy.  Thousands, sometimes hundreds of thousands, of slaves pour their blood, sweat and tears into erecting one of these mega-structures.  Only a fool would attempt to assault such a massive base without a fleet behind him.\r\n\r\nDocking has been prohibited into this station without proper authorization.',0,0,0,1,4,0.0000,0,NULL,0),(23643,555,'Elder Blood Arch Templar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23644,555,'Elder Blood Revenant','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23645,555,'Elder Blood Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23646,555,'Elder Blood Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(23647,561,'Dire Guristas Killer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23648,561,'Dire Guristas Murderer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23649,561,'Dire Guristas Annihilator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23650,561,'Dire Guristas Nullifier','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23651,566,'Sansha\'s Loyal Beast','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(23652,566,'Sansha\'s Loyal Juggernaut','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(23653,566,'Sansha\'s Loyal Slaughterer','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(23654,566,'Sansha\'s Loyal Execrator','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(23655,571,'Guardian Chief Watchman','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23656,571,'Guardian Chief Patroller','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23657,571,'Guardian Chief Guard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23658,571,'Guardian Chief Safeguard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(23659,544,'Acolyte EV-300','Energy Neutralizer Drone',3000,5,0,1,4,2094.0000,1,843,0),(23660,1142,'Acolyte EV-300 Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,1586,0),(23663,319,'Asteroid Station - 1','Dark and ominous metal structures jut outwards from this crumbled asteroid. Scanners indicate a distant powersource far within the adamant rock.',1000000,100000000,10000,1,NULL,0.0000,0,NULL,0),(23664,523,'Kador Surveillance General',' ',19000000,1150000,235,1,4,0.0000,0,NULL,0),(23665,520,'Kador Surveillance Sergeant',' ',1050000,28100,235,1,4,0.0000,0,NULL,0),(23666,517,'Damaged Drone Mind','A rogue drone mind that was once part of a hive. It is severely damaged, but semi-functional. It uses a hologram image interface for communication purposes.',0,0,0,1,NULL,0.0000,0,NULL,0),(23667,522,'Corpum Arch Sage_COSMOS','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0);
INSERT INTO `invTypes` VALUES (23668,370,'Blood Lower-Tier Tag','This bronze tag carries the rank insignia equivalent of a private within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23669,370,'Blood Grunt Tag','This copper tag carries the rank insignia equivalent of a new recruit within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23670,522,'Dark Corpum Arch Templar_COSMOS','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(23671,520,'Corpii Phantom_COSMOS','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23672,520,'Corpii Templar_COSMOS','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23673,526,'Key To Lord Manel\'s Mansion','This acceleration gate key gets you past the first gate leading into Manel\'s Mansion complex.',1,1,0,1,NULL,0.0000,1,NULL,0),(23674,588,'Gjallarhorn','Righteous fury given form, this weapon system rains a firestorm of unmatched raw destruction upon its target.\r\r\n\r\r\nNotes: This weapon can only fire on ships that are capital-sized or larger. After firing, you will be immobile for thirty seconds and will be unable to activate your jump drive or cloaking device for ten minutes.',100,8000,0,1,NULL,769167134.0000,1,912,0),(23675,526,'Drone Observation Data','Surveillance data and recordings gathered by the Thukkers on the rogue drones in the Skeletal Comet complex.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23676,526,'Cognitive Hive Mind','A fragile piece of a super advanced drone hive mind.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23677,526,'Neural Bio Link','A recently evolved drone technology where the drones are incorporated even further into the central hive mind.',500,2,0,1,NULL,0.0000,1,NULL,0),(23678,526,'Aether Hive Link','Insta-feedback communication device based on zero-G tachyon fields. Utilized by advanced drone hives. ',2500,2,0,1,NULL,0.0000,1,NULL,0),(23679,526,'Latent Submission Tapes','Recordings using the new egonics latent submissions technology developed by Egonics. Nobody seems to know much about how it works and people are strangely indifferent about it...',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23680,526,'Smuggler Tag','This is a tag proudly worn by Serpentis smugglers in the Algintal constellation.',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(23681,526,'Shattered Forgery Tools','Broken and mangled pieces used by forgers to hide illegal goods from the prying eyes of custom officials.',1000,1,0,1,NULL,0.0000,1,NULL,0),(23682,526,'Strike Force Gear','Weapons and equipment of a strike force team that Serpentis is assembling in Algintal. ',2500,2,0,1,NULL,0.0000,1,NULL,0),(23683,526,'Binary Transpositional Code','This sheet can be used to dechiper layered binary codes with extreme ease.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23684,526,'Drone Mind Embryo','An embryonic drone hive mind, showing organic-oriented evolution taking place.  ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23685,533,'Serpentis Drug Runner','A smuggler belonging to the Serpentis corporation.',11200000,112000,480,1,8,0.0000,0,NULL,0),(23686,803,'Drone Perimeter Guard','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23687,803,'Drone Worker','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23688,494,'Cracked Hive Mind Cage','Battered cage of a drone hive mind destroyed by rogue drones sent by another drone queen.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(23689,494,'Dysfunctional Raid Drone','Out of order rogue drone part of a strike force sent by a hive queen to get rid of competing drones.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(23690,526,'Raid Drone Navigation Chip','The Navigation Chip of the damaged drone. Hooking it up reveals the next destination the drone was supposed to go to: Parchanier VI - Moon 5.',1,1,0,1,NULL,0.0000,1,NULL,0),(23691,494,'Shattered Hive Mind Cage','Mangled remains of a cage that once housed a rogue drone hive mind.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(23692,526,'Ruined Hive Mind','A ruined piece of a super advanced drone hive mind.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23695,494,'Serpentis Repackaging Factory','This huge installation was constructed by the Serpentis to take care of forgery and other smuggler related things for the Federation/Republic border, such as repackaging illegal goods to look more innocent.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(23696,494,'Serpentis Command Outpost','A newly-erected Serpentis installation used by the drug lords to oversee matters in the Algintal constellation.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(23697,517,'Nossa Farad\'s Inquisitor','An Inquisitor piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 5.5</b> ',2155000,28700,315,1,4,0.0000,0,NULL,0),(23698,517,'Odan Poun\'s Tormentor','A Tormentor piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 6</b> ',1700000,24398,235,1,4,0.0000,0,NULL,0),(23699,283,'Manel\'s Servant','Servant of Duke Manel Kador.',75,2,0,1,NULL,0.0000,1,NULL,0),(23700,526,'Ader\'s Message','Ader\'s message has been recorded inside this data chip.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23701,306,'Stranded Personnel Transport',' ',13500000,260000,4800,1,4,0.0000,0,NULL,0),(23702,544,'Infiltrator EV-600','Energy Neutralizer Drone',3000,10,0,1,4,20794.0000,1,843,0),(23703,1142,'Infiltrator EV-600 Blueprint',' ',0,0.01,0,1,NULL,1700000.0000,1,1586,0),(23705,639,'Vespa EC-600','Medium ECM Drone',3000,10,0,1,1,21406.0000,1,841,0),(23706,1143,'Vespa EC-600 Blueprint',' ',0,0.01,0,1,NULL,1600000.0000,1,1029,0),(23707,639,'Hornet EC-300','Light ECM Drone',3000,5,0,1,1,3164.0000,1,841,0),(23708,1143,'Hornet EC-300 Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,1029,0),(23709,640,'Medium Armor Maintenance Bot I','Armor Maintenance Drone',3000,10,0,1,NULL,28022.0000,1,842,0),(23710,1144,'Medium Armor Maintenance Bot I Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,1030,0),(23711,640,'Light Armor Maintenance Bot I','Armor Maintenance Drone',3000,5,0,1,NULL,5444.0000,1,842,0),(23712,1144,'Light Armor Maintenance Bot I Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,1030,0),(23713,639,'Hammerhead SD-600','Medium Sensor Dampener Drone',3000,10,0,1,8,23610.0000,1,841,0),(23714,1143,'Hammerhead SD-600 Blueprint',' ',0,0.01,0,1,NULL,1800000.0000,1,1029,0),(23715,639,'Hobgoblin SD-300','Light Sensor Dampener Drone',3000,5,0,1,8,2610.0000,1,841,0),(23716,1143,'Hobgoblin SD-300 Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1029,0),(23717,640,'Medium Shield Maintenance Bot I','Shield Maintenance Drone',3000,10,0,1,NULL,28022.0000,1,842,0),(23718,1144,'Medium Shield Maintenance Bot I Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,1030,0),(23719,640,'Light Shield Maintenance Bot I','Shield Maintenance Drone',3000,5,0,1,NULL,5444.0000,1,842,0),(23720,1144,'Light Shield Maintenance Bot I Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,1030,0),(23721,639,'Valkyrie TP-600','Medium Target Painter Drone',3000,10,0,1,2,16392.0000,1,841,0),(23722,1143,'Valkyrie TP-600 Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1029,0),(23723,639,'Warrior TP-300','Light Target Painter Drone',3000,5,0,1,2,4230.0000,1,841,0),(23724,1143,'Warrior TP-300 Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,1029,0),(23725,639,'Infiltrator TD-600','Medium Tracking Disruptor Drone',3000,10,0,1,4,20794.0000,1,841,0),(23726,1143,'Infiltrator TD-600 Blueprint',' ',0,0.01,0,1,NULL,1700000.0000,1,1029,0),(23727,639,'Acolyte TD-300','Light Tracking Disruptor Drone',3000,5,0,1,4,2094.0000,1,841,0),(23728,1143,'Acolyte TD-300 Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,1029,0),(23729,641,'Valkyrie SW-600','Medium Webifier Drone\r\r\n\r\r\nBecause of the instability inherent in affixing large, ship-capable webifier equipment to a small, mobile, independently powered carrier such as a mobile drone, the manufacturer had to sacrifice certain aspects of the drone\'s infrastructure. As a result, the drone has a high signature radius, making it relatively easy to target and hit, and isn\'t sturdy enough to suffer more than a few blows to its carapace.',3000,10,0,1,2,16392.0000,1,843,0),(23730,1147,'Valkyrie SW-600 Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1586,0),(23731,641,'Warrior SW-300','Light Webifier Drone\r\r\n\r\r\nBecause of the instability inherent in affixing large, ship-capable webifier equipment to a small, mobile, independently powered carrier such as a mobile drone, the manufacturer had to sacrifice certain aspects of the drone\'s infrastructure. As a result, the drone has a high signature radius, making it relatively easy to target and hit, and isn\'t sturdy enough to suffer more than a few blows to its carapace.',3000,5,0,1,2,4230.0000,1,843,0),(23732,1147,'Warrior SW-300 Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,1586,0),(23733,310,'Drone Celestial Beacon','Celestial beacon created by a new breed of rogue drones.',1,1,0,1,NULL,0.0000,0,NULL,0),(23734,23,'Clone Grade Sigma',' ',0,1,0,1,NULL,14000000.0000,0,NULL,0),(23735,815,'Clone Vat Bay I','When activated, the Clone Vat Bay allows for the capital ship to receive transneural brain scan data from a capsule-mounted scanner into one of the bay\'s clones, effectively turning the ship into a mobile clone station.\r\r\n\r\r\nNote:  In order to be able to clone to your ship, a pilot must have a working clone already installed in the vessel.  In addition, the power required to safely and accurately receive and transmit transneural scanner data is diverted from the ship\'s engines; therefore, when the Clone Vat Bay is activated, the capital ship becomes unable to move.\r\r\n\r\r\nCan only be fit on Titans and Capital Industrial Ships.',0,4000,0,1,NULL,89467196.0000,1,1642,0),(23736,532,'Clone Vat Bay I Blueprint',' ',0,0.01,0,1,NULL,598328800.0000,1,799,0),(23737,526,'FON-Wiyrkomi Data Chip','This data chip contains extremely sensitive visual data of a high-ranking Wiyrkomi suit in a compromising position.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23738,526,'Wiyrkomi Scandal Holoreel','This holoreel contains explicit footage of a high-ranking Wiyrkomi executive conducting some extremely off-the-record business with a few women of the night.',100,0.5,0,1,NULL,0.0000,1,NULL,0),(23739,526,'Recon Speeders','Reconnaissance vehicles that comprise an essential part of any respectable ground force.',2500,2,0,1,NULL,0.0000,1,NULL,0),(23740,526,'Custom-built Guidance System','An electrical device used in targeting systems and tracking computers.  This model has been custom-built for use by FON\'s operatives in the Algintal system.',2500,2,0,1,NULL,0.0000,1,NULL,0),(23741,226,'Fortified Shipyard','Large construction tasks can be undertaken at this shipyard.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(23742,226,'Pulsating Sensor',' ',100000,100000000,10000,1,1,0.0000,0,NULL,0),(23743,306,'Kador Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(23744,526,'Nossa Farad\'s Voucher',' ',1,1,0,1,NULL,0.0000,1,NULL,0),(23745,526,'Odan Poun\'s Message','Odan Poun\'s message has been recorded inside this data chip.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23746,517,'Ader Finn\'s Zealot','A Zealot piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 1</b> \r\r\n\r\r\n<i>Warning: This agent is a link in another mission chain.</i> ',11950000,85000,240,1,4,0.0000,0,NULL,0),(23748,526,'Lord Manel\'s Message','Lord Manel\'s message has been recorded inside this data chip.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23749,526,'Blood Raider Squad Leader\'s Head','This is the head of a squad leader serving in the Blood Raider organization.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23752,226,'Cloven Grey Asteroid','This towering asteroid seems to have suffered a tremendous impact, splitting it in multiple pieces.',0,0,0,1,NULL,0.0000,0,NULL,0),(23753,226,'Cloven Red Asteroid','This towering asteroid seems to have suffered a tremendous impact, splitting it in multiple pieces.',0,0,0,1,NULL,0.0000,0,NULL,0),(23754,226,'Broken Blue Crystal Asteroid','This towering asteroid seems to have suffered a tremendous impact, splitting it into multiple pieces.',0,0,0,1,NULL,0.0000,0,NULL,0),(23755,226,'Broken Metallic Crystal Asteroid','This towering asteroid seems to have suffered a tremendous impact, splitting it into multiple pieces.',0,0,0,1,NULL,0.0000,0,NULL,0),(23756,226,'Broken Orange Crystal Asteroid','This towering asteroid seems to have suffered a tremendous impact, splitting it into multiple pieces.',0,0,0,1,NULL,0.0000,0,NULL,0),(23757,547,'Archon','The Archon was commissioned by the Imperial Navy to act as a personnel and fighter carrier.  The order to create the ship came as part of a unilateral initative issued by Navy Command in the wake of Emperor Kor-Azor\'s assassination.  Sporting the latest in fighter command interfacing technology and possessing characteristically strong defenses, the Archon is a powerful aid in any engagement.',1113750000,13950000,825,1,4,1189143722.0000,1,818,0),(23758,643,'Archon Blueprint',' ',0,0.01,0,1,NULL,1100000000.0000,1,888,0),(23759,549,'FA-14 Templar','Fighter Bomber',12000,5000,0,1,4,106788.0000,0,NULL,0),(23760,176,'FA-14 Templar Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(23761,226,'Amarr Starbase Control Tower','The Amarr have always been fond of majestic and intimidating constructions. Their Control Towers do not deviate from that tradition and are truly big and powerful structures, intended more for preservation of territorial interests than commercial benefits.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(23762,226,'Fortified Amarr Lookout','A lookout post, constructed so that its inhabitants may have a better look at the vast expanses of space and whatever wonders they may hold.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(23763,226,'Fortified Cargo Rig','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(23764,526,'Bartezo\'s Message','Bartezo\'s message has been recorded inside this data chip.  It implicates Nossa Farad in the assassination attempt against Lord Manel.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23765,517,'Kofur Karveran\'s Armageddon','An Armageddon piloted by an agent.',110000000,1100000,600,1,4,0.0000,0,NULL,0),(23766,526,'Ader\'s Keycard','Ader Finn\'s Keycard.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23767,227,'Drone Beacon','With it\'s swirling orange light, this drone beacon appears to be marking a point of interest, or perhaps a waypoint in a greater trail.',1,0,0,1,NULL,0.0000,0,NULL,0),(23768,517,'Pomari Maara\'s Condor','A Condor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(23769,517,'Hosiwo Onima\'s Condor','A Condor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(23770,517,'Nakkito Ihadechi\'s Condor','A Condor piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(23771,517,'Furas Vaupero\'s Merlin','A Merlin piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(23772,517,'Ontaa Jila\'s Harpy','A Harpy piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(23773,30,'Ragnarok','The liberty of our people is solely our responsibility.  Tempting as it is to foist this burden upon our well-wishers, we must never forget that the onus of our emancipation rests with us and us alone.\r\r\n\r\r\nFor too long, our proud people have been subjugated to the whims of enslavers, forced to endure relentless suffering and humiliation at the hands of people whose motivations, masked though they may be by florid religious claptrap, remain as base and despicable as those of the playground bully.\r\r\n\r\r\nIf ever there was a time to rise   if ever there was a time to join hands with our brothers   that time is now.  At this exact junction in history we have within our grasp the means to loosen our tormentors\' hold and win freedom for our kin.  Opportunities are there to be taken.\r\r\n\r\r\nBrothers, we must rise.\r\r\n\r\r\n<i>-Malaetu Shakor, Republic Parliament Head\r\r\n                Speaking before the Tribal Council\r\r\n                                   November 27th, YC 107</i>\r\r\n',2075625000,100000000,15000,1,2,78989674128.0000,1,816,0),(23774,110,'Ragnarok Blueprint',' ',0,0.01,0,1,NULL,67500000000.0000,1,887,0),(23775,517,'Cosmos Crucifier','A Crucifier piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(23776,517,'Cosmos Maller','A Maller piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(23777,517,'Cosmos Arbitrator','An Arbitrator piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(23778,517,'Cosmos Coercer','A Coercer piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(23779,517,'Cosmos Malediction','A Malediction piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(23780,517,'Cosmos Crusader','A Crusader piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(23781,517,'Cosmos Purifier','A Purifier piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(23782,517,'Cosmos Prophecy','A Prophecy piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(23783,329,'\'Abatis\' 100mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,23886.0000,1,1672,0),(23784,349,'\'Abatis\' 100mm Steel Plates I Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(23785,329,'\'Bailey\' 1600mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,4,832436.0000,1,1676,0),(23786,349,'\'Bailey\' 1600mm Steel Plates Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(23787,329,'\'Chainmail\' 200mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,101624.0000,1,1673,0),(23788,349,'\'Chainmail\' 200mm Steel Plates Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(23789,329,'\'Bastion\' 400mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,198230.0000,1,1674,0),(23790,349,'\'Bastion\' 400mm Steel Plates Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(23791,329,'\'Citadella\' 100mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,11052.0000,1,1672,0),(23792,349,'\'Citadella\' 100mm Steel Plates Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(23793,329,'\'Barbican\' 800mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,4,466500.0000,1,1675,0),(23794,349,'\'Barbican\' 800mm Steel Plates Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(23795,62,'\'Gorget\' Small Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,NULL,36788.0000,1,1049,0),(23796,142,'\'Gorget\' Small Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23797,62,'\'Greaves\' Medium Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,NULL,44214.0000,1,1050,0),(23798,142,'\'Greaves\' Medium Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23799,62,'\'Hauberk\' Large Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,NULL,88788.0000,1,1051,0),(23800,142,'\'Hauberk\' Large Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23801,61,'\'Crucible\' Small Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,5,0,1,NULL,10960.0000,1,703,0),(23802,141,'\'Crucible\' Small Capacitor Battery I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23803,61,'\'Censer\' Medium Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,10,0,1,NULL,27684.0000,1,704,0),(23804,141,'\'Censer\' Medium Capacitor Battery I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23805,61,'\'Thurifer\' Large Capacitor Battery I','Increases capacitor storage. Provides defense against Energy Leech and Energy Neutralizer effects.',0,15,0,1,NULL,73036.0000,1,705,0),(23806,141,'\'Thurifer\' Large Capacitor Battery I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23807,76,'\'Saddle\' Small Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,5,15,1,NULL,20010.0000,1,699,0),(23808,156,'\'Saddle\' Small Capacitor Booster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23809,76,'\'Harness\' Medium Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,10,32,1,NULL,40356.0000,1,700,0),(23810,156,'\'Harness\' Medium Capacitor Booster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23811,76,'\'Plough\' Heavy Capacitor Booster I','Provides a quick injection of power into the capacitor.',0,20,128,1,NULL,78242.0000,1,701,0),(23812,156,'\'Plough\' Heavy Capacitor Booster I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23813,43,'\'Palisade\' Cap Recharger I','Increases the capacitor recharge rate.',1,5,0,1,NULL,33662.0000,1,665,0),(23814,123,'\'Palisade\' Cap Recharger I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23815,71,'\'Caltrop\' Small Energy Neutralizer I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,40456.0000,1,689,0),(23816,151,'\'Caltrop\' Small Energy Neutralizer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23817,71,'\'Ditch\' Medium Energy Neutralizer I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,173776.0000,1,690,0),(23818,151,'\'Ditch\' Medium Energy Neutralizer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23819,71,'\'Moat\' Heavy Energy Neutralizer I','Neutralizes a portion of the energy in the target ship\'s capacitor.',2000,5,0,1,NULL,850636.0000,1,691,0),(23820,151,'\'Moat\' Heavy Energy Neutralizer I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23821,68,'\'Upir\' Small Nosferatu I','Drains energy from the target ship and adds it to your own.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,51194.0000,1,692,0),(23822,148,'\'Upir\' Small Nosferatu I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23824,68,'\'Strigoi\' Medium Nosferatu I','Drains energy from the target ship and adds it to your own. This is a more powerful version  designed for cruiser class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,315910.0000,1,693,0),(23825,148,'\'Strigoi\' Medium Nosferatu I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23826,226,'Fortified Amarr Battery','A small missile battery designed to repel invaders and other hazards.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(23827,517,'Cora Chaktaren Armageddon','A Armageddon piloted by an agent.',110000000,1100000,600,1,4,0.0000,0,NULL,0),(23828,366,'Spatial Rift','These natural phenomenum that rumour says will hurtle those that come too close to faraway places.  Wary travelers stay away from them as some that have ventured too close have never been seen again.',100000,0,0,1,NULL,0.0000,0,NULL,0),(23829,68,'\'Vrykolakas\' Heavy Nosferatu I','Drains energy from the target ship and adds it to your own. This huge unit is designed for battleship class ships.\r\r\n\r\r\nNote: a Nosferatu module will not drain your target\'s capacitor below your own capacitor level.',1000,5,0,1,NULL,1663554.0000,1,694,0),(23830,148,'\'Vrykolakas\' Heavy Nosferatu I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23831,517,'Zar Forari\'s Bestower','A Bestower piloted by Zar Forari an Agent in Space working for Imperial Shipments.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 7.5</b> ',13500000,260000,4800,1,4,0.0000,0,NULL,0),(23832,517,'Zach Himen\'s Omen','An Omen piloted by an Agent in space working for the Imperial Chancellor',11950000,118000,450,1,4,0.0000,0,NULL,0),(23833,226,'Fortified Amarr Wall','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(23834,53,'\'Mace\' Dual Light Beam Laser I','This light beam laser uses two separate laser focusing systems to reduce the cool down period between shots. Good short to medium range weapon. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,NULL,11788.0000,1,567,0),(23835,133,'\'Mace\' Dual Light Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23836,53,'\'Longbow\' Small Focused Pulse Laser I','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,NULL,13368.0000,1,570,0),(23837,133,'\'Longbow\' Small Focused Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23838,53,'\'Gauntlet\' Small Focused Beam Laser I','A high-powered beam laser. Good for medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,NULL,20248.0000,1,567,0),(23839,133,'\'Gauntlet\' Small Focused Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23840,53,'\'Crossbow\' Focused Medium Beam Laser I','A high-energy, concentrated laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,NULL,99930.0000,1,568,0),(23841,133,'\'Crossbow\' Focused Medium Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23842,53,'\'Joust\' Heavy Pulse Laser I','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,NULL,133234.0000,1,572,0),(23843,133,'\'Joust\' Heavy Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23844,53,'\'Arquebus\' Heavy Beam Laser I','A high-energy heavy laser designed for medium range engagements. Delivers powerful damage. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,10,1,1,NULL,166754.0000,1,568,0),(23845,133,'\'Arquebus\' Heavy Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23846,53,'\'Halberd\' Mega Pulse Laser I','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1116734.0000,1,573,0),(23847,133,'\'Halberd\' Mega Pulse Laser I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23848,53,'\'Catapult\' Mega Beam Laser I','A super-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',2000,20,1,1,NULL,1568334.0000,1,569,0),(23849,133,'\'Catapult\' Mega Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23850,53,'\'Ballista\' Tachyon Beam Laser I','An ultra-heavy beam laser designed for medium to long range engagements. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',1000,20,1,1,NULL,2015232.0000,1,569,0),(23851,133,'\'Ballista\' Tachyon Beam Laser I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23852,67,'\'Squire\' Small Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,40448.0000,1,695,0),(23853,147,'\'Squire\' Small Remote Capacitor Transmitter Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23854,67,'\'Knight\' Medium Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,40448.0000,1,696,0),(23855,147,'\'Knight\' Medium Remote Capacitor Transmitter Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23856,67,'\'Chivalry\' Large Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,5,0,1,NULL,109562.0000,1,697,0),(23857,147,'\'Chivalry\' Large Remote Capacitor Transmitter Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23858,319,'Amarr Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,4,0.0000,0,NULL,0),(23859,319,'Amarr Administration Complex','This building functions as the command and control center for the local region within the Amarr Empire. Usually guarded by several military units. This stronghold is designed to function as a military base during times of war aswell as a government office during peace times.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(23860,319,'Docked Bestower','This Bestower-class industrial is currently offloading and loading supplies to this installation.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(23863,314,'Nidupadian Yorak Eggs','The eggs of the Yorak Fish are prized delicacies of the Amarrian Emperor and its house. Only those of royal blood are allowed to consume these rare eggs. Transportation of these eggs is only given to highly trusted employees and associates of Imperial Shipments. \r\r\n\r\r\nWith the complete control on the consumption of these eggs controlled by the Emperor\'s House the processing plants are often a target of raiding factions to gain a few portions of these true delicacies.',1.5,1,0,1,4,0.0000,1,NULL,0),(23864,72,'\'Pike\' Small EMP Smartbomb I','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',10,5,0,1,NULL,83152.0000,1,382,0),(23865,152,'\'Pike\' Small EMP Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23866,72,'\'Lance\' Medium EMP Smartbomb I','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,10,0,1,NULL,205464.0000,1,383,0),(23867,152,'\'Lance\' Medium EMP Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23868,72,'\'Warhammer\' Large EMP Smartbomb I','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,410754.0000,1,381,0),(23869,152,'\'Warhammer\' Large EMP Smartbomb I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23871,314,'Keron\'s Head','Keron Vandafelt\'s Head. Preserved in a vat of Liquid.',1,10,0,1,4,0.0000,1,NULL,0),(23873,534,'COSMOS BOSS: Keron Vandafelt','Keron Vandafelt, a well known mercenary working for the Blood Raiders. His most notable brush with death was when CONCORD DED raiders tracked him down to a remote region of space. Cornered, he managed to fool their sensors into believing he had an entire army with him. While DED moved to secure the area and await reinforcements, Kieron made fast his escape and publicly tormented DED officials for their newbish mistake.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23874,526,'Lord Methros\' Encrypted Data Burst','A Heavily coded data fragment, retrieved from the wreckage of a transport ship.\r\r\n\r\r\nData fragments such as this are usually transported by ship rather than FTL communication systems due to their complexity and sensitivity of the data contained within them.',1,50,0,1,4,12800.0000,1,NULL,0),(23875,522,'COSMOS Mythos Transport Cruiser',' ',11800000,118000,235,1,4,0.0000,0,NULL,0),(23876,526,'Lord Arachnan\'s Encrypted Data Burst','A Heavily coded data fragment, retrieved from the wreckage of a transport ship.\r\r\n\r\r\nData fragments such as this are usually transported by ship rather than FTL communication systems due to their complexity and sensitivity of the data contained within them.',1,50,0,1,4,0.0000,1,NULL,0),(23877,526,'Encoded Data Transmission','A heavily coded data fragment.\r\r\n\r\r\nData fragments such as this are usually transported by ship rather than FTL communication systems due to their complexity and sensitivity of the data contained within them.',1,50,0,1,4,0.0000,1,NULL,0),(23878,521,'Blood Raider Commander\'s Medalion','This medalion is awarded to high level commanding officers of the The Blood Raider Covenant, for strong leadership and courage under fire, very few officers ever recieve this award.',0.1,1,0,1,NULL,0.0000,1,NULL,0),(23879,523,'Blood Raider Commander','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(23880,526,'Identity Data Chip','This data chip contains massive ammounts of data about a person to help confirm their identity. Allowing safe knowlege that the person they recieve the Identity Chip from is who they say they are.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23881,517,'Ammargal Detrone\'s Zealot','A Zealot piloted by Ammargal Detrone, one of the leading intelligence agents in the sector.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 8</b> ',11950000,85000,240,1,4,0.0000,0,NULL,0),(23882,314,'Standard Decoding Device','A standard decoding device, used to decode valuable transmissions often sent via non-FTL transport.',80,50,0,1,NULL,0.0000,1,NULL,0),(23883,526,'Methros Enhanced Decoding Device','A standard decoding device, used to decode valuable transmissions often sent via non-FTL transport.',80,50,0,1,NULL,0.0000,1,NULL,0),(23888,356,'Methros Enhanced Decoding Device Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(23889,226,'Indestructible Acceleration Gate','This acceleration gate has been locked down and is not usable by the general public.',100000,0,0,1,NULL,0.0000,0,NULL,0),(23890,526,'Inter-Galactic Media Report - The Audesder Incident (1 of 3)','Minmatar pioneers recently discovered an ancient Nefantar holy site within Audesder which was thought to have been lost forever during the Rebellion.  It is the burial place of the long-dead Nefantar prophet, Tyrion Plethar, the first Minmatar priest of the Amarrian religion, as well as hundreds of other priests and saints.  It so happens that this holy site is located inside a giant space ship, still intact despite many years of neglect, and incredibly the crew was found still alive, albeit in a cryogenic state.  <br><br>  Originally this holy site was located in Hjoramold XII which now resides in Minmatar Republic space.  During the great Rebellion, the Nefantar government on the planet had given up all hope of defending their solar system against the massive rebel forces headed their way.  The neighboring constellations had already fallen and it was only a matter of time before their own fell into the hands of their enemies.  So they decided upon a drastic plan to save the holiest site located within Nefantar space, the burial place of Tyrion Plethar.  <br><br>  The plan was to transfer as much of the holy site, buildings and all, into a giant space ship, renamed to the  Pletharian\', which would in turn fly towards the Amarr Empire, where it would most assuredly be kept safe.  The ship had originally been built by Amarrian engineers to be a mobile outpost of sorts, but was the only available vessel that could carry the massive buildings which were part of the burial site.  <br><br>  Loading the burial site onto the ship took a matter of days, although it was quite a hasty procedure and resulted in a number of mishaps, where a number of the buildings were damaged and one even completely destroyed as it toppled from the cranes used to elevate it from the ground.   But eventually the majority of the buildings had been painstakingly transferred into the space ship.  It was then that the rebels attacked, appearing out of nowhere and quickly descended upon the meager Nefantar defenses,.  <br><br>  But even though the defenders were no match for the incoming Minmatar armada, they still bought the Pletharian enough time to set off on its course towards Amarr Space.  The only problem was, it was too massive to use the stargate.  It had been brought to the system in parts and assembled, but in its current state there was no way it could access the stargate out of Hjoramold.   So they had to manually fly it through the vastness of space, without any jump-drive capability.  <br><br>  The destination was Audesder, a solar-system heavily fortified with Amarr forces.  At the time the Nefantar government in Hjormold believed that it was impossible for the rebels to advance far enough to conquer Audesder.  Ironically this system was one of the last to be taken during the later stages of the rebellion.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23891,526,'Inter-Galactic Media Report - The Audesder Incident (2 of 3)','Little is known of what happened to the Pletharian during its journey, and eventually the remaining Nefantars, now called Ammatars, gave up hope of ever finding it again.  But with its discovery by Minmatar explorers,  the situation has changed dramatically.  The Republic has released little info on their findings to the public, but one thing is clear, something must have caused the Pletharian to malfunction and become stranded in space for all these years.  Possibly a collision with an asteroid, or simply a breakdown of their thruster system.  Whatever the cause, the Pletharian has now become the hottest topic on everyone\'s lips within the Ammatar / Minmatar border zone.  <br><br>  Needless to say, shortly after the discovery had been confirmed by Republic authorities, the Ammatar government demanded that it be handed over to them.  The Republic refused, citing that it contains the remains of convicted mass-murderers and Amarrian collaborators, and it would be an affront to all those enslaved and tortured during Amarrian rule to hand them over to the Ammatar.  Instead they intend to make it into a museum, to be shown to Republic citizens as a grim reminder of the past.  <br><br>  The Ammatars were far from pleased.  This was the last straw in a chain of political collisions between their people and the Republic.  Their citizens demanded action, and even within the Amarr empire itself there were rumors that the imperial fleet was preparing for war.  After all, Tyrion Plethar was the most highly regarded member of the Amarr faith which was of Minmatar origin.  The Republic\'s refusal to hand over his remains was not only an affront to the Ammatar nation, but to the Amarrian church as well.  <br><br>  And so the buildup for war has begun.  The Amarr and Ammatars have built a massive military outpost in Kenobanala, which is directly connected to Audesder.  Cruisers and battleships keep arriving daily from all over the empire, and media reports indicate that even Minas Iksan, one of the Empire\'s most prestigious military generals, who led the successful campaign against the Blood Raiders a few years ago, has arrived.  This does not bode well for the stability of the region, which is already on the brink of a potentially disastrous war.  <br><br>  To top it all off, the Caldari and Khanid, which have recently become official allies of the Amarr Empire and Ammatar, have been caught up in the fray.  They have sent both financial support and military aid to the front lines, boosting up the already massive invasion force.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23892,526,'Inter-Galactic Media Report - The Audesder Incident (3 of 3)','On the other side of the fence, the Minmatar Republic has been flooding Audesder with its own troops.  Desperate to prevent another Amarr occupation, it has poured all of its resources into creating an impregnable defensive barrier between it and the Ammatar.  The Gallente Federation and ORE have lent their support as well, the Federation sending an armada of ships to help defend Audesder incase of an attack, and ORE supplying the Minmatar forces with financial aid as well as hired mercenaries.  <br><br>  War looms over this troubled area, and analysts suspect that it may spread to outlying regions.  This could even be the start of a new galactic war that no one wants except the most fanatical nationalists.  CONCORD are monitoring the situation closely, and have reportedly been trying their hardest to soothe the political climate to prevent an all-out-war.  But even they cannot prevent the inevitable battle over Audesder, and we can only hope the conflict will not spread to the neighboring regions.  \r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23893,526,'Enigma Cypher Book','Cyphers used by Lord Mythos.',1,0.01,0,1,NULL,0.0000,1,NULL,0),(23894,768,'\'Page\' Capacitor Flux Coil I','Increases capacitor recharge rate, but causes a reduction in maximum capacitor storage.  ',20,5,0,1,NULL,4654.0000,1,666,0),(23895,137,'\'Page\' Capacitor Flux Coil I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23896,767,'\'Motte\' Capacitor Power Relay I','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,10656.0000,1,667,0),(23897,137,'\'Motte\' Capacitor Power Relay I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23898,769,'\'Portcullis\' Reactor Control Unit I','Boosts power core output.',20,5,0,1,NULL,10976.0000,1,659,0),(23899,137,'\'Portcullis\' Reactor Control Unit I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23900,205,'\'Mangonel\' Heat Sink I','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,40456.0000,1,647,0),(23901,218,'\'Mangonel\' Heat Sink I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23902,205,'\'Trebuchet\' Heat Sink I','Dissipates energy weapon damage efficiently, thus allowing them to be fired more rapidly. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,40456.0000,1,647,0),(23903,218,'\'Trebuchet\' Heat Sink I Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(23904,306,'The Scope Storage Container','This storage container is property of The Scope.  Tamper with it at your own risk.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(23906,319,'Stationary Revelation','A stationary Revelation Dreadnought.',0,0,0,1,4,0.0000,0,NULL,0),(23907,474,'Shiny Sentry Key','This security passcard is one of two needed to pass this sentry station.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23908,494,'Core Serpentis Sentry','This is a well defended guard station.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(23909,314,'Komni History (1 of 2)','The Komni corporation was founded by the multi-billionaire Kaimo Nayen, who had garnered his fortune by building up a real estate empire on Caldari Prime.  The purpose of the company was to give his firstborn son, Shojin Nayen, a chance to receive experience as a CEO, before the time came for him to take over the reigns of his father\'s mega-corporation.  Komni dealt in simple garbage hauling tasks, employing a few dozen washed up pilots to do the sordid task of transporting unrecyclable material to remote locations within the Caldari solarsystems.<br><br>Unfortunately Shojin had been inexcusably spoiled as a child, and lacked all of his fathers virtues which had helped him become so successful.  The Komni corporation quickly began losing money, bad deals were made and the daily affairs were generally ignored by Shojin who spent most of his time dating beautiful women and staying out late at night at popular Caldari bars.  But when his father learned of the state of things, and that the Komni corporation had slid to the verge of bankruptcy, he became furious.  He demanded that his son straighten things out, or all of his shares within the mega-real-estate corporation would go to his other son, Akimo.<br><br>Shojin became terrified at these grim tidings, and was especially worried that his father would also strip him of access to his bank account which he so much relied on to live his extravagant lifestyle.  So he turned to the underworld for aid, secretly contacting an agent employed by the Guristas Pirates, Drako Minai, to manage his corporate affairs.  At first this worked out perfectly, the Komni stock rose considerably and money came streaming in.  Better pilots and maintainance on the old company haulers were finally affordable, without any intervention from Kaimo.',1,1,0,1,NULL,0.0000,1,NULL,0),(23911,547,'Thanatos','Sensing the need for a more moderately-priced version of the Nyx, Federation Navy authorities commissioned the design of the Thanatos.  Designed to act primarily as a fighter carrier for small- to mid-scale engagements, its significant defensive capabilities and specially-fitted fighter bays make it ideal for its intended purpose.',1163250000,13095000,875,1,8,1325732764.0000,1,820,0),(23912,643,'Thanatos Blueprint',' ',0,0.01,0,1,NULL,1250000000.0000,1,890,0),(23913,659,'Nyx','The Nyx is a gigantic homage to a figure much loved in Gallente society.  The ship\'s design is based on the scepter of Doule dos Rouvenor III, the king who, during his peaceful 36-year reign, was credited with laying the foundation for the technologically and socially progressive ideologies which have pervaded Gallente thought in the millennia since.  Indeed, the Nyx itself is emblematic of the Gallenteans\' love for progress; packed to the ergonomic brim with the latest in cutting-edge advancements, it is a proud reminder of the things that make the Federation what it is.',1615625000,58200000,1415,1,8,21906642536.0000,1,820,0),(23914,1013,'Nyx Blueprint',' ',0,0.01,0,1,NULL,20000000000.0000,1,890,0),(23915,547,'Chimera','The Chimera\'s design is based upon the Kairiola, a vessel holding tremendous historical significance for the Caldari.  Initially a water freighter, the Kairiola was refitted in the days of the Gallente-Caldari war to act as a fighter carrier during the orbital bombardment of Caldari Prime. \r\r\n\r\r\nIt was most famously flown by the legendary Admiral Yakia Tovil-Toba directly into Gallente Prime\'s atmosphere, where it fragmented and struck several key locations on the planet.  This event, where the good Admiral gave his life, marked the culmination of a week\'s concentrated campaign of distraction which enabled the Caldari to evacuate their people from their besieged home planet.  Where the Chimera roams, the Caldari remember.',1188000000,11925000,870,1,1,1139614394.0000,1,819,0),(23916,643,'Chimera Blueprint',' ',0,0.01,0,1,NULL,1050000000.0000,1,889,0),(23917,659,'Wyvern','The Wyvern is based on documents detailing the design of the ancient Raata empire\'s seafaring flagship, the Oryioni-Haru.  According to historical sources the ship was traditionally taken on parade runs between the continent of Tikiona and the Muriyuke archipelago, seat of the Emperor, and represented the pride and joy of what would one day become the Caldari State.  Today\'s starfaring version gives no ground to its legendary predecessor; with its varied applications in the vast arena of deep space, the Wyvern is likely to stand as a symbol of Caldari greatness for untold years to come. ',1650000000,53000000,1405,1,1,19450223068.0000,1,819,0),(23918,1013,'Wyvern Blueprint',' ',0,0.01,0,1,NULL,18000000000.0000,1,889,0),(23919,659,'Aeon','Ships like the Aeon have been with the Empire for a long time.  They have remained a mainstay of Amarr expansion as, hopeful for a new beginning beyond the blasted horizon, whole cities of settlers sojourn from their time-worn homesteads to try their luck on infant worlds.  The Aeon represents the largest ship of its kind in the history of the Empire, capable of functioning as a mobile citadel in addition to fielding powerful wings of fighter bombers.\r\r\n',1546875000,62000000,1337,1,4,20184356580.0000,1,818,0),(23920,1013,'Aeon Blueprint',' ',0,0.01,0,1,NULL,18500000000.0000,1,888,0),(23921,803,'Strain Annihilator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23922,803,'Strain Devastator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23923,803,'Strain Viral Infector Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23924,803,'Strain Violator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(23925,526,'Blood Fund','Bags and bags of blood collected by the Blood Raiders throughout Araz.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23926,526,'Plague Spores','Seeds of a potent plague bacteria collected from the coat of small mammals. Has a history of ravaging any population it comes into contact with.',100,0.5,0,1,NULL,0.0000,1,NULL,0),(23929,526,'Truthteller','An ingenious piece of equipment that only a delightfully deranged mind could conjure, used to make just about anybody spill his beans (and his guts too, usually).',2500,2,0,1,NULL,0.0000,1,NULL,0),(23930,526,'Foreman\'s Head','This is the head of a foreman working for the Blood Raiders in the Araz constellation.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23931,526,'House Methros Coat of Arms','A heraldry emblem of the distinguished House Methros family.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23932,526,'Blood Reel','A horrifying holo reel depicting the atrocities committed by the Blood Raiders in the Araz constellation.',100,0.5,0,1,NULL,0.0000,1,NULL,0),(23933,526,'Dynasty Ring','A ring with the emblem of House Arachnan. Only worn by members of the Arachnan family.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23934,526,'Edict of Ancestry','A formal decree issued by an Amarr Holder. This one questions the legitimacy of Lord Arachnan as the head of the Arachnan family. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23935,526,'Aradim Arachnan\'s Head','This is the head of Aradim Arachnan, son and heir of Lord Arachnan.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23936,526,'Ancestral Armor','Ancestral personal armor of House Arachnan, dating back to the heights of the Reclaiming, worn by lords of the House in ground warfare. Though thousands of years old it is still in good order.',250,2,0,1,NULL,0.0000,1,NULL,0),(23937,526,'Perpetual Chamber Warden','A security and surveillance device used to track movement and other activity inside buildings. This one is used to track and record all activity inside the personal chambers of Lord Arachnan.',2500,2,0,1,NULL,0.0000,1,NULL,0),(23939,798,'Deuce Murderer','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(23940,579,'Vagrant Nihilist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23941,579,'Vagrant Anarchist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23942,799,'Desperado Nihilist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23943,799,'Desperado Anarchist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23945,314,'Komni History (2 of 2)','But soon the old man became suspicious.  He couldn\'t believe the incredibly good fortune his son was suddenly blessed with was simply due to hard, honest work.  So he hired an expensive private detective, Asamura, to investigate the internal affairs within Komni, to better understand exactly what had changed since disaster loomed over the corporation.  Asamura, being an ex-elite agent within the Caldari State special forces, quickly discovered who was behind this turn of events; that the Guristas had been using the garbage haulers as a means to smuggle drugs and other illegal goods into Caldari high security space for enormous profits.  Due to Kaimos\'s close relationship with many members of the Caldari State government, the garbage haulers received far less attention from local security forces than other, more suspcious craft.<br><br>When Kaimo heard of these tidings he became furious. If the news surfaced about Komni being under the influence of the Guristas Pirates and committing illegal acts within the Caldari State borders, his status and even his life might be forfeit.  He immediately confronted his son and ordered him to cut all ties with the Guristas, as well as letting him know that he had just blown any chance he had of acquiring the family fortune.  But there was one single flaw in Kaimos plan, and that was his underestimating of his sons determination to remain wealthy.  Threatening to expose Komnis illegal dealings to the media, Shojin played the only card he had.  Either his father leave his corporation alone and give it a large credit \"donation\", or both of their reputations would be ruined.  In return Shojin would severe all ties with the Guristas.  His father reluctantly accepted his sons terms.<br><br>Shortly thereafter Shojin held a secret meeting with his contact within the Guristas.  He demanded that Drako stop the illegal activity the Guristas had been conducting behind his back, and remove all ties they had with Komni.  But the wry, finely dressed agent simply laughed, they had played Shojin for a fool all along.  While Shojin had been endulging himself with the finer things in life, Drako had been busily hoarding the company stocks in preparation for a takeover.  He knew about Asamuras involvement, and expected this very conversation.  As Shojin looked in horror, two burly, brown-skinned men entered the room where he stood next to Drako.  With a simple move of his right hand, Drako ordered his guards to execute his unfortunate client.  And as he left the room, followed by high-pitched screams which were quickly silenced, the smiling, middle-aged man dressed in a shiny black tuxedo thought of how happy he was that the Komni stock had risen drastically upon the news of the takeover.  No longer would he need to answer to his less-than-trustworthy superiors within the Guristas, from this day forward he would own his very own branch within the vast Caldari criminal network.  \r\n\r\n',1,1,0,1,NULL,0.0000,1,NULL,0),(23946,517,'Dakumon\'s Punisher','A Punisher piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(23947,517,'Ebotiz\'s Retribution','A Retribution piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(23948,314,'Native Freshfood Special','The Native Freshfood Special is a meat-heavy meal which is sought after all throughout the Minmatar Republic.  The recipe has been handed down through countless generations, and is considered part of the Minmatar heritage.  ',400,0.5,0,1,NULL,0.0000,1,NULL,0),(23950,257,'Command Ships','Skill for the operation of Command Ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,64000000.0000,1,377,0),(23951,533,'Aradim Arachnan','The Omen is a good example of the sturdy and powerful cruisers of the Amarr, with super strong armor and defenses. It also mounts multiple turret hardpoints.  This Omen is piloted by Aradim Arachnan, the son of Lord Arachnan.',11950000,118000,450,1,4,0.0000,0,NULL,0),(23952,715,'Karo Zulak\'s Bestower','This Bestower-class industrial is currently undergoing maintenance.  Although an excellent military tactician, Zulak is not known for his bravery in combat, rather opting to fly in a heavily armored industrial behind the scene while his men do the fighting.  This is highly unusual, but he claims it has helped him avoid unneccessary attention in the past, as few suspect anyone of importance would choose to fly a Bestower.',0,0,0,1,4,0.0000,0,NULL,0),(23953,590,'Jump Portal Generator I','A piece of machinery designed to allow a capital vessel to create a bridge between systems without the use of a stargate, allowing its companions access through vast tracts of space to join it on the battlefield.<br>\r\r\nNote: Can only be fitted on Titans.<br>\r\r\nJump Portal Generators use the same isotopes as your ships jump drive to jump other ships through the portal. You will need sufficient fuel in your holds in order to allow ships in your fleet to use the jump portal when it is activated. You will still require Strontium Clathrates to activate this module and enable bridging operations.',1,10000,0,1,NULL,1454349648.0000,1,1640,0),(23954,516,'Jump Portal Generator I Blueprint',' ',0,0.01,0,1,NULL,481455760.0000,1,799,0),(23955,826,'Thukker Mercenary Fighter','This is a mercenary of Thukker Tribe origin.  Renowned for their brutality, Thukker mercenaries are not to be taken lightly.  Threat level: High',1100000,27289,130,1,2,0.0000,0,NULL,0),(23956,824,'Thukker Mercenary Captain','This is a mercenary of Thukker Tribe origin. Renowned for their brutality, Thukker mercenaries are not to be taken lightly. Threat level: High',11500000,96000,365,1,2,0.0000,0,NULL,0),(23957,824,'Thukker Mercenary Eliminator','This is a mercenary of Thukker Tribe origin. Renowned for their brutality, Thukker mercenaries are not to be taken lightly. Threat level: High',10000000,80000,450,1,2,0.0000,0,NULL,0),(23958,826,'Thukker Mercenary Rookie','This is a mercenary of Thukker origin, who is obviously starting out in his profession.   Threat level: Moderate',1000000,17400,120,1,2,0.0000,0,NULL,0),(23959,826,'Thukker Mercenary Elite Fighter','This is a mercenary of Thukker Tribe origin.  Renowned for their brutality, Thukker mercenaries are not to be taken lightly.  Threat level: High',1200000,22500,200,1,2,0.0000,0,NULL,0),(23960,494,'Sentry Station Alpha/Beta','This station is one of two guard bases where access to the SCCCCCS deadspace complex is monitored.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(23961,474,'Serpentis Sentry Station Gate Crystal','This is one half of the crystal that activates the first Ancient Acceleration Gate in the SCCCCCS deadspace complex.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(23963,319,'Stargate Gallente 1','This stargate has been manufactured according to Federation design.  It is not usable without the proper authorization code.',1e35,100000000,10000,1,8,0.0000,0,NULL,0),(23964,494,'Blood Kernel','The human farm is for farming humans. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(23965,533,'Blood Raider Foreman',' ',11800000,118000,235,1,4,0.0000,0,NULL,0),(23968,226,'Fortified Blood Raider Barrier','A barrier. Tune in, turn up, keep out.',0,0,0,1,4,0.0000,0,NULL,0),(23969,596,'Gistior Shatterer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(23970,605,'Corpior Visionary','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23971,614,'Pithior Nihilist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23972,623,'Centior Misshape','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23973,632,'Corelior Trooper','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23974,596,'Gistior Defacer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(23975,596,'Gistior Haunter','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(23976,596,'Gistior Defiler','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(23977,596,'Gistior Seizer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(23978,596,'Gistior Trasher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(23979,605,'Corpior Converter','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23980,605,'Corpior Templar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23981,605,'Corpior Devoter','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23982,605,'Corpior Friar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23983,605,'Corpior Cleric','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(23984,614,'Pithior Anarchist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23985,614,'Pithior Renegade','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23986,614,'Pithior Guerilla','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23987,614,'Pithior Terrorist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23988,614,'Pithior Supremacist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(23989,623,'Centior Cannibal','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23990,623,'Centior Devourer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23991,623,'Centior Abomination','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23992,623,'Centior Monster','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23993,623,'Centior Horror','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(23994,632,'Corelior Soldier','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23995,632,'Corelior Infantry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23996,632,'Corelior Sentinel','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23997,632,'Corelior Cannoneer','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23998,632,'Corelior Artillery','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(23999,593,'Gistatis Legionnaire','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24000,602,'Corpatis Bishop','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24001,611,'Pithatis Executor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24002,620,'Centatis Phantasm','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24003,629,'Corelatis Wing Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24004,593,'Gistatis Primus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24005,593,'Gistatis Tribuni','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24006,593,'Gistatis Praefectus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24007,593,'Gistatis Tribunus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24008,593,'Gistatis Legatus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24009,602,'Corpatis Seer','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24010,602,'Corpatis Shade','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24011,602,'Corpatis Fanatic','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24012,602,'Corpatis Phantom','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24013,602,'Corpatis Exorcist','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24014,611,'Pithatis Enforcer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24015,611,'Pithatis Assaulter','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24016,611,'Pithatis Assassin','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24017,611,'Pithatis Death Dealer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24018,611,'Pithatis Revolter','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24019,620,'Centatis Specter','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24020,620,'Centatis Wraith','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24021,620,'Centatis Devil','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24022,620,'Centatis Daemon','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24023,620,'Centatis Behemoth','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24024,629,'Corelatis Squad Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24025,629,'Corelatis Platoon Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24026,629,'Corelatis Captain','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24027,629,'Corelatis Captain Sentry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24028,629,'Corelatis High Captain','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24029,226,'Fortified Blood Raider Fence','A fence. Sheep.',0,0,0,1,4,0.0000,0,NULL,0),(24030,526,'R.S. Officer\'s Passcard','This is a security passcard for Roden Shipyard officers.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24031,526,'R.S. Officer\'s Alpha Passcard','This is a security passcard for Roden Shipyard officers.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24032,226,'Human Farm','The human farm is for farming humans.',0,0,0,1,4,0.0000,0,NULL,0),(24033,597,'Arch Gistii Ruffian','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24034,597,'Arch Gistii Nomad','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24035,597,'Arch Gistii Ambusher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24036,597,'Arch Gistii Raider','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24037,597,'Arch Gistii Hunter','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24038,597,'Arch Gistii Impaler','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24039,606,'Elder Corpii Seeker','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24040,606,'Elder Corpii Collector','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24041,606,'Elder Corpii Raider','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24042,606,'Elder Corpii Diviner','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24043,606,'Elder Corpii Reaver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24044,606,'Elder Corpii Engraver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24045,615,'Dire Pithi Despoiler','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24046,615,'Dire Pithi Saboteur','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24047,615,'Dire Pithi Plunderer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24048,615,'Dire Pithi Wrecker','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24049,615,'Dire Pithi Destructor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24050,615,'Dire Pithi Demolisher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24051,624,'Centii Loyal Savage','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24052,624,'Centii Loyal Slavehunter','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24053,624,'Centii Loyal Enslaver','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24054,624,'Centii Loyal Plague','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24055,624,'Centii Loyal Manslayer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24056,624,'Centii Loyal Butcher','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24057,633,'Coreli Guardian Watchman','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24058,633,'Coreli Guardian Patroller','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24059,633,'Coreli Guardian Guard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24060,633,'Coreli Guardian Safeguard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24061,633,'Coreli Guardian Defender','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24062,633,'Coreli Guardian Protector','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24063,631,'Corelum Chief Infantry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24064,631,'Corelum Chief Sentinel','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24065,631,'Corelum Guardian Chief Scout','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24066,631,'Corelum Guardian Chief Spy','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24067,631,'Corelum Guardian Chief Watchman','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24068,631,'Corelum Guardian Chief Patroller','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24069,631,'Corelum Guardian Chief Guard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24070,631,'Corelum Guardian Chief SafeGuard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24071,631,'Corelum Guardian Chief Defender','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24072,631,'Corelum Guardian Chief Protector','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24073,631,'Corelum Guardian Chief Infantry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24074,631,'Corelum Guardian Chief Sentinel','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24075,622,'Centum Fiend','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24076,622,'Centum Hellhound','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24077,622,'Centum Loyal Ravisher','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24078,622,'Centum Loyal Ravager','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24079,622,'Centum Loyal Beast','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24080,622,'Centum Loyal Juggernaut','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24081,622,'Centum Loyal Slaughterer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24082,622,'Centum Loyal Execrator','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24083,622,'Centum Loyal Mutilator','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24084,622,'Centum Loyal Torturer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24085,622,'Centum Loyal Fiend','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24086,622,'Centum Loyal Hellhound','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24087,613,'Pithum Eraser','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24088,613,'Pithum Abolisher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24089,613,'Dire Pithum Silencer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24090,613,'Dire Pithum Ascriber','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24091,613,'Dire Pithum Killer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24092,613,'Dire Pithum Murderer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24093,613,'Dire Pithum Annihilator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24094,613,'Dire Pithum Nullifier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24095,613,'Dire Pithum Mortifier','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24096,613,'Dire Pithum Inferno','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24097,613,'Dire Pithum Eraser','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24098,613,'Dire Pithum Abolisher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24099,604,'Corpum Shadow Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24100,604,'Corpum Dark Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24101,604,'Elder Corpum Arch Reaver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24102,604,'Elder Corpum Arch Engraver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24103,604,'Elder Corpum Arch Templar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24104,604,'Elder Corpum Revenant','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24105,604,'Elder Corpum Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24106,604,'Elder Corpum Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24107,604,'Elder Corpum Arch Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24108,604,'Elder Corpum Arch Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24109,604,'Elder Corpum Shadow Sage','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24110,604,'Elder Corpum Dark Priest','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24111,595,'Gistum Phalanx','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24112,595,'Gistum Centurion','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24113,595,'Arch Gistum Depredator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24114,595,'Arch Gistum Predator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24115,595,'Arch Gistum Smasher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24116,595,'Arch Gistum Crusher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24117,595,'Arch Gistum Breaker','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24118,595,'Arch Gistum Defeater','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24119,595,'Arch Gistum Marauder','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24120,595,'Arch Gistum Liquidator','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24121,595,'Arch Gistum Phalanx','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24122,595,'Arch Gistum Centurion','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24123,526,'Elite Laser Pistols','High-tech laser pistols.',2500,2,0,1,NULL,0.0000,1,NULL,0),(24124,306,'Laser-Pistol Stash','This storage container is used to store a batch of high-tech laser pistols which were recently stolen from an Imperial military convoy.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(24125,594,'Gist Saint','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24126,594,'Gist Nephilim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24127,594,'Gist Malakim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24128,594,'Gist Throne','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24129,594,'Gist Cherubim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24130,594,'Gist Seraphim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24131,594,'Gist Domination Malakim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24132,594,'Gist Domination Throne','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24133,594,'Gist Domination Cherubim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24134,594,'Gist Domination Seraphim','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24135,603,'Corpus Archbishop','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24136,603,'Corpus Harbinger','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24137,603,'Corpus Monsignor','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24138,603,'Corpus Cardinal','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24139,603,'Corpus Patriarch','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24140,603,'Corpus Pope','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24141,603,'Dark Corpus Monsignor','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24142,603,'Dark Corpus Cardinal','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24143,603,'Dark Corpus Patriarch','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24144,603,'Dark Corpus Pope','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24145,612,'Pith Eliminator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(24146,612,'Pith Exterminator','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(24147,612,'Pith Destroyer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(24148,612,'Pith Conquistador','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(24149,612,'Pith Massacrer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(24150,612,'Pith Usurper','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(24151,612,'Dread Pith Destroyer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(24152,612,'Dread Pith Conquistador','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(24153,612,'Dread Pith Massacrer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(24154,612,'Dread Pith Usurper','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(24155,621,'Centus Plague Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24156,621,'Centus Beast Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24157,621,'Centus Overlord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24158,621,'Centus Dark Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24159,621,'Centus Dread Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24160,621,'Centus Tyrant','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24161,621,'True Centus Overlord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24162,621,'True Centus Dark Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24163,621,'True Centus Dread Lord','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24164,621,'True Centus Tyrant','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24165,630,'Core Flotilla Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(24166,630,'Core Vice Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(24167,630,'Core Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(24168,630,'Core High Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(24169,630,'Core Grand Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(24170,630,'Core Lord Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(24171,630,'Shadow Core Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(24172,630,'Shadow Core High Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(24173,630,'Shadow Core Grand Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(24174,630,'Shadow Core Lord Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(24175,593,'Gistatis Domination Legionnaire','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24176,593,'Gistatis Domination Primus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24177,593,'Gistatis Domination Tribuni','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24178,593,'Gistatis Domination Praefectus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24179,593,'Gistatis Domination Tribunus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24180,593,'Gistatis Domination Legatus','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(24181,602,'Dark Corpatis Bishop','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24182,602,'Dark Corpatis Seer','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24183,602,'Dark Corpatis Shade','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24184,602,'Dark Corpatis Fanatic','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24185,602,'Dark Corpatis Phantom','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24186,602,'Dark Corpatis Exorcist','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24187,611,'Dread Pithatis Executor','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24188,611,'Dread Pithatis Enforcer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24189,611,'Dread Pithatis Assaulter','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24190,611,'Dread Pithatis Assassin','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24191,611,'Dread Pithatis Death Dealer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24192,611,'Dread Pithatis Revolter','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24193,620,'True Centatis Phantasm','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24194,620,'True Centatis Specter','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24195,620,'True Centatis Wraith','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24196,620,'True Centatis Devil','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24197,620,'True Centatis Daemon','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24198,620,'True Centatis Behemoth','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(24199,629,'Shadow Corelatis Wing Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24200,629,'Shadow Corelatis Squad Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24201,629,'Shadow Corelatis Platoon Leader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24202,629,'Shadow Corelatis Captain','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24203,629,'Shadow Corelatis Captain Sentry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24204,629,'Shadow Corelatis High Captain','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(24205,632,'Shadow Corelior Trooper','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24206,632,'Shadow Corelior Soldier','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24207,632,'Shadow Corelior Infantry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24208,632,'Shadow Corelior Sentinel','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24209,632,'Shadow Corelior Cannoneer','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24210,632,'Shadow Corelior Artillery','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24211,623,'True Centior Misshape','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24212,623,'True Centior Cannibal','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24213,623,'True Centior Devourer','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24214,623,'True Centior Abomination','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24215,623,'True Centior Monster','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24216,623,'True Centior Horror','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(24217,614,'Dread Pithior Nihilist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24218,614,'Dread Pithior Anarchist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24219,614,'Dread Pithior Renegade','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24220,614,'Dread Pithior Guerilla','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24221,614,'Dread Pithior Terrorist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24222,614,'Dread Pithior Supremacist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(24223,605,'Dark Corpior Visioner','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24224,605,'Dark Corpior Converter','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24225,605,'Dark Corpior Templar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24226,605,'Dark Corpior Devoter','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24227,605,'Dark Corpior Friar','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24228,605,'Dark Corpior Cleric','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24229,596,'Gistior Domination Shatterer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24230,596,'Gistior Domination Defacer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24231,596,'Gistior Domination Haunter','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24232,596,'Gistior Domination Defiler','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24233,596,'Gistior Domination Seizer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24234,596,'Gistior Domination Trasher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(24237,306,'Blood Factory','Inside these structures are breeding grounds for humans, body parts and human blood used in sinister Blood Raider rituals.  ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24238,283,'Blood Raider Scientist','Scientists working for the Blood Raider organization, most likely involved in their human breeding programs.',250,3,0,1,NULL,0.0000,1,NULL,0),(24239,517,'Amokin\'s Malediction','A Malediction piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24240,517,'Parsik\'s Crucifier','A Crucifier piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24241,273,'Light Drone Operation','Skill at controlling light combat drones. 5% bonus to damage of light drones per level.',0,0.01,0,1,NULL,50000.0000,1,366,0),(24242,1220,'Infomorph Psychology','Psychological training that strengthens the pilot\'s mental tenacity. The reality of having one\'s consciousness detached from one\'s physical form, scattered across the galaxy and then placed in a vat-grown clone can be very unsettling to the untrained mind.\r\r\n\r\r\nAllows 1 jump clone per level.\r\r\n\r\r\nNote: Clones can only be installed in stations with medical facilities or in ships with clone vat bays. Installed clones are listed in the character sheet.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,1000000.0000,1,1746,0),(24243,494,'Altar of the Blessed','This impressive structure operates as a place for religious practice and the throne of a high ranking member within the clergy.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24244,526,'The Apocryphon','Ancient texts that some believe were once part of the holy scriptures of the Amarr religion. These texts are considered heretical by the Amarr clergy and anyone found preaching or distributing them is persecuted relentlessly.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24245,319,'Smuggler Stargate','The old smuggling route gates were built by a coalition of Minmatar rebels and various pirate factions as a means to travel quickly and discreetly between the outer regions of space. They are favored by many to whom Empire Space is too high-profile and wish to keep a good distance from the vigilant fleet commanders of CONCORD.',1e35,100000000,10000,1,4,0.0000,0,NULL,0),(24246,526,'Bug-Ridden Corpse','A corpse drained of all blood and filled with nasty bug devices.',80,1,0,1,NULL,0.0000,1,NULL,0),(24247,526,'Antiseptic Biomass','A mass of organic material. Antiseptic substance has been added to the mix to hinder decay.',1000,1,0,1,NULL,0.0000,1,NULL,0),(24248,526,'Noble Remains','DNA remains from some young count.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24249,526,'Generator Debris','Debris from a disintegrated power generator.',2000,1,0,1,NULL,0.0000,1,NULL,0),(24250,526,'Archpriest Hakram\'s Head','This is the head of an archpriest in the Blood Raider Covenant that was calling the shots in the Araz constellation.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24251,283,'Pilgrims','Amarr pilgrims seeking enlightenment at the holy sites that litter the Empire.',20,1,0,1,NULL,0.0000,1,NULL,0),(24252,226,'Fortified Smuggler Stargate','The old smuggling route gates were built by a coalition of Minmatar rebels and various pirate factions as a means to travel quickly and discreetly between the outer regions of space. They are favored by many to whom Empire Space is too high-profile and wish to keep a good distance from the vigilant fleet commanders of CONCORD.',1e35,100000000,10000,1,4,0.0000,0,NULL,0),(24253,526,'Dead Pilgrim','The corpse of an Amarrian pilgrim.',80,1,0,1,NULL,0.0000,1,NULL,0),(24254,526,'Saintly Shroud','The holy shroud worn by St. Ageroth on his deathbed.',2,1,0,1,NULL,0.0000,1,NULL,0),(24255,526,'Arc of Revelation','This is the Arc of Revelation, a sacred relic that is said to hold immense power for those of true faith.',1000,50,0,1,NULL,0.0000,1,NULL,0),(24256,494,'Generator Building','The building where the Blood Raiders are housing their immense power generator.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(24257,494,'Temple of the Revelation','This decorated structure serves as a place for religious practice.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24258,527,'Corpse Dealer','A Blood Raider frigate distributing corpses around the Slope.',2860000,28600,235,1,4,0.0000,0,NULL,0),(24259,527,'Corpse Collector','A Blood Raider frigate bringing biomass harvested by other Blood Raiders around Araz.',2860000,28600,235,1,4,0.0000,0,NULL,0),(24260,534,'Archpriest Hakram','Archpriest Hakram of the Blood Raiders have been overseeing their effort in infiltrating and taking over Araz.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24261,533,'Corpse Harvester','A Blood Raider vessel responsible for assaulting innocent travelers and harvesting their bodies.',11800000,118000,235,1,4,0.0000,0,NULL,0),(24262,494,'Asteroid Station','Dark and ominous metal structures jut outwards from this crumbled asteroid. Scanners indicate a distant powersource far within the adamant rock.',1000000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24263,526,'Anema Bluechip','\'Bluechip\' is a name for the data chips which store valuable information on what happened shortly before a structure, normally a space structure, has been destroyed.  Introduced by Gallantean mining corporations after they endured numerous inexplicable losses of their mining barges in deep space, the Bluechip has become universally used due to its incredible survivability.  \r\r\n\r\r\nIf the Bluechip survives an explosion or crash, researchers can usually quickly determine the cause of the accident.  ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24264,474,'Bastion Master Key','This is a passkey used in the ancient imperial fortress known as the Bastion of Blood to access its innermost chamber. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24265,288,'Thukker Wingman','This is a support fighter, which usually acts as backup for larger and more powerfull ships.  Beware of its deadly warp scrambling ability. Threat level: Very high',1580000,15800,145,1,2,0.0000,0,NULL,0),(24267,306,'Lord Methros\' Outpost','This outpost was constructed by Lord Methros\' henchmen.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(24268,268,'Supply Chain Management','Proficiency at starting manufacturing jobs remotely. Without this skill, one can only start jobs within the solar system where one is located. Each level increases the distance at which manufacturing jobs can be started. Level 1 allows for jobs at a range within 5 jumps, and each subsequent level adds 5 more jumps to the range, with a maximum of a 25 jump range.',0,0.01,0,1,NULL,7500000.0000,1,369,0),(24269,306,'Lord Arachnan\'s Outpost','This outpost was constructed by Lord Arachnan\'s henchmen.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(24270,270,'Scientific Networking','Skill at running research operations remotely. Without this skill, one can only start jobs within the solar system where one is located. Each level increases the distance at which research projects can be started. Level 1 allows for jobs at a range within 5 jumps, and each subsequent level adds 5 more jumps to the range, with a maximum of a 25 jump range.',0,0.01,0,1,NULL,7500000.0000,1,375,0),(24271,678,'Federation Navy Officer Vexor','The Vexor is a strong combat ship that is also geared to operate in a variety of other roles. The Vexor is especially useful for surveying in potentially hostile sectors as it can stay on duty for a very long time before having to return to base. Furthermore, it is well capable of defending itself against even concentrated attacks.  Threat level: Deadly',13075000,115000,480,1,8,0.0000,0,NULL,0),(24276,526,'Amolah Kesti\'s Data Fragment I','Information has been frantically scribbled on this piece of paper before it was ejected into space.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24277,526,'Amolah Kesti\'s Data Fragment II','Information has been frantically scribbled on this piece of paper before it was ejected into space.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24278,526,'Amolah Kesti\'s Data Fragment III','Information has been frantically scribbled on this piece of paper before it was ejected into space.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24279,306,'Strange Drifting Cask','The worn container drifts quietly in space, waiting patiently to be pried open by a hungry looter.',10000,1200,1400,1,NULL,0.0000,0,NULL,0),(24280,306,'Strange Drifting Cask_2','The worn container drifts quietly in space, waiting patiently to be pried open by a hungry looter.',10000,1200,1400,1,NULL,0.0000,0,NULL,0),(24281,306,'Strange Drifting Cask_3','The worn container drifts quietly in space, waiting patiently to be pried open by a hungry looter.',10000,1200,1400,1,NULL,0.0000,0,NULL,0),(24282,534,'New Breed Queen','The matriarch of a new breed of rogue drones. Looks extremely deadly.',19000000,1010000,950,1,8,0.0000,0,NULL,0),(24283,407,'Drone Control Unit I','Gives you one extra drone. You need Advanced Drone Interfacing to use this module, it gives you the ability to fit one drone control unit per level.\r\r\n\r\r\nNote: Can only be fit to Carriers and Supercarriers.',200,4000,0,1,4,67283326.0000,1,938,0),(24284,408,'Drone Control Unit I Blueprint',' ',0,0.01,0,1,NULL,55000000.0000,1,939,0),(24285,370,'Corpum Commander Medallion','This medallion is worn by certain high-ranking Corpum officers, usually those who are in charge of a Blood Raider complex.  ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24286,522,'Corpum Blood Duke','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(24287,526,'Zach\'s Note','Zach Himun\'s note to the Emperor Family bureau, authorizing the creation of an ID card for the deliverer.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24288,526,'E.F.A. ID Card',' ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24289,526,'Encoding Matrix Component','A component for Methros Enhanced Decoding Device.',2500,2,0,1,NULL,0.0000,1,NULL,0),(24290,517,'Arshah\'s Armageddon','An Armageddon piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24291,517,'Cosmos Apocalypse','An Apocalypse piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24292,517,'Cosmos Impel','An Impel piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24293,517,'Cosmos Anathema','An Anathema piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24294,517,'Kerth\'s Apocalypse','An Apocalypse piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24295,517,'Robikar\'s Anathema','An Anathema piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24296,517,'Shakai\'s Impel','An Impel piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24300,526,'Yamia Mida\'s Remains','The remains of Yamia Mida.  The body has completely decomposed.',80,1,0,1,NULL,0.0000,1,NULL,0),(24301,306,'Yamia Mida\'s Residence','The fugitive Yamia Mida resides here.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24304,526,'Excavation Note','A scribbled note from an earlier digger, telling that he has uncovered evidence that another Yan Jung site orbits the moon around Deltole VI.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24305,483,'Modulated Deep Core Strip Miner II','The modulated deep core miner is a technological marvel that combines the capacities of the commonly used Miner II with that of the deep core mining laser. Using a modular mining crystal system, it can be altered on the fly for maximum efficiency.\r\r\n\r\r\nCan only be fit to Mining Barges and Exhumers.\r\r\n',0,5,10,1,NULL,6486278.0000,1,1040,0),(24306,490,'Modulated Deep Core Strip Miner II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(24307,533,'Serpentis Surveyor','A Serpentis smuggler with a bit of archaeological skills that has been digging around in the ancient ruins.',11200000,112000,480,1,8,0.0000,0,NULL,0),(24308,474,'Smuggler Knot Lock','This is a gate passkey used by smugglers, especially those working for Serpentis, to lock up their stash of illegal goods or areas they want to keep to themselves.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24309,517,'Zach Himum\'s Armageddon','An Armageddon piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 8</b> ',0,0,0,1,4,0.0000,0,NULL,0),(24310,319,'Amarr Citadel','This Amarrian Citadel looms over the acceleration gate leading to the Palace grounds.  Anyone attempting to enter the palace without authorization would have to overcome the inhabitants of this majestic structure as well as its defenses.  The Citadel is the primary link that the outside world has to the Imperial Palace, often serving as the meeting ground between Emperor Family staff and outsiders intent on getting the Emperor\'s attention.\r\r\n\r\r\nDocking has been prohibited into this station without proper authorization.',0,0,0,1,4,0.0000,0,NULL,0),(24311,257,'Amarr Carrier','Skill at operating Amarr carriers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,500000000.0000,1,377,0),(24312,257,'Caldari Carrier','Skill at operating Caldari carriers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,1,500000000.0000,1,377,0),(24313,257,'Gallente Carrier','Skill at operating Gallente carriers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,8,500000000.0000,1,377,0),(24314,257,'Minmatar Carrier','Skill at operating Minmatar carriers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,2,500000000.0000,1,377,0),(24315,526,'Thyram Arachnan\'s Dossier','This detailed dossier contains encrypted evidence linking Thyram Arachnan, Amarrian nobleman, to criminal elements in the Araz constellation.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24316,526,'Lord Arachnan\'s Medal','A medal awarded to Lord Arachnan years ago.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(24317,526,'House Arachnan Legal Documents','Legal data collected by House Arachnan\'s lawyers and archivists.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24342,283,'Lord Arachnan','The resplendent Lord Arachnan, disguised as a humble janitor.  Even through the disguise, the sheen of his glory stings your eyes.',100,3,0,1,NULL,0.0000,1,NULL,0),(24343,300,'Aurora Alpha','You will be banned if you have this and you are not in ISD :)',0,1,0,1,NULL,0.0000,0,NULL,0),(24344,300,'Aurora Delta','You will be banned if you have this and you are not in ISD :)',0,1,0,1,NULL,0.0000,0,NULL,0),(24345,300,'Aurora Omega','You will be banned if you have this and you are not in ISD :)',0,1,0,1,NULL,0.0000,0,NULL,0),(24346,300,'Aurora Epsilon','You will be banned if you have this and you are not in ISD :)',0,1,0,1,NULL,0.0000,0,NULL,0),(24347,300,'Aurora Beta','You will be banned if you have this and you are not in ISD :)',0,1,0,1,NULL,0.0000,0,NULL,0),(24348,650,'Small Tractor Beam I','By manipulating gravity fields, this module can pull cargo containers towards the ship.',50,50,0.8,1,NULL,2084852.0000,1,872,0),(24349,723,'Small Tractor Beam I Blueprint',' ',0,0.01,0,1,NULL,90000.0000,1,905,0),(24350,517,'Mathon\'s Helios','A Helios piloted by an agent.',1700000,19700,305,1,8,0.0000,0,NULL,0),(24351,494,'Force Repeller Relic','A strange device built by a human civilization dead for thousands of years that repels any ships that try to near it. It must be destroyed from afar, preferably with EM damage weapons.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(24352,474,'Passkey to Yan Jung Relic Site','This passkey will get you into the hard to reach relic site where the now exinct Yan Jung nation once went about their business.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24353,474,'Gargoyle Passkey','This passkey allows entry to the Yan Jung relic site itself. It is only good for one go though.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24354,526,'Threaded Waypoint Map','This strange map seems to show a route of some sort, but as it lacks the source and destination locations it is of little use.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24355,526,'Yan Jung Micro Processor','This micro processor is thousands of years old, but miraculously it still seems to be functioning.',20,1,0,1,NULL,0.0000,1,NULL,0),(24356,494,'Yan Jung Gargoyle','A very old object that seems to once have acted as a guardian of this space. It is not active at the moment and perhaps it has malfunctioned.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24357,526,'Robikar\'s Recommendation','This letter of recommendation is to be shown to Torval Kerth at the Carchatur Outpost in Nidupad.  It contains proof of its possessor\'s identity as a person gainfully employed by Lord Arachnan.',1,1,0,1,NULL,0.0000,1,NULL,0),(24361,572,'Crook Spy','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2500000,25000,60,1,8,0.0000,0,NULL,0),(24362,572,'Crook Agent','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Moderate',2250000,22500,235,1,8,0.0000,0,NULL,0),(24363,572,'Crook Watchman','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2950000,29500,175,1,8,0.0000,0,NULL,0),(24364,572,'Crook Patroller','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2950000,29500,235,1,8,0.0000,0,NULL,0),(24365,572,'Crook Guard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,60,1,8,0.0000,0,NULL,0),(24366,572,'Crook Safeguard','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,235,1,8,0.0000,0,NULL,0),(24367,572,'Crook Defender','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,140,1,8,0.0000,0,NULL,0),(24368,572,'Crook Protector','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24369,814,'Marauder Spy','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2500000,25000,60,1,8,0.0000,0,NULL,0),(24370,814,'Marauder Agent','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2250000,22500,235,1,8,0.0000,0,NULL,0),(24371,814,'Marauder Watchman','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2950000,29500,175,1,8,0.0000,0,NULL,0),(24372,814,'Marauder Patroller','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2950000,29500,235,1,8,0.0000,0,NULL,0),(24373,814,'Marauder Guard','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2300000,23000,60,1,8,0.0000,0,NULL,0),(24374,814,'Marauder Safeguard','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2300000,23000,235,1,8,0.0000,0,NULL,0),(24375,814,'Marauder Defender','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2650000,26500,140,1,8,0.0000,0,NULL,0),(24376,814,'Marauder Protector','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2650000,26500,235,1,8,0.0000,0,NULL,0),(24377,573,'Mule Harvester','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,60,1,8,0.0000,0,NULL,0),(24378,573,'Mule Gatherer','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2300000,23000,235,1,8,0.0000,0,NULL,0),(24379,573,'Mule Ferrier','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,140,1,8,0.0000,0,NULL,0),(24380,573,'Mule Loader','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(24381,558,'Barrow Harvester','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2870000,28700,235,1,4,0.0000,0,NULL,0),(24382,558,'Barrow Gatherer','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2860000,28600,235,1,4,0.0000,0,NULL,0),(24383,558,'Barrow Ferrier','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2870000,28700,135,1,4,0.0000,0,NULL,0),(24384,558,'Barrow Loader','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24385,557,'Warrior Collector','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2810000,28100,315,1,4,0.0000,0,NULL,0),(24386,557,'Warrior Raider','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2870000,28700,235,1,4,0.0000,0,NULL,0),(24387,557,'Warrior Diviner','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: High',2860000,28600,235,1,4,0.0000,0,NULL,0),(24388,557,'Warrior Reaver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2870000,28700,135,1,4,0.0000,0,NULL,0),(24389,557,'Warrior Engraver','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(24390,792,'Sellsword Collector','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,315,1,4,0.0000,0,NULL,0),(24391,792,'Sellsword Raider','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2870000,28700,235,1,4,0.0000,0,NULL,0),(24392,792,'Sellsword Diviner','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2860000,28600,235,1,4,0.0000,0,NULL,0),(24393,792,'Sellsword Reaver','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2870000,28700,135,1,4,0.0000,0,NULL,0),(24394,792,'Sellsword Engraver','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2860000,28600,235,1,4,0.0000,0,NULL,0),(24395,644,'Drone Navigation Computer I','Increases microwarpdrive speed of drones.',200,25,0,1,NULL,161834.0000,1,938,0),(24396,408,'Drone Navigation Computer I Blueprint',' ',0,0.01,0,1,NULL,1400000.0000,1,939,0),(24407,557,'Warrior Seeker','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Significant',2810000,28100,165,1,4,0.0000,0,NULL,0),(24408,792,'Sellsword Seeker','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',2810000,28100,165,1,4,0.0000,0,NULL,0),(24417,644,'Drone Navigation Computer II','Increases microwarpdrive speed of drones.',200,5,0,1,NULL,394230.0000,1,938,0),(24418,408,'Drone Navigation Computer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(24427,647,'Drone Link Augmentor II','Increases drone control range.',200,25,0,1,4,674116.0000,1,938,0),(24428,408,'Drone Link Augmentor II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(24429,306,'Rolette Residence','A multitude of people inhabit these structures.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24438,646,'Omnidirectional Tracking Link II','Improves the optimal range and tracking of all drones. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,250556.0000,1,938,0),(24439,408,'Omnidirectional Tracking Link II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(24441,283,'Civilians','Civilians are a group of people who follow the pursuits of civil life.',1000,5,0,1,NULL,0.0000,1,NULL,0),(24443,338,'Shield Boost Amplifier II','Focuses and amplifies the efficiency of shield boosting modules. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,0,1,NULL,732830.0000,1,613,0),(24444,360,'Shield Boost Amplifier II Blueprint',' ',0,0.01,0,1,NULL,3500000.0000,1,NULL,0),(24445,649,'Giant Freight Container','A massive cargo container, used for inter-regional freight; most commonly used in freighter cargo bays.',1000000,120000,120000,1,NULL,110000.0000,1,1653,0),(24446,526,'Dorga Roes','Dorga are a species of saltwater fish indigenous to Munory VI.  Due to the inhospitable conditions these fish have evolved in, their extremely resilient eggs are in high demand among spacefarers and others who require sustenance in unforgiving environments.  While very nutritious, dorga roes possess a horribly bitter flavor, a fact which has hamstrung all marketing campaigns attempted for them so far.',400,1,0,1,NULL,0.0000,1,NULL,0),(24447,306,'Corpse Stash','A container filled with bug-ridden corpses created by the Blood Raiders to get spy devices into the ships of unwary scavengers.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(24452,319,'Gallente Factory','This is a standard Federation-built Manufacturing Station.  It has been equipped with powerful energy shield systems, although it\'s armor and hull would be considered fairly weak compared to Amarrian standards.\r\r\n\r\r\nDocking has been prohibited into this station without proper authorization.',0,0,0,1,8,0.0000,0,NULL,0),(24453,319,'Smuggler Stargate Strong','The old smuggling route gates were built by a coalition of Minmatar rebels and various pirate factions as a means to travel quickly and discreetly between the outer regions of space. They are favored by many to whom Empire Space is too high-profile and wish to keep a good distance from the vigilant fleet commanders of CONCORD.',1e35,100000000,10000,1,NULL,0.0000,0,NULL,0),(24454,817,'Kungizo Eladar','This is a mercenary warship of Minmatar origin.  The faction it belongs to is unknown.  Threat level: Deadly',11200000,112000,480,1,2,0.0000,0,NULL,0),(24455,817,'Tukkito Usa','The Moa-class is almost exclusively used by the Caldari Navy, and only factions or persons in very good standing with the Caldari State can acquire one. The Moa was designed as an all-out combat ship, and its heavy armament allows the Moa to tackle almost anything that floats in space. Threat level: Deadly',10100000,101000,250,1,1,0.0000,0,NULL,0),(24456,319,'Ammatar Battlestation','This massive military installation is the pride of the Ammatar Navy.\r\r\n\r\r\nDocking has been prohibited into this station without proper authorization.',0,0,0,1,NULL,0.0000,0,NULL,0),(24457,226,'Fortified Blood Raider Bunker','A bunker. Beware.',0,0,0,1,4,0.0000,0,NULL,0),(24458,226,'Fortified Blood Raider Junction','A junction. Blind date.',0,0,0,1,4,0.0000,0,NULL,0),(24459,306,'Habitation Module With Encoded Data Chip','A multitude of people inhabit these structures.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24462,474,'Key of the Arcane','Lavishly decorated passkey that allows entrance to the Museum Arcana.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24463,517,'Udokas\' Crusader','A Crusader piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24464,1207,'Trial of Skill','This is an old data crystal. Only those proficient in decyphering ancient information centrals stand a chance of unraveling its mysteries.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(24465,526,'Runic Inscription','An elaborate parchment inscribed with runic signs declaring the bearer to be a true scholar.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24466,474,'Museum Arcana Guest Pass','This passkey allows the bearer and his friends to enter the Museum Arcana. It is good for only one visit, so use wisely.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24467,517,'The Curator\'s Armageddon','An Armageddon piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24468,332,'R.A.M.- Battlecruiser Tech','Robotic assembly modules designed for Battlecruiser Class Ship Manufacturing',0,15,0,1,NULL,64270.0000,0,NULL,0),(24469,356,'R.A.M.- Battlecruiser Tech Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(24471,648,'Scourge Rage Rocket','A small rocket with a piercing warhead.\r\r\n\r\r\nThis modified version of the Scourge rocket packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',100,0.005,0,5000,NULL,45068.0000,1,930,0),(24472,166,'Scourge Rage Rocket Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24473,648,'Nova Rage Rocket','A small rocket with a nuclear warhead.\r\r\n\r\r\nThis modified version of the Nova rocket packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',100,0.005,0,5000,NULL,45068.0000,1,930,0),(24474,166,'Nova Rage Rocket Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24475,648,'Inferno Rage Rocket','A small rocket with a plasma warhead.\r\r\n\r\r\nThis modified version of the Inferno Rocket packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',100,0.005,0,5000,NULL,45068.0000,1,930,0),(24476,166,'Inferno Rage Rocket Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24477,648,'Scourge Javelin Rocket','A small rocket with a piercing warhead.\r\r\n\r\r\nA modified version of the Scourge rocket. It can reach higher velocity than the Scourge rocket at the expense of warhead size.',100,0.005,0,5000,NULL,45068.0000,1,928,0),(24478,648,'Nova Javelin Rocket','A small rocket with a nuclear warhead.\r\r\n\r\r\nA modified version of the Nova rocket. It can reach higher velocity than the Nova rocket at the expense of warhead size.',100,0.005,0,5000,NULL,45068.0000,1,928,0),(24479,648,'Inferno Javelin Rocket','A small rocket with a plasma warhead.\r\r\n\r\r\nA modified version of the Inferno Rocket. It can reach higher velocity than the Inferno Rocket at the expense of warhead size.',100,0.005,0,5000,NULL,45068.0000,1,928,0),(24480,226,'Fortified Spatial Rift','A natural phenomena that rumour says will hurtle those that come too close to faraway places.  Wary travelers stay away from them as some that have ventured too close have never been seen again.',1,0,0,1,4,0.0000,0,NULL,0),(24482,474,'Key to the Labyrinth','This key allows entry into the labyrinth, a complex maze built by the Takmahls to hide themselves from the Amarr Empire thousands of years ago.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24483,547,'Nidhoggur','Essentially a pared-down version of its big brother the Hel, the Nidhoggur nonetheless displays the same austerity of vision evident in its sibling.  Quite purposefully created for nothing less than all-out warfare, and quite comfortable with that fact, the Nidhoggur will no doubt find itself a mainstay on many a battlefield.',1014750000,11250000,845,1,2,1207661914.0000,1,821,0),(24484,643,'Nidhoggur Blueprint',' ',0,0.01,0,1,NULL,1150000000.0000,1,891,0),(24485,300,'Aurora Gamma','You will be banned if you have this and you are not in ISD :)',0,1,0,1,NULL,0.0000,0,NULL,0),(24486,654,'Inferno Rage Heavy Assault Missile','A plasma warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.\r\r\n\r\r\nThis modified version of the Inferno Heavy Assault Missile packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',700,0.015,0,5000,NULL,63488.0000,1,973,0),(24487,166,'Inferno Rage Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24488,654,'Nova Rage Heavy Assault Missile','A nuclear warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.\r\r\n\r\r\nThis modified version of the Nova Heavy Assault Missile packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',700,0.015,0,5000,NULL,63488.0000,1,973,0),(24489,166,'Nova Rage Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24490,654,'Mjolnir Rage Heavy Assault Missile','An EMP warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.\r\r\n\r\r\nThis modified version of the Mjolnir Heavy Assault Missile packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',700,0.015,0,5000,NULL,63488.0000,1,973,0),(24491,166,'Mjolnir Rage Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24492,654,'Scourge Javelin Heavy Assault Missile','A kinetic warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range. \r\r\n\r\r\nA modified version of the Scourge Heavy Assault Missile. It can reach higher velocity than the Scourge Heavy Assault Missile at the expense of warhead size.',625,0.015,0,5000,NULL,63488.0000,1,972,0),(24493,654,'Mjolnir Javelin Heavy Assault Missile','An EMP warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.\r\r\n\r\r\nA modified version of the Mjolnir Heavy Assault Missile. It can reach higher velocity than the Mjolnir Heavy Assault Missile at the expense of warhead size.',625,0.015,0,5000,NULL,63488.0000,1,972,0),(24494,654,'Inferno Javelin Heavy Assault Missile','A plasma warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range. \r\r\n\r\r\nA modified version of the Inferno Heavy Assault Missile. It can reach higher velocity than the Inferno Heavy Assault Missile at the expense of warhead size.',625,0.015,0,5000,NULL,63488.0000,1,972,0),(24495,653,'Scourge Fury Light Missile','From its humble beginnings in tiny Minmatar design labs, the Scourge light missile has quickly established itself throughout the star cluster as a premier missile for light launchers.\r\r\n\r\r\nA modified version of the Scourge light missile. Does more damage than its predecessor but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',700,0.015,0,5000,NULL,63488.0000,1,927,0),(24496,166,'Scourge Fury Light Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24497,653,'Nova Fury Light Missile','The Nova light missile is a tiny nuclear projectile based on a classic Minmatar design that has been in use since the early days of the Minmatar Resistance.\r\r\n\r\r\nA modified version of the Nova light missile. Does more damage than its predecessor but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',700,0.015,0,5000,NULL,63488.0000,1,927,0),(24498,166,'Nova Fury Light Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24499,653,'Inferno Fury Light Missile','The explosion the Inferno light missile creates upon impact is stunning enough for any display of fireworks - just ten times more deadly.\r\r\n\r\r\nA modified version of the Inferno light missile. Does more damage than its predecessor but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',700,0.015,0,5000,NULL,63488.0000,1,927,0),(24500,166,'Inferno Fury Light Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24501,653,'Scourge Precision Light Missile','From its humble beginnings in tiny Minmatar design labs, the Scourge light missile has quickly established itself throughout the star cluster as a premier missile for light launchers.\r\r\n\r\r\nA modified version of the Scourge light missile. Great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',700,0.015,0,5000,NULL,63488.0000,1,917,0),(24502,166,'Scourge Precision Light Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24503,653,'Nova Precision Light Missile','The Nova light missile is a tiny nuclear projectile based on a classic Minmatar design that has been in use since the early days of the Minmatar Resistance.\r\r\n\r\r\nA modified version of the Nova light missile. Great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',700,0.015,0,5000,NULL,63488.0000,1,917,0),(24504,166,'Nova Precision Light Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24505,653,'Mjolnir Precision Light Missile','An advanced missile with a volatile payload of magnetized plasma, the Mjolnir light missile is specifically engineered to take down shield systems.\r\r\n\r\r\nA modified version of the Mjolnir light missile. Great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',700,0.015,0,5000,NULL,63488.0000,1,917,0),(24506,166,'Mjolnir Precision Light Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24507,655,'Nova Fury Heavy Missile','The be-all and end-all of medium-sized missiles, the Nova heavy missile is a must for those who want a guaranteed kill no matter the cost.\r\r\n\r\r\nA modified version of the Nova heavy missile. Does more damage than its predecessor but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',1000,0.03,0,5000,NULL,418054.0000,1,926,0),(24508,166,'Nova Fury Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24509,655,'Mjolnir Fury Heavy Missile','First introduced by the armaments lab of the Wiyrkomi Corporation, the Mjolnir heavy missile is a solid investment with a large payload and steady performance.\r\r\n\r\r\nA modified version of the Mjolnir heavy missile. Does more damage than its predecessor but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',1000,0.03,0,5000,NULL,418054.0000,1,926,0),(24510,166,'Mjolnir Fury Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24511,655,'Inferno Fury Heavy Missile','Originally designed as a \'finisher\' - the killing blow to a crippled ship - the Inferno heavy missile has since gone through various technological upgrades. The latest version has a lighter payload than the original, but much improved guidance systems.\r\r\n\r\r\nA modified version of the Inferno heavy missile. Does more damage than its predecessor but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',1000,0.03,0,5000,NULL,418054.0000,1,926,0),(24512,166,'Inferno Fury Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24513,655,'Scourge Precision Heavy Missile','The Scourge heavy missile is an old relic from the Caldari-Gallente War that is still in widespread use because of its low price and versatility.\r\r\n\r\r\nA modified version of the Scourge heavy missile. Great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',1000,0.03,0,5000,NULL,418054.0000,1,919,0),(24514,166,'Scourge Precision Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24515,655,'Inferno Precision Heavy Missile','Originally designed as a \'finisher\' - the killing blow to a crippled ship - the Inferno heavy missile has since gone through various technological upgrades. The latest version has a lighter payload than the original, but much improved guidance systems.\r\r\n\r\r\nA modified version of the Inferno heavy missile. Great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',1000,0.03,0,5000,NULL,418054.0000,1,919,0),(24516,166,'Inferno Precision Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24517,655,'Mjolnir Precision Heavy Missile','First introduced by the armaments lab of the Wiyrkomi Corporation, the Mjolnir heavy missile is a solid investment with a large payload and steady performance.\r\r\n\r\r\nA modified version of the Mjolnir heavy missile. Great for taking down smaller ships, but velocity has to be curbed to get a better launch.',1000,0.03,0,5000,NULL,418054.0000,1,919,0),(24518,166,'Mjolnir Precision Heavy Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24519,657,'Nova Rage Torpedo','An ultra-heavy nuclear missile. While it is a slow projectile, its sheer damage potential is simply staggering.\r\r\n\r\r\nThis modified version of the Nova Torpedo packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',1000,0.1,0,5000,NULL,1457525.0000,1,931,0),(24520,166,'Nova Rage Torpedo Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24521,657,'Scourge Rage Torpedo','An ultra-heavy piercing missile. While it is a slow projectile, its sheer damage potential is simply staggering.\r\r\n\r\r\nThis modified version of the Scourge Torpedo packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',1000,0.1,0,5000,NULL,1457525.0000,1,931,0),(24522,166,'Scourge Rage Torpedo Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24523,657,'Mjolnir Rage Torpedo','An ultra-heavy EMP missile. While it is a slow projectile, its sheer damage potential is simply staggering.\r\r\n\r\r\nThis modified version of the Mjolnir Torpedo packs a considerably stronger punch, but as a result is heavier and slower. This makes it very effective against larger targets, but markedly less effective against smaller and more agile targets.',1000,0.1,0,5000,NULL,1457525.0000,1,931,0),(24524,166,'Mjolnir Rage Torpedo Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24525,657,'Inferno Javelin Torpedo','An ultra-heavy plasma missile. While it is a slow projectile, its sheer damage potential is simply staggering.\r\r\n\r\r\nA modified version of the Inferno Torpedo. It can reach higher velocity than the Inferno Torpedo at the expense of warhead size.',1500,0.1,0,5000,NULL,1457525.0000,1,929,0),(24526,166,'Inferno Javelin Torpedo Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24527,657,'Mjolnir Javelin Torpedo','An ultra-heavy EMP missile. While it is a slow projectile, its sheer damage potential is simply staggering.\r\r\n\r\r\n\r\r\nA modified version of the Mjolnir Torpedo. It can reach higher velocity than the Mjolnir Torpedo at the expense of warhead size.',1500,0.1,0,5000,NULL,1457525.0000,1,929,0),(24528,166,'Mjolnir Javelin Torpedo Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24529,657,'Scourge Javelin Torpedo','An ultra-heavy piercing missile. While it is a slow projectile, its sheer damage potential is simply staggering.\r\r\n\r\r\nA modified version of the Scourge Torpedo. It can reach higher velocity than the Scourge Torpedo at the expense of warhead size.',1500,0.1,0,5000,NULL,1457525.0000,1,929,0),(24530,166,'Scourge Javelin Torpedo Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24531,656,'Nova Fury Cruise Missile','A very basic missile for large launchers with reasonable payload. Utilizes the now substandard technology of bulls-eye guidance systems.\r\r\n\r\r\nA modified version of the Nova cruise missile. Does more damage than the Nova cruise, but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',1250,0.05,0,5000,NULL,673545.0000,1,925,0),(24532,166,'Nova Fury Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24533,656,'Scourge Fury Cruise Missile','The first Minmatar-made large missile. Constructed of reactionary alloys, the Scourge cruise missile is built to get to the target. Guidance and propulsion systems are of Gallente origin and were initially used in drones, making this a nimble projectile despite its heavy payload.\r\r\n\r\r\nA modified version of the Scourge cruise. Does more damage than its predecessor but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',1250,0.05,0,5000,NULL,673545.0000,1,925,0),(24534,166,'Scourge Fury Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24535,656,'Mjolnir Fury Cruise Missile','The mother of all missiles, the Mjolnir cruise missile delivers a tremendous payload, guaranteed to get its victims acquainted with their personal god in a quick, but painful manner.\r\r\n\r\r\nA modified version of the Mjolnir cruise. Does more damage than its predecessor but the volatile nature of the warhead, and its powerful containment system, reduce both flight time and precision.',1250,0.05,0,5000,NULL,673545.0000,1,925,0),(24536,166,'Mjolnir Fury Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24537,656,'Nova Precision Cruise Missile','A very basic missile for large launchers with reasonable payload. Utilizes the now substandard technology of bulls-eye guidance systems.\r\r\n\r\r\nA modified version of the Nova cruise missile. Is great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',1250,0.05,0,5000,NULL,673545.0000,1,918,0),(24538,166,'Nova Precision Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24539,656,'Mjolnir Precision Cruise Missile','The mother of all missiles, the Mjolnir delivers a tremendous payload, guaranteed to get its victims acquainted with their personal god in a quick, but painful manner.\r\r\n\r\r\nA modified version of the Mjolnir cruise. Great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',1250,0.05,0,5000,NULL,673545.0000,1,918,0),(24540,166,'Mjolnir Precision Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24541,656,'Scourge Precision Cruise Missile','The first Minmatar-made large missile. Constructed of reactionary alloys, the Scourge cruise missile is built to get to the target. Guidance and propulsion systems are of Gallente origin and were initially used in drones, making this a nimble projectile despite its heavy payload.\r\r\n\r\r\nA modified version of the Scourge cruise. Great for taking down smaller ships, but fuel use by stabilization thrusters reduces maximum flight time.',1250,0.05,0,5000,NULL,673545.0000,1,918,0),(24542,166,'Scourge Precision Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,9999999.0000,1,NULL,0),(24543,166,'Inferno Javelin Rocket Blueprint',' ',1,0.01,0,1,NULL,0.0000,1,NULL,0),(24544,166,'Mjolnir Javelin Rocket Blueprint',' ',1,0.01,0,1,NULL,0.0000,1,NULL,0),(24545,873,'Capital Jump Bridge Array','A massive hulk of machinery containing all the components necessary for the installation of a capital jump portal.',10000,10000,0,1,NULL,23622550.0000,1,781,0),(24546,915,'Capital Jump Bridge Array Blueprint',' ',0,0.01,0,1,NULL,3141342800.0000,1,796,0),(24547,873,'Capital Clone Vat Bay','Sheets of massive metal which link together to form a fully functional clone vat bay, for insertion into capital ships.',10000,10000,0,1,NULL,12276778.0000,1,781,0),(24548,915,'Capital Clone Vat Bay Blueprint',' ',0,0.01,0,1,NULL,1683418400.0000,1,796,0),(24549,651,'Gjallarhorn Blueprint',' ',0,0.01,0,1,NULL,240435272.0000,1,913,0),(24550,588,'Judgement','The ultimate expression of God\'s Divine wrath, this weapon projects a beam of the Lord\'s holy light, designed to put sinners in their proper place.\r\r\n\r\r\nNotes: This weapon can only fire on ships that are capital-sized or larger. After firing, you will be immobile for thirty seconds and will be unable to activate your jump drive or cloaking device for ten minutes.',100,8000,0,1,NULL,719866058.0000,1,912,0),(24551,651,'Judgement Blueprint',' ',0,0.01,0,1,NULL,240727880.0000,1,913,0),(24552,588,'Oblivion','Using a targeting and tracking control system more advanced than any other in existence, this weapon launches and controls a storm of missile fire capable of neutralizing almost any target.\r\r\n\r\r\nNotes: This weapon can only fire on ships that are capital-sized or larger. After firing, you will be immobile for thirty seconds and will be unable to activate your jump drive or cloaking device for ten minutes.',100,8000,0,1,NULL,688595964.0000,1,912,0),(24553,651,'Oblivion Blueprint',' ',0,0.01,0,1,NULL,240947786.0000,1,913,0),(24554,588,'Aurora Ominae','By using reverse-engineered Sleeper technology and advances in focused magnetic fields, this weapon emits a beam of antimatter that is capable of obliterating nearly anything it touches.\r\r\n\r\r\nNotes: This weapon can only fire on ships that are capital-sized or larger. After firing, you will be immobile for thirty seconds and will be unable to activate your jump drive or cloaking device for ten minutes.',100,8000,0,1,NULL,710825072.0000,1,912,0),(24555,651,'Aurora Ominae Blueprint',' ',0,0.01,0,1,NULL,240950758.0000,1,913,0),(24556,873,'Capital Doomsday Weapon Mount','A hardpoint that allows a titan to fit a custom-made doomsday weapon, capable of obliterating its hapless target in one fell stroke.',10000,10000,0,1,NULL,15407530.0000,1,781,0),(24557,915,'Capital Doomsday Weapon Mount Blueprint',' ',0,0.01,0,1,NULL,2146886800.0000,1,796,0),(24558,873,'Capital Ship Maintenance Bay','Massive metal sheets and stacks of equipment which links together in modular fashion to form a gigantic maintenance bay, for insertion into capital ships.',10000,10000,0,1,NULL,12072094.0000,1,781,0),(24559,915,'Capital Ship Maintenance Bay Blueprint',' ',0,0.01,0,1,NULL,1697361200.0000,1,796,0),(24560,873,'Capital Corporate Hangar Bay','Sheets of massive metal which link together to form a multiple-thousand-cubic meter cargo bay, for insertion into capital ships.',10000,10000,0,1,NULL,12030660.0000,1,781,0),(24561,915,'Capital Corporate Hangar Bay Blueprint',' ',0,0.01,0,1,NULL,1670784800.0000,1,796,0),(24562,275,'Jump Portal Generation','Skill for the generation of jump portals to distant solar systems. 10% reduced material cost for jump portal activation per level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,50000000.0000,1,374,0),(24563,255,'Doomsday Operation','Skill at operating titan doomsday weapons. 10% increased damage per level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,250000000.0000,1,364,0),(24564,526,'Chanounian Wine','Chanounian Wine is a rare luxury commodity, manufactured in Chanoun and in distribution only throughout a small portion of Amarr space.  It is highly prized for its wonderful flavor, created by a combination of rare ingredients - none of which are illegal in Amarr space.',500,0.5,0,1,NULL,0.0000,1,NULL,0),(24565,319,'Stargate - Caldari 1','This stargate is currently only usable from the other end.',1e35,100000000,10000,1,1,0.0000,0,NULL,0),(24566,226,'Stargate - Caldari ','This stargate is currently only usable from the other end.',1e35,0,0,1,1,0.0000,0,NULL,0),(24567,413,'Experimental Laboratory','Experimental Laboratories are used for reverse engineering of ancient technology. This structure has Reverse Engineering activities (with no specific time or material bonuses).\r\r\n\r\r\n',100000000,3000,25000,1,4,100000000.0000,1,933,0),(24568,1210,'Capital Remote Armor Repair Systems','Operation of capital sized remote armor repair systems. 5% reduced capacitor need for capital remote armor repair system modules per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,10000000.0000,1,1745,0),(24569,325,'Capital Remote Armor Repairer I','This module uses nano-assemblers to repair damage done to the armor of the Target ship.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',20,4000,0,1,4,34177156.0000,1,1056,0),(24570,350,'Capital Remote Armor Repairer I Blueprint',' ',0,0.01,0,1,NULL,24200788.0000,1,1539,0),(24571,1209,'Capital Shield Emission Systems','Operation of capital sized shield transfer array and other shield emission systems. 5% reduced capacitor need for capital shield emission system modules per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,10000000.0000,1,1747,0),(24572,1216,'Capital Capacitor Emission Systems','Operation of capital remote capacitor transmitters and other capacitor emission systems. 5% reduced capacitor need of capital capacitor emission systems per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,10000000.0000,1,368,0),(24574,397,'Small Ship Assembly Array','A mobile assembly facility where smaller ships such as Fighter and Fighter Bomber Drones, Frigates and Destroyers can be manufactured. \r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials\r\r\n\r\r\nNote: To use a ship from a Ship Assembly Array a Ship Maintenance Array with enough free storage space needs to be in range that the ship can be moved there.',200000000,10000,2000000,1,NULL,100000000.0000,1,932,0),(24575,397,'Supercapital Ship Assembly Array','A mobile assembly facility where capital and supercapital ships can be manufactured. Anchoring this structure requires system sovereignty. This structure has no specific time or material requirement bonuses to ship manufacturing.\r\r\n\r\r\nNote: To use a ship from a Ship Assembly Array a Ship Maintenance Array with enough free storage space needs to be in range that the ship can be moved there.',200000000,850000,155000500,1,NULL,2000000000.0000,1,932,0),(24576,526,'Imperial Navy Gate Permit','A standard gate permit leading to an Imperial Navy complex.',1,1,0,1,4,0.0000,1,NULL,0),(24577,306,'Imperial Armory','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24578,227,'Debris Cloud Flat',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(24579,494,'Core Serpentis Operational Headquarters','This terrifying structure is really a jewel of architecture.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(24580,526,'Ritual Texts','Ancient texts of the Takmahl people, describing many of their religious rituals.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24581,526,'Holy Statue','Holy statue made by the Takmahl people, depicting their god.',100,5,0,1,NULL,2000.0000,1,NULL,0),(24582,820,'The Negotiator','Hardly for the faint of heart, this Core Serpentis member is the one attempting to keep the peace between the rogue drones and the pirates in the Canyon of Rust.',11600000,116000,900,1,8,0.0000,0,NULL,0),(24583,534,'Arcana Patron',' ',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24584,820,'Wiyrkomi Head Engineer','The head engineer of this maintainance station is responsible for both the quality of work performed by the pirate corporation as well as the security of the operation.',11200000,112000,480,1,8,0.0000,0,NULL,0),(24587,319,'Amarr Stargate','This stargate has been manufactured according to Amarr design. It is not usable without the proper authorization code.',1e35,100000000,10000,1,4,0.0000,0,NULL,0),(24588,319,'Station Caldari 4','Docking has been prohibited into this Caldari station without proper authorization.',0,0,0,1,1,0.0000,0,NULL,0),(24589,226,'Warning Sign','Why?',0,0,0,1,NULL,0.0000,0,NULL,0),(24592,652,'Amarr Empire Starbase Charter','An electronic charter code issued by the Amarr Empire which permits the bearer to use a starbase around a moon in Amarr Empire sovereign space for 1 hour. The code is stored on tamperproof chips which must be inserted into the starbase control tower. ',1,0.1,0,1,4,50000.0000,1,940,0),(24593,652,'Caldari State Starbase Charter','An electronic charter code issued by the Caldari State which permits the bearer to use a starbase around a moon in State sovereign space for 1 hour. The code is stored on tamperproof chips which must be inserted into the starbase control tower. ',1,0.1,0,1,1,50000.0000,1,940,0),(24594,652,'Gallente Federation Starbase Charter','An electronic charter code issued by the Gallente Federation which permits the bearer to use a starbase around a moon in Federation sovereign space for 1 hour. The code is stored on tamperproof chips which must be inserted into the starbase control tower. ',1,0.1,0,1,8,50000.0000,1,940,0),(24595,652,'Minmatar Republic Starbase Charter','An electronic charter code issued by the Minmatar Republic which permits the bearer to use a starbase around a moon in Republic sovereign space for 1 hour. The code is stored on tamperproof chips which must be inserted into the starbase control tower. ',1,0.1,0,1,2,50000.0000,1,940,0),(24596,652,'Khanid Kingdom Starbase Charter','An electronic charter code issued by the Khanid Kingdom which permits the bearer to use a starbase around a moon in Kingdom sovereign space for 1 hour. The code is stored on tamperproof chips which must be inserted into the starbase control tower. ',1,0.1,0,1,NULL,50000.0000,1,940,0),(24597,652,'Ammatar Mandate Starbase Charter','An electronic charter code issued by the Ammatar Mandate which permits the bearer to use a starbase around a moon in Mandate sovereign space for 1 hour. The code is stored on tamperproof chips which must be inserted into the starbase control tower. ',1,0.1,0,1,NULL,50000.0000,1,940,0),(24604,166,'Nova Javelin Rocket Blueprint',' ',1,0.01,0,1,NULL,0.0000,1,NULL,0),(24605,166,'Scourge Javelin Rocket Blueprint',' ',1,0.01,0,1,NULL,0.0000,1,NULL,0),(24606,1220,'Cloning Facility Operation','Needed for use of the Clone Vat Bay module. \r\r\n\r\r\nSpecial: Increases a Clone Vat Bay\'s maximum clone capacity by 15% per skill level.',0,0.01,0,1,4,125000000.0000,1,1746,0),(24607,624,'TestScanRadar','This is a captured frigate from the Centus deadspace pirates of Sansha\'s Nation. It has been modified by CONCORD to serve as target practice for pilots fresh out of the Flight Academy. Judging by its name, it should carry some kind of key for the gate.',2450000,24500,60,1,4,0.0000,0,NULL,0),(24608,500,'SnowballNewEffect','This snowball is bigger than your head.  Its shape looks suspiciously like it could fit into a snowball launcher with great ease.',100,1,0,100,NULL,0.0000,0,NULL,0),(24609,226,'Gallente Stargate','This stargate has been manufactured according to Federation design.  It is not usable without the proper authorization code.',1e35,100000000,10000,1,8,0.0000,0,NULL,0),(24613,273,'Advanced Drone Interfacing','Allows the use of the Drone Control Unit module. One extra module can be fitted per skill level. Each fitted Drone Control Unit allows the operation of one extra drone.',0,0.01,0,1,NULL,15000000.0000,1,366,0),(24614,166,'Scourge Javelin Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,0.0000,1,NULL,0),(24615,166,'Inferno Javelin Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,0.0000,1,NULL,0),(24616,166,'Nova Javelin Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,0.0000,1,NULL,0),(24617,166,'Mjolnir Javelin Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,0.0000,1,NULL,0),(24620,650,'Medium Tractor Beam I','By manipulating gravity field this modules can pull cargo containers towards the ship. ',50,10,0.8,1,NULL,2130206.0000,0,NULL,0),(24621,154,'Medium Tractor Beam I Blueprint',' ',0,0.01,0,1,NULL,90000.0000,0,NULL,0),(24622,650,'Large Tractor Beam I','By manipulating gravity field this modules can pull cargo containers towards the ship. ',50,10,0.8,1,NULL,2130206.0000,0,NULL,0),(24623,154,'Large Tractor Beam I Blueprint',' ',0,0.01,0,1,NULL,90000.0000,0,NULL,0),(24624,270,'Advanced Laboratory Operation','Further training in the operation of multiple laboratories.  Ability to run 1 additional research job per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,20000000.0000,1,375,0),(24625,268,'Advanced Mass Production','Further training in the operation of multiple factories. Ability to run 1 additional manufacturing job per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,20000000.0000,1,369,0),(24630,555,'TEST DRAINER','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(24632,746,'Zainou \'Deadeye\' Guided Missile Precision GP-803','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n3% reduced factor of signature radius for all missile explosions.',0,1,0,1,NULL,200000.0000,1,1495,0),(24636,746,'Zainou \'Deadeye\' Missile Bombardment MB-705','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n5% bonus to all missiles\' maximum flight time.',0,1,0,1,NULL,200000.0000,1,1494,0),(24637,746,'Zainou \'Deadeye\' Missile Projection MP-705','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n5% bonus to all missiles\' maximum velocity.',0,1,0,1,NULL,200000.0000,1,1494,0),(24638,746,'Zainou \'Deadeye\' Rapid Launch RL-1005','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n5% bonus to all missile launcher rate of fire.',0,1,0,1,NULL,200000.0000,1,1497,0),(24639,746,'Zainou \'Deadeye\' Target Navigation Prediction TN-905','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n5% decrease in factor of target\'s velocity for all missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(24640,746,'Zainou \'Deadeye\' Guided Missile Precision GP-805','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n5% reduced factor of signature radius for all missile explosions.',0,1,0,1,NULL,200000.0000,1,1495,0),(24641,746,'Zainou \'Gnome\' Launcher CPU Efficiency LE-603','3% reduction in the CPU need of missile launchers.',0,1,0,1,NULL,0.0000,1,1493,0),(24642,746,'Zainou \'Gnome\' Launcher CPU Efficiency LE-605','5% reduction in the CPU need of missile launchers.',0,1,0,1,NULL,0.0000,1,1493,0),(24643,226,'Ammatar Holy Dome','This shrine entombs someone of significant standing within the Amarr/Ammatar religion.',0,0,0,1,NULL,0.0000,0,NULL,0),(24644,650,'Capital Tractor Beam I','By manipulating gravity fields, this module can pull cargo containers towards the ship. \r\r\n\r\r\nNote: this tractor beam can only be fitted on the Rorqual ORE Capital Ship',50,4000,0.8,1,NULL,54663984.0000,1,872,0),(24645,723,'Capital Tractor Beam I Blueprint',' ',0,0.01,0,1,NULL,400000000.0000,1,905,0),(24646,363,'X-Large Ship Maintenance Array','Massive hangar and fitting structure. Used for large volume ship storage and in-space fitting of modules contained in a ship\'s cargo bay.',2000000000,40000,155000000,1,128,1000000000.0000,1,484,0),(24652,471,'Capital Shipyard','A large hangar structure with divisional compartments, for easy separation and storage of materials and modules.',100000,4000,200000,1,NULL,10000000.0000,0,NULL,0),(24653,397,'Advanced Small Ship Assembly Array','A mobile assembly facility where advanced small ships such as Assault Frigates, Covert Ops Frigates, Electronic Attack Frigates, Interceptors, Interdictors, Stealth Bombers and Tactical Destroyers can be manufactured.\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials\r\r\n\r\r\nNote: To use a ship from a Ship Assembly Array a Ship Maintenance Array with enough free storage space needs to be in range that the ship can be moved there.',200000000,10000,2000000,1,4,100000000.0000,1,932,0),(24654,397,'Medium Ship Assembly Array','A mobile assembly facility where medium sized ships such as Cruisers and Battlecruisers can be manufactured.\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials\r\r\n\r\r\nNote: To use a ship from a Ship Assembly Array a Ship Maintenance Array with enough free storage space needs to be in range that the ship can be moved there.',200000000,17000,2000000,1,NULL,100000000.0000,1,932,0),(24655,397,'Advanced Medium Ship Assembly Array','A mobile assembly facility where advanced medium sized ships such as Logistics Cruisers, Heavy Assault Cruisers, Recon Cruisers, Heavy Interdiction Cruisers and Command Battlecruisers can be manufactured.\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials\r\r\n\r\r\nNote: To use a ship from a Ship Assembly Array a Ship Maintenance Array with enough free storage space needs to be in range that the ship can be moved there.',200000000,17000,2000000,1,NULL,100000000.0000,1,932,0),(24656,397,'Capital Ship Assembly Array','A mobile assembly facility where large ships such as Battleships, Carriers, Dreadnoughts, Freighters, Industrial Command Ships and Capital Industrial Ships can be manufactured.\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials\r\r\n\r\r\nNote: To use a ship from a Ship Assembly Array a Ship Maintenance Array with enough free storage space needs to be in range that the ship can be moved there.',200000000,25000,18500500,1,NULL,100000000.0000,1,932,0),(24657,397,'Advanced Large Ship Assembly Array','A mobile assembly facility where advanced large ships such as Black Ops, Marauder class battleships as well as Jump Freighters can be manufactured.\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials\r\r\n\r\r\nNote: To use a ship from a Ship Assembly Array a Ship Maintenance Array with enough free storage space needs to be in range that the ship can be moved there.',200000000,25000,19500000,1,NULL,100000000.0000,1,932,0),(24658,397,'Ammunition Assembly Array','A mobile assembly facility where most ammunition such as Missiles, Hybrid Charges, Projectile Ammo and Frequency Crystals can be manufactured. Fuel Blocks can also be manufactured here.\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials',100000000,1250,1000000,1,NULL,10000000.0000,1,932,0),(24659,397,'Drone Assembly Array','A mobile assembly facility where small unmanned drones can be manufactured.\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials\r\r\n\r\r\nNote: Fighters are built in Small Ship Assembly Arrays.',100000000,1250,1000000,1,NULL,10000000.0000,1,932,0),(24660,397,'Component Assembly Array','A mobile assembly facility where Construction Components such as Capital Ship, Tech II and Hybrid (Tech III) Components of all sorts can be manufactured. Fuel Blocks can also be manufactured here.\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials',100000000,12500,1500000,1,NULL,10000000.0000,1,932,0),(24661,533,'Ytari Niaga','Ytari Niaga is an elite bounty hunter, famous throughout the EVE universe for his daring escapades while growing up as a member of the Mordu\'s Legion. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(24662,534,'Ratah Niaga','Ratah Niaga is an elite bounty hunter, famous throughout the EVE universe for his daring escapades while growing up as a member of the Mordu\'s Legion.  He is the elder brother of Ytari Niaga. Threat level: Deadly',19000000,22000000,235,1,1,0.0000,0,NULL,0),(24663,747,'Zor\'s Custom Navigation Hyper-Link','A neural Interface upgrade that boost the pilots skill in a specific area. This Navigation Hyper-Link was created for the ruthless pirate commander, referred to as \'Zor\'.  \r\r\n\r\r\n\r\r\n5% bonus to afterburner and micro-warpdrive speed-boost.',0,1,0,1,NULL,800000.0000,1,1491,0),(24664,517,'Mazed Karadom\'s Armageddon','An Armageddon piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24669,747,'Shaqil\'s Speed Enhancer','A hardwiring implant designed to enhance pilot navigation skill.\r\r\n\r\r\n8% bonus to ship velocity.',0,1,0,1,NULL,0.0000,1,1489,0),(24670,494,'Starbase Major Assembly Array','Assembly Arrays are oftentimes required to manufacture many high-tech and illegal modules that the empires don\'t want manufactured in their stations.  This is one of the biggest of its kind, able to churn out a great deal of equipment in relatively short order.\r\r\n\r\r\nThis structure is being guarded by Baron Haztari Arkhi.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(24671,494,'Starbase Major Assembly Array','Assembly Arrays are oftentimes required to manufacture many high-tech and illegal modules that the empires don\'t want manufactured in their stations.  This is one of the biggest of its kind, able to churn out a great deal of equipment in relatively short order.\r\r\n\r\r\nThis structure is being guarded by General Matar Pol.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(24682,523,'Maphante Guardian',' ',19000000,1150000,235,1,4,0.0000,0,NULL,0),(24683,520,'Maphante Interceptor',' ',1050000,28100,135,1,4,0.0000,0,NULL,0),(24684,438,'Biochemical Reactor Array','An arena for various different substances to mix and match. The Biochemical Reactor Array is where biochemical processes take place that can turn a simple element into a complex chemical.\r\r\n\r\r\nThe Biochemical Reactor Array may only contain Complex Biochemical Reactions.',100000000,4000,1,1,NULL,25000000.0000,1,490,0),(24685,319,'Stargate Minmatar 1','This stargate has been manufactured according to Republic design.  It is not usable without the proper authorization code.',1e35,100000000,10000,1,2,0.0000,0,NULL,0),(24688,27,'Rokh','Having long suffered the lack of an adequate hybrid platform, the Caldari State\'s capsule pilots found themselves rejoicing as the Rokh\'s design specs were released. A fleet vessel if ever there was one, this far-reaching and durable beast is expected to see a great deal of service on battlefields near and far.',105300000,486000,625,1,1,228452150.0000,1,80,0),(24689,107,'Rokh Blueprint',' ',0,0.01,0,1,NULL,1650000000.0000,1,280,0),(24690,27,'Hyperion','Recognizing the necessity for a blaster platform to round out their high-end arsenal, the Federation Navy brought in top-level talent to work on the Hyperion. The result: one of the most lethal and versatile gunboats ever to take to the dark skies.',100200000,495000,675,1,8,235223264.0000,1,81,0),(24691,107,'Hyperion Blueprint',' ',0,0.01,0,1,NULL,1760000000.0000,1,281,0),(24692,27,'Abaddon','The Abaddon class ship is a celestial tool of destruction. It is designed to enter combat from the outset, targeting enemies at range and firing salvo after salvo at them, and to remain intact on the battlefield until every heretic in sight has been torn to shreds.',103200000,495000,525,1,4,232044778.0000,1,79,0),(24693,107,'Abaddon Blueprint',' ',0,0.01,0,1,NULL,1800000000.0000,1,279,0),(24694,27,'Maelstrom','With the Maelstrom, versatility is the name of the game. Its defensive capabilities make it ideally suited for small raid groups or solo work, while its 8 turret hardpoints present opportunities for untold carnage on the fleet battlefield. ',103600000,472500,550,1,2,202108588.0000,1,78,0),(24695,107,'Maelstrom Blueprint',' ',0,0.01,0,1,NULL,1450000000.0000,1,278,0),(24696,419,'Harbinger','Right from its very appearance on a battlefield, the Harbinger proclaims its status as a massive weapon, a laser burning through the heart of the ungodly. Everything about it exhibits this focused intent, from the lights on its nose and wings that root out the infidels, to the large number of turreted high slots that serve to destroy them. Should any heathens be left alive after the Harbinger\'s initial assault, its drones will take care of them.',13800000,234000,375,1,4,60780698.0000,1,470,0),(24697,489,'Harbinger Blueprint',' ',0,0.01,0,1,NULL,585000000.0000,1,589,0),(24698,419,'Drake','Of the meticulous craftsmanship the Caldari are renowned for, the Drake was born. It was found beneath such a ship to rely on anything other than the time-honored combat tradition of missile fire, while the inclusion of sufficient CPU capabilities for decent electronic warfare goes without saying.',14810000,252000,450,1,1,59996916.0000,1,471,0),(24699,489,'Drake Blueprint',' ',0,0.01,0,1,NULL,580000000.0000,1,590,0),(24700,419,'Myrmidon','Worried that their hot-shot pilots would burn brightly in their eagerness to engage the enemy, the Federation Navy created a ship that encourages caution over foolhardiness. A hardier version of its counterpart, the Myrmidon is a ship designed to persist in battle. Its numerous medium and high slots allow it to slowly bulldoze its way through the opposition, while its massive drone space ensures that no enemy is left unscathed.',13100000,270000,400,1,8,60102766.0000,1,472,0),(24701,489,'Myrmidon Blueprint',' ',0,0.01,0,1,NULL,600000000.0000,1,591,0),(24702,419,'Hurricane','The force with which this ship hits is more than sufficient to leave a trail of shattered enemies, floating around like so much lifeless debris. An adaptable vessel, it has enough turret hardpoints for a full-scale assault while remaining versatile enough to allow for plenty of missile fire, and has both sufficient speed to outrun its enemies and sufficient capacitor charge to outlast them.',12800000,216000,425,1,2,64135040.0000,1,473,0),(24703,489,'Hurricane Blueprint',' ',0,0.01,0,1,NULL,565000000.0000,1,592,0),(24706,366,'Newly Constructed Acceleration Gate','Acceleration gate technology reaches far back to the expansion era of the empires that survived the great EVE gate collapse. While their individual setup might differ in terms of ship size they can transport and whether they require a certain passkey or code to be used, all share the same fundamental function of hurling space vessels to a destination beacon within solarsystem boundaries.',100000,0,0,1,NULL,0.0000,0,NULL,0),(24707,526,'Caldari Graduation Certificate','This certificate certifies the receiver as a graduate from a prominent Caldari aerospace aviation school.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24708,526,'Caldari Graduation Certificate (signed)','This certificate certifies the receiver as a graduate from a prominent Caldari aerospace aviation school.  It is ready to be shown to Aviekko Ta at Autama V - Moon 5 - Echelon Entertainment Development Studio.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24709,517,'Korhonomi Oti\'s Sparrow','A Sparrow piloted by an agent.',5250000,28100,165,1,1,0.0000,0,NULL,0),(24710,517,'Tillen Matsu\'s Sparrow','A Sparrow piloted by an agent.',5250000,28100,165,1,1,0.0000,0,NULL,0),(24711,517,'Autaris Pia\'s Sparrow','A Sparrow piloted by an agent.',5250000,28100,165,1,1,0.0000,0,NULL,0),(24712,517,'Kikko Roisen\'s Retribution','A Retribution piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(24713,306,'Guristas Stash','The worn container drifts quietly in space, closely guarded by pirates.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24714,526,'Important Surveillance Data','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24715,526,'Severed Head','This is the head of Ryoke Laika, a veteran Guristas pilot.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24716,319,'Station Caldari 6','Docking has been prohibited into this Caldari station without proper authorization.',0,0,0,1,1,0.0000,0,NULL,0),(24717,314,'Havatiah\'s Ship Database','This tiny, glassy data chip holds information from the database of a ship formerly in the possession of Havatiah Kiin.  Information stored within here could be anything from the ship\'s logs.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24718,818,'Havatiah Kiin','The Condor is fast and agile. It has limited cargo space so it\'s not very suitable for trading or mining. It is best used as an assault vessel in a hit-and-run type of operations.  It is sometimes used by the Caldari Navy and is generally considered an expendable low-cost craft.  Threat level: Moderate',1300000,18000,150,1,1,0.0000,0,NULL,0),(24719,526,'Gallente Graduation Certificate','This certificate certifies the receiver as a graduate from a prominent Gallente aerospace aviation school.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24720,526,'Gallente Graduation Certificate (signed)','This certificate certifies the receiver as a graduate from a prominent Gallente aerospace aviation school.  It is ready to be shown to Avrue Auz at Lirsautton I - CreoDron Factory.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24721,306,'Warehouse_MISSION2','This is a standard storage facility.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(24722,526,'Kelmiler\'s Transaction Documents 18992 D','These documents contain transaction logs for Kelimiler\'s trade hub in Meves.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24723,517,'Mamo Guerre\'s Megathron','A Megathron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(24724,306,'Serpentis Stash','A Serpentis stasis security vault. Nearly impossible to destroy but perhaps it is possible to bypass its security.  ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(24725,526,'Crash Ultra','This expensive booster is highly addictive and has been known to cause heart attacks and seizures.',5,0.2,0,1,NULL,0.0000,1,NULL,0),(24726,526,'FedMart Reports','These encoded reports may mean little to the untrained eye, but can prove valuable to the relevant institution.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24727,526,'Mamo\'s Message','Mamo Guerre\'s message has been recorded inside this data chip.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24728,526,'Eilard\'s Corpse','The rotting corpse of the unfortunate Eilard Ansti.',80,1,0,1,NULL,0.0000,1,NULL,0),(24729,283,'Govarde Alourtine','A serpentis goon.',80,1,0,1,NULL,0.0000,1,NULL,0),(24730,526,'Avrue\'s Token','This token might be of value in the future, so hold on to it.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24731,283,'Khanid Marine','When war breaks out, the demand for transporting military personnel on site can exceed the grasp of the military organization. In these cases, the aid from non-military spacecrafts is often needed.',1000,2,0,1,NULL,0.0000,1,NULL,0),(24732,517,'Mamin Choonka\'s Crusader','A Crusader piloted by an agent.\r\r\n\r\r\nMissions: \r\r\n\r\r\n<b>Difficulty Rating: Grade 1</b> ',0,0,0,1,4,0.0000,0,NULL,0),(24733,526,'Choonka\'s Coordinates','Coordinates for the meeting place with officers of the Khanid Traditionalist Movement.  Arizam Gimit might be interested in this data ...',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24734,526,'Secret Documents','These documents hold incriminating evidence against Mamin Choonka, implicating him with conspiracy with the Khanid rebel forces led by Deza Yobili.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24735,526,'Amarr Graduation Certificate','This certificate certifies the receiver as a graduate from a prominent Amarr aerospace aviation school.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24736,526,'Amarr Graduation Certificate (signed)','This certificate certifies the receiver as a graduate from a prominent Amarr aerospace aviation school.  It is ready to be shown to Arizam Gimit at Lossa II - Ministry of Assessment Information Center.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24737,517,'Shafra Gulias\'s Hawk','A Hawk piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(24738,517,'Sevan Fagided\'s Hawk','A Hawk piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(24739,517,'Hefaka Chubid\'s Hawk','A Hawk piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(24740,517,'Etien Duloure\'s Navitas','A Navitas piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(24741,517,'Vausitte Yrier\'s Navitas','A Navitas piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(24742,517,'Maray Ygier\'s Navitas','A Navitas piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(24743,517,'Avrue Auz\'s Merlin','A Merlin piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(24744,526,'Minmatar Graduation Certificate','This certificate certifies the receiver as a graduate from a prominent Minmatar aerospace aviation school.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24745,526,'Minmatar Graduation Certificate (signed)','This certificate certifies the receiver as a graduate from a prominent Minmatar aerospace aviation school.  It is ready to be shown to Pinala Adala at Eram IX - Moon 4 - Sebiestor tribe Bureau.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24746,517,'Rilbedur Tjar\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(24747,517,'West Ludorim\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(24748,517,'Albedur Vatzako\'s Rifter','A Rifter piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(24750,306,'Angel Stash_Extrava','The worn container drifts quietly in space, closely guarded by pirates.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24751,494,'Storage Silo','Built to withstand assault, these behemoths can each hold roughly 8.5 million m3 worth of materials.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24752,283,'Angel Cartel Pilot','A pilot working for the Angel Cartel.',80,1,0,1,NULL,0.0000,1,NULL,0),(24754,337,'A Hired Saboteur','This is an inexperienced saboteur. Saboteurs usually has skills for different kinds of related work, such as espionage, counterfeiting or infiltration. Such actions are often required before an actual sabotage takes place.',80000,20400,1200,1,NULL,0.0000,0,NULL,0),(24755,283,'Logut Akell','The old Vherokior shaman, Logut Akell, is rarely seen in public, rather opting for a hermitical life.  Since he has little contact with other Minmatars, few will notice his absence should he disappear.',80,5,0,1,NULL,0.0000,1,NULL,0),(24756,526,'Stolen Documents','Documents reported stolen.',1,0.01,0,1,NULL,0.0000,1,NULL,0),(24757,818,'Saboteur Mercenary','This is an inexperienced saboteur. Saboteurs usually has skills for different kinds of related work, such as espionage, counterfeiting or infiltration. Such actions are often required before an actual sabotage takes place.',2450000,24500,60,1,4,0.0000,0,NULL,0),(24758,517,'Logut Akell\'s Abode','Massive construction girders stretch between the crumbled asteroids, giving a solid ground for a station or outpost.  The structure connecting the asteroids appears to be inhabited.',0,0,0,1,NULL,0.0000,0,NULL,0),(24759,818,'Dari Akell\'s Maulus','The Maulus is a high-tech vessel, specialized for electronic warfare. It is particularly valued amongst bounty hunters for the ship\'s optimization for warp scrambling technology, giving its targets no chance of escape.  Threat level: Moderate',1400000,23000,175,1,8,0.0000,0,NULL,0),(24760,283,'Dari Akell','A Minmatar civilian.',80,5,0,1,NULL,0.0000,1,NULL,0),(24761,494,'Blasted Neon Sign_mission','Once the pride and joy of its parent corporation, this broken-down heap of neon and metal is now no more than a symbolic manifestation of capitalistic decline.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24762,474,'Logut\'s Keycard','This security passcard is manufactured by the Minmatar Fleet and allows the user to unlock a specific acceleration gate to another sector. The gate will remain open for a short period of time and the keycard will be rendered useless after uploading the card\'s data to the gate\'s activation device.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(24763,526,'Encryption Code Book','A book used to decrypt messages',1,0.01,0,1,NULL,0.0000,1,NULL,0),(24764,258,'Fleet Command','Grants the Fleet Commander the ability to pass on their bonuses to an additional Wing per skill level, up to a maximum of 5 Wings. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,20000000.0000,1,370,0),(24765,306,'Damaged Heron','This ship has been damaged and has lost its ability to maneuver, as well as its warp capability.',1450000,16120,145,1,1,0.0000,0,NULL,0),(24766,283,'Ship\'s Crew','A non-capsuleer member of a ship\'s crew relegated to manual tasks essential for maintaining the operational status of the ship.',1000,2,0,1,NULL,0.0000,1,NULL,0),(24767,383,'Guristas Basic Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(24768,319,'Gallente Station 7','Docking has been prohibited into this station without proper authorization.',0,0,0,1,8,0.0000,0,NULL,0),(24769,319,'Gallente Station 8','Docking has been prohibited into this station without proper authorization.',0,0,0,1,8,0.0000,0,NULL,0),(24770,319,'Gallente Station 4','Docking has been prohibited into this station without proper authorization.',0,0,0,1,8,0.0000,0,NULL,0),(24771,494,'Overseer\'s Stash','A small bunker, there for accommodation for the overseer of a faction within Sansha\'s army.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(24772,383,'Deficient Tower Sentry Sansha II','Sansha tachyon beam sentry ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(24777,683,'Republic Radur','A frigate of the Minmatar Republic.',2112000,21120,100,1,2,0.0000,0,NULL,0),(24779,683,'Republic Skani','A frigate of the Minmatar Republic.',2250000,22500,75,1,2,0.0000,0,NULL,0),(24781,683,'Republic Otur','A frigate of the Minmatar Republic.',1740000,17400,220,1,2,0.0000,0,NULL,0),(24784,683,'Republic Kvarm','A frigate of the Minmatar Republic.',2600500,26005,120,1,2,0.0000,0,NULL,0),(24785,683,'Republic Tribal Gleeda','A powerful frigate of the Minmatar Republic.',1766000,17660,120,1,2,0.0000,0,NULL,0),(24786,683,'Republic Tribal Baldur','A powerful frigate of the Minmatar Republic.',1750000,17500,180,1,2,0.0000,0,NULL,0),(24787,683,'Republic Gleeda','A frigate of the Minmatar Republic.',1766000,17660,120,1,2,0.0000,0,NULL,0),(24790,683,'Republic Baldur','A frigate of the Minmatar Republic.',1645000,16450,110,1,2,0.0000,0,NULL,0),(24791,683,'Republic Takan','A frigate of the Minmatar Republic.',1910000,19100,80,1,2,0.0000,0,NULL,0),(24793,683,'Republic Tribal Takan','A powerful frigate of the Minmatar Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(24797,684,'Republic Faxi','A destroyer of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24798,684,'Republic Austri','A destroyer of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24799,684,'Republic Bormin','A destroyer of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24801,684,'Republic Tribal Faxi','A powerful destroyer of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24805,684,'Republic Tribal Bormin','A powerful destroyer of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24810,684,'Republic Tribal Austri','A powerful destroyer of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24811,683,'Chief Republic Isak','An elite frigate of the Minmatar Republic.\r\r\n',1645000,16450,110,1,2,0.0000,0,NULL,0),(24812,683,'Chief Republic Iflin','An elite frigate of the Minmatar Republic.\r\r\n',1645000,16450,110,1,2,0.0000,0,NULL,0),(24813,683,'Chief Republic Ivan','An elite frigate of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24814,683,'Chief Republic Magni','An elite frigate of the Minmatar Republic.\r\r\n\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24815,683,'Chief Republic Kvarm','An elite frigate of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24816,683,'Chief Republic Gleeda','An elite frigate of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24817,683,'Chief Republic Baldur','An elite frigate of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24818,683,'Chief Republic Ofeg','An elite frigate of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24819,683,'Chief Republic Hrakt','An elite frigate of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24820,683,'Chief Republic Takan','An elite frigate of the Minmatar Republic.\r\r\n',1645000,16450,120,1,2,0.0000,0,NULL,0),(24821,705,'Republic Solon','A cruiser of the Minmatar Republic.\r\r\n',9900000,99000,1900,1,2,0.0000,0,NULL,0),(24823,705,'Republic Ormur','A cruiser of the Minmatar Republic.\r\r\n',9900000,99000,120,1,2,0.0000,0,NULL,0),(24824,705,'Republic Rodul','A cruiser of the Minmatar Republic.\r\r\n',10900000,109000,1400,1,2,0.0000,0,NULL,0),(24826,705,'Republic Manadis','A cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24828,705,'Republic Jarpur','A cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24830,705,'Republic Tribal Solon','A powerful cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24832,705,'Republic Tribal Ormur','A powerful cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24834,705,'Republic Tribal Rodul','A powerful cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24835,705,'Republic Tribal Manadis','A powerful cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24836,705,'Republic Tribal Jarpur','A powerful cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24843,685,'Republic Nutia','A battlecruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24847,685,'Republic Venis','A battlecruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24848,685,'Republic Tribal Nutia','A powerful battlecruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24851,685,'Republic Norn','A battlecruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24855,685,'Republic Tribal Venis','A powerful battlecruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24857,685,'Republic Tribal Norn','A powerful battlecruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24859,705,'Chief Republic Klaki','An elite cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24860,705,'Chief Republic Orsin','An elite cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24861,705,'Chief Republic Pafi','An elite cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24862,705,'Chief Republic Tenar','An elite cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24863,705,'Chief Republic Rodul','An elite cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24864,705,'Chief Republic Manadis','An elite cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24865,705,'Chief Republic Orka','An elite cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24866,705,'Chief Republic Jarpur','An elite cruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(24867,706,'Republic Pytara','A battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24868,706,'Republic Jarl','A battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24869,706,'Republic Jotun','A battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24870,706,'Republic Sigur','A battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24875,706,'Republic Ymir','A battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24876,706,'Republic Tribal Pytara','A battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24883,706,'Republic Tribal Sigur','A powerful battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24884,706,'Republic Tribal Ymir','A powerful battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24886,706,'Republic Tribal Jarl','A powerful battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24888,706,'Republic Tribal Jotun','A powerful battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(24891,665,'Imperial Disciple','A frigate of the Amarr Empire.\r\r\n',2810000,28100,120,1,4,0.0000,0,NULL,0),(24892,665,'Imperial Dopa','A frigate of the Amarr Empire.\r\r\n',2810000,28100,120,1,4,0.0000,0,NULL,0),(24893,665,'Imperial Haran','A frigate of the Amarr Empire.\r\r\n',2820000,24398,235,1,4,0.0000,0,NULL,0),(24894,665,'Imperial Iezaz','A frigate of the Amarr Empire.\r\r\n',2820000,24398,235,1,4,0.0000,0,NULL,0),(24895,665,'Imperial Matendi','A frigate of the Amarr Empire.\r\r\n',2810000,28100,235,1,4,0.0000,0,NULL,0),(24896,665,'Imperial Nabih','A frigate of the Amarr Empire.\r\r\n',2810000,28100,135,1,4,0.0000,0,NULL,0),(24897,665,'Imperial Felix_old','A frigate of the Amarr Empire.\r\r\n',2810000,28100,235,1,4,0.0000,0,NULL,0),(24898,665,'Imperial Sixtus','A frigate of the Amarr Empire.\r\r\n',2810000,28100,135,1,4,0.0000,0,NULL,0),(24899,665,'Imperial Bahir','A frigate of the Amarr Empire.\r\r\n',2810000,28100,165,1,4,0.0000,0,NULL,0),(24900,665,'Imperial Templar Forian','A powerful frigate of the Amarr Empire.\r\r\n',2810000,28100,315,1,4,0.0000,0,NULL,0),(24901,665,'Imperial Forian','A frigate of the Amarr Empire.\r\r\n',2810000,28100,165,1,4,0.0000,0,NULL,0),(24902,665,'Imperial Sprite','A frigate of the Amarr Empire.\r\r\n',2810000,28100,315,1,4,0.0000,0,NULL,0),(24903,665,'Imperial Forian_old','A frigate of the Amarr Empire.\r\r\n',2870000,28700,235,1,4,0.0000,0,NULL,0),(24904,665,'Imperial Paladin','A frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24905,665,'Imperial Felix','A frigate of the Amarr Empire.\r\r\n',2870000,28700,135,1,4,0.0000,0,NULL,0),(24906,665,'Imperial Templar Napat','A powerful frigate of the Amarr Empire.\r\r\n',2870000,28700,235,1,4,0.0000,0,NULL,0),(24907,665,'Imperial Templar Paladin','A powerful frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24908,665,'Imperial Templar Forian_old','A powerful frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24909,665,'Imperial Templar Valok','A powerful frigate of the Amarr Empire.\r\r\n',2870000,28700,135,1,4,0.0000,0,NULL,0),(24910,665,'Imperial Templar Paladin_old','A powerful frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24911,669,'Imperial Deacon','A destroyer of the Amarr empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24912,669,'Imperial Exarp','A destroyer of the Amarr empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24913,669,'Imperial Caius','A destroyer of the Amarr empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24915,669,'Imperial Crusader','A destroyer of the Amarr empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24917,669,'Imperial Templar Caius','A powerful destroyer of the Amarr empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24919,669,'Imperial Templar Crusader','A powerful destroyer of the Amarr empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24923,665,'Divine Imperial Nabih','An elite frigate of the Amarr Empire.\r\r\n',2870000,28700,235,1,4,0.0000,0,NULL,0),(24924,665,'Divine Imperial Felix','An elite frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24925,665,'Divine Imperial Imran','An elite frigate of the Amarr Empire.\r\r\n',2870000,28700,135,1,4,0.0000,0,NULL,0),(24926,665,'Divine Imperial Sixtus','An elite frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24927,665,'Divine Imperial Bahir','An elite frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24928,665,'Divine Imperial Napat','An elite frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24929,665,'Divine Imperial Sprite','An elite frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24930,665,'Divine Imperial Forian','An elite frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24931,665,'Divine Imperial Valok','An elite frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24932,665,'Divine Imperial Paladin','An elite frigate of the Amarr Empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(24933,668,'Imperial Muzakir','A cruiser of the Amarr Empire.\r\r\n',11500000,115000,465,1,4,0.0000,0,NULL,0),(24935,668,'Imperial Mathura','A cruiser of the Amarr Empire.\r\r\n',12000000,120000,450,1,4,0.0000,0,NULL,0),(24938,668,'Imperial Donus','A cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24940,668,'Imperial Tamir','A cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24941,668,'Imperial Agatho','A cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24942,668,'Imperial Templar Muzakir','A powerful cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24944,668,'Imperial Templar Mathura','A powerful cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24947,668,'Imperial Templar Donus','A powerful cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24949,668,'Imperial Templar Tamir','A powerful cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24952,668,'Imperial Templar Agatho','A powerful cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24956,666,'Imperial Equalizer','A battlecruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24957,666,'Imperial Avenger','A battlecruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24958,666,'Imperial Justicar','A battlecruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24959,666,'Imperial Champion','A battlecruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24960,666,'Imperial Templar Justicar','A powerful battlecruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24962,666,'Imperial Templar Champion','A powerful battlecruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24968,668,'Divine Imperial Wrath','An elite cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24969,668,'Divine Imperial Tamir','An elite cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24970,668,'Divine Imperial Ambrose','An elite cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24971,668,'Divine Imperial Basil','An elite cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24972,668,'Divine Imperial Equalizer','An elite cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24973,668,'Divine Imperial Avenger','An elite cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24974,668,'Divine Imperial Justicar','An elite cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24975,668,'Divine Imperial Champion','An elite cruiser of the Amarr Empire.\r\r\n',11800000,118000,235,1,4,0.0000,0,NULL,0),(24976,667,'Imperial Origen','A battleship of the Amarr Empire.\r\r\n',20500000,1100000,235,1,4,0.0000,0,NULL,0),(24977,667,'Imperial Bataivah','A battleship of the Amarr Empire.\r\r\n',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24978,667,'Imperial Tanakh','A battleship of the Amarr Empire.\r\r\n',20500000,1100000,235,1,4,0.0000,0,NULL,0),(24979,667,'Imperial Ultara','A battleship of the Amarr Empire.\r\r\n',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24982,667,'Imperial Dominator','A battleship of the Amarr Empire.\r\r\n',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24983,667,'Imperial Martyr','A battleship of the Amarr Empire.\r\r\n',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24985,667,'Imperial Templar Torah','A powerful battleship of the Amarr Empire.\r\r\n',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24988,667,'Imperial Templar Ultara','A powerful battleship of the Amarr Empire.\r\r\n',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24991,667,'Imperial Templar Dominator','A powerful battleship of the Amarr Empire.\r\r\n',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24992,667,'Imperial Templar Martyr','A powerful battleship of the Amarr Empire.\r\r\n',19500000,1150000,235,1,4,0.0000,0,NULL,0),(24997,671,'State Bo-Hi','A frigate of the Caldari State.\r\r\n',1500100,15001,45,1,1,0.0000,0,NULL,0),(24999,671,'State Showato','A frigate of the Caldari State.\r\r\n',1612000,16120,80,1,1,0.0000,0,NULL,0),(25001,671,'State Nagasa','A frigate of the Caldari State.\r\r\n',2025000,20250,235,1,1,0.0000,0,NULL,0),(25004,671,'State Shinai','A frigate of the Caldari State.\r\r\n',2025000,20250,65,1,1,0.0000,0,NULL,0),(25007,671,'State Shuriken','A frigate of the Caldari State.\r\r\n',2040000,20400,100,1,1,0.0000,0,NULL,0),(25008,671,'State Daito','A frigate of the Caldari State.\r\r\n',2040000,20400,235,1,1,0.0000,0,NULL,0),(25011,671,'State Wakizashi','A frigate of the Caldari State.\r\r\n',1970000,19700,125,1,1,0.0000,0,NULL,0),(25012,671,'State Katana','A frigate of the Caldari State.\r\r\n',1650000,16500,130,1,1,0.0000,0,NULL,0),(25013,671,'State Shukuro Shinai','A powerful frigate of the Caldari State.\r\r\n',1970000,19700,235,1,1,0.0000,0,NULL,0),(25015,671,'State Shukuro Shuriken','A powerful frigate of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25020,676,'State Kai Gunto','A destroyer of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25021,676,'State Yumi','A destroyer of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25022,676,'State Kissaki','A destroyer of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25024,676,'State Tsuba','A destroyer of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25026,676,'State Shukuro Choji','A powerful destroyer of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25028,676,'State Shukuro Kamikazi','A powerful destroyer of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25033,671,'Taibu State Shirasaya','An elite frigate of the Caldari State.\r\r\n',1970000,19700,125,1,1,0.0000,0,NULL,0),(25034,671,'Taibu State Suriage','An elite frigate of the Caldari State.\r\r\n',1650000,16500,130,1,1,0.0000,0,NULL,0),(25035,671,'Taibu State Nagasa','An elite frigate of the Caldari State.\r\r\n',1970000,19700,235,1,1,0.0000,0,NULL,0),(25036,671,'Taibu State Shinai','An elite frigate of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25037,671,'Taibu State Shuriken','An elite frigate of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25038,671,'Taibu State Tachi','An elite frigate of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25039,671,'Taibu State Yari','An elite frigate of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25040,671,'Taibu State Daito','An elite frigate of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25041,671,'Taibu State Wakizashi','An elite frigate of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25042,671,'Taibu State Katana','An elite frigate of the Caldari State.\r\r\n',1650000,16500,235,1,1,0.0000,0,NULL,0),(25043,673,'State Bushi','A cruiser of the Caldari State.\r\r\n',10700000,107000,850,1,1,0.0000,0,NULL,0),(25045,673,'State Dogo','A cruiser of the Caldari State.\r\r\n',9600000,96000,450,1,1,0.0000,0,NULL,0),(25046,673,'State Fudai','A cruiser of the Caldari State.\r\r\n',9200000,92000,235,1,1,0.0000,0,NULL,0),(25048,673,'State Ashigaru','A cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25050,673,'State Chugen','A cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25052,673,'State Buke','A cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25054,673,'State Shukuro Ashigaru','A powerful cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25056,673,'State Shukuro Chugen','A powerful cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25057,673,'State Shukuro Buke','A powerful cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25058,673,'State Shukuro Ashura','A powerful cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25063,672,'State Kerai','A battlecruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25064,672,'State Ronin','A battlecruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25065,672,'State Oni','A battlecruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25066,672,'State Kanpaku','A battlecruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25067,672,'State Shukuro Bajo','A powerful battlecruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25069,672,'State Shukuro Samurai','A powerful battlecruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25075,673,'Taibu State Tendai','An elite cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25076,673,'Taibu State Sohei','An elite cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25077,673,'Taibu State Shugo','An elite cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25078,673,'Taibu State Daimyo','An elite cruiser of the Caldari State.\r\r\n\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25079,673,'Taibu State Oni','An elite cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25080,673,'Taibu State Kanpaku','An elite cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25081,673,'Taibu State Bajo','An elite cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25082,673,'Taibu State Samurai','An elite cruiser of the Caldari State.\r\r\n',10100000,101000,235,1,1,0.0000,0,NULL,0),(25083,674,'State Tenkyu','A battleship of the Caldari State.\r\r\n',21000000,1040000,235,1,1,0.0000,0,NULL,0),(25084,674,'State Utaisho','A battleship of the Caldari State.\r\r\n',22000000,1080000,235,1,1,0.0000,0,NULL,0),(25085,674,'State Yojimbo','A battleship of the Caldari State.\r\r\n',21000000,1040000,235,1,1,0.0000,0,NULL,0),(25086,674,'State Zen','A battleship of the Caldari State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(25089,674,'State Oshiro','A battleship of the Caldari State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(25090,674,'State Shukuro Tenno','A battleship of the Caldari State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(25092,674,'State Shukuro Taisho','A battleship of the Caldari State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(25094,674,'State Shukuro Daijo','A powerful battleship of the Caldari State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(25097,674,'State Shukuro Bishamon','This is a powerful battleship of the Caldari State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(25098,674,'State Shukuro Shogun','A powerful battleship of the Caldari State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(25103,677,'Federation Clavis','A frigate of the Gallente Federation.\r\r\n',2450000,24500,60,1,8,0.0000,0,NULL,0),(25105,677,'Federation Hastile','A frigate of the Gallente Federation.\r\r\n',2250000,22500,125,1,8,0.0000,0,NULL,0),(25106,677,'Federation Kontos','A frigate of the Gallente Federation.\r\r\n',2500000,25000,60,1,8,0.0000,0,NULL,0),(25107,677,'Federation Hoplon','A frigate of the Gallente Federation.\r\r\n',2250000,22500,235,1,8,0.0000,0,NULL,0),(25110,677,'Federation Manica','A frigate of the Gallente Federation.\r\r\n',2950000,29500,175,1,8,0.0000,0,NULL,0),(25112,677,'Federation Libertus','A frigate of the Gallente Federation.\r\r\n',2950000,29500,235,1,8,0.0000,0,NULL,0),(25116,677,'Federation Insidiator','A frigate of the Gallente Federation.\r\r\n',2300000,23000,60,1,8,0.0000,0,NULL,0),(25117,677,'Federation Praktor Balra','A powerful frigate of the Gallente Federation.\r\r\n',2300000,23000,235,1,8,0.0000,0,NULL,0),(25118,677,'Federation Praktor Belos','A powerful frigate of the Gallente Federation.\r\r\n',2650000,26500,140,1,8,0.0000,0,NULL,0),(25120,677,'Federation Praktor Harpago','A powerful frigate of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25124,677,'Federation Kopis','A frigate of the Gallente Federation.\r\r\n',2250000,22500,125,1,8,0.0000,0,NULL,0),(25125,679,'Federation Machaira','A destroyer of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25126,679,'Federation Matara','A destroyer of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25127,679,'Federation Arcus','A destroyer of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25129,679,'Federation Pelekus','A destroyer of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25131,679,'Federation Praktor Phalarica','A powerful destroyer of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25133,679,'Federation Praktor Machina','A powerful destroyer of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25137,677,'Elite Federation Lixa','An elite frigate of the Gallente Federation.\r\r\n',2300000,23000,60,1,8,0.0000,0,NULL,0),(25138,677,'Elite Federation Lochos','An elite frigate of the Gallente Federation.\r\r\n',2300000,23000,235,1,8,0.0000,0,NULL,0),(25139,677,'Elite Federation Manica','An elite frigate of the Gallente Federation.\r\r\n',2650000,26500,140,1,8,0.0000,0,NULL,0),(25140,677,'Elite Federation Libertus','An elite frigate of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25141,677,'Elite Federation Insidiator','An elite frigate of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25142,677,'Elite Federation Matara','An elite frigate of the Gallente Federation.\r\r\n\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25143,677,'Elite Federation Arcus','An elite frigate of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25144,677,'Elite Federation Pelekus','An elite frigate of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25145,677,'Elite Federation Phalarica','An elite frigate of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25146,677,'Elite Federation Machina','An elite frigate of the Gallente Federation.\r\r\n',2650000,26500,235,1,8,0.0000,0,NULL,0),(25147,678,'Federation Loras','A cruiser of the Gallente Federation.\r\r\n',11300000,113000,235,1,8,0.0000,0,NULL,0),(25149,678,'Federation Hastarius','A cruiser of the Gallente Federation.\r\r\n',11600000,116000,900,1,8,0.0000,0,NULL,0),(25150,678,'Federation Hastatus','A cruiser of the Gallente Federation.\r\r\n',11500000,115000,235,1,8,0.0000,0,NULL,0),(25152,678,'Federation Misthios','A cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25154,678,'Federation Nauclarius','A cruiser of the Gallente Federation.\r\r\n\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25156,678,'Federation Praktor Hippeus','A powerful cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25158,678,'Federation Praktor Ouragos','A powerful cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25160,678,'Federation Praktor Optioon','A powerful cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25161,678,'Federation Praktor Legionarius','A powerful cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25162,678,'Federation Praktor Centurion','A powerful cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25167,681,'Federation Pezos','A battlecruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25168,681,'Federation Praeco','A battlecruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25169,681,'Federation Calo','A battlecruiser of the Gallente Federation.\r\r\n\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25170,681,'Federation Praktor Bearcus','A powerful battlecruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25171,681,'Federation Praktor Arx','A powerful battlecruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25173,681,'Federation Praktor Auxilia','A powerful battlecruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25179,678,'Elite Federation Calo','An elite cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25180,678,'Elite Federation Bearcus','An elite cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25181,678,'Elite Federation Arx','An elite cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25182,678,'Elite Federation Auxilia','An elite cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25183,678,'Elite Federation Liburna','An elite cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25184,678,'Elite Federation Navis','An elite cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25185,678,'Elite Federation Quadrieris','An elite cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25186,678,'Elite Federation Mentes','An elite cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25187,680,'Federation Triarius','A battleship of the Gallente Federation.\r\r\n',19000000,1010000,480,1,8,0.0000,0,NULL,0),(25188,680,'Federation Xenan','A battleship of the Gallente Federation.\r\r\n',17500000,1140000,480,1,8,0.0000,0,NULL,0),(25189,680,'Federation Helepolis','A battleship of the Gallente Federation.\r\r\n',19000000,1010000,480,1,8,0.0000,0,NULL,0),(25190,680,'Federation Covinus','A battleship of the Gallente Federation.\r\r\n',17500000,1140000,480,1,8,0.0000,0,NULL,0),(25193,680,'Federation Navis Longa','A battleship of the Gallente Federation.\r\r\n',17500000,1140000,480,1,8,0.0000,0,NULL,0),(25194,680,'Federation Praktor Navis Praetoria','A powerful battleship of the Gallente Federation.\r\r\n',17500000,1140000,480,1,8,0.0000,0,NULL,0),(25196,680,'Federation Praktor Hexeris','A powerful battleship of the Gallente Federation.\r\r\n',17500000,1140000,480,1,8,0.0000,0,NULL,0),(25198,680,'Federation Praktor Praeses','A powerful battleship of the Gallente Federation.\r\r\n\r\r\n',17500000,1140000,480,1,8,0.0000,0,NULL,0),(25201,680,'Federation Praktor Phanix','A powerful battleship of the Gallente Federation.\r\r\n',17500000,1140000,480,1,8,0.0000,0,NULL,0),(25202,680,'Federation Praktor Magister','A powerful battleship of the Gallente Federation.\r\r\n',17500000,1140000,480,1,8,0.0000,0,NULL,0),(25215,185,'Apocalypse 125ms 2500m','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(25230,409,'Republic Fleet High Captain Insignia II','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,100000.0000,1,NULL,0),(25231,226,'Stargate - Minmatar','This stargate has been manufactured according to Republic design.  It is not usable without the proper authorization code.',1e35,100000000,10000,1,2,0.0000,0,NULL,0),(25232,226,'Stargate - Gallente','This stargate has been manufactured according to Federation design.  It is not usable without the proper authorization code.',1e35,100000000,10000,1,8,0.0000,0,NULL,0),(25233,274,'Corporation Contracting','You are familiar with the intricacies of formalizing contracts between your corporation and other entities. \r\r\n\r\r\nFor each level of this skill the number of concurrent corporation/alliance contracts you make on behalf of your corporation is increased by 10 up to a maximum of 60. \r\r\n\r\r\nThis skill has no effect on contracts you make personally.\r\r\n\r\r\nThere is no limit on the number of contracts a corporation can assign to itself.\r\r\n\r\r\nCorporations have a hard limit of 500 outstanding public contracts. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,150000.0000,1,378,0),(25235,274,'Contracting','This skill allows you to create formal agreements with other characters. \r\r\n\r\r\nFor each level of this skill the number of outstanding contracts is increased by four (up to a maximum of 21 at level 5)\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,150000.0000,1,378,0),(25236,305,'Gas Cloud 1',' ',10,100,0,200,NULL,0.0000,0,NULL,0),(25237,712,'Pure Standard Blue Pill Booster','Standard Blue pill compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25239,370,'Blood Gold Tag','This gold tag carries the rank insignia equivalent of a sergeant within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,4500.0000,1,741,0),(25240,662,'Improved Blue Pill Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25241,712,'Pure Improved Blue Pill Booster','Improved Blue Pill compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25242,712,'Pure Standard Crash Booster','Standard Crash compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25243,661,'Standard Crash Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(25244,305,'Gas Cloud 2',' ',0,100,0,1,NULL,0.0000,0,NULL,0),(25245,305,'Gas Cloud 3',' ',0,100,0,1,NULL,0.0000,0,NULL,0),(25246,305,'Gas Cloud 4',' ',0,100,0,1,NULL,0.0000,0,NULL,0),(25247,305,'Gas Cloud 5',' ',0,100,0,1,NULL,0.0000,0,NULL,0),(25248,305,'Gas Cloud 6',' ',0,100,0,1,NULL,0.0000,0,NULL,0),(25249,305,'Gas Cloud 7',' ',0,100,0,1,NULL,0.0000,0,NULL,0),(25250,305,'Gas Cloud 8',' ',0,100,0,1,NULL,0.0000,0,NULL,0),(25251,661,'Standard Frentix Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(25252,712,'Pure Standard Frentix Booster','Standard Frentix compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25255,306,'Damaged Heron_2','This ship has been damaged and has lost its ability to maneuver, as well as its warp capability.',1450000,16120,145,1,1,0.0000,0,NULL,0),(25266,737,'Gas Cloud Harvester I','The core technology employed by Gas Harvesters dates back centuries, to a time when the extraction of material in space was still a growing industry. Originally, asteroid miners had seen the tractor beams and in-space catalytic conversions used by today\'s Gas Harvesters as a promising new method for extracting spacebound ore. After many unsuccessful research projects and years of fruitless experiments however, the industry decided to return its focus to laser technology, which was eventually mastered to a level that has sustained the mining profession to this day.\r\r\n\r\r\nWhen the first interstellar Gas Clouds were discovered, they proved particularly challenging for industrialists to extract raw materials from. Many methods were tried, and although successful acquisition was always guaranteed, there was a need for much greater efficiency. It was not until the mining industry returned to long-abandoned projects that a solution was found. Since that time, Gas harvesting technology has slowly moved forward, giving birth to new industries and economies in the process. \r\r\n',0,5,0,1,NULL,5103964.0000,1,1037,0),(25267,134,'Gas Cloud Harvester I Blueprint',' ',0,0.01,0,1,NULL,16500000.0000,1,338,0),(25268,711,'Amber Cytoserocin','Cytoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. It is used in electronics and weapon manufacturing, as well as the production of high-grade combat boosters. Cytoserocin can only be found in a few areas, such as interstellar gas clouds out in low security and 0.0 space.  ',0,10,0,1,NULL,0.0000,1,983,0),(25270,404,'Biochemical Silo','Specialized container designed to store and handle gas clouds.',100000000,4000,20000,1,NULL,20000000.0000,1,483,0),(25271,404,'Catalyst Silo','Specialized container designed to store and handle hazardous liquids.',100000000,4000,20000,1,NULL,7500000.0000,1,483,0),(25273,711,'Golden Cytoserocin','Cytoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. It is used in electronics and weapon manufacturing, as well as the production of high-grade combat boosters. Cytoserocin can only be found in a few areas, such as interstellar gas clouds out in low security and 0.0 space.  ',0,10,0,1,NULL,0.0000,1,983,0),(25274,711,'Viridian Cytoserocin','Cytoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. It is used in electronics and weapon manufacturing, as well as the production of high-grade combat boosters. Cytoserocin can only be found in a few areas, such as interstellar gas clouds out in low security and 0.0 space.  ',0,10,0,1,NULL,0.0000,1,983,0),(25275,711,'Celadon Cytoserocin','Cytoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. It is used in electronics and weapon manufacturing, as well as the production of high-grade combat boosters. Cytoserocin can only be found in a few areas, such as interstellar gas clouds out in low security and 0.0 space.  ',0,10,0,1,NULL,0.0000,1,983,0),(25276,711,'Malachite Cytoserocin','Cytoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. It is used in electronics and weapon manufacturing, as well as the production of high-grade combat boosters. Cytoserocin can only be found in a few areas, such as interstellar gas clouds out in low security and 0.0 space.  ',0,10,0,1,NULL,0.0000,1,983,0),(25277,711,'Lime Cytoserocin','Cytoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. It is used in electronics and weapon manufacturing, as well as the production of high-grade combat boosters. Cytoserocin can only be found in a few areas, such as interstellar gas clouds out in low security and 0.0 space.  ',0,10,0,1,NULL,0.0000,1,983,0),(25278,711,'Vermillion Cytoserocin','Cytoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. It is used in electronics and weapon manufacturing, as well as the production of high-grade combat boosters. Cytoserocin can only be found in a few areas, such as interstellar gas clouds out in low security and 0.0 space.  ',0,10,0,1,NULL,0.0000,1,983,0),(25279,711,'Azure Cytoserocin','Cytoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. It is used in electronics and weapon manufacturing, as well as the production of high-grade combat boosters. Cytoserocin can only be found in a few areas, such as interstellar gas clouds out in low security and 0.0 space.  ',0,10,0,1,NULL,0.0000,1,983,0),(25280,404,'Hazardous Chemical Silo','Used to store and handle hazardous biochemicals.',100000000,4000,20000,1,NULL,25000000.0000,1,483,0),(25281,474,'The Red Card','Captain Rogue found that the acceleration gate he was supposed to be guarding was \"leaking\", and so decided to personally hold the passkey which he calls the \"Red Card\".',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25282,662,'Strong Blue Pill Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25283,712,'Pure Strong Blue Pill Booster','Strong Blue Pill compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25284,661,'Standard Drop Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(25285,661,'Standard Exile Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(25286,661,'Standard Mindflood Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(25287,661,'Standard X-Instinct Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(25288,661,'Standard Sooth Sayer Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(25289,662,'Improved Crash Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25290,662,'Improved Drop Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25291,662,'Improved Exile Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25292,662,'Improved Mindflood Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25293,662,'Improved Frentix Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25294,662,'Improved X-Instinct Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25295,662,'Improved Sooth Sayer Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25296,662,'Strong Crash Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25297,662,'Strong Drop Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25298,662,'Strong Exile Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25299,662,'Strong Mindflood Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25300,662,'Strong Frentix Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25301,662,'Strong X-Instinct Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25302,662,'Strong Sooth Sayer Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1853,0),(25303,718,'Standard Blue Pill Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25304,474,'Pith Guristas Spa-Card','Keys like this one are expensive ones, manufactured for members of the deadspace Pith Guristas and handed out to those that have \"delivered\".',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25305,397,'Drug Lab','A laboratory to produce performance enhancing drugs. This structure has no specific time or material requirement bonuses to booster manufacturing.',100000000,1250,100000,1,NULL,75000000.0000,1,933,0),(25306,820,'Pithatis Speaker','A speaker for the pith guristas, this oratory expert makes his living giving speeches that invigorate and inspire. If anything, then the demand for this particular skill is on the increase.',10100000,101000,235,1,1,0.0000,0,NULL,0),(25307,718,'Improved Blue Pill Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25308,718,'Strong Blue Pill Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25309,718,'Standard Crash Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25310,718,'Improved Crash Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25311,718,'Strong Crash Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25314,718,'Standard Sooth Sayer Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25322,718,'Strong Frentix Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25323,718,'Standard Mindflood Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25327,718,'Standard Drop Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25328,718,'Improved Drop Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25329,718,'Strong Drop Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25330,712,'Pure Standard Drop Booster','Standard Drop compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25331,712,'Pure Standard Exile Booster','Standard Exile compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25332,712,'Pure Standard Mindflood Booster','Standard Mindflood compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25333,712,'Pure Standard X-Instinct Booster','Standard X-Instinct compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25334,712,'Pure Standard Sooth Sayer Booster','Standard Sooth Sayer compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25335,712,'Pure Improved Crash Booster','Improved Crash compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25336,712,'Pure Improved Drop Booster','Improved Drop compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25337,712,'Pure Improved Exile Booster','Improved Exile compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25338,712,'Pure Improved Mindflood Booster','Improved Mindflood compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25339,712,'Pure Improved Frentix Booster','Improved Frentix compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25340,712,'Pure Improved X-Instinct Booster','Improved X-Instinct compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25341,712,'Pure Improved Sooth Sayer Booster','Improved Sooth Sayer compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25342,712,'Pure Strong Crash Booster','Strong Crash compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25343,712,'Pure Strong Drop Booster','Strong Drop compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25344,712,'Pure Strong Exile Booster','Strong Exile compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25345,712,'Pure Strong Mindflood Booster','Strong Mindflood compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25346,712,'Pure Strong Frentix Booster','Strong Frentix compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25347,712,'Pure Strong X-Instinct Booster','Strong X-Instinct compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25348,712,'Pure Strong Sooth Sayer Booster','Strong Sooth Sayer compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(25349,303,'Strong Exile Booster','This booster hardens a pilot\'s resistance to attacks, letting him withstand their impact to a greater extent. The discomfort of having his armor reduced piecemeal remains unaltered, but the pilot is filled with such a surge of rage that he bullies through it like a living tank.',1,1,0,1,NULL,65536.0000,1,977,0),(25351,715,'Isana Dagin\'s Machariel','While its utilitarian look may not give much of an indication, many are convinced that the Machariel is based on an ancient Jovian design uncovered by the Angel Cartel in one of their extensive exploratory raids into uncharted territory some years ago. Whatever the case may be, this behemoth appeared on the scene suddenly and with little fanfare, and has very quickly become one of the Arch Angels\' staple war vessels.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(25352,283,'Black Jack\'s Underling','An underling of the notorious Angel Cartel commander, Black Jack.',80,1,0,1,NULL,0.0000,1,NULL,0),(25353,474,'Serpentis Shipyard Cipher','This cipher seems to be meant for use on one of the acceleration gates in the Serpentis Fleet Shipyard.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25354,310,'Celestial Agent Site Beacon','Fitted with a power flash-battery, this beacon sends out signals throughout the entire solar system.',1,1,0,1,NULL,0.0000,0,NULL,0),(25355,319,'Station Caldari 1','Docking has been prohibited into this Caldari station without proper authorization.',0,0,0,1,1,0.0000,0,NULL,0),(25356,319,'Station Caldari 2','Docking has been prohibited into this Caldari station without proper authorization.',0,0,0,1,1,0.0000,0,NULL,0),(25357,319,'Station Caldari 3','Docking has been prohibited into this Caldari station without proper authorization.',0,0,0,1,1,0.0000,0,NULL,0),(25358,319,'Station Caldari 5','Docking has been prohibited into this Caldari station without proper authorization.',0,0,0,1,1,0.0000,0,NULL,0),(25359,319,'Station Caldari Research Outpost','Docking has been prohibited into this Caldari station without proper authorization.',0,0,0,1,1,0.0000,0,NULL,0),(25360,494,'Caldari Research Outpost','Docking has been prohibited into this Caldari station without proper authorization.',0,0,0,1,1,0.0000,0,NULL,0),(25363,319,'Static Caracal Navy Issue','Created specifically in order to counter the ever-increasing numbers of pirate invaders in Caldari territories, the Navy Issue Caracal has performed admirably in its task.  Sporting added defensive capability as well as increased fitting potential, it is seeing ever greater use in defense of the homeland.',10100000,101000,250,1,1,0.0000,0,NULL,0),(25364,526,'Black Jack\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the notorious Angel Cartel Commander, Black Jack.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25365,715,'Oronata Vion\'s Caracal','Oronata Vion\'s Caracal',10100000,101000,250,1,1,0.0000,0,NULL,0),(25366,409,'Oronata Vion\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,750000.0000,1,NULL,0),(25367,526,'Kois Entry Passcard','Kois Entry Passcard',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25368,715,'Rattlesnake_Airkio Yanjulen','In the time-honored tradition of pirates everywhere, Korako  Rabbit\' Kosakami shamelessly stole the idea of the Scorpion-class battleship and put his own spin on it. \r\r\nThe result: the fearsome Rattlesnake, flagship of any large Gurista attack force. \r\r\nThere are, of course, also those who claim things were the other way around; that the notorious silence surrounding the Scorpion\'s own origins is, in fact, \r\r\nan indication of its having been designed by Kosakami all along. ',100000,100000000,10000,1,1,0.0000,0,NULL,0),(25369,526,'Airkio Yanjulen\'s Corpse','The corpse of the Guristas officer Airkio Yanjulen.',80,1,0,1,NULL,0.0000,1,NULL,0),(25371,715,'Tomi_Hakiro Caracal','The Caracal is a powerful vessel that specializes in missile deployment. It has excellent shield defenses, but poor armor plating. Its missile arsenal, when fully stocked, is capable of making mincemeat of almost anyone.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(25372,409,'Tomi Hakiro\'s Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,20000.0000,1,NULL,0),(25373,283,'Militants','A combative character; aggressive, especially in the service of a cause.',1000,2,0,1,NULL,1000.0000,1,NULL,0),(25374,821,'Mutated Drone Parasite','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25375,226,'Fortified Guristas Control Tower','Originally designed by the Kaalakiota, the Caldari Control Tower blueprint was quickly obtained by the Guristas, through their agents within the State, to serve their own needs.',0,0,0,1,4,0.0000,0,NULL,0),(25377,494,'Akkeshu\'s Storage Facility','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(25378,474,'Drone Modified Passcard','The data within this chip unlocks the acceleration gate leading to a deadspace area behind the infamous Cadaver Reef. The accesscards are singe-use.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25379,802,'Anti-Stabilizer Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25382,314,'Guristas War Plans','Guristas War Plans',1,0.1,0,1,NULL,100.0000,1,NULL,0),(25383,526,'Otsalen Mano\'s Corpse','The corpse of the Caldari agenet Otsalen Mano lies mangled inside one of the ejected capsules.  Upon closer examination, a map has been madly scribbled on a piece of cloth torn from his garments.  Perhaps these are the Guristas War Plans he had discovered?  ',80,1,0,1,NULL,0.0000,1,NULL,0),(25384,494,'Shielded Prison Facility','Smaller confined shield generators with their own access restrictions can be deployed outside the Control Tower\'s defense perimeter. This allows for lesser security areas around the Starbase, for purposes of storage or pickup. ',1,1,0,1,NULL,0.0000,0,NULL,0),(25385,383,'H-2874 Defense Sentinel','An unstable yet extremely powerful 425mm railgun sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(25386,474,'Prison Area Pass','This security passcard is manufactured by the Guristas Pirates, and allows the user to access the Prison grounds connected with the Iacta Space Plain in O-LR1H.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25387,526,'Guristas Armory Codes','These complicated data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.',1,1,0,1,NULL,0.0000,1,NULL,0),(25388,494,'Guristas_Small Armory','This small armory has a thick layer of reinforced tritanium and a customized shield module for deflecting incoming fire.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(25389,674,'Tantima Areki\'s Raven','An agent working for the Caldari State.  Tantima was picked up by this battleship once his operation in Guristas territory had failed.',20500000,22000000,235,1,1,0.0000,0,NULL,0),(25390,283,'Tantima Areki','A person following the pursuits of civil life.',80,5,0,1,NULL,0.0000,1,NULL,0),(25391,526,'Hakiro\'s Scanner Data','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25392,715,'Knaaninn Aranuri\'s Rattlesnake','In the time-honored tradition of pirates everywhere, Korako  Rabbit\' Kosakami shamelessly stole the idea of the Scorpion-class battleship and put his own spin on it. The result: the fearsome Rattlesnake, flagship of any large Gurista attack force. There are, of course, also those who claim things were the other way around; that the notorious silence surrounding the Scorpion\'s own origins is, in fact, an indication of its having been designed by Kosakami all along.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(25393,526,'Imperial Navy Gate Permit Container','A container, inside of which can be found standard gate permits leading to an Imperial Navy complex.',1,10,0,1,NULL,0.0000,1,NULL,0),(25394,526,'Gue Mouey\'s Message','Gue\'s message has been recorded inside this data chip.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25396,715,'Gue Mouey Vindicator','Gue Mouey is being used as a Syndicate dealer. He was recently sent here as the Syndicates answer to the growing demand for drugs and weapons in this constellation.  he also acts as a neutral bargaining partner between Caldari vendors from Kois City and the pirate elements.',0,0,0,1,8,0.0000,0,NULL,0),(25397,306,'Tikui\'s Stash','This Tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interestin information from its mainframe',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(25398,526,'Tikui\'s Message','Tikui\'s message has been recorded inside this data chip.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25400,816,'Tikui Makan','The personal battleship of the Guristas pirate Tikui Makan.  Threat level:  Deadly',19000000,1080000,665,1,1,0.0000,0,NULL,0),(25401,526,'Expeditionary Data','Data collected by the Caldari expeditions in E-8CSQ.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25402,494,'Expeditionary Storage Facility','Built to withstand assault, these behemoths can each hold roughly 8.5 million m3 worth of materials.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(25403,517,'Fetosa Kanim\'s Crane','A Crane piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25404,517,'Vena Saapialen\'s Crane','A Crane piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25405,517,'Ocho Shusiian\'s Crane','A Crane piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25406,517,'Ozomi Obanen\'s Crane','A Crane piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25407,821,'Akkeshu Karuan','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',21000000,22000000,235,1,1,0.0000,0,NULL,0),(25408,526,'Akkeshu Karuan\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.\r\r\n\r\r\nThis DNA sample is taken from the former Guristas commander, Akkeshu Karuan.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25409,715,'Rakka\'s Rattlesnake','In the time-honored tradition of pirates everywhere, Korako  Rabbit\' Kosakami shamelessly stole the idea of the Scorpion-class battleship and put his own spin on it. The result: the fearsome Rattlesnake, flagship of any large Gurista attack force. There are, of course, also those who claim things were the other way around; that the notorious silence surrounding the Scorpion\'s own origins is, in fact, an indication of its having been designed by Kosakami all along.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(25411,422,'Gaseous Fluorine Isotopes','Fluorine is a corrosive yellow gas. Its uncommon combination of characteristics, such as its electronegativity and its tiny atomic radius, give it a wide variety of unique applications in the field of booster production.',0,0.1,0,1,NULL,0.0000,0,NULL,0),(25412,422,'Gaseous Chlorine Isotopes','Chlorine is a common nonmetallic element belonging to the halogens, best known as a heavy yellow irritating toxic gas. It is commonly used as a bleaching agent and disinfectant, and its effectiveness as an oxidizing agent lends it great value in the production of boosters.',0,0.1,0,1,NULL,0.0000,0,NULL,0),(25413,422,'Gaseous Bromine Isotopes','Bromine gas is a strong-smelling red vapor. It is extremely reactive with various substances and one of its primary uses is as an organic synthesis intermediate, something which gives it great value in booster production.',0,0.1,0,1,NULL,0.0000,0,NULL,0),(25414,422,'Gaseous Iodine Isotopes','Iodine is a noxious-smelling purple gas. It forms ',0,0.1,0,1,NULL,0.0000,0,NULL,0),(25415,517,'Kara Morato\'s Bustard','A Bustard piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25416,517,'Tehjus Otsini\'s Bustard','A Bustard piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25417,517,'Heiraitah Siakkano\'s Bustard','A Bustard piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25418,517,'Rahli Saronu\'s Impel','An Impel piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25419,517,'Enna Ahruneh\'s Impel','An Impel piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25420,517,'Desra Nekri\'s Impel','An Impel piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25421,517,'Galhar Lahara\'s Impel','An Impel piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25422,517,'Marera Arghun\'s Prorator','An Prorator piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25423,517,'Rasa Jaswelu\'s Prorator','An Prorator piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25424,517,'Yoti Haraisha\'s Prorator','An Prorator piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25425,517,'Nemphad Azbias\'s Prorator','A Prorator piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25430,517,'Goligere Debanelis\'s Viator','An Viator piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25431,517,'Gomosabin Zerdanne\'s Viator','An Viator piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25432,517,'Juvoire Sche\'s Viator','An Viator piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25433,517,'Oguet Aene\'s Viator','A Viator piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25434,517,'Ravacesel Roque\'s Viator','An Viator piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25435,517,'Binnie Nigolier\'s Occator','An Occator piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25436,517,'Grisier Challier\'s Occator','An Occator piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25437,517,'Mabvrion Atlete\'s Occator','An Occator piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25438,517,'Baftot Asluzof\'s Prorator','An Prorator piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25439,517,'Horir Firvoon\'s Prorator','An Prorator piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25440,517,'Vianes Ounid\'s Prorator','An Prorator piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25449,517,'Bollen Odridur\'s Prowler','A Prowler piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25450,517,'Golarad Hjom\'s Prowler','An Prowler piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25455,517,'Urandi Krilin\'s Machariel','A Machariel piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25456,517,'Bleur Hein\'s Machariel','A Machariel piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25457,517,'Lunuin Eurek\'s Machariel','A Machariel piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25458,517,'Henara Vern\'s Sleipnir','A Sleipnir piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25459,517,'Kamal Sharadon\'s Nightmare','A Nightmare piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25460,517,'Shusa Lemihonn\'s Nightmare','A Nightmare piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25461,517,'Maboula Ahrenon\'s Phantasm','A Phantasm piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25462,517,'Rerina Tarit\'s Phantasm','A Phantasm piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25463,517,'Avora Alkas\'s Phantasm','A Phantasm piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25464,517,'Riluko Hik\'s Prowler','A Prowler piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25465,517,'Uiswin Aurtur\'s Prowler','A Prowler piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25466,517,'Zwod Aden\'s Prowler','A Prowler piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25467,526,'Caldari Corpse','The corpse of someone with Caldari ancestry.',80,1,0,1,NULL,0.0000,1,NULL,0),(25468,306,'Ship Carcass_2','The mangled wreck floats motionless in space, surrounded with a field of scorched debris.',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(25471,306,'Erakki\'s Storage Bin','The enclosed storage bin drifts quietly in space.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(25472,495,'Drone Creation Compound','This drone manufacturing facility is controlled by a highly advanced AI.  It will attack anyone it perceives as a threat.',100000,100000000,1000,1,1,0.0000,0,NULL,0),(25503,718,'Improved X-Instinct Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25504,718,'Improved Exile Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25505,718,'Improved Frentix Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25506,718,'Improved Mindflood Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25507,718,'Improved Sooth Sayer Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25508,718,'Standard Exile Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25509,718,'Standard Frentix Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25510,718,'Standard X-Instinct Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25511,718,'Strong Mindflood Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25512,718,'Strong Sooth Sayer Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25513,718,'Strong X-Instinct Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25514,526,'Kakala\'s Voucher','A voucher of approval.  The mayor of Pioneer\'s Sanctuary in ZH3-BS has asked the major players in town to hand vouchers like these to ship farers who have proven themselves through some dangerous feat.',1,1,0,1,NULL,0.0000,1,NULL,0),(25515,526,'Nuomo\'s Voucher','A voucher of approval.  The mayor of Pioneer\'s Sanctuary in ZH3-BS has asked the major players in town to hand vouchers like these to ship farers who have proven themselves through some dangerous feat.',1,1,0,1,NULL,0.0000,1,NULL,0),(25516,526,'Erakki\'s Voucher','A voucher of approval.  The mayor of Pioneer\'s Sanctuary in ZH3-BS has asked the major players in town to hand vouchers like these to ship farers who have proven themselves through some dangerous feat.',1,1,0,1,NULL,0.0000,1,NULL,0),(25517,526,'Oduma\'s Voucher','A voucher of approval.  The mayor of Pioneer\'s Sanctuary in ZH3-BS has asked the major players in town to hand vouchers like these to ship farers who have proven themselves through some dangerous feat.',1,1,0,1,NULL,0.0000,1,NULL,0),(25518,517,'Kakala Ikkawa\'s Obsidian','An Obsidian piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25519,517,'Erakki Kihuo\'s Obsidian','An Obsidian piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25520,517,'Oduma Pakane\'s Rokh','A Rokh piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25522,526,'Nuomo\'s Scanner Data','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25523,306,'Nuomo\'s Scanner','This is a radio telescope used for scouting nearby territory',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(25524,495,'Angel Central Command','The headquarters of the Angel forces within Freebooters Haven.',0,0,0,1,2,0.0000,0,NULL,0),(25526,306,'Hidden Treasure Chest','The enclosed storage bin drifts quietly in space, waiting patiently to be pried open by a hungry looter.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(25528,495,'Guristas Fleet Stronghold','One of the many quarters of the Gurista fleet.',1000,1000,1000,1,1,0.0000,0,NULL,0),(25530,1220,'Neurotoxin Recovery','Proficiency at biofeedback techniques intended to negate the side effects typically experienced upon injection of combat boosters.',0,0.01,0,1,NULL,25000.0000,1,1746,0),(25531,715,'Dorim Fatimar\'s Punisher','The Amarr Imperial Navy has been upgrading many of its ships in recent years and adding new ones. The Punisher is one of the most recent ones and considered by many to be the best Amarr frigate in existence. As witnessed by its heavy armaments, the Punisher is mainly intended for large-scale military operations, acting in coordination with larger military vessels, but it is more than powerful enough for solo operations.',0,0,0,1,NULL,0.0000,0,NULL,0),(25532,715,'Reqqa Bratesch\'s Vengeance','The Vengeance represents the latest in the Kingdom\'s ongoing mission to wed Amarr and Caldari tech, molding the two into new and exciting forms. Sporting a Caldari ship\'s launcher hardpoints as well as an Amarr ship\'s armor systems, this relentless slugger is perfect for when you need to get up close and personal. Developer: Khanid Innovation Constantly striving to combine the best of two worlds, Khanid Innovation have utilized their Caldari connections to such an extent that the Kingdom\'s ships now possess the most advanced missile systems outside Caldari space, as well as fairly robust electronics systems.',0,0,0,1,NULL,0.0000,0,NULL,0),(25533,715,'Kushan Horeat\'s Arbitrator','The Arbitrator is unusual for Amarr ships in that it\'s primarily a drone carrier. While it is not the best carrier around, it has superior armor that gives it greater durability than most ships in its class.',0,0,0,1,NULL,0.0000,0,NULL,0),(25534,715,'Ragot Parah\'s Maller','Quite possibly the toughest cruiser in the galaxy, the Maller is a common sight in Amarrian Imperial Navy operations. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches.',0,0,0,1,NULL,0.0000,0,NULL,0),(25535,715,'Nimpor Fatimar\'s Omen','The Omen is a stereotypical example of the Amarrian School of thinking when it comes to ship design: thick armor and hard hitting lasers. Advancements in heat dissipation allow the Omen to fire its lasers faster than other ships without this technology.',0,0,0,1,NULL,0.0000,0,NULL,0),(25537,306,'Damaged Prorator','This ship has been damaged and has lost its ability to maneuver, as well as its warp capability.',1450000,16120,145,1,4,0.0000,0,NULL,0),(25538,1220,'Neurotoxin Control','Proficiency at reducing the severity of the side effects experienced upon injection of combat boosters.',0,0.01,0,1,NULL,1000000.0000,1,1746,0),(25539,718,'Strong Exile Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25540,737,'\'Crop\' Gas Cloud Harvester','Originally invented and supplied by the pirate organizations of New Eden, the \'Crop\' and  Plow\' Gas Cloud Harvesters once stood as the most advanced pieces of harvesting equipment available. Although they did not offer any improvement in their harvesting yield, the CPU reduction was valued by many who otherwise struggled to fit a full rack of harvesters to cruiser-class vessels. This one small improvement set the two harvesters above the standard, Tech I variant for many years. \r\r\n\r\r\nAll that changed however when new, stable wormholes began proliferating across the cluster. As soon as the wormholes were discovered, so too, were the giant gas cloud pockets within the unknown systems they linked to. In a single day, the demand for Tech II Gas Cloud Harvested exploded. Research projects were hastily established and grants hurriedly thrown out to the most promising firms pursuing a redesign. It was only a few days before a breakthrough was made, and the mighty  Crop\' and  Plow\' variants soon took second place to a superior Tech II counterpart that vastly increased the harvesting yield. ',0,5,0,1,NULL,2417838.0000,1,1037,0),(25541,134,'\'Crop\' Gas Cloud Harvester Blueprint',' ',0,0.01,0,1,NULL,92720.0000,0,NULL,0),(25542,737,'\'Plow\' Gas Cloud Harvester','Originally invented and supplied by the pirate organizations of New Eden, the \'Crop\' and  Plow\' Gas Cloud Harvesters once stood as the most advanced pieces of harvesting equipment available. Although they did not offer any improvement in their harvesting yield, the CPU reduction was valued by many who otherwise struggled to fit a full rack of harvesters to cruiser-class vessels. This one small improvement set the two harvesters above the standard, Tech I variant for many years. \r\r\n\r\r\nAll that changed however when new, stable wormholes began proliferating across the cluster. As soon as the wormholes were discovered, so too, were the giant gas cloud pockets within the unknown systems they linked to. In a single day, the demand for Tech II Gas Cloud Harvested exploded. Research projects were hastily established and grants hurriedly thrown out to the most promising firms pursuing a redesign. It was only a few days before a breakthrough was made, and the mighty  Crop\' and  Plow\' variants soon took second place to a superior Tech II counterpart that vastly increased the harvesting yield. ',0,5,0,1,NULL,2417838.0000,1,1037,0),(25543,134,'\'Plow\' Gas Cloud Harvester Blueprint',' ',0,0.01,0,1,NULL,92720.0000,0,NULL,0),(25544,1218,'Gas Cloud Harvesting','Skill at harvesting gas clouds. Allows use of one gas cloud harvester per level.',0,0.01,0,1,NULL,24000000.0000,1,1323,0),(25545,1231,'Eifyr and Co. \'Alchemist\' Neurotoxin Control NC-903','A neural Interface upgrade that boost the pilot\'s skill at handling boosters. \r\r\n\r\r\n3% bonus reduction to side effects.',0,1,0,1,NULL,21504.0000,1,1776,0),(25546,1231,'Eifyr and Co. \'Alchemist\' Neurotoxin Control NC-905','A neural Interface upgrade that boost the pilot\'s skill at handling boosters. \r\r\n\r\r\n5% bonus reduction to side effects.',0,1,0,1,NULL,21504.0000,1,1776,0),(25547,1231,'Eifyr and Co. \'Alchemist\' Neurotoxin Recovery NR-1003','A neural Interface upgrade that boost the pilot\'s skill at handling boosters. \r\r\n\r\r\n3% less chance of side effects when using boosters.',0,1,0,1,NULL,21504.0000,1,1777,0),(25548,1231,'Eifyr and Co. \'Alchemist\' Neurotoxin Recovery NR-1005','A neural Interface upgrade that boost the pilot\'s skill at handling boosters. \r\r\n\r\r\n5% less chance of side effects when using boosters.',0,1,0,1,NULL,21504.0000,1,1777,0),(25549,821,'Security Overseer','The security is handled by this trusted servant of the Gist Angels serving straight from the Angel high command.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(25550,474,'Freebooter\'s Key Alpha','This key allows you entrance into the Freebooter\'s Maintainance Facility',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25551,474,'Blood Raider Shipyard Keycard','This keycard grants access to the deepest pockets of the Blood Raider Naval Shipyard.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25552,319,'Blood Raider Bhaalgorn','Bhaalgorn battleship. Owned by the Blood Raider Covenant. Only those with the correct security codes can hope to pilot this ship.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(25553,716,'Cryptic Data Interface','Designed for use with Minmatar technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed.',0,1,0,1,NULL,0.0000,1,NULL,0),(25554,716,'Occult Data Interface','Designed for use with Amarr technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed.',0,1,0,1,NULL,0.0000,1,NULL,0),(25555,716,'Esoteric Data Interface','Designed for use with Caldari technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed.',0,1,0,1,NULL,0.0000,1,NULL,0),(25556,716,'Incognito Data Interface','Designed for use with Gallente technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed.',0,1,0,1,NULL,0.0000,1,NULL,0),(25557,670,'Jamur Fatimar','A powerful battleship of the Amarr Empire.\r\r\n',19500000,1150000,235,1,4,0.0000,0,NULL,0),(25559,495,'Blood Raider Fleet Stronghold','The largest and deadliest military facility currently owned by the Blood Raiders. High-ranking Blood Raider commanders are rumored to meet here every few months.',1000,1000,1000,1,4,0.0000,0,NULL,0),(25560,26,'Opux Dragoon Yacht','Originally designed and built by Roden Shipyards exclusively for the Caldari Gaming Commission the Opux Dragoon Yacht is now being supplied to the IGC. Dragoon class Yachts are used to carry wealthy spectators for various high-profile sporting events around the galaxy.',13075000,115000,1750,1,8,0.0000,0,NULL,0),(25561,514,'Signal Distortion Amplifier I','Magnifies the operational ability of regular ECM target jammers, making them stronger and giving them greater reach. Works only with regular ECMs, not ECM Bursts.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,40456.0000,1,967,0),(25562,1222,'Signal Distortion Amplifier I Blueprint',' ',0,0.01,0,1,NULL,249600.0000,1,1567,0),(25563,514,'Signal Distortion Amplifier II','Magnifies the operational ability of regular ECM target jammers, making them stronger and giving them greater reach. Works only with regular ECMs, not ECM Bursts.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,677688.0000,1,967,0),(25564,1222,'Signal Distortion Amplifier II Blueprint',' ',0,0.01,0,1,NULL,249600.0000,1,NULL,0),(25565,514,'\'Hypnos\' Signal Distortion Amplifier I','Magnifies the operational ability of regular ECM target jammers, making them stronger and giving them greater reach. Works only with regular ECMs, not ECM Bursts.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,967,0),(25567,514,'Compulsive Signal Distortion Amplifier I','Magnifies the operational ability of regular ECM target jammers, making them stronger and giving them greater reach. Works only with regular ECMs, not ECM Bursts.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,967,0),(25569,514,'Induced Signal Distortion Amplifier I','Magnifies the operational ability of regular ECM target jammers, making them stronger and giving them greater reach. Works only with regular ECMs, not ECM Bursts.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,967,0),(25571,514,'Initiated Signal Distortion Amplifier I','Magnifies the operational ability of regular ECM target jammers, making them stronger and giving them greater reach. Works only with regular ECMs, not ECM Bursts.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,24960.0000,1,967,0),(25575,526,'Damaged Cloaking Device','A damaged, non-functional cloaking device.  ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25576,533,'Ketta Tomin2','This is a hostile pirate vessel. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(25577,474,'Freebooter\'s Key Beta','This key allows you entrance into the Freebooter\'s Mining Facility',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25578,821,'Security Maintenance Facility Overseer','The security is handled by this trusted servant of the Gist Angels serving straight from the Angel high command.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(25579,474,'Freebooter\'s Key Gamma','This key allows you entrance into the Krur Tajar Operation Command Center.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25581,821,'Security Mining Facility Overseer','The security is handled by this trusted servant of the Gist Angels serving straight from the Angel high command.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(25582,517,'Nuomo Kaavunin\'s Rokh','A Rokh piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25583,517,'Lauka Ikunol\'s Phoenix','A Phoenix piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(25584,356,'Esoteric Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25585,356,'Occult Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25586,356,'Incognito Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25587,356,'Cryptic Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25588,754,'Scorched Telemetry Processor','An expert system used in the construction of missile launchers. This one has been damaged by fire or an explosion.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25589,754,'Malfunctioning Shield Emitter','This Shield Emitter, while not being totally out of commission doesn\'t seem to be living up to its full potential. With some tender loving care the parts could be put to good use. ',0,0.01,0,1,NULL,0.0000,1,1863,0),(25590,754,'Contaminated Nanite Compound','A soup of nanite assemblers typically used in armor manufacturing processes. This compound needs to go through purification before it\'s of use again.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25591,754,'Contaminated Lorentz Fluid','So named for its myriad electrodynamic properties, Lorentz Fluid exhibits strong conductivity with extreme resistance to heat. ',0,0.01,0,1,NULL,0.0000,1,1863,0),(25592,754,'Defective Current Pump','Used to transfer energy from a ships capacitor to a laser gain medium. The mechanism on this device is in need of repair.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25593,754,'Smashed Trigger Unit','This Thermonuclear Trigger Unit while smashed still seems to have it\'s nuclei containment field intact and the plasma seems to be near thermal equilibrium. It would be a shame to waste this unit just because of its cosmetic damage.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25594,754,'Tangled Power Conduit','Power Conduit runs through ships delivering energy like arteries deliver blood through a body. Large ships can have hundreds of miles of conduit. This conduit is tangled and knotted as it seems to have gone through some sort of catastrophe.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25595,754,'Alloyed Tritanium Bar','Tritanium based alloy for use in applications requiring extremely high strength and temperature resistance. Some examples are thruster mounts or afterburner nozzles.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25596,754,'Broken Drone Transceiver','A multifunction chip with digital modulator and oscillator utilized in drone communication hardware. This one looks broken.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25597,754,'Damaged Artificial Neural Network','ANNs preside over a starship\'s various electronics subsystems and keep everything in working order, rerouting power and processing when systems are damaged or go offline. This ANN is damaged but doesn\'t seem to be a total loss. ',0,0.01,0,1,NULL,0.0000,1,1863,0),(25598,754,'Tripped Power Circuit','A closed loop electrical network with redundant autonomous switchgear. This unit has all of its breakers tripped but isn\'t beyond repair. ',0,0.01,0,1,NULL,0.0000,1,1863,0),(25599,754,'Charred Micro Circuit','Micro Circuits are one of the most common electronics components seen in use. This one has seen better days but could still be of some use.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25600,754,'Burned Logic Circuit','Autonomous field programmable holographic signal processor with embedded holographic data storage. Used in most modern computers, the ubiquitous AFPHSPEHDS is colloquially known as the \"Aphid\". This name leads of course to many bad puns about bugs in the system. ',0,0.01,0,1,NULL,0.0000,1,1863,0),(25601,754,'Fried Interface Circuit','Interface Circuits are common building blocks of starship subsystems. This one seems a little worse for wear but might be useful for something with a little ingenuity. ',0,0.01,0,1,NULL,0.0000,1,1863,0),(25602,754,'Thruster Console','The control unit for a starships thrusters.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25603,754,'Melted Capacitor Console','A slightly damaged but still seemingly usable capacitor console. Capacitor consoles are a necessary component of starship capacitor units.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25604,754,'Conductive Polymer','An extremely conductive synthetic compound of high molecular weight. Used in the construction of electronics.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25605,754,'Armor Plates','Typical armor plating',0,0.01,0,1,NULL,0.0000,1,1863,0),(25606,754,'Ward Console','The control unit for a starships shield systems.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25607,754,'Telemetry Processor','An expert system used in the construction of missile launchers.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25608,754,'Intact Shield Emitter','An intact shield emitter component.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25609,754,'Nanite Compound','A soup of nanite assemblers typically used in armor manufacturing processes.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25610,754,'Lorentz Fluid','So named for its myriad electrodynamic properties, Lorentz Fluid exhibits strong conductivity with extreme resistance to heat.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25611,754,'Current Pump','Used to transfer energy from a ships capacitor to a laser gain medium.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25612,754,'Trigger Unit','A perfectly functioning cannon trigger unit.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25613,754,'Power Conduit','Power Conduit runs through ships delivering energy like arteries deliver blood through a body. Large ships can have hundreds of miles of conduit.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25614,754,'Single-crystal Superalloy I-beam','An intact section of tritanium based single-crystal alloy i-beam for use in applications requiring extremely high strength and temperature resistance. Some examples are thruster mounts or afterburner nozzles.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25615,754,'Drone Transceiver','Multifunction chip with digital modulator and oscillator.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25616,754,'Artificial Neural Network','ANNs preside over a starship\'s various electronics subsystems and keep everything in working order, rerouting power and processing when systems are damaged or go offline. ',0,0.01,0,1,NULL,0.0000,1,1863,0),(25617,754,'Power Circuit','Your average run-of-the-mill closed loop electrical network with redundant autonomous switchgear.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25618,754,'Micro Circuit','The Micro Circuit is one of the most common electronics components seen in use.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25619,754,'Logic Circuit','An \"Aphid\" logic circuit. The nickname is derived from the unfortunate acronym of autonomous field programmable holographic signal processor with embedded holographic data storage.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25620,754,'Interface Circuit','Interface Circuits are common building blocks of starship subsystems.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25621,754,'Impetus Console','A more advanced version of the common Thruster Console.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25622,754,'Capacitor Console','Capacitor consoles are a necessary component of starship capacitor units.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25623,754,'Conductive Thermoplastic','Used to build Tech II ship upgrades',0,0.01,0,1,NULL,0.0000,1,1863,0),(25624,754,'Intact Armor Plates','Used to build Tech II ship upgrades',0,0.01,0,1,NULL,0.0000,1,1863,0),(25625,754,'Enhanced Ward Console','A control unit for Tech II shield systems.',0,0.01,0,1,NULL,0.0000,1,1863,0),(25626,383,'Guristas Annihilation Missile Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(25632,757,'Annihilator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25633,761,'Arachula Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25634,761,'Asmodeus Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25635,757,'Atomizer Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25636,759,'Barracuda Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25637,761,'Beelzebub Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25638,761,'Belphegor Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25639,757,'Bomber Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25640,755,'Crippler Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25641,759,'Decimator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25642,755,'Defeater Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25643,757,'Destructor Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25644,757,'Devastator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25645,759,'Devilfish Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25646,757,'Disintegrator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25647,758,'Dismantler Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25648,756,'Domination Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25649,761,'Dragonfly Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25650,756,'Drone Controller','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25651,756,'Drone Creator','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25652,756,'Drone Queen','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25653,756,'Drone Ruler','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25654,755,'Enforcer Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25655,755,'Exterminator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25656,759,'Hunter Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25657,761,'Incubus Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25658,759,'Infester Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25659,761,'Malphas Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25660,761,'Mammon Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25661,758,'Marauder Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25662,756,'Matriarch Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25663,761,'Moth Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25664,757,'Nuker Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25665,756,'Patriarch Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25666,758,'Predator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25667,759,'Raider Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25668,759,'Render Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25669,758,'Ripper Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25670,761,'Scorpionfly Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25671,758,'Shatter Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25672,758,'Shredder Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25673,755,'Siege Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25674,759,'Silverfish Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25675,756,'Spearhead Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25676,759,'Splinter Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25677,757,'Strain Annihilator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25678,757,'Strain Atomizer Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25679,759,'Strain Barracude Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25680,757,'Strain Bomber Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25681,759,'Strain Decimator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: High',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25682,757,'Strain Destructor Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25683,757,'Strain Devastator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25684,759,'Strain Devilfish Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25685,757,'Strain Disintegrator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25686,759,'Strain Hunter Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25687,759,'Strain Infester Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: High',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25688,757,'Strain Nuker Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25689,759,'Strain Raider Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25690,759,'Strain Render Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: High',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25691,759,'Strain Silverfish Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25692,759,'Strain Splinter Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: High',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25693,759,'Strain Sunder Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25694,757,'Strain Violator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25695,757,'Strain Viral Infector Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25696,757,'Strain Wrecker Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25697,755,'Striker Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25698,759,'Sunder Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25699,756,'Supreme Drone Parasite','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25700,756,'Swarm Preserver Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25701,761,'Tarantula Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25702,761,'Termite Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',2000000,20000,235,1,NULL,0.0000,0,NULL,0),(25703,757,'Violator Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25704,757,'Viral Infector Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25705,757,'Wrecker Drone','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(25706,383,'Tower Sentry Guristas III_buffed','Guristas 425mm railgun sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(25707,771,'Prototype \'Arbalest\' Heavy Assault Missile Launcher I','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations.',0,10,0.9,1,NULL,80118.0000,1,974,0),(25709,771,'Upgraded \'Malkuth\' Heavy Assault Missile Launcher I','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,0.78,1,NULL,80118.0000,1,974,0),(25711,771,'Limited \'Limos\' Heavy Assault Missile Launcher I','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,0.825,1,NULL,80118.0000,1,974,0),(25713,771,'Experimental XT-2800 Heavy Assault Missile Launcher I','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,0.855,1,NULL,80118.0000,1,974,0),(25715,771,'Heavy Assault Missile Launcher II','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,0.99,1,NULL,313818.0000,1,974,0),(25716,136,'Heavy Assault Missile Launcher II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25717,494,'Guristas War Installation','This gigantic suprastructure is one of the military installations of the Guristas pirate corporation. Even for its size it has no commercial station services or docking bays to receive guests.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(25718,256,'Heavy Assault Missile Specialization','Specialist training in the operation of advanced heavy assault missile launchers. 2% bonus per level to the rate of fire of modules requiring Heavy Assault Missile Specialization. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,NULL,3000000.0000,1,373,0),(25719,256,'Heavy Assault Missiles','Skill with heavy assault missiles. Special: 5% bonus to heavy assault missile damage per skill level.',0,0.01,0,1,NULL,100000.0000,1,373,0),(25722,517,'Yekti Kimebu\'s Malediction','A Malediction piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25725,319,'Stabber LCS','Walls inside deadspace complexes both serve as personal transportation lanes between structures, as well as reinforcement tubes to make sure larger structures don\'t drift away from each other.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(25734,494,'Pagera Manton','This used to be a space-ship at the head of an Amarrian exploration fleet.  Later it was defiled by the Blood Raiders and today it serves as one of their holiest sites.',0,0,0,1,NULL,0.0000,0,NULL,0),(25735,306,'Ship Wreckage6','The mangled wreck floats motionless in space, surrounded with a field of scorched debris.',1000000,100000000,8850,1,NULL,0.0000,0,NULL,0),(25736,773,'Large Anti-EM Pump I','This ship modification is designed to increase a ship\'s armor EM resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(25737,787,'Large Anti-EM Pump I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1202,0),(25739,1217,'Astrometric Rangefinding','Skill for the advanced operation of long range scanners. 5% increase to scan probe strength per level.',0,0.01,0,1,NULL,450000.0000,1,1110,0),(25740,517,'Kaymotin Gradance\'s Oneiros','An Oneiros piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25741,517,'Wessette Gauze\'s Oneiros','An Oneiros piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25742,517,'Bley Oreriel\'s Myrmidon','A Myrmidon piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25743,517,'Cliene Veine\'s Dominix','A Dominix piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25744,517,'Jarvas Ladier\'s Megathron','A Megathron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25745,517,'Valedt Midalle\'s Dominix','A Dominix piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25746,517,'Ovon Flac\'s Megathron','A Megathron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25747,517,'Dars Amene\'s Brutix','A Brutix piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(25748,517,'Orain Purcour\'s Tristan','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(25749,517,'Marvernois Ruemin\'s Tristan','A Tristan piloted by an agent.',1250000,26500,140,1,8,0.0000,0,NULL,0),(25750,517,'Androver Hnill\'s Tempest','A Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25751,517,'Akelf Ortar\'s Tempest','A Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25752,517,'Lafuni Oduntra\'s Tempest','A Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25753,517,'Sigulo Ansa\'s Nidhoggur','A Nidhoggur piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25754,517,'Ilkur Eiren\'s Nidhoggur','A Nidhoggur piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25771,481,'Recon Probe Launcher II','A missile launcher shell modified to fit recon probes. Only one probe launcher can be fitted per ship.',0,5,1,1,NULL,0.0000,0,NULL,0),(25772,918,'Recon Probe Launcher II Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(25797,972,'Radar Quest Probe','Lith probes pick up the diffraction of quasar emissions around large stationary objects in space, and utilize the resultant interference to estimate the distance at which the objects lie. The Quest probe is the longest-distance lith probe available.',1,1.25,0,1,NULL,4646.0000,0,NULL,0),(25805,495,'Outgrowth Strain Mother_00COSMOS','This gargantuan mother drone holds the central CPU, controlling the rogue drones throughout the sector. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(25806,562,'TEST ATTACKER','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(25807,474,'TestMeetingKeycard','Kickass direct description of key, what gate, background, Overseer, etc.',1,0.1,0,1,NULL,0.0000,0,NULL,0),(25808,821,'TestProphetBlood','TestNPC_uber descfripitjnsol',19500000,1150000,235,1,4,0.0000,0,NULL,0),(25809,495,'Kois City','The major State outpost in E-8CSQ was recently nicknamed \'Kois City\', in referral to Admiral Aurobe Kois who runs the military operation in the constellation.\r\r\n\r\r\nIt is now a bustling hub of activity, \'a beacon of Caldari strength that shines through the unremarkable corner of the galaxy we call E-8CSQ\' (Admiral Aurobe Kois\'s words). ',1000,1000,1000,1,1,0.0000,0,NULL,0),(25810,1217,'Astrometric Pinpointing','Greater accuracy in hunting down targets found through scanning. Reduces maximum scan deviation by 5% per level.',0,0.01,0,1,NULL,450000.0000,1,1110,0),(25811,1217,'Astrometric Acquisition','Skill at the advanced operation of long range scanners. 5% reduction in scan probe scan time per level.',0,0.01,0,1,NULL,450000.0000,1,1110,0),(25812,737,'Gas Cloud Harvester II','The core technology employed by Gas Harvesters dates back centuries, to a time when the extraction of material in space was still a growing industry. Originally, asteroid miners had seen the tractor beams and in-space catalytic conversions used by today\'s Gas Harvesters as a promising new method for extracting spacebound ore. After many unsuccessful research projects and years of fruitless experiments however, the industry decided to return its focus to laser technology, which was eventually mastered to a level that has sustained the mining profession to this day.\r\r\n\r\r\nWhen the first interstellar Gas Clouds were discovered, they proved particularly challenging for industrialists to extract raw materials from. Many methods were tried, and although successful acquisition was always guaranteed, there was a need for much greater efficiency. It was not until the mining industry returned to long-abandoned projects that a solution was found. Since that time, Gas harvesting technology has slowly moved forward, giving birth to new industries and economies in the process. \r\r\n\r\r\nResearch interest picked back up in Gas Harvesting technology when new, stable wormholes began proliferating across the cluster. As soon as the wormholes were discovered, so too, were the giant gas cloud pockets within the unknown systems they linked to. In a single day, the demand for Tech II Gas Cloud Harvester exploded. Research projects were hastily established and grants hurriedly thrown out to the most promising firms pursuing a redesign. It was only a few days before a breakthrough was made, and all the harvesting technology that had come before was quickly relegated to second place. ',0,5,0,1,NULL,5434024.0000,1,1037,0),(25813,134,'Gas Cloud Harvester II Blueprint',' ',0,0.01,0,1,NULL,92720.0000,1,NULL,0),(25814,674,'Admiral Aurobe Kois','A powerful battleship of the Caldari State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(25815,319,'AoE SmartBomb Test','The Amarr have always been fond of majestic and intimidating constructions. Their Control Towers do not deviate from that tradition and are truly big and powerful structures, intended more for preservation of territorial interests than commercial benefits.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(25816,335,'TEST Triggered Damage Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(25817,383,'TEST Cap Drain Sentry',' ',100000,60,235,1,NULL,0.0000,0,NULL,0),(25818,821,'Black Jack','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(25819,319,'Amarr Trade Post','Docking in this station has been prohibited without private authorization.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(25820,678,'Kristjan\'s Gallente Boss','An elite cruiser of the Gallente Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(25821,404,'General Storage','Used to store or provide general commodities.',100000000,4000,20000,1,NULL,7500000.0000,1,483,0),(25822,594,'Gist_Defender Battleship','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(25823,597,'Gistii_Defender_Frigate','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(25824,612,'Pith Defender','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(25825,615,'Pithi Defender','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1650000,16500,130,1,1,0.0000,0,NULL,0),(25826,319,'Minmatar Mining Station','Docking has been prohibited into this station without proper authorization.',0,0,0,1,2,0.0000,0,NULL,0),(25827,383,'Minmatar Station Sentry','Minmatar Station Sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(25828,319,'Fortified Drug Lab','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',1000000,0,0,1,4,0.0000,0,NULL,0),(25829,784,'Angel Chaos Frigate','This ship is currently undergoing maintenance.',1200000,0,0,1,2,0.0000,0,NULL,0),(25830,517,'Pondah Shanjih\'s Malediction','A Malediction piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25831,517,'Charit Rish\'s Baalgorn','A Baalgorn piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25832,517,'Neyan Khahsel\'s Baalgorn','A Baalgorn piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25833,517,'Dalitat Dakpor\'s Damnation','A Damnation piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(25840,383,'Station Sentry 9F','A powerful station sentry gun primarily manufactured in the Amarr/Khanid/Ammatar territories.',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(25841,306,'Slave Pens','This tower acts as a Network relay. It might be possible for the right person to \"liberate\" some interesting information from its mainframe.',100000,100000000,2700,1,NULL,0.0000,0,NULL,0),(25844,526,'Head in a Jar','This is a human head, sealed in a jar of preservative fluid.',1,1,0,1,NULL,0.0000,1,NULL,0),(25845,306,'Prison_Mission','This rat-infested prison is being closely guarded.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(25846,517,'Kanmilia Oldit\'s Tempest','A Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(25847,283,'A Really REALLY Clueless Tourist','This poor sod intended on taking a sight seeing tour through Yulai, but because he managed to hold his starmap upside-down he ended up \'touring\' rat infested Blood Raider prisons in Delve.  ',200,1,0,1,NULL,100.0000,1,NULL,0),(25848,821,'Kalorr Makur','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(25849,370,'Kalorr Makur\'s Tag','This diamond tag carries the rank insignia equivalent of an officer within the Blood Raider pirate cult. It may prove valuable if turned in at proper authorities.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25850,283,'Dalitat Dakpor\'s Clone','Dalitat Dakpor\'s Clone.',80,5,0,1,NULL,0.0000,1,NULL,0),(25851,716,'Occult Ship Data Interface','Designed for use with Amarr technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed.',0,1,0,1,NULL,0.0000,1,NULL,0),(25852,356,'Occult Ship Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25853,716,'Esoteric Ship Data Interface','Designed for use with Caldari technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed.',0,1,0,1,NULL,0.0000,1,NULL,0),(25854,356,'Esoteric Ship Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25855,716,'Incognito Ship Data Interface','Designed for use with Gallente technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed.',0,1,0,1,NULL,0.0000,1,NULL,0),(25856,356,'Incognito Ship Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25857,716,'Cryptic Ship Data Interface','Designed for use with Minmatar technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed.',0,1,0,1,NULL,0.0000,1,NULL,0),(25858,356,'Cryptic Ship Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(25859,319,'Amarr Battlestation 2','This gigantic military installation is the pride of the Imperial Navy.  Thousands, sometimes hundreds of thousands, of slaves pour their blood, sweat and tears into erecting one of these mega-structures.  Only a fool would attempt to assault such a massive base without a fleet behind him.\r\r\n\r\r\nDocking has been prohibited into this station without proper authorization.',0,0,0,1,4,0.0000,0,NULL,0),(25860,335,'Argon Gas Environment_Damage',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(25861,1122,'Salvager I','A specialized scanner used to detect salvageable items in ship wrecks.',0,5,0,1,NULL,51464.0000,1,1715,0),(25862,1123,'Salvager I Blueprint',' ',0,0.01,0,1,NULL,332640.0000,1,1712,0),(25863,1218,'Salvaging','Proficiency at salvaging ship wrecks. Required skill for the use of salvager modules. 100% increase in chance of salvage retrieval per additional level.',0,0.01,0,1,NULL,1000000.0000,1,1323,0),(25864,474,'Rakogh Officer Gate Key','This passkey activates the highest level acceleration gate in the Rakogh Administration Complex. It is good for only one visit, so use it wisely.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25865,821,'Pashan\'s Battle-Commander','This is one of Pashan Mitah\'s commanders.  They control many squadrons of his fighters, and answer only to Pashan himself or his closest advisors. Threat level: Deadly',21000000,100100,235,1,4,0.0000,0,NULL,0),(25866,495,'Rakogh Citadel','A mighty bastion of Sansha\'s strength, this Citadel resides deep within the Rakogh Administration Complex.  From within its maze of corriders and dark rooms Pashan Mitah fervently controls his subjects with a mind control device, ever so often contacted by his own superior many astronomical units away.',1000,1000,1000,1,4,0.0000,0,NULL,0),(25867,742,'Pashan\'s Turret Handling Mindlink','A gunnery hardwiring implant designed to enhance skill with large energy turrets.\r\r\n\r\r\n7% bonus to large energy turret damage.',0,1,0,1,NULL,0.0000,1,1502,0),(25868,742,'Pashan\'s Turret Customization Mindlink','A gunnery hardwiring implant designed to enhance turret rate of fire.\r\r\n\r\r\n7% bonus to all turret rate of fire.',0,1,0,1,NULL,0.0000,1,1501,0),(25869,283,'Harlots','Exotic dancing is considered an art form, even though not everyone might agree. Exposing the flesh in public places may be perfectly acceptable within the Federation, but in the Amarr Empire it\'s considered a grave sin and a sign of serious deviancy.',50,1,0,1,NULL,0.0000,1,NULL,0),(25870,821,'Serpentis Procurer','A deadly procurer with interesting cargo.',19000000,1010000,480,1,8,0.0000,0,NULL,0),(25873,821,'Piran Ketoisa','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',21000000,22000000,235,1,1,0.0000,0,NULL,0),(25875,283,'Minmatar Reporter',' ',80,2,0,1,NULL,0.0000,1,NULL,0),(25877,820,'TestNPC001','Test',10100000,101000,235,1,1,0.0000,0,NULL,0),(25878,526,'Ovon Flac\'s Documents','Detailed information regarding the Legends Trial.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(25879,526,'Ovon Flac\'s Container','Contains documents which detail procedures for the Legends Trial tournament.',1,10,0,1,NULL,0.0000,1,NULL,0),(25880,502,'Cosmic Agent Site Signature','A cosmic signature.',0,1,0,1,NULL,0.0000,0,NULL,0),(25881,821,'Serpentis Thief','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(25883,705,'Minmatar Harvester Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',89000000,890000,2000,1,2,0.0000,0,NULL,0),(25884,821,'Shadow Serpentis Thief','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(25885,283,'Scientist','A scientist.',65,1,0,1,NULL,0.0000,1,NULL,0),(25886,821,'Rogue Drone Saboteur','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(25887,333,'Datacore - Caldari Starship Engineering','This datacore is a veritable storehouse of information, containing a considerable portion of mankind\'s collected knowledge in the field of Caldari starship engineering.',1,0.1,0,1,4,0.0000,1,1880,0),(25888,773,'Large Anti-Explosive Pump I','This ship modification is designed to increase a ship\'s armor explosive resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(25889,787,'Large Anti-Explosive Pump I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1202,0),(25890,773,'Large Anti-Kinetic Pump I','This ship modification is designed to increase a ship\'s armor kinetic resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(25891,787,'Large Anti-Kinetic Pump I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1202,0),(25892,773,'Large Anti-Thermic Pump I','This ship modification is designed to increase a ship\'s armor thermal resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(25893,787,'Large Anti-Thermic Pump I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1202,0),(25894,773,'Large Trimark Armor Pump I','This ship modification is designed to increase a ship\'s total armor hit points at the expense of max velocity.',200,20,0,1,NULL,0.0000,1,1208,0),(25895,787,'Large Trimark Armor Pump I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1202,0),(25896,773,'Large Auxiliary Nano Pump I','This ship modification is designed to increase a ship\'s armor repairer repair amount at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(25897,787,'Large Auxiliary Nano Pump I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1202,0),(25898,773,'Large Nanobot Accelerator I','This ship modification is designed to reduce a ship\'s armor repair cycle duration at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(25899,787,'Large Nanobot Accelerator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1202,0),(25900,773,'Large Remote Repair Augmentor I','This ship modification is designed to reduce the capacitor need for a ship\'s remote armor repair modules at the expense of max velocity.',200,20,0,1,NULL,0.0000,1,1208,0),(25901,787,'Large Remote Repair Augmentor I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1202,0),(25902,1232,'Large Salvage Tackle I','This ship modification is designed to increase a ship\'s chance of salvage retrieval at the expense of max velocity.',200,20,0,1,NULL,0.0000,1,1784,0),(25903,787,'Large Salvage Tackle I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1798,0),(25906,774,'Large Core Defense Capacitor Safeguard I','This ship modification is designed to reduce the capacitor need of modules which require shield operation skills at the expense of increased signature radius.',200,20,0,1,NULL,0.0000,1,1236,0),(25907,787,'Large Core Defense Capacitor Safeguard I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1269,0),(25908,778,'Large Drone Control Range Augmentor I','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(25909,787,'Large Drone Control Range Augmentor I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1245,0),(25910,778,'Large Drone Repair Augmentor I','This ship modification is designed to increase a ship\'s drone repair amount at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(25911,787,'Large Drone Repair Augmentor I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1245,0),(25912,778,'Large Drone Scope Chip I','This ship modification is designed to increase a ship\'s drone optimal range at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(25913,787,'Large Drone Scope Chip I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1245,0),(25914,778,'Large Drone Speed Augmentor I','This ship modification is designed to increase a ship\'s drone max velocity at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',200,20,0,1,NULL,0.0000,1,1215,0),(25915,787,'Large Drone Speed Augmentor I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1245,0),(25916,778,'Large Drone Durability Enhancer I','This ship modification is designed to increase a ship\'s drone shield, armor and structure hit points at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(25917,787,'Large Drone Durability Enhancer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1245,0),(25918,778,'Large Drone Mining Augmentor I','This ship modification is designed to increase a ship\'s mining drone yield at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(25919,787,'Large Drone Mining Augmentor I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1245,0),(25920,778,'Large Sentry Damage Augmentor I','This ship modification is designed to increase a ship\'s sentry drone damage at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1215,0),(25921,787,'Large Sentry Damage Augmentor I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1245,0),(25922,778,'Large EW Drone Range Augmentor I','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,0,NULL,0),(25923,787,'Large EW Drone Range Augmentor I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,0,NULL,0),(25924,778,'Large Stasis Drone Augmentor I','This ship modification is designed to increase a ship\'s stasis web drones\' factor of velocity decrease at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(25925,787,'Large Stasis Drone Augmentor I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1245,0),(25928,786,'Large Signal Disruption Amplifier I','This ship modification is designed to reduce a ship\'s capacitor need for ECM and ECM Burst modules.\r\r\n',200,20,0,1,NULL,0.0000,1,1221,0),(25929,787,'Large Signal Disruption Amplifier I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1251,0),(25930,1233,'Large Emission Scope Sharpener I','This ship modification is designed to increase the efficiency of a ship\'s relic modules.',200,20,0,1,NULL,0.0000,1,1788,0),(25931,787,'Large Emission Scope Sharpener I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1803,0),(25932,1233,'Large Memetic Algorithm Bank I','This ship modification is designed to increase the efficiency of a ship\'s data modules.\r\r\n',200,20,0,1,NULL,0.0000,1,1788,0),(25933,787,'Large Memetic Algorithm Bank I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1803,0),(25934,781,'Large Liquid Cooled Electronics I','This ship modification is designed to reduce the CPU need of modules which require the electronics upgrades skill.\r\r\n',200,20,0,1,NULL,0.0000,1,1224,0),(25935,787,'Large Liquid Cooled Electronics I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1254,0),(25936,1233,'Large Gravity Capacitor Upgrade I','This ship modification is designed to increase a ship\'s scan probe strength.',200,20,0,1,NULL,0.0000,1,1788,0),(25937,787,'Large Gravity Capacitor Upgrade I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1803,0),(25948,781,'Large Capacitor Control Circuit I','This ship modification is designed to increase a ship\'s capacitor recharge rate.\r\r\n',200,20,0,1,NULL,0.0000,1,1224,0),(25949,787,'Large Capacitor Control Circuit I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1254,0),(25950,781,'Large Egress Port Maximizer I','This ship modification is designed to reduce a ship\'s capacitor need for all energy emission modules.',200,20,0,1,NULL,0.0000,1,1224,0),(25951,787,'Large Egress Port Maximizer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1254,0),(25952,781,'Large Powergrid Subroutine Maximizer I','This ship modification is designed to reduce a ship\'s CPU need for all power upgrade modules.',200,20,0,1,NULL,0.0000,1,1224,0),(25953,787,'Large Powergrid Subroutine Maximizer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1254,0),(25954,781,'Large Semiconductor Memory Cell I','This ship modification is designed to increase a ship\'s capacitor capacity.\r\r\n',200,20,0,1,NULL,0.0000,1,1224,0),(25955,787,'Large Semiconductor Memory Cell I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1254,0),(25956,781,'Large Ancillary Current Router I','This ship modification is designed to increase a ship\'s powergrid capacity.',200,20,0,1,NULL,0.0000,1,1224,0),(25957,787,'Large Ancillary Current Router I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1254,0),(25968,775,'Large Energy Discharge Elutriation I','This ship modification is designed to decrease the capacitor need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,20,0,1,NULL,0.0000,1,1227,0),(25969,787,'Large Energy Discharge Elutriation I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1257,0),(25970,775,'Large Energy Ambit Extension I','This ship modification is designed to increase the accuracy falloff range of a ship\'s energy turrets at the expense of increased power grid need for them.',200,20,0,1,NULL,0.0000,1,1227,0),(25971,787,'Large Energy Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1257,0),(25972,775,'Large Energy Locus Coordinator I','This ship modification is designed to increase the optimal range of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1227,0),(25973,787,'Large Energy Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1257,0),(25974,775,'Large Energy Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1227,0),(25975,787,'Large Energy Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1257,0),(25976,775,'Large Algid Energy Administrations Unit I','This ship modification is designed to decrease the CPU need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,20,0,1,NULL,0.0000,1,1227,0),(25977,787,'Large Algid Energy Administrations Unit I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1257,0),(25978,775,'Large Energy Burst Aerator I','This ship modification is designed to increase a ship\'s energy turrets\' rate of fire at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1227,0),(25979,787,'Large Energy Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1257,0),(25980,775,'Large Energy Collision Accelerator I','This ship modification is designed to increase the damage output of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1227,0),(25981,787,'Large Energy Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1257,0),(25988,526,'Mining Equipment','Expensive mining equipment.',1000,1,50,1,NULL,0.0000,1,NULL,0),(25989,283,'Minecore Harvester','These are dedicated Minecore workers. Highly skilled in operating complex mining equipment.',80,2,0,1,NULL,0.0000,1,NULL,0),(25990,820,'Republic Fleet Keeper','A powerful battlecruiser of the Minmatar Republic.\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(25991,319,'Guristas Starbase Control Tower_Tough','Originally designed by the Kaalakiota, the Caldari Control Tower blueprint was quickly obtained by the Guristas, through their agents within the State, to serve their own needs.',100000,1150,8850,1,1,0.0000,0,NULL,0),(25992,319,'Conquerable Station 3','Docking has been prohibited into this station without proper authorization.',0,0,0,1,8,0.0000,0,NULL,0),(25993,319,'Conquerable Station 2','Docking has been prohibited into this station without proper authorization.',0,0,0,1,8,0.0000,0,NULL,0),(25994,319,'Conquerable Station 1','Docking has been prohibited into this station without proper authorization.',0,0,0,1,8,0.0000,0,NULL,0),(25995,821,'Sansha\'s Slave Master','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',21000000,100100,235,1,4,0.0000,0,NULL,0),(25996,776,'Large Hybrid Discharge Elutriation I','This ship modification is designed to reduce the capacitor need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,20,0,1,NULL,0.0000,1,1230,0),(25997,787,'Large Hybrid Discharge Elutriation I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1260,0),(25998,776,'Large Hybrid Ambit Extension I','This ship modification is designed to increase the accuracy falloff range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,20,0,1,NULL,0.0000,1,1230,0),(25999,787,'Large Hybrid Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1260,0),(26000,776,'Large Hybrid Locus Coordinator I','This ship modification is designed to increase the optimal range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1230,0),(26001,787,'Large Hybrid Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1260,0),(26002,776,'Large Hybrid Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1230,0),(26003,787,'Large Hybrid Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1260,0),(26004,776,'Large Algid Hybrid Administrations Unit I','This ship modification is designed to decrease the CPU need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,20,0,1,NULL,0.0000,1,1230,0),(26005,787,'Large Algid Hybrid Administrations Unit I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1260,0),(26006,776,'Large Hybrid Burst Aerator I','This ship modification is designed to increase a ship\'s hybrid turret rate of fire at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1230,0),(26007,787,'Large Hybrid Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1260,0),(26008,776,'Large Hybrid Collision Accelerator I','This ship modification is designed to increase a ship\'s hybrid turret damage at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1230,0),(26009,787,'Large Hybrid Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1260,0),(26016,779,'Large Hydraulic Bay Thrusters I','This ship modification is designed to increase missile velocity at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1233,0),(26017,787,'Large Hydraulic Bay Thrusters I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1263,0),(26018,779,'Launcher Processor Rig I','THIS MOD NOT RELEASED',200,5,0,1,NULL,0.0000,0,NULL,0),(26019,787,'Launcher Processor Rig I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,0,NULL,0),(26020,779,'Large Warhead Rigor Catalyst I','This ship modification is designed to decrease the signature radius factor for missile explosions at the expense of increased CPU requirements for launchers.',200,20,0,1,NULL,0.0000,1,1233,0),(26021,787,'Large Warhead Rigor Catalyst I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1263,0),(26022,779,'Large Rocket Fuel Cache Partition I','This ship modification is designed to increase maximum missile flight time at the expense of increased CPU requirements for launchers.',200,20,0,1,NULL,0.0000,1,1233,0),(26023,787,'Large Rocket Fuel Cache Partition I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1263,0),(26024,779,'Missile Guidance System Rig I','This rig isn\'t supposed to be in game until a use for it is decided.\r\r\n\r\r\nOnce affixed to the controlling mechanisms of a ship\'s missile launchers, this durable and multiplexing part assumes direct control of the ship\'s launching operations. All commands are routed through it, re-calculated and optimized, with the result that both the launchers themselves and the missiles they fire are made all the more deadlier - but, naturally, at a cost. Decreases missile launcher TO BE DECIDED at the expense of increased CPU requirements for launchers.',200,5,0,1,NULL,0.0000,0,NULL,0),(26025,787,'Missile Guidance System Rig I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26026,779,'Large Bay Loading Accelerator I','This ship modification is designed to increase a ship\'s missile launchers\' rate of fire at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1233,0),(26027,787,'Large Bay Loading Accelerator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1263,0),(26028,779,'Large Warhead Flare Catalyst I','This ship modification is designed to decrease the effect of a target\'s velocity in avoiding the radius of missile explosions at the expense of increased CPU requirements for launchers.',200,20,0,1,NULL,0.0000,1,1233,0),(26029,787,'Large Warhead Flare Catalyst I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1263,0),(26030,779,'Large Warhead Calefaction Catalyst I','This ship modification is designed to increase missile damage at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1233,0),(26031,787,'Large Warhead Calefaction Catalyst I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1263,0),(26036,777,'Projectile Cache Distributor I','This ship modification is designed to increase a ship\'s projectile turret ammo capacity at the expense of increased power grid need for projectile weapons.',200,5,0,1,NULL,0.0000,0,NULL,0),(26038,777,'Large Projectile Ambit Extension I','This ship modification is designed to increase a ship\'s projectile turret accuracy falloff range at the expense of increased power grid need for projectile weapons.',200,20,0,1,NULL,0.0000,1,1239,0),(26039,787,'Large Projectile Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1266,0),(26040,777,'Large Projectile Locus Coordinator I','This ship modification is designed to increase the optimal range of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1239,0),(26041,787,'Large Projectile Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1266,0),(26042,777,'Large Projectile Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1239,0),(26043,787,'Large Projectile Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1266,0),(26044,777,'Projectile Consumption Elutriator I','THIS MOD NOT RELEASED',200,5,0,1,NULL,0.0000,0,NULL,0),(26046,777,'Large Projectile Burst Aerator I','This ship modification is designed to increase a ship\'s projectile turret rate of fire at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1239,0),(26047,787,'Large Projectile Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1266,0),(26048,777,'Large Projectile Collision Accelerator I','This ship modification is designed to increase a ship\'s projectile turret damage output at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1239,0),(26049,787,'Large Projectile Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1266,0),(26056,782,'Large Dynamic Fuel Valve I','This ship modification is designed to reduce the capacitor need of a ship\'s afterburner and microwarpdrive modules at the expense of armor amount.\r\r\n',200,20,0,1,NULL,0.0000,1,1212,0),(26057,787,'Large Dynamic Fuel Valve I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1242,0),(26058,782,'Large Low Friction Nozzle Joints I','This ship modification is designed to increase a ship\'s agility at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1212,0),(26059,787,'Large Low Friction Nozzle Joints I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1242,0),(26060,782,'Large Auxiliary Thrusters I','This ship modification is designed to increase a ship\'s max velocity at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1212,0),(26061,787,'Large Auxiliary Thrusters I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1242,0),(26062,782,'Large Engine Thermal Shielding I','This ship modification is designed to increase the duration of a ship\'s afterburner or microwarpdrive modules at the expense of armor amount.',200,20,0,1,NULL,0.0000,1,1212,0),(26063,787,'Large Engine Thermal Shielding I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1242,0),(26064,782,'Propellant Injection Vent I','This ship modification is designed to increase the speed boost of a ship\'s afterburner and microwarpdrive modules at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,0,NULL,0),(26065,787,'Propellant Injection Vent I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26066,782,'Large Warp Core Optimizer I','This ship modification is designed to reduce a ship\'s capacitor need for initiating warp at the expense of increased signature radius.',200,20,0,1,4,0.0000,1,1212,0),(26067,787,'Large Warp Core Optimizer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1242,0),(26068,782,'Large Hyperspatial Velocity Optimizer I','This ship modification is designed to increase a ship\'s warp speed at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,4,0.0000,1,1212,0),(26069,787,'Large Hyperspatial Velocity Optimizer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1242,0),(26070,782,'Large Polycarbon Engine Housing I','This ship modification is designed to increase ship\'s velocity and maneuverability at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1212,0),(26071,787,'Large Polycarbon Engine Housing I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1242,0),(26072,782,'Large Cargohold Optimization I','This ship modification is designed to increase a ship\'s cargo capacity at the expense of armor amount.',200,20,0,1,NULL,0.0000,1,1212,0),(26073,787,'Large Cargohold Optimization I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1242,0),(26076,774,'Large Anti-EM Screen Reinforcer I','This ship modification is designed to increase the EM resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1236,0),(26077,787,'Large Anti-EM Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1269,0),(26078,774,'Large Anti-Explosive Screen Reinforcer I','This ship modification is designed to increase the explosive resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1236,0),(26079,787,'Large Anti-Explosive Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1269,0),(26080,774,'Large Anti-Kinetic Screen Reinforcer I','This ship modification is designed to increase the kinetic resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1236,0),(26081,787,'Large Anti-Kinetic Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1269,0),(26082,774,'Large Anti-Thermal Screen Reinforcer I','This ship modification is designed to increase the thermal resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1236,0),(26083,787,'Large Anti-Thermal Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1269,0),(26084,774,'Large Core Defense Field Purger I','This ship modification is designed to improve shield recharge rate at the expense of increased signature radius.',200,20,0,1,NULL,0.0000,1,1236,0),(26085,787,'Large Core Defense Field Purger I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1269,0),(26086,774,'Large Core Defense Operational Solidifier I','This ship modification is designed to reduce the duration of shield booster cycles at the expense of increased signature radius.',200,20,0,1,NULL,0.0000,1,1236,0),(26087,787,'Large Core Defense Operational Solidifier I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1269,0),(26088,774,'Large Core Defense Field Extender I','This ship modification is designed to increase shield capacity at the expense of increased signature radius.',200,20,0,1,NULL,0.0000,1,1236,0),(26089,787,'Large Core Defense Field Extender I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1269,0),(26090,774,'Large Core Defense Charge Economizer I','This ship modification is designed to reduce the power need of all shield upgrade modules at the expense of increased signature radius.',200,20,0,1,NULL,0.0000,1,1236,0),(26091,787,'Large Core Defense Charge Economizer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1269,0),(26096,786,'Large Targeting Systems Stabilizer I','This ship modification is designed to reduce a ship\'s targeting delay after de-cloaking at the expense of shields.',200,20,0,1,NULL,0.0000,1,1221,0),(26097,787,'Large Targeting Systems Stabilizer I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1251,0),(26100,1234,'Large Targeting System Subcontroller I','This ship modification is designed to increase a ship\'s targeting speed at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1792,0),(26101,787,'Large Targeting System Subcontroller I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1807,0),(26102,1234,'Large Ionic Field Projector I','This ship modification is designed to increase a ship\'s targeting range at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1792,0),(26103,787,'Large Ionic Field Projector I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1807,0),(26104,1233,'Large Signal Focusing Kit I','This ship modification is designed to increase the scan speed of modules which require the electronics skill (cargo scanner, ship scanner and survey scanner), at the expense of shields.',200,20,0,1,NULL,0.0000,1,1788,0),(26105,787,'Large Signal Focusing Kit I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1803,0),(26106,786,'Large Particle Dispersion Augmentor I','This ship modification is designed to increase the strength of a ship\'s ECM jammers at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1221,0),(26107,787,'Large Particle Dispersion Augmentor I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1251,0),(26108,786,'Large Particle Dispersion Projector I','This ship modification is designed to increase the optimal range of a ship\'s ECM, remote sensor dampeners, tracking disruptors and target painters at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1221,0),(26109,787,'Large Particle Dispersion Projector I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1251,0),(26110,786,'Large Inverted Signal Field Projector I','This ship modification is designed to increase the effectiveness of fitted remote sensor dampeners at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1221,0),(26111,787,'Large Inverted Signal Field Projector I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1251,0),(26112,786,'Large Tracking Diagnostic Subroutines I','This ship modification is designed to increase the effectiveness of fitted tracking disruptors at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1221,0),(26113,787,'Large Tracking Diagnostic Subroutines I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1251,0),(26115,283,'Informant','This informant is rumoured to know the whereabouts of the evil Thukker lord, Martokar Alash.',80,2,0,1,NULL,0.0000,1,NULL,0),(26117,820,'Thukker Informant','This person is rumoured to know the whereabouts of the evil Thukker lord, Martokar Alash.',10900000,109000,120,1,2,0.0000,0,NULL,0),(26118,821,'Martokar Alash','The legendary Thukker lord, Martokar Alash.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26119,821,'Abufyr Joek','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others.',21000000,100100,235,1,4,0.0000,0,NULL,0),(26120,526,'Abufyr Joek\'s Head','This is the head of Abufyr Joek, a feared Sansha lord.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26121,319,'Amarr Battlestation 3','This gigantic military installation is the pride of the Imperial Navy.  Thousands, sometimes hundreds of thousands, of slaves pour their blood, sweat and tears into erecting one of these mega-structures.  Only a fool would attempt to assault such a massive base without a fleet behind him.\r\r\n\r\r\nDocking has been prohibited into this station without proper authorization.',0,0,0,1,4,0.0000,0,NULL,0),(26122,526,'Pillaging 101','This informative brochure contains helpful diagrams and elaborate tutorials on how to effectively function as a successful brigand. Key chapters include:<br>\r\r\n<br>\r\r\nPriority Pillaging   Triage style tactics for post-combat logistics<br>\r\r\nPursuing Passersby   Why anonymity is more useful than infamy<br>\r\r\nPunishing Pirates   What to do with a drunken crewman early in the morning<br>\r\r\n<br>\r\r\nThis handy guide could turn even the noblest capsuleer into a ruthless raider in just a few short years of night courses.\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26123,526,'The Little Pirate That Could','An inspirational story if there ever was one. Fills every pirate wannabe with pride.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26124,526,'17 Successful Torture Techniques','You can only wonder about the dedication in filtering the successful techniques from the unsuccessful ones.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26125,526,'Test Bong','A curious device used by pirates to test their own product. Seems heavily used.',100,1,0,1,NULL,0.0000,1,NULL,0),(26126,526,'Flower Power Powder','Oddly smelling powder presumably used by pirates in some of their more exotic formulas.',1000,1,0,1,NULL,0.0000,1,NULL,0),(26127,526,'Angel Cartel Dust','Finely grained dust manufactured by the Angel Cartel for use in hallucination drugs.',1000,1,0,1,NULL,0.0000,1,NULL,0),(26128,370,'Sansha Infiltrator Tag','A dogtag carried by members of the Sansha\'s navy. Members carrying the rank of infiltrator are often tasked with intercepting and deciphering enemy communications.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26129,526,'Cold Turkey','From what little information you can garner the pirates seemed severely afraid of encountering cold turkeys and were researching ways to counter them. Why frozen poultry would frighten space pirates so is anybody\'s guess.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26130,820,'Sansha Infiltrator','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Sansha Infiltrators are often tasked with intercepting and deciphering enemy communications.',10010000,100100,235,1,4,0.0000,0,NULL,0),(26131,526,'Booster Pack','Apparently the pirates were researching a pack to store drugs in. It\'s supposed to have 11 racks, one for strong boosters, three for improved boosters and seven for standard boosters. What a curious idea.  ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26132,526,'Purple Haze','Purple haze is apparently a nirvana-like state that all pirates dream of entering, yet one that can kill the uninitiated. From the pieces of research notes you have here it seems the pirates sought to prolong this euphoric state while minimizing the risks of entering it. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26135,1207,'Production Cache','A locked storage bin containing various items used by the local pirates in their drug manufacturing. A bit of hacking might unlock it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26136,1207,'Training Cube','The training cube is used by the local pirates to learn how to become good pirates. It is password protected, but probably not all that well.',10000,27500,2700,1,1,0.0000,0,NULL,0),(26137,1207,'Research Lab','The local pirates are actively trying to enhance the potency of their products, as well as improving other aspects of drug manufacturing. With the right equipment it might be possible to hack into the lab\'s mainframe and get something of interest.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26138,474,'Research Tower Key','Security key that grants entry into the Research Tower room.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26139,534,'Guristas Sloth','The top security officer of this outpost, while being a superb fighter, is more a liability than help in the security department. He should be guarding the entrance to the research tower room, but instead lingers here, lured by the promised pleasures of the brothels.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(26140,283,'Rogue Harvester','A rogue harvester.',100,5,0,1,NULL,0.0000,1,NULL,0),(26142,819,'Rogue Harvesting Vessel','A  rogue harvesting vessel.',1645000,16450,120,1,2,0.0000,0,NULL,0),(26145,1207,'Shipping Crate','A locked storage bin containing various items used by the local pirates in their drug distribution. A bit of hacking might unlock it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26146,1207,'Com Relay','The com relay is used in environments with high interference. It is used by the local pirates to chat about the booster industry. It is password protected, but probably not all that well.',10000,27500,2700,1,1,0.0000,0,NULL,0),(26148,1207,'Product Sample Case','The local pirates are actively trying to enhance the potency of their products, as well as improving other aspects of drug manufacturing. This case contains their latest discoveries and avenues of research. It has an advanced password protection, but very skillful hackers should be able to break through.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26149,1207,'Test Crate','A locked storage bin containing various items used by the local pirates in their drug manufacturing. A bit of hacking might unlock it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26150,1207,'Victim\'s Stash','Leftovers from some unfortunate pirate overconfidant in his abilities. A bit of hacking might unlock it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26151,1207,'Component Bin','A locked storage bin containing various items used by the local pirates in their drug manufacturing. A bit of hacking might unlock it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26152,1207,'Outbound Freight','A locked storage bin containing various items used by the local pirates in their drug manufacturing. A bit of hacking might unlock it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26153,1207,'Demo Kit','A locked storage bin containing various items used by the local pirates in their drug manufacturing. A bit of hacking might unlock it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26154,1207,'Gadget Casket','A locked storage bin containing various items used by the local pirates in their drug manufacturing. A bit of hacking might unlock it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26155,1207,'Info Matrix','The info matrix is used by the local pirates to learn how to become good pirates. It is password protected, but probably not all that well.',10000,27500,2700,1,1,0.0000,0,NULL,0),(26161,1207,'Think Tank','The local pirates are actively trying to enhance the potency of their products, as well as improving other aspects of drug manufacturing. With the right equipment it might be possible to hack into the tank\'s mainframe and get something of interest.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26162,1207,'Restricted Punch Bowl','Guests of honor are allowed to dip into whatever treasures and secrets the hosts have in their possession. It is password protected to keep not-so-VIP guests out, but a bit of hacking should suffice to get to the goods inside.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26163,1207,'Science Lab','The local pirates are actively trying to enhance the potency of their products, as well as improving other aspects of drug manufacturing. With the right equipment it might be possible to hack into the lab\'s mainframe and get something of interest.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26164,1207,'Prototype Crate','The local pirates are actively trying to enhance the potency of their products, as well as improving other aspects of drug manufacturing. This crate contains some of their latest efforts and might be accessible with the right equipment.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26165,1207,'Backup Array','The local pirates are actively trying to enhance the potency of their products, as well as improving other aspects of drug manufacturing. This unit stores some of their backup files and with the right equipment it might be possible to hack into it.',10000,27500,2700,1,1,0.0000,0,NULL,0),(26166,1207,'Novelty Box','The local pirates are searching for ways to enhance their products. They collect their findings in these boxes. Those skilled in hacking might be able to bypass the security measures and access the contents of the box.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26167,526,'Okelle\'s Encryption-Protected Hard Drive','A small wafer of semiconductor material that forms the base for an integrated circuit.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26168,494,'Okelle\'s Pleasure Hub','This pleasure resort sports various activities open for guests, including casinos, baths, escort booths and three domes of simulated tropical paradise for maximum bliss.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(26173,481,'Demo Probe Launcher','A missile launcher shell modified to fit scanner probes.  Can hold up to twelve system scan probes of any one configuration. Can also be used to launch survey probes. Only one probe launcher can be fitted per ship.',0,5,8,1,NULL,6670.0000,0,NULL,0),(26174,136,'Demo Probe Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(26176,517,'Altan Uigot\'s Bunker','A bunker inhabited by personnel of the Minmatar Republic.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26177,517,'Frera Elgas\'s Bunker','A bunker inhabited by personnel of the Minmatar Republic.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26178,517,'Frie Tasmulo\'s Bunker','A bunker inhabited by personnel of the Minmatar Republic.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26179,517,'Adari Jammalgen\'s Bunker','A bunker inhabited by personnel of the Minmatar Republic.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26180,517,'Sanderi Ualmun\'s Bunker','A bunker inhabited by personnel of the Minmatar Republic.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26181,517,'Habad Rokusten\'s Bunker','A bunker inhabited by personnel of the Minmatar Republic.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26182,517,'Skia Alfota\'s Bunker','A bunker inhabited by personnel of the Minmatar Republic.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26183,517,'Eget Skovilen\'s Bunker','A bunker inhabited by personnel of the Minmatar Republic.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26184,517,'Osidei Esama\'s Bunker','A bunker inhabited by personnel of the Minmatar Republic.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26185,517,'Blique Hazardt\'s Bunker','A bunker inhabited by personnel of the Gallente Federation.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26186,517,'Alliot Graferr\'s Bunker','A bunker inhabited by personnel of the Gallente Federation.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26187,517,'Mobas Jouey\'s Bunker','A bunker inhabited by personnel of the Gallente Federation.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26188,517,'Alon Ahrassine\'s Bunker','A bunker inhabited by personnel of the Gallente Federation.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26189,517,'Amatin Chens\'s Bunker','A bunker inhabited by personnel of the Gallente Federation.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26190,517,'Fims Artalanche\'s Bunker','A bunker inhabited by personnel of the Gallente Federation.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26191,517,'Hana Isourin\'s Bunker','A bunker inhabited by personnel of the Gallente Federation.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26192,517,'Carvaire Botesane\'s Bunker','A bunker inhabited by personnel of the Gallente Federation.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26193,517,'Oisedia Gync\'s Bunker','A bunker inhabited by personnel of the Gallente Federation.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26194,517,'Selate Kalami\'s Bunker','A bunker inhabited by personnel of the Amarr Empire.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26195,517,'Jur Zehbani\'s Bunker','A bunker inhabited by personnel of the Amarr Empire.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26196,517,'Subin Barama\'s Bunker','A bunker inhabited by personnel of the Amarr Empire.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26197,517,'Timafa Esihiz\'s Bunker','A bunker inhabited by personnel of the Amarr Empire.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26198,517,'Hatia Madase\'s Bunker','A bunker inhabited by personnel of the Amarr Empire.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26199,517,'Odoosh Teroul\'s Bunker','A bunker inhabited by personnel of the Amarr Empire.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26200,517,'Matna Meri\'s Bunker','A bunker inhabited by personnel of the Amarr Empire.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26201,517,'Juki Khoun\'s Bunker','A bunker inhabited by personnel of the Amarr Empire.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26202,517,'Urat Mehrekar\'s Bunker','A bunker inhabited by personnel of the Amarr Empire.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26203,517,'Ollen Alulama\'s Outpost','An outpost manned by personnel of the Caldari State.',11950000,100000000,240,1,1,0.0000,0,NULL,0),(26204,517,'Ichmari Obesa\'s Outpost','An outpost manned by personnel of the Caldari State.',11950000,100000000,240,1,1,0.0000,0,NULL,0),(26205,517,'Kui Hisken\'s Outpost','An outpost manned by personnel of the Caldari State.',11950000,100000000,240,1,1,0.0000,0,NULL,0),(26206,517,'Tojawara Saziras\'s Outpost','An outpost manned by personnel of the Caldari State.',11950000,100000000,240,1,1,0.0000,0,NULL,0),(26207,517,'Oko Alo\'s Outpost','An outpost manned by personnel of the Caldari State.',11950000,100000000,240,1,1,0.0000,0,NULL,0),(26208,517,'Isu Jokaga\'s Outpost','An outpost manned by personnel of the Caldari State.',11950000,100000000,240,1,1,0.0000,0,NULL,0),(26209,517,'Ruupas Vonni\'s Outpost','An outpost manned by personnel of the Caldari State.',11950000,100000000,240,1,1,0.0000,0,NULL,0),(26210,517,'Ozunoa Poskat\'s Outpost','An outpost manned by personnel of the Caldari State.',11950000,100000000,240,1,1,0.0000,0,NULL,0),(26211,517,'Kanouchi Hisama\'s Outpost','An outpost manned by personnel of the Caldari State.',11950000,100000000,240,1,1,0.0000,0,NULL,0),(26212,534,'Complex Supervisor','The supervisor of this outpost is extremely paranoid and carefully controls who enters the packaging center, from fear of theft or sabotage.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(26213,517,'Hazar Arjidsi\'s Bunker','A bunker manned by personnel of the Ammatar Mandate.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26214,517,'Sish Iaokih\'s Bunker','A bunker manned by personnel of the Ammatar Mandate.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26215,517,'Darabu Harva\'s Bunker','A bunker manned by personnel of the Ammatar Mandate.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26216,474,'Packaging Center Passkey','This is a passkey used to enter the packaging center.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26217,517,'Derqa Mandame\'s Bunker','A bunker manned by personnel of the Ammatar Mandate.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26218,517,'Cimalo Mahnab\'s Bunker','A bunker manned by personnel of the Ammatar Mandate.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26219,517,'Bamona Pizteed\'s Bunker','A bunker manned by personnel of the Ammatar Mandate.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26220,517,'Rolnia Houmar\'s Bunker','A bunker manned by personnel of the Ammatar Mandate.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26221,517,'Migart Anunat\'s Bunker','A bunker manned by personnel of the Ammatar Mandate.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26222,517,'Tizeli Reymta\'s Bunker','A bunker manned by personnel of the Ammatar Mandate.',11950000,100000000,240,1,NULL,0.0000,0,NULL,0),(26224,268,'Drug Manufacturing','Needed to manufacture boosters. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,25000000.0000,1,369,0),(26225,283,'Jamiella Ortar','Akelf Ortar\'s niece.',60,0.1,0,1,NULL,0.0000,1,NULL,0),(26227,534,'Research Overseer','The overseer of this research facility takes his job very seriously and keeps the most important area of the facility, the Think Tank, locked at all times.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(26228,474,'Think Tank Security Pad','This security pad is used to access the Think Tank room.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26229,226,'Fortified Minmatar Trade Station Ruins','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26230,226,'Fortified Minmatar Mining Station Ruins','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26231,226,'Fortified Minmatar Commercial Station Ruins','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26232,226,'Amarr Commercial Station Ruins','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26233,226,'Fortified Amarr Mining Station Ruins','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26234,226,'Fortified Amarr Research Station Ruins','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26235,226,'Caldari Station Ruins - Flat Hulk','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26236,226,'Caldari Station Ruins - Huge & Sprawling','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26237,226,'Fortified Gallente Station Ruins - Fathom','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26238,226,'Fortified Gallente Station Ruins - Military','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26239,226,'Fortified Gallente Station Ruins - Ugly Industrial','Ruins.',0,0,0,1,4,0.0000,0,NULL,0),(26240,319,'Weapon\'s Storage Facility','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(26241,474,'VIP Pass','This pass allows entrance for you and your entourage into the exclusive VIP Room.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26244,534,'Head Bouncer','The head bouncer has the final say in who is allowed entrance into the exclusive VIP Room.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(26245,474,'Coded Research Zone Key','This is a passkey used to enter the off-limit Research Zone room.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26246,534,'Soul Keeper','The Soul Keeper is responsible for the spiritual well-being of all Blood Raiders in the complex. He also acts as liaison between the research team and the leaders of the Blood Raiders and has the authority to go anywhere he pleases within the complex.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(26247,494,'Blood Raider Control Center','A control center.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26248,494,'Guristas Control Center','A control center.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26249,494,'Sansha Control Center','A control center.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26250,494,'Serpentis Control Center','A control center.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26251,494,'Angel Control Center','A control center.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26252,269,'Jury Rigging','General understanding of the inner workings of starship components. Allows makeshift modifications to ship systems through the use of rigs. Required learning for further study in the field of rigging. ',0,0.01,0,1,NULL,60000.0000,1,372,0),(26253,269,'Armor Rigging','Advanced understanding of armor systems. Allows makeshift modifications to armor systems through the use of rigs. \r\r\n\r\r\n10% reduction in Armor Rig drawbacks per level.',0,0.01,0,1,NULL,100000.0000,1,372,0),(26254,269,'Astronautics Rigging','Advanced understanding of a ships navigational systems. Allows makeshift modifications to warp drive, sub warp drive and other navigational systems through the use of rigs. \r\r\n\r\r\n10% reduction in Astronautics Rig drawbacks per level.',0,0.01,0,1,NULL,20000.0000,1,372,0),(26255,269,'Drones Rigging','Advanced understanding of a ships drone control systems. Allows makeshift modifications to drone systems through the use of rigs. \r\r\n\r\r\n10% reduction in Drone Rig drawbacks per level.',0,0.01,0,1,NULL,100000.0000,1,372,0),(26256,269,'Electronic Superiority Rigging','Advanced understanding of electronics systems. Allows makeshift modifications to targeting, scanning and ECM systems through the use of rigs. \r\r\n\r\r\n10% reduction in Electronic Superiority Rig drawbacks per level.',0,0.01,0,1,NULL,100000.0000,1,372,0),(26257,269,'Projectile Weapon Rigging','Advanced understanding of the interface between projectile weapons and the numerous ship systems. Allows makeshift modifications to ship system architecture through the use of rigs. \r\r\n\r\r\n10% reduction in Projectile Weapon Rig drawbacks per level.',0,0.01,0,1,NULL,100000.0000,1,372,0),(26258,269,'Energy Weapon Rigging','Advanced understanding of the interface between energy weapons and the numerous ship systems. Allows makeshift modifications to ship system architecture through the use of rigs. \r\r\n\r\r\n10% reduction in Energy Weapon Rig drawbacks per level.',0,0.01,0,1,NULL,100000.0000,1,372,0),(26259,269,'Hybrid Weapon Rigging','Advanced understanding of the interface between hybrid weapons and the numerous ship systems. Allows makeshift modifications to ship system architecture through the use of rigs. \r\r\n\r\r\n10% reduction in Hybrid Weapon Rig drawbacks per level.',0,0.01,0,1,NULL,100000.0000,1,372,0),(26260,269,'Launcher Rigging','Advanced understanding of the interface between Missile Launchers and the numerous ship systems. Allows makeshift modifications to ship system architecture through the use of rigs. \r\r\n\r\r\n10% reduction in Launcher Rig drawbacks per level.',0,0.01,0,1,NULL,100000.0000,1,372,0),(26261,269,'Shield Rigging','Advanced understanding of shield systems. Allows makeshift modifications to shield systems through the use of rigs. \r\r\n\r\r\n10% reduction in Shield Rig drawbacks per level.',0,0.01,0,1,NULL,100000.0000,1,372,0),(26262,517,'Jeremy Tacs\'s Eagle','Once bound within the confines of a tiny blue planet, enterprising young Jeremy Tacs decided at a tender age that his destiny lay between the stars. Having shed the limitations of his planetbound life, he now glides through celestial heavens, lending a hand of help to those proving themselves worthy.',13000000,85000,450,1,1,0.0000,0,NULL,0),(26264,821,'Lazron Kamon_','A former scientist working for the Angel Cartel, Lazron was an expert in drone manufacturing.  Many years ago he disappeared entirely into the cosmos.  His co-workers claimed he had suffered a mental breakdown from work related stress, and had simply left.  Few know where he has been, or what he has been up to, these past few years ...',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26266,283,'Lazron Kamon','A scientist specialized in Drone Creation and AI programming.',80,3,0,1,NULL,0.0000,1,NULL,0),(26269,803,'Elite Repair Drone','An elite repair drone.',100000,60,1200,1,NULL,0.0000,0,NULL,0),(26270,314,'Federal Star of Justice','The Federal Star of Justice is a golden medallion, awarded by the Gallente Federation to individuals who have displayed exceptional bravery, self-sacrifice and wisdom in promoting the causes of liberty and democracy across the universe.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26271,283,'Torin Tacs','The son of Jeremy Tacs.',60,5,0,1,NULL,0.0000,1,NULL,0),(26272,226,'Unstable Wormhole','Your sensors show readings of the chart when you aim them at this peculiar phenomenon. From what little information you can gather you surmise that a stabling mechanism of some sort is needed for it to be safe to venture through the wormhole. But the readings also seem to indicate that this wormhole might not be a totally random natural phenomenon, but rather something that was created. When or by whom is impossible to tell and where it leads is an even bigger mystery.',1,0,0,1,NULL,0.0000,0,NULL,0),(26275,495,'Hive mother 2_Complex','Hive mother',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(26276,1207,'Floating Debris','At first glance this looks like just another piece of space debris, but on closer inspection it looks to be very old. What secrets might it unveil to proficient archaeologists?',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26277,1207,'Ancient Ruins','Eons seperate you and this foreboding ruins. One can only wonder over who built it long ago and, more importantly, what they left behind. A shrewd archaeologist might be able to unearth something of interest.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26278,474,'Privileged Guest Pass','This passkey allows the bearer to enter the Inner Court of this complex.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26279,534,'Sansha Administrator','This is the administrator appointed by Sansha to run this facility. It is likely he as a key to enter the administration area, as his offices are located there. ',10010000,100100,235,1,4,0.0000,0,NULL,0),(26283,474,'Master Key','This key unlocks all acceleration gates in the complex, most notably the R&D Circle.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26284,534,'Angel Inspector','The inspector is here to keep a tab on the operation and make sure the workers don\'t get too fond of the products. He has the authority to enter any part of the complex.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26285,534,'Akkeshu Karuan_2','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(26286,773,'Large Anti-EM Pump II','This ship modification is designed to increase a ship\'s armor EM resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(26287,787,'Large Anti-EM Pump II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26288,773,'Large Anti-Explosive Pump II','This ship modification is designed to increase a ship\'s armor explosive resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(26289,787,'Large Anti-Explosive Pump II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26290,773,'Large Anti-Kinetic Pump II','This ship modification is designed to increase a ship\'s armor kinetic resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(26291,787,'Large Anti-Kinetic Pump II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26292,773,'Large Anti-Thermic Pump II','This ship modification is designed to increase a ship\'s armor thermal resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(26293,787,'Large Anti-Thermic Pump II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26294,773,'Large Auxiliary Nano Pump II','This ship modification is designed to increase a ship\'s armor repairer repair amount at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(26295,787,'Large Auxiliary Nano Pump II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26296,773,'Large Nanobot Accelerator II','This ship modification is designed to reduce a ship\'s armor repair cycle duration at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1208,0),(26297,787,'Large Nanobot Accelerator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26298,773,'Large Remote Repair Augmentor II','This ship modification is designed to reduce the capacitor need for a ship\'s remote armor repair modules at the expense of max velocity.\r\r\n',200,20,0,1,NULL,0.0000,1,1208,0),(26299,787,'Large Remote Repair Augmentor II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26300,1232,'Large Salvage Tackle II','This ship modification is designed to increase a ship\'s chance of salvage retrieval at the expense of max velocity.',200,20,0,1,NULL,0.0000,1,1784,0),(26301,787,'Large Salvage Tackle II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26302,773,'Large Trimark Armor Pump II','This ship modification is designed to increase a ship\'s total armor hit points at the expense of max velocity.',200,20,0,1,NULL,0.0000,1,1208,0),(26303,787,'Large Trimark Armor Pump II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26304,782,'Large Cargohold Optimization II','This ship modification is designed to increase a ship\'s cargo capacity at the expense of armor amount.',200,20,0,1,NULL,0.0000,1,1212,0),(26305,787,'Large Cargohold Optimization II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26306,782,'Large Dynamic Fuel Valve II','This ship modification is designed to reduce the capacitor need of a ship\'s afterburner and microwarpdrive modules at the expense of armor amount.\r\r\n',200,20,0,1,NULL,0.0000,1,1212,0),(26307,787,'Large Dynamic Fuel Valve II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26308,782,'Large Engine Thermal Shielding II','This ship modification is designed to increase the duration of a ship\'s afterburner or microwarpdrive modules at the expense of armor amount.',200,20,0,1,NULL,0.0000,1,1212,0),(26309,787,'Large Engine Thermal Shielding II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26310,782,'Large Low Friction Nozzle Joints II','This ship modification is designed to increase a ship\'s agility at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1212,0),(26311,787,'Large Low Friction Nozzle Joints II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26312,782,'Large Polycarbon Engine Housing II','This ship modification is designed to increase ship\'s velocity and maneuverability at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1212,0),(26313,787,'Large Polycarbon Engine Housing II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26314,782,'Propellant Injection Vent II','This ship modification is designed to increase the speed boost of a ship\'s afterburner and microwarpdrive modules at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,0,NULL,0),(26315,787,'Propellant Injection Vent II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26318,782,'Large Auxiliary Thrusters II','This ship modification is designed to increase a ship\'s max velocity at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1212,0),(26319,787,'Large Auxiliary Thrusters II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26320,782,'Large Warp Core Optimizer II','This ship modification is designed to reduce a ship\'s capacitor need for initiating warp at the expense of increased signature radius.',200,20,0,1,4,0.0000,1,1212,0),(26321,787,'Large Warp Core Optimizer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26322,782,'Large Hyperspatial Velocity Optimizer II','This ship modification is designed to increase a ship\'s warp speed at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,4,0.0000,1,1212,0),(26323,787,'Large Hyperspatial Velocity Optimizer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26324,778,'Large Drone Control Range Augmentor II','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(26325,787,'Large Drone Control Range Augmentor II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26326,778,'Large Drone Durability Enhancer II','This ship modification is designed to increase a ship\'s drone shield, armor and structure hit points at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(26327,787,'Large Drone Durability Enhancer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26328,778,'Large Drone Mining Augmentor II','This ship modification is designed to increase a ship\'s mining drone yield at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(26329,787,'Large Drone Mining Augmentor II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26330,778,'Large Drone Repair Augmentor II','This ship modification is designed to increase a ship\'s drone repair amount at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(26331,787,'Large Drone Repair Augmentor II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26332,778,'Large Drone Scope Chip II','This ship modification is designed to increase a ship\'s drone optimal range at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(26333,787,'Large Drone Scope Chip II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26334,778,'Large Drone Speed Augmentor II','This ship modification is designed to increase a ship\'s drone max velocity at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1215,0),(26335,787,'Large Drone Speed Augmentor II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26336,778,'Large EW Drone Range Augmentor II','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,0,NULL,0),(26337,787,'Large EW Drone Range Augmentor II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,0,NULL,0),(26338,778,'Large Sentry Damage Augmentor II','This ship modification is designed to increase a ship\'s sentry drone damage at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1215,0),(26339,787,'Large Sentry Damage Augmentor II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26340,778,'Large Stasis Drone Augmentor II','This ship modification is designed to increase a ship\'s stasis web drones\' factor of velocity decrease at the expense of the ship\'s CPU capacity.',200,20,0,1,NULL,0.0000,1,1215,0),(26341,787,'Large Stasis Drone Augmentor II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26342,1233,'Large Emission Scope Sharpener II','This ship modification is designed to increase the efficiency of a ship\'s relic modules.',200,20,0,1,NULL,0.0000,1,1788,0),(26343,787,'Large Emission Scope Sharpener II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26344,786,'Large Signal Disruption Amplifier II','This ship modification is designed to reduce a ship\'s capacitor need for ECM and ECM Burst modules.\r\r\n',200,20,0,1,NULL,0.0000,1,1221,0),(26345,787,'Large Signal Disruption Amplifier II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26346,1233,'Large Memetic Algorithm Bank II','This ship modification is designed to increase the efficiency of a ship\'s data modules.',200,20,0,1,NULL,0.0000,1,1788,0),(26347,787,'Large Memetic Algorithm Bank II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26348,781,'Large Liquid Cooled Electronics II','This ship modification is designed to reduce the CPU need of modules which require the electronics upgrades skill.\r\r\n',200,20,0,1,NULL,0.0000,1,1224,0),(26349,787,'Large Liquid Cooled Electronics II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26350,1233,'Large Gravity Capacitor Upgrade II','This ship modification is designed to increase a ship\'s scan probe strength.',200,20,0,1,NULL,0.0000,1,1788,0),(26351,787,'Large Gravity Capacitor Upgrade II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26352,786,'Large Particle Dispersion Augmentor II','This ship modification is designed to increase the strength of a ship\'s ECM jammers at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,9600.0000,1,1221,0),(26353,787,'Large Particle Dispersion Augmentor II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26354,786,'Large Inverted Signal Field Projector II','This ship modification is designed to increase the effectiveness of fitted remote sensor dampeners at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,9600.0000,1,1221,0),(26355,787,'Large Inverted Signal Field Projector II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26356,786,'Large Tracking Diagnostic Subroutines II','This ship modification is designed to increase the effectiveness of fitted tracking disruptors at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,9600.0000,1,1221,0),(26357,787,'Large Tracking Diagnostic Subroutines II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26358,1234,'Large Ionic Field Projector II','This ship modification is designed to increase a ship\'s targeting range at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,9600.0000,1,1792,0),(26359,787,'Large Ionic Field Projector II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26360,786,'Large Particle Dispersion Projector II','This ship modification is designed to increase the optimal range of a ship\'s ECM, remote sensor dampeners, tracking disruptors and target painters at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,9600.0000,1,1221,0),(26361,787,'Large Particle Dispersion Projector II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26362,1233,'Large Signal Focusing Kit II','This ship modification is designed to increase the scan speed of modules which require the electronics skill (cargo scanner, ship scanner and survey scanner), at the expense of shields.',200,20,0,1,NULL,9600.0000,1,1788,0),(26363,787,'Large Signal Focusing Kit II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26364,1234,'Large Targeting System Subcontroller II','This ship modification is designed to increase a ship\'s targeting speed at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,9600.0000,1,1792,0),(26365,787,'Large Targeting System Subcontroller II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26366,786,'Large Targeting Systems Stabilizer II','This ship modification is designed to reduce a ship\'s targeting delay after de-cloaking at the expense of shields.',200,20,0,1,NULL,9600.0000,1,1221,0),(26367,787,'Large Targeting Systems Stabilizer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26368,781,'Large Egress Port Maximizer II','This ship modification is designed to reduce a ship\'s capacitor need for all energy emission modules.',200,20,0,1,NULL,0.0000,1,1224,0),(26369,787,'Large Egress Port Maximizer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26370,781,'Large Ancillary Current Router II','This ship modification is designed to increase a ship\'s powergrid capacity.',200,20,0,1,NULL,0.0000,1,1224,0),(26371,787,'Large Ancillary Current Router II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26372,781,'Large Powergrid Subroutine Maximizer II','This ship modification is designed to reduce a ship\'s CPU need for all power upgrade modules.\r\r\n',200,20,0,1,NULL,0.0000,1,1224,0),(26373,787,'Large Powergrid Subroutine Maximizer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26374,781,'Large Capacitor Control Circuit II','This ship modification is designed to increase a ship\'s capacitor recharge rate.\r\r\n',200,20,0,1,NULL,0.0000,1,1224,0),(26375,787,'Large Capacitor Control Circuit II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26376,781,'Large Semiconductor Memory Cell II','This ship modification is designed to increase a ship\'s capacitor capacity.',200,20,0,1,NULL,0.0000,1,1224,0),(26377,787,'Large Semiconductor Memory Cell II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26378,775,'Large Energy Discharge Elutriation II','This ship modification is designed to decrease the capacitor need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,20,0,1,NULL,0.0000,1,1227,0),(26379,787,'Large Energy Discharge Elutriation II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26380,775,'Large Energy Burst Aerator II','This ship modification is designed to increase a ship\'s energy turrets\' rate of fire at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1227,0),(26381,787,'Large Energy Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26382,775,'Large Energy Collision Accelerator II','This ship modification is designed to increase the damage output of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1227,0),(26383,787,'Large Energy Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26384,775,'Large Algid Energy Administrations Unit II','This ship modification is designed to decrease the CPU need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,20,0,1,NULL,0.0000,1,1227,0),(26385,787,'Large Algid Energy Administrations Unit II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26386,775,'Large Energy Ambit Extension II','This ship modification is designed to increase the accuracy falloff range of a ship\'s energy turrets at the expense of increased power grid need for them.',200,20,0,1,NULL,0.0000,1,1227,0),(26387,787,'Large Energy Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26388,775,'Large Energy Locus Coordinator II','This ship modification is designed to increase the optimal range of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1227,0),(26389,787,'Large Energy Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26390,775,'Large Energy Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1227,0),(26391,787,'Large Energy Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26392,776,'Large Hybrid Discharge Elutriation II','This ship modification is designed to reduce the capacitor need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,20,0,1,NULL,0.0000,1,1230,0),(26393,787,'Large Hybrid Discharge Elutriation II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26394,776,'Large Hybrid Burst Aerator II','This ship modification is designed to increase a ship\'s hybrid turret rate of fire at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1230,0),(26395,787,'Large Hybrid Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26396,776,'Large Hybrid Collision Accelerator II','This ship modification is designed to increase a ship\'s hybrid turret damage at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1230,0),(26397,787,'Large Hybrid Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26398,776,'Large Algid Hybrid Administrations Unit II','This ship modification is designed to decrease the CPU need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,20,0,1,NULL,0.0000,1,1230,0),(26399,787,'Large Algid Hybrid Administrations Unit II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26400,776,'Large Hybrid Ambit Extension II','This ship modification is designed to increase the accuracy falloff range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,20,0,1,NULL,0.0000,1,1230,0),(26401,787,'Large Hybrid Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26402,776,'Large Hybrid Locus Coordinator II','This ship modification is designed to increase the optimal range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1230,0),(26403,787,'Large Hybrid Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26404,776,'Large Hybrid Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1230,0),(26405,787,'Large Hybrid Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26406,779,'Large Bay Loading Accelerator II','This ship modification is designed to increase a ship\'s missile launchers\' rate of fire at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1233,0),(26407,787,'Large Bay Loading Accelerator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26408,779,'Launcher Processor Rig II','THIS MOD NOT RELEASED',200,5,0,1,NULL,0.0000,0,NULL,0),(26409,787,'Launcher Processor Rig II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,0,NULL,0),(26410,779,'Missile Guidance System Rig II','This rig isn\'t supposed to be in game until a use for it is decided.\r\r\n\r\r\nOnce affixed to the controlling mechanisms of a ship\'s missile launchers, this durable and multiplexing part assumes direct control of the ship\'s launching operations. All commands are routed through it, re-calculated and optimized, with the result that both the launchers themselves and the missiles they fire are made all the more deadlier - but, naturally, at a cost. Decreases missile launcher TO BE DECIDED at the expense of increased CPU requirements for launchers.',200,5,0,1,NULL,0.0000,0,NULL,0),(26411,787,'Missile Guidance System Rig II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26412,779,'Large Warhead Flare Catalyst II','This ship modification is designed to decrease the effect of a target\'s velocity in avoiding the radius of missile explosions at the expense of increased CPU requirements for launchers.',200,20,0,1,NULL,0.0000,1,1233,0),(26413,787,'Large Warhead Flare Catalyst II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26414,779,'Large Warhead Rigor Catalyst II','This ship modification is designed to decrease the signature radius factor for missile explosions at the expense of increased CPU requirements for launchers.',200,20,0,1,NULL,0.0000,1,1233,0),(26415,787,'Large Warhead Rigor Catalyst II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26416,779,'Large Hydraulic Bay Thrusters II','This ship modification is designed to increase missile velocity at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1233,0),(26417,787,'Large Hydraulic Bay Thrusters II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26418,779,'Large Rocket Fuel Cache Partition II','This ship modification is designed to increase maximum missile flight time at the expense of increased CPU requirements for launchers.',200,20,0,1,NULL,0.0000,1,1233,0),(26419,787,'Large Rocket Fuel Cache Partition II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26420,779,'Large Warhead Calefaction Catalyst II','This ship modification is designed to increase missile damage at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1233,0),(26421,787,'Large Warhead Calefaction Catalyst II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26422,777,'Projectile Cache Distributor II','This ship modification is designed to increase a ship\'s projectile turret ammo capacity at the expense of increased power grid need for projectile weapons.',200,5,0,1,NULL,0.0000,0,NULL,0),(26423,787,'Projectile Cache Distributor II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26424,777,'Large Projectile Collision Accelerator II','This ship modification is designed to increase a ship\'s projectile turret damage output at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1239,0),(26425,787,'Large Projectile Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26426,777,'Projectile Consumption Elutriator II','THIS MOD NOT RELEASED',200,5,0,1,NULL,0.0000,0,NULL,0),(26427,787,'Projectile Consumption Elutriator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26428,777,'Large Projectile Ambit Extension II','This ship modification is designed to increase a ship\'s projectile turret accuracy falloff range at the expense of increased power grid need for projectile weapons.',200,20,0,1,NULL,0.0000,1,1239,0),(26429,787,'Large Projectile Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26430,777,'Large Projectile Burst Aerator II','This ship modification is designed to increase a ship\'s projectile turret rate of fire at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1239,0),(26431,787,'Large Projectile Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26432,777,'Large Projectile Locus Coordinator II','This ship modification is designed to increase the optimal range of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1239,0),(26433,787,'Large Projectile Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26434,777,'Large Projectile Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1239,0),(26435,787,'Large Projectile Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26436,774,'Large Anti-EM Screen Reinforcer II','This ship modification is designed to increase the EM resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1236,0),(26437,787,'Large Anti-EM Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26438,774,'Large Anti-Explosive Screen Reinforcer II','This ship modification is designed to increase the explosive resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1236,0),(26439,787,'Large Anti-Explosive Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26440,774,'Large Anti-Kinetic Screen Reinforcer II','This ship modification is designed to increase the kinetic resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1236,0),(26441,787,'Large Anti-Kinetic Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26442,774,'Large Anti-Thermal Screen Reinforcer II','This ship modification is designed to increase the thermal resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,NULL,0.0000,1,1236,0),(26443,787,'Large Anti-Thermal Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26444,774,'Large Core Defense Capacitor Safeguard II','This ship modification is designed to reduce the capacitor need of modules which require shield operation skills at the expense of increased signature radius.',200,20,0,1,NULL,0.0000,1,1236,0),(26445,787,'Large Core Defense Capacitor Safeguard II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26446,774,'Large Core Defense Charge Economizer II','This ship modification is designed to reduce the power need of all shield upgrade modules at the expense of increased signature radius.',200,20,0,1,NULL,0.0000,1,1236,0),(26447,787,'Large Core Defense Charge Economizer II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26448,774,'Large Core Defense Field Extender II','This ship modification is designed to increase shield capacity at the expense of increased signature radius.',200,20,0,1,NULL,0.0000,1,1236,0),(26449,787,'Large Core Defense Field Extender II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26450,774,'Large Core Defense Field Purger II','This ship modification is designed to improve shield recharge rate at the expense of increased signature radius.',200,20,0,1,NULL,0.0000,1,1236,0),(26451,787,'Large Core Defense Field Purger II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26452,774,'Large Core Defense Operational Solidifier II','This ship modification is designed to reduce the duration of shield booster cycles at the expense of increased signature radius.',200,20,0,1,NULL,0.0000,1,1236,0),(26453,787,'Large Core Defense Operational Solidifier II Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,NULL,0),(26454,534,'Angel Courtesan','The courtesan is nothing but a high-level prostitute, but at least she\'s got class. What intrigues you is the fact that being in the favor of the powers that be in this complex allows the courtesan to go where she pleases.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26455,474,'Administrative Key','This passkey allows the bearer to enter the Administration Area of this complex.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26458,526,'Me, Myself and Plunder','A harrowing tear-jerk tale of a pirate that succumbs to greed and gluttony. Have your handkerchief handy.\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26459,526,'Navigation for Dummies','Gives you the answers to all the important questions, such as whether starboard is left or right.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26460,526,'Cartography: The Art of Treasure Map Making','X always marks the spot.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26461,526,'Seasoned Dandruff','What this has to do with booster manufacturing is anybody\'s guess.\r\r\n',1000,1,0,1,NULL,0.0000,1,NULL,0),(26462,526,'Sweet Leaves','Don\'t grow too fond of them.',1000,1,0,1,NULL,0.0000,1,NULL,0),(26463,526,'Free Sample','The first one is always free.',1000,1,0,1,NULL,0.0000,1,NULL,0),(26464,526,'Speedometer','Just how drugged are you?',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26465,526,'Divine Opium','Religion and Opium. What a strange notion. You wonder who could have thought of such a thing.\r\r\n',1000,1,0,1,NULL,0.0000,1,NULL,0),(26466,526,'Swirling Color-cards','You guess you have to be under heavy influence to be entertained by this.\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26467,227,'Amber Cytoserocin 2','Light-bluish crystal, formed by intense pressure deep within large asteroids and moons. Used in electronic and weapon manufacturing. Only found in abundance in a few areas. ',0,10,0,1,NULL,0.0000,0,NULL,0),(26468,186,'Wreck','Destroyed remains; perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26469,186,'Amarr Battlecruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26470,186,'Amarr Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26472,186,'Amarr Carrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26473,186,'Amarr Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26474,186,'Amarr Destroyer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26475,186,'Amarr Dreadnought Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26476,186,'Amarr Elite Battlecruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26477,186,'Amarr Elite Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26478,186,'Amarr Elite Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26479,186,'Amarr Elite Destroyer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26480,186,'Amarr Elite Frigate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26481,186,'Amarr Elite Industrial Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26482,186,'Amarr Elite Mining Barge Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26483,186,'Amarr Freighter Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,735000,735000,1,NULL,0.0000,0,NULL,0),(26484,186,'Amarr Frigate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26485,186,'Amarr Industrial Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26486,186,'Amarr Mining Barge Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26487,186,'Amarr Supercarrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26488,186,'Amarr Rookie ship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26489,186,'Amarr Shuttle Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26490,186,'Amarr Titan Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,45000,45000,1,NULL,0.0000,0,NULL,0),(26491,186,'Caldari Battlecruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26492,186,'Caldari Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26494,186,'Caldari Carrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26495,186,'Caldari Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26496,186,'Caldari Destroyer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26497,186,'Caldari Dreadnought Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26498,186,'Caldari Elite Battlecruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26499,186,'Caldari Elite Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26500,186,'Caldari Elite Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26501,186,'Caldari Elite Destroyer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26502,186,'Caldari Elite Frigate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26503,186,'Caldari Elite Industrial Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26504,186,'Caldari Elite Mining Barge Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26505,186,'Caldari Freighter Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,785000,785000,1,NULL,0.0000,0,NULL,0),(26506,186,'Caldari Frigate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26507,186,'Caldari Industrial Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26508,186,'Caldari Mining Barge Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26509,186,'Caldari Supercarrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26510,186,'Caldari Rookie ship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26511,186,'Caldari Shuttle Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26512,186,'Caldari Titan Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,55000,55000,1,NULL,0.0000,0,NULL,0),(26513,186,'Gallente Battlecruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26514,186,'Gallente Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26516,186,'Gallente Carrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26517,186,'Gallente Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26518,186,'Gallente Destroyer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26519,186,'Gallente Dreadnought Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26520,186,'Gallente Elite Battlecruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26521,186,'Gallente Elite Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26522,186,'Gallente Elite Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26523,186,'Gallente Elite Destroyer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26524,186,'Gallente Elite Frigate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26525,186,'Gallente Elite Industrial Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26526,186,'Gallente Elite Mining Barge Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26527,186,'Gallente Freighter Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,750000,750000,1,NULL,0.0000,0,NULL,0),(26528,186,'Gallente Frigate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26529,186,'Gallente Industrial Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26530,186,'Gallente Mining Barge Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26531,186,'Gallente Supercarrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26532,186,'Gallente Rookie ship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26533,186,'Gallente Shuttle Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26534,186,'Gallente Titan Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,65000,65000,1,NULL,0.0000,0,NULL,0),(26535,186,'Minmatar Battlecruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26536,186,'Minmatar Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26538,186,'Minmatar Carrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26539,186,'Minmatar Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26540,186,'Minmatar Destroyer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26541,186,'Minmatar Dreadnought Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26542,186,'Minmatar Elite Battlecruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26543,186,'Minmatar Elite Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26544,186,'Minmatar Elite Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26545,186,'Minmatar Elite Destroyer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26546,186,'Minmatar Elite Frigate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26547,186,'Minmatar Elite Industrial Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26548,186,'Minmatar Elite Mining Barge Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26549,186,'Minmatar Freighter Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,720000,720000,1,NULL,0.0000,0,NULL,0),(26550,186,'Minmatar Frigate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26551,186,'Minmatar Industrial Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26552,186,'Minmatar Mining Barge Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26553,186,'Minmatar Supercarrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26554,186,'Minmatar Rookie ship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26555,186,'Minmatar Shuttle Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26556,186,'Minmatar Titan Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,60000,60000,1,NULL,0.0000,0,NULL,0),(26557,186,'Frigate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26558,186,'Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26559,186,'Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26560,186,'Pirate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26561,186,'Angel Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26562,186,'Angel Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26563,186,'Angel Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26564,186,'Angel Small Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26565,186,'Angel Large Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26566,186,'Angel Officer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26567,186,'Blood Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26568,186,'Blood Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26569,186,'Blood Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26570,186,'Blood Small Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26571,186,'Blood Medium Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26572,186,'Blood Officer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26573,186,'Guristas Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26574,186,'Guristas Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26575,186,'Guristas Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26576,186,'Guristas Small Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26577,186,'Guristas Medium Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26578,186,'Guristas Officer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26579,186,'Sanshas Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26580,186,'Sanshas Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26581,186,'Sanshas Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26582,186,'Sanshas Small Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26583,186,'Sanshas Medium Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26584,186,'Sanshas Officer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26585,186,'Serpentis Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26586,186,'Serpentis Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26587,186,'Serpentis Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26588,186,'Serpentis Small Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26589,186,'Serpentis Medium Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26590,186,'Serpentis Officer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26591,186,'Rogue Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26592,186,'Rogue Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26593,186,'Rogue Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26594,186,'Rogue Elite Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26595,186,'Rogue Elite Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26596,186,'Rogue Officer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26597,716,'Cryptic Tuner Data Interface','Designed for use with Minmatar technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed. The tuner interface is used in rig invention.',0,1,0,1,NULL,0.0000,1,NULL,0),(26598,356,'Cryptic Tuner Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(26599,716,'Esoteric Tuner Data Interface','Designed for use with Caldari technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed. The tuner interface is used in rig invention.',0,1,0,1,NULL,0.0000,1,NULL,0),(26600,356,'Esoteric Tuner Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(26601,716,'Incognito Tuner Data Interface','Designed for use with Gallente technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed. The tuner interface is used in rig invention.',0,1,0,1,NULL,0.0000,1,NULL,0),(26602,356,'Incognito Tuner Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(26603,716,'Occult Tuner Data Interface','Designed for use with Amarr technology, this portable interface permits its user to course through the electronic stream of item schematics, hunting down the stray bits of data necessary for his grand creation. Only one data interface is required for invention, and it can be re-used as often as needed. The tuner interface is used in rig invention.',0,1,0,1,NULL,0.0000,1,NULL,0),(26604,356,'Occult Tuner Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(26605,306,'Drone Hold','Drone Utility Container',10000,1200,1400,1,NULL,0.0000,0,NULL,0),(26606,494,'Sansha Deadspace Outpost','Containing an inner habitation core surrounded by an outer shell filled with a curious fluid, the purpose of which remains unclear, this outpost is no doubt the brain-child of some nameless True Slave engineer.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26607,134,'Civilian Miner Blueprint',' ',0,0.01,0,1,NULL,463600.0000,0,NULL,0),(26657,306,'Angel Waste','You surmise that with some salvaging equipment there is still something of value to be had from this old waste.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26658,306,'Angel Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this old wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26659,306,'Angel Derelict','You surmise that with some salvaging equipment there is still something of value to be had from this old derelict.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26660,306,'Angel Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this old hulk.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26661,819,'Gistii Domination Scavenger','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',1766000,17660,120,1,2,0.0000,0,NULL,0),(26662,306,'Blood Waste','You surmise that with some salvaging equipment there is still something of value to be had from this old waste.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26663,306,'Blood Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this old wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26664,306,'Blood Derelict','You surmise that with some salvaging equipment there is still something of value to be had from this old derelict.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26665,306,'Blood Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this old hulk.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26666,306,'Guristas Waste','You surmise that with some salvaging equipment there is still something of value to be had from this old waste.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26667,306,'Guristas Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this old wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26668,306,'Guristas Derelict','You surmise that with some salvaging equipment there is still something of value to be had from this old derelict.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26669,306,'Guristas Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this old hulk.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26670,306,'Sansha Waste','You surmise that with some salvaging equipment there is still something of value to be had from this old waste.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26671,306,'Sansha Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this old wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26672,306,'Sansha Derelict','You surmise that with some salvaging equipment there is still something of value to be had from this old derelict.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26673,306,'Sansha Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this old hulk.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26674,306,'Serpentis Waste','You surmise that with some salvaging equipment there is still something of value to be had from this old waste.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26675,306,'Serpentis Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this old wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26676,306,'Serpentis Derelict','You surmise that with some salvaging equipment there is still something of value to be had from this old derelict.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26677,306,'Serpentis Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this old hulk.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(26678,820,'Gistum Domination Racer','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',10900000,109000,120,1,2,0.0000,0,NULL,0),(26679,821,'Gist Domination Murderer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26680,819,'Corpii Monk','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2810000,28100,120,1,4,0.0000,0,NULL,0),(26682,820,'Dark Corpum Believer','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(26683,821,'Dark Corpus Preacher','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(26684,819,'Dread Pithi Terminator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',1970000,19700,235,1,1,0.0000,0,NULL,0),(26686,820,'Dread Pithum Vindicator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(26687,819,'True Centii Revelator','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',2112000,21120,100,1,4,0.0000,0,NULL,0),(26688,819,'Shadow Coreli Antagonist','The heavily armed Serpentis Commanders follow the creed of the paranoid. They shoot first and don\'t give a damn about the questions. Threat level: Deadly.',2650000,26500,235,1,8,0.0000,0,NULL,0),(26689,821,'Dread Pith Protagonist','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,22000000,235,1,1,0.0000,0,NULL,0),(26690,820,'True Centum General','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(26691,820,'Shadow Corelum Infantry','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(26692,821,'True Centus Preacher','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,100100,235,1,4,0.0000,0,NULL,0),(26694,821,'Shadow Grand Admiral','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(26696,283,'Sidura Meisana','The niece of a Minmatar harvester working in 760-9C.',60,0.1,0,1,NULL,0.0000,1,NULL,0),(26699,186,'Angel Medium Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26700,186,'Blood Large Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26701,186,'Guristas Large Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26702,186,'Sanshas Large Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26703,186,'Serpentis Large Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26704,319,'Storage Facility - radioactive stuff and small arms','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(26706,319,'Radioactive Cargo Rig','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',100000,100000000,8850,1,NULL,0.0000,0,NULL,0),(26707,314,'Hidden Data Sheets','Secret documents.',1,1,0,1,NULL,0.0000,1,NULL,0),(26708,283,'Port Rolette Residents','A resident of the illegal settlement, Port Rolette.',1000,5,0,1,NULL,0.0000,1,NULL,0),(26709,383,'Secret Angel Facility','A secret Angel facility.  Its purpose is unknown.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(26710,526,'Prototype Nuclear Small Arms','Prototype Nuclear Small Arms.',2500,2,0,1,NULL,0.0000,1,NULL,0),(26712,604,'Blood Phantom - Ectoplasm','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(26713,467,'Flawed Gneiss','Gneiss is a popular ore type because it holds significant volumes of three heavily used minerals, increasing its utility value. Flawed Gneiss however has the same properties as fools gold, in the sense that it looks like the original but is worth almost nothing in comparison.',1e35,5,0,400,4,162.0000,0,NULL,0),(26714,821,'Blood Factory Overseer','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',20500000,1100000,235,1,4,0.0000,0,NULL,0),(26715,306,'Viral Stash','The worn container drifts quietly in space.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26716,821,'Centus Colony General','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',21000000,100100,235,1,4,0.0000,0,NULL,0),(26717,520,'Serpentis Prankster','A member of the Serpentis organization.',2950000,29500,175,1,8,0.0000,0,NULL,0),(26718,520,'Serpentis Prankster_2','A member of the Serpentis organization.',2950000,29500,175,1,8,0.0000,0,NULL,0),(26719,306,'Madcat\'s Stash','The worn container drifts quietly in space, closely guarded by pirates.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26720,319,'Starbase Silo','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,4000,20000,1,NULL,0.0000,0,NULL,0),(26721,319,'Starbase Ultra-Fast Silo','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,4000,20000,1,NULL,0.0000,0,NULL,0),(26722,319,'Starbase Ship-Maintenance Array','Mobile hangar and fitting structure. Used for ship storage and in-space fitting of modules contained in a ship\'s cargo bay.',1000000,8000,20000000,1,NULL,0.0000,0,NULL,0),(26723,319,'Starbase Capital Ship Maintenance Array','Massive hangar and fitting structure.',1000000,40000,155000000,1,NULL,0.0000,0,NULL,0),(26724,319,'Starbase Capital Shipyard','A large hangar structure with divisional compartments, for easy separation and storage of materials and modules.',100000,4000,200000,1,NULL,0.0000,0,NULL,0),(26725,319,'Starbase Stealth Emitter Array','Decreases signature radius of control tower.',100,100,0,1,NULL,0.0000,0,NULL,0),(26726,319,'Starbase Mobile Factory','Mobile Factory',1000000,150,8850,1,NULL,0.0000,0,NULL,0),(26727,319,'Starbase Explosion Dampening Array','Boosts the control tower\'s shield resistance against explosive damage.',4000,4000,0,1,NULL,0.0000,0,NULL,0),(26728,319,'Starbase Moon Mining Silo','Storage silos are much more secure and durable than their Secure Container counterparts. They are usually the focus of attacks on outposts and commonly contain ore, reprocessed minerals or valuable items waiting to be transported to empire space.',1000000,4000,20000,1,NULL,0.0000,0,NULL,0),(26729,319,'Minmatar Starbase Control Tower_Tough_Good Loot','The Matari aren\'t really that high-tech, preferring speed rather than firepower or involved technology. Unfortunately that doesn\'t apply very well to stationary objects, much to the liking of the Amarr Empire.\r\r\n\r\r\nAmarrians call it a scrapheap of epic proportions. But don\'t underestimate these structures. Minmatar commanders usually have the last laugh when it comes to combat.',100000,1150,8850,1,2,0.0000,0,NULL,0),(26731,494,'Cartel Research Outpost','Equally equipped for scientific observation and entertainment of all sorts, these multi-purpose structures, while not quite big enough to be classified as stations, nonetheless see quite a bit of use by both tourists and professionals.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(26732,319,'Amarr Starbase Control Tower_Tough_Good Loot','The Amarr have always been fond of majestic and intimidating constructions. Their Control Towers do not deviate from that tradition and are truly big and powerful structures, intended more for preservation of territorial interests than commercial benefits.',100000,1150,8850,1,4,0.0000,0,NULL,0),(26733,494,'Blood Research Outpost','Equally equipped for scientific observation and entertainment of all sorts, these multi-purpose structures, while not quite big enough to be classified as stations, nonetheless see quite a bit of use by both tourists and professionals.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(26734,319,'Caldari Starbase Control Tower_Tough_Good Loot','At first the Caldari Control Towers were manufactured by Kaalakiota, but since they focused their efforts mostly on other, more profitable installations, they soon lost the contract and the Ishukone corporation took over the Control Towers\' development and production.',100000,1150,8850,1,1,0.0000,0,NULL,0),(26735,494,'Guristas Research Outpost','Equally equipped for scientific observation and entertainment of all sorts, these multi-purpose structures, while not quite big enough to be classified as stations, nonetheless see quite a bit of use by both tourists and professionals.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(26736,494,'Sansha Research Outpost','Equally equipped for scientific observation and entertainment of all sorts, these multi-purpose structures, while not quite big enough to be classified as stations, nonetheless see quite a bit of use by both tourists and professionals.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(26737,319,'Gallente Starbase Control Tower_Tough_Good Loot','Gallente Control Towers are more pleasing to the eye than they are strong or powerful. They have above average electronic countermeasures, average CPU output, and decent power output compared to towers from the other races, but are quite lacking in sophisticated defenses.',100000,1150,8850,1,8,0.0000,0,NULL,0),(26738,494,'Serpentis Research Outpost','Equally equipped for scientific observation and entertainment of all sorts, these multi-purpose structures, while not quite big enough to be classified as stations, nonetheless see quite a bit of use by both tourists and professionals.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(26739,226,'Fortified Bursar','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another.',112000000,1120000,0,1,2,0.0000,0,NULL,0),(26740,319,'Bursar','A Mammoth-class industrial.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(26741,533,'Kaerleiks Bjorn','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3800,1,2,0.0000,0,NULL,0),(26742,534,'Einhas Malak','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26743,226,'Amarr Prorator Industrial','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another.',10750000,200000,0,1,4,0.0000,0,NULL,0),(26744,533,'Cura Gigno','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',10750000,200000,3800,1,4,0.0000,0,NULL,0),(26745,821,'High Ritualist Padio Atour','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(26746,226,'Caldari Crane Industrial','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another.',11500000,195000,0,1,1,0.0000,0,NULL,0),(26747,383,'Guristas Annihilation Missile Battery_Uber','This missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(26748,533,'Teinei Kuma','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',11500000,195000,3500,1,1,0.0000,0,NULL,0),(26749,821,'Terrorist Overlord Inzi Kika','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',21000000,22000000,235,1,1,0.0000,0,NULL,0),(26750,622,'Sansha Miner','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(26751,319,'Fragmented Cathedral I_Under Construction','This looks like a construction site of a grand structure of great importance.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26752,595,'Angel Transport','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(26753,819,'chantal testing thingy','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(26754,603,'Corpus Messiah','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(26755,604,'Gurista Guerilla Special Acquirement Division Captain','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Extreme',12000000,120000,450,1,4,0.0000,0,NULL,0),(26756,820,'Gurista Special Acquirement Captain','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(26757,821,'Sansha Shipyard Foreman','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,100100,235,1,4,0.0000,0,NULL,0),(26758,820,'Serpentis Drug Carrier','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(26759,136,'Heavy Assault Missile Launcher I Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,340,0),(26760,166,'Mjolnir Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,600000.0000,1,975,0),(26761,166,'Inferno Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,600000.0000,1,975,0),(26762,166,'Scourge Heavy Assault Missile Blueprint',' ',1,0.01,0,1,NULL,600000.0000,1,975,0),(26763,820,'Rogue Drone Logistic Overseer','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(26764,820,'Rogue Production Captain','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(26765,820,'Hive Overseer','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(26766,820,'Hive Logistic Captain','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(26767,527,'Dread Guristas Envoy_destroyer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(26768,820,'Colony Captain','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(26769,821,'Rogue Drone Liaisons Captain','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(26770,821,'Independence Queen','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(26771,821,'Radiant Hive Mother','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(26772,821,'Hierarchy Hive Queen','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(26773,283,'Regiment of Marines','When war breaks out, the demand for transporting military personnel on site can exceed the grasp of the military organization. In these cases, the aid from non-military spacecrafts is often needed.',1000000,2000,0,1,NULL,1000.0000,1,NULL,0),(26774,314,'Crates of Long-limb Roes','The eggs of the Hanging Long-limb are among the most sought after delicacies in fancy restaurants. The main reason why the roe of the Hanging Long-limb is so rare is because no one has succeeded in breeding the species outside their natural habitat.',40000,100,0,1,NULL,2400.0000,1,NULL,0),(26775,283,'Group of Janitors','The janitor is the person who is in charge of keeping the premises of a building (as an apartment or office) clean, tends the heating system, and makes minor repairs.',10000,50,0,1,NULL,0.0000,1,NULL,0),(26776,314,'Barrels of Soil','Fertile soil rich with nutrients is very sought after by agricultural corporations and colonists on worlds with short biological history.',2000000,8000,0,1,NULL,80.0000,1,NULL,0),(26777,284,'Barrels Of Viral Agent','The causative agent of an infectious disease, the viral agent is a parasite with a noncellular structure composed mainly of nucleic acid within a protein coat.',1000000,5000,0,1,NULL,850.0000,1,NULL,0),(26778,314,'Crates of Holoreels','Holo-Vid reels are the most common type of personal entertainment there is. From interactive gaming to erotic motion pictures, these reels can contain hundreds of titles each.',1000,50,0,1,NULL,250.0000,1,NULL,0),(26779,314,'Crates of Electronic Parts','These basic elements of all electronic hardware are sought out by those who require spare parts in their hardware. Factories and manufacturers take these parts and assemble them into finished products, which are then sold on the market.',40000,40,0,1,NULL,750.0000,1,NULL,0),(26780,313,'Crates of Crystal Eggs','Crystal is a common feel-good booster, used and abused around the universe in abundance.',90000,90,0,1,NULL,5000.0000,1,NULL,0),(26781,314,'Crates of Transmitters','An electronic device that generates and amplifies a carrier wave, modulates it with a meaningful signal derived from speech or other sources, and radiates the resulting signal from an antenna.',65000,60,0,1,NULL,313.0000,1,NULL,0),(26782,314,'Barrels of Fertilizer','Fertilizer is particularly valued on agricultural worlds, where there is constant supply for all commodities that boost export value.',9000000,6000,0,1,NULL,200.0000,1,NULL,0),(26783,283,'Group of Homeless','In most societies there are those who, for various reasons, live a life considered below the living standards of the normal citizen. These people are sometimes called tramps, beggars, drifters, vagabonds or homeless. They are especially common in the ultra-capitalistic Caldari State, but are also found elsewhere in most parts of the galaxy.',6000,40,0,1,NULL,0.0000,1,NULL,0),(26784,314,'Heap-Load of Garbage','Production waste can mean garbage to some but valuable resource material to others.',25000000,2500,0,1,NULL,20.0000,1,NULL,0),(26785,314,'Crates of Frozen Plant Seeds','Frozen plant seeds are in high demand in many regions, especially on stations orbiting a non-habitable planet.',4000,50,0,1,NULL,75.0000,1,NULL,0),(26786,314,'Crates of Spirits','Alcoholic beverages made by distilling a fermented mash of grains.',25000,60,0,1,NULL,455.0000,1,NULL,0),(26787,314,'Crates of Rocket Fuel','Augmented and concentrated fuel used primarily for missile production.',5000,40,0,1,NULL,505.0000,1,NULL,0),(26788,283,'Gang of Miners','A sturdy miner.',200000,6000,0,1,NULL,0.0000,1,NULL,0),(26789,526,'Cache of Pistols','Semi-automatic small arms used for personal protection and skirmish warfare.',2500000,2000,0,1,NULL,0.0000,1,NULL,0),(26790,314,'Crates of Tobacco','Tubular rolls of tobacco designed for smoking. The tube consists of finely shredded tobacco enclosed in a paper wrapper and is generally outfitted with a filter tip at the end.',250000,40,0,1,NULL,48.0000,1,NULL,0),(26791,314,'Crates of Construction Blocks','Metal girders, plasteel concrete and fiber blocks are all very common construction material used around the universe.',1000000,70,0,1,NULL,500.0000,1,NULL,0),(26792,314,'Barrels of Water','Water is one of the basic conditional elements of human survival. Most worlds have this compound in relative short supply and hence must rely on starship freight.',25000000,2500,0,1,NULL,35.0000,1,NULL,0),(26793,821,'Colonial Master Diabolus Maytor','This is the master of all nearby Sansha colonies, the infamous Diabolus Maytor.  Few are above him in rank. Threat level: Deadly',21000000,100100,235,1,4,0.0000,0,NULL,0),(26794,226,'Gallente Viator Industrial','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another.',11150000,190000,0,1,8,0.0000,0,NULL,0),(26795,533,'Ours De Soin','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',11150000,190000,3000,1,8,0.0000,0,NULL,0),(26796,821,'Privateer Admiral Heysus Sarpati','Heysus Sarpati is the official recruiter of the Serpentis in this sector.  He commands a mighty battleship that is rivaled by few, hearing the mere mention of his name sparks fear into his enemies\' hearts. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(26797,821,'Black Caesar','An old warhorse, Black Caesar has been a dedicated member of the Guardian Angels since he was a boy.  His name has been plastered upon \'most wanted\' lists all over Gallente space for the last three decades. Threat level: Deadly',17500000,1140000,480,1,8,0.0000,0,NULL,0),(26798,821,'Naberius Marquis','Dark and mysterious, little is known of Naberious, other than his extreme loyalty to Sansha\'s Nation and convincing leadership skills. Threat level: Deadly',21000000,100100,235,1,4,0.0000,0,NULL,0),(26799,821,'Dread Guristas Colonel','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving of the straight path to become outlaws. Threat level: Deadly.',21000000,22000000,235,1,1,0.0000,0,NULL,0),(26800,821,'Angel Colonel','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26801,821,'Shadow Serpentis Colonel','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(26802,821,'True Sansha\'s Colonel','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',21000000,100100,235,1,4,0.0000,0,NULL,0),(26803,821,'Dark Blood Colonel','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',20500000,1100000,235,1,4,0.0000,0,NULL,0),(26806,534,'Haruo Wako','Formerly member of the Intaki Syndicate, Haruo has quickly risen through the ranks in the Guristas organization. Which comes as no wonder, as he is brilliant, charismatic and utterly corrupt. Threat level: Deadly',22000000,1080000,235,1,1,0.0000,0,NULL,0),(26807,821,'Jorun \'Red Legs\' Greaves','Jorun has an air of vulnerability about her petite body, but don\'t expect any mercy from the infamous pirate leader, she\'d sooner cut your throat than do any man\'s bidding. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26810,821,'Serpentis Tournament Host','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',19000000,1010000,480,1,8,0.0000,0,NULL,0),(26812,821,'Sepentis Regional Baron Arain Percourt','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(26818,821,'Serpentis Regional Baron - Arain Percourt','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(26832,821,'Captain Blood Raven','Little is known of Blood Raven, even his true name remains a secret.  His nickname was acquired due to his tendency to walk around with a black Raven on his shoulder.  Men under his command even claimed it was the only creature he truly loved.  His other hobby was cutting open bodies of slain enemies and drinking their blood ... Threat level: Deadly',19500000,1150000,235,1,4,0.0000,0,NULL,0),(26833,821,'Serpentis Holder','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(26840,27,'Raven State Issue','This State Issued version of the powerhouse Caldari Battleship - The Raven - was designed in a joint venture by the eight Caldari supercorporations. It was created expressly to honor those whose valor in combat, and adherence to the Caldari code of battle, has surpassed that of their comrades in arms. Of course, should the ship be lost, the immense dishonour to the pilot demands that he take his own life, but seeing as how this wouldn\'t affect him in the slightest, tradition holds that the highest-ranked of the surviving crew members take his place.',99300000,486000,665,1,1,108750000.0000,1,1620,0),(26842,27,'Tempest Tribal Issue','Commissioned by the four ruling tribes of the Republic, the Tribal Issue of their Fleet\'s key vessel is presented only to those who have displayed unyielding valor in the Republic\'s interest, and a tireless commitment to maintaince of the Tribes\' precious freedom. Given the ship\'s status as a badge of honour, it is not uncommon for pilots or ship crew to add special tattoos to their anatomy, celebrating both the gift of the ship and the honour of piloting it.',103300000,486000,600,1,2,157405934.0000,1,1620,0),(26843,107,'Tempest Tournament Issue TEST Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(26844,821,'Rubin Sozar','Rubin Sozar was appointed into the Angel Cartel a few years ago, having defected from the Minmatar Navy after having been involved in a scandal that tarnished his reputation and prevented him from advancing further in the ranks of the military.  He is an excellent pilot and naval commander, and has served the Cartel well in his few years of service.  Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26846,283,'Okelle Alash','Okelle Alash',80,5,0,1,NULL,0.0000,0,NULL,0),(26848,534,'Okelle Alash_','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation.\r\r\n\r\r\nOkelle is a fierce pirate captain that has been under his brothers shadow for a long time and is eager to prove himself. He knows the republic is after him and he is looking for confrontation to get the recognition he believes he deserves.\r\r\n\r\r\nThreat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26849,361,'Tournament Bubble TEST','A Large deployable self powered unit that prevents warping within its area of effect ',0,5000000,0,1,NULL,19153712.0000,0,NULL,0),(26850,371,'Tournament Bubble TEST Blueprint',' ',0,0.01,0,1,NULL,119764480.0000,0,NULL,0),(26851,452,'Fools Crokite','Crokite is a very heavy ore that is always in high demand because it has the largest ratio of nocxium for any ore in the universe. Fools Crokite on the other hand is infamous for making inexperienced miners look like fools.  It closely resembles the real Crokite, while having very little usable mineral content.',1e35,16,0,250,4,522.0000,0,NULL,0),(26852,450,'Flawed Arkonor','Arkonor is one of the rarest and most sought-after ore in the known world. Flawed Arkonor on the other hand is very rarely sought after. In fact more than a few inexperienced miners have turned red-faced when discovering their \'valuable\' cargo was in fact flawed and worth only a handful of ISK ...',1e35,16,0,200,NULL,4116.0000,0,NULL,0),(26853,319,'Drug Lab Crash','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',1000000,0,0,1,4,0.0000,0,NULL,0),(26854,319,'Drug Lab Exile','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',1000000,0,0,1,4,0.0000,0,NULL,0),(26855,319,'Drug Lab Mindflood','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',1000000,0,0,1,4,0.0000,0,NULL,0),(26856,383,'Serpentis Crash Storage Platform','This Serpentis Battlestation has several formidable defensive systems. Although used to store small quantities of their drugs, it is also able to detect and attack hostile forces. ',1000,1000,1000,1,8,0.0000,0,NULL,0),(26857,383,'Serpentis Exile Storage Platform','This Serpentis Battlestation has several formidable defensive systems. Although used to store small quantities of their drugs, it is also able to detect and attack hostile forces. ',1000,1000,1000,1,8,0.0000,0,NULL,0),(26858,383,'Serpentis Mindflood Storage Platform','This Serpentis Battlestation has several formidable defensive systems. Although used to store small quantities of their drugs, it is also able to detect and attack hostile forces. ',1000,1000,1000,1,8,0.0000,0,NULL,0),(26859,533,'Hodura Amaba','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(26860,226,'Docked Mammoth','This Mammoth-class industrial is currently undergoing maintenance.',0,0,0,1,2,0.0000,0,NULL,0),(26862,819,'Jols Eytur','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1910000,19100,120,1,2,0.0000,0,NULL,0),(26863,819,'Vlye Cadille','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2870000,28700,135,1,4,0.0000,0,NULL,0),(26864,819,'Eha Hidaiki','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',1970000,19700,125,1,1,0.0000,0,NULL,0),(26865,819,'Gamat Hakoot','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2112000,21120,235,1,4,0.0000,0,NULL,0),(26866,819,'Elgur Erinn','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,140,1,8,0.0000,0,NULL,0),(26867,533,'Nikmar Eitan','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(26868,456,'Flawed Jaspet','Jaspet has three valuable mineral types, making it easy to sell. It has a large portion of mexallon plus some nocxium and zydrine. Flawed Jaspet, unfortunately, is rather harder to sell, as it is practically devoid of usable minerals and is good only for duping the unwary.',1e35,2,0,500,4,3124.0000,0,NULL,0),(26869,353,'QA ECM Burst','Emits random electronic bursts intended to disrupt target locks on any ship with lower sensor strengths than the ECM burst jamming strength. Given the unstable nature of the bursts and the amount of internal shielding needed to ensure they do not affect their own point of origin, only battleship-class vessels can use this module to its fullest extent. \r\r\n\r\r\nNote: Only one module of this type can be activated at the same time',5000,1,0,1,NULL,227888.0000,0,NULL,0),(26870,160,'Tournament ECM Burst Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,0,NULL,0),(26871,798,'Dini Mator','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',10100000,101000,235,1,1,0.0000,0,NULL,0),(26878,533,'Kazah Durn','Revelling in the symbiotic relationship of man and machine Sansha\'s Commanders can push themselves harder and further than others. Threat level: Deadly.',10010000,100100,235,1,4,0.0000,0,NULL,0),(26879,533,'Marin Matola','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',11200000,112000,480,1,8,0.0000,0,NULL,0),(26880,533,'Motoh Olin','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',11800000,118000,235,1,4,0.0000,0,NULL,0),(26881,821,'Dark Templar Uthius','Blood Raider Commanders have mastered the Rites of Blood, giving them unnatural affinity with all things living. Threat level: Deadly.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(26882,534,'Quertah Bleu','The Angel Cartel profits enough from its protection deal with the Serpentis Corporation for it to send its best and brightest pilots on guarding duty. Threat level: Deadly.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(26883,533,'Suard Fish','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(26884,534,'Hakirim Grautur','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Deadly.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(26885,534,'Oushii Torun','Guristas Commanders are master tacticians, frequently veterans of empire navies before swerving off the straight path to become outlaws. Threat level: Deadly.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(26888,361,'Mobile Large Warp Disruptor II','A Large deployable self powered unit that prevents warping within its area of effect. ',0,585,0,1,NULL,4216146.0000,1,405,0),(26889,371,'Mobile Large Warp Disruptor II Blueprint',' ',0,0.01,0,1,NULL,119764480.0000,1,NULL,0),(26890,361,'Mobile Medium Warp Disruptor II','A Medium deployable self powered unit that prevents warping within its area of effect. ',0,195,0,1,NULL,1702858.0000,1,405,0),(26891,371,'Mobile Medium Warp Disruptor II Blueprint',' ',0,0.01,0,1,NULL,29941120.0000,1,NULL,0),(26892,361,'Mobile Small Warp Disruptor II','A small deployable self powered unit that prevents warping within its area of effect. ',0,65,0,1,NULL,699466.0000,1,405,0),(26893,371,'Mobile Small Warp Disruptor II Blueprint',' ',0,0.01,0,1,NULL,7485280.0000,1,NULL,0),(26894,319,'Habitation Module - Breeding Facility','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26895,319,'Amarrian Breeding Facility','This breeding facility produces Minmatar children ready to assume their place as servants to the Amarr. Once they reach puberty, the boys are sent away to take their place amongst the lower classes in Amarr society.\r\r\n\r\r\nThe girls, on the other hand, are left behind. Their place is here, stretched out on cold metal tables, silent and tense. The facility wears out its brood, but that\'s all right; more are created all the time.\r\r\n\r\r\nAnd every now and then, a caravan will arrive, carrying men with cold eyes and clammy hands, ready and willing to help with the production.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26896,319,'Amarr Battlestation_Event','This gigantic military installation is the pride of the Imperial Navy.  Hundreds of thousands, of slaves poured their blood, sweat and tears into erecting one of these mega-structures.  Only a fool would attempt to assault such a massive base without a fleet behind him.\r\n\r\nDocking has been prohibited into this station without proper authorization.',0,0,0,1,4,0.0000,0,NULL,0),(26897,319,'Sisters of EVE Aid Station','The Sisters need to rapidly receive and deploy aid has led to the creation of the Aid Stations, relatively quick and easy to construct and place in orbit these stations can recieve vast quantities of aid and transfer them to orbital craft for quick deployment on a planet. Since their inception they have saved vast quantities of lives and other corporations have leased the design for their own purposes.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26898,319,'Asteroid Slave Mine','\"There are some who will never embrace enlightment, and those poor souls we must.. educate\"<br>\r\r\nGavrin Lothril - Asteroid Mine XVII-232 Foreman',0,1,0,1,NULL,0.0000,0,NULL,0),(26899,319,'Unlicensed Mindclash Arena','Mind Clash is one of the most popular sports throughout known space, it is as enthusiastically played in the royal court on Amarr Prime as in the gambling halls of the Caldari. However there are a certain cadre of people who think that the official sport is too tame, so they created a new set of rules, to the death - which was promptly banned from Empire space. However their is much underground hunger for this sport so hidden in space arena\'s have started to be constructed in which sport enthusiasts can enjoy watching their heroes fight and die without the inteference of the beaurcratic empires.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26900,319,'Broadcast Tower','The Caldari call these propoganda towers, however the Gallente people prefer to call them liberty towers. Whatever their designation these hidden broadcast towers send their amplified signal throughout the system they are located in. The Gallente networks use them to broadcast their channels to areas of space where such signals are usually banned. There are a network of relay towers which utilise the FTL networks to bring their underground signal to the source tower.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(26901,283,'Breeder Slave','These slaves are held within breeder colonies for years for the sole purpose of increasing a slaver\'s stock. Discarded when they have outlived their usefulness, these poor creatures have a short life expectancy that might be a blessing when compared to the misery of their existence in captivity. ',80,1.5,0,1,NULL,0.0000,1,NULL,0),(26902,526,'Fedo','The Fedo is an omnivorous, sponge-like creature. It has reddish skin and numerous small claw-like tentacles which it uses to move around and protect itself. A primitive being, the Fedo\'s method of eating and absorbing nutrition is slow and inefficient. This means that food stays for a long time in the Fedo\'s body, and will most often have rotted or turned foul before the animal passes it out of its system. The Fedos eject fumes from their body which, for the reasons explained above, have a most horrible odor. The Fedos possess a fantastic sense of smell and so use these fumes to communicate with each other; they are however both blind and deaf, having no eyes or ears. The mouth is located on the underside of the beast, and the Fedo feeds by positioning itself over the food and lowering itself down on it.',3000,0.5,0,1,NULL,0.0000,1,23,0),(26903,526,'Military Intelligence Report','A military intelligence report on Fleet movements in the local vicinity, patrol schedules and current strength,',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26904,526,'Secure Coded Package','A generic package containing goods in a protective wrapping. It is secured with a code lock and cannot be opened without knowing the proper combination.',25,120,0,1,NULL,0.0000,1,NULL,0),(26905,526,'Slave Ownership Record','A Record of owner ship of a single slave, previous owners, work history and current state of health',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26906,526,'Slave Manifests','A Manifest of slave movements in the local area, quantity and quality of stock',1,0.1,0,1,NULL,0.0000,1,NULL,0),(26907,283,'Starkmanir Slave','The Starkmanir Tribe was virtually wiped after a failed rebellion, only a handful remain in the Empire and have now turned into collector\'s items for Amarrian Holder\'s. These slave\'s are rarely ever put to hard labour and generally live out their lives as exhibits for their Amarrian masters to show off. A pure blooded Starkmanir slave has made many a Holder a rich man',95,3,0,1,NULL,0.0000,1,NULL,0),(26908,283,'Valkears','\"We aren\'t going to try to train you, we\'re going to try to kill you.\"<br>\r\r\n- Valklear Instructor\r\r\n<br><br>\r\r\nIn the great war for liberation the Minmatar tribes, finding themselves lacking able-bodied men, were forced to create soldiers from their most dangerous criminals their thieves, schemers, and murderers. This method proved remarkably successful and continues to this day. One would have to be mad to join in a Valkear unit\'s fifteen-year tour of duty, and among the criminal element, the rivers of madness run deep indeed.',90,1,0,1,2,50000.0000,1,NULL,0),(26911,226,'Avatar Wreck','These are the remnants of the Avatar-class titan piloted by CYVOK of Ascendant Frontier. It was destroyed by Band of Brothers in the war between the two alliances. The event marked the destruction of the first capsuleer owned titan in existence.',0,0,0,1,NULL,0.0000,0,NULL,0),(26912,325,'Small Remote Armor Repairer II','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,128466.0000,1,1059,0),(26913,325,'Medium Remote Armor Repairer II','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,10,0,1,NULL,292210.0000,1,1058,0),(26914,325,'Large Remote Armor Repairer II','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,25,0,1,NULL,447880.0000,1,1057,0),(26915,350,'Large Remote Armor Repairer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(26916,350,'Medium Remote Armor Repairer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(26917,350,'Small Remote Armor Repairer II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(26918,186,'Overseer Frigate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26919,186,'Overseer Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26920,186,'Overseer Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26925,778,'Drone Damage Rig I','This ship modification is designed to increase a ship\'s drone damage at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,0,NULL,0),(26926,787,'Drone Damage Rig I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26927,778,'Drone Damage Rig II','This ship modification is designed to increase a ship\'s drone damage at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,0,NULL,0),(26928,787,'Drone Damage Rig II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26929,781,'Small Processor Overclocking Unit I','This ship modification is designed to increase a ship\'s CPU.\r\r\n\r\r\nPenalty: - 5% Shield Recharge Rate Bonus.\r\r\n',200,5,0,1,NULL,0.0000,1,1222,0),(26930,787,'Small Processor Overclocking Unit I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1252,0),(26931,781,'Small Processor Overclocking Unit II','This ship modification is designed to increase a ship\'s CPU.\r\r\n\r\r\nPenalty: - 10% Shield Recharge Rate Bonus.',200,5,0,1,NULL,0.0000,1,1222,0),(26932,787,'Small Processor Overclocking Unit II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(26933,186,'Mission Generic Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26934,186,'Mission Generic Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26935,186,'Mission Generic Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26939,186,'CONCORD Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26940,186,'CONCORD Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26941,186,'CONCORD Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26959,828,'testing group','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(26960,786,'Sensor Strength Rig I','This rig increases the ship\'s sensor strength to make it more resistant to being jammed at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,0,NULL,0),(26961,787,'Sensor Strength Rig I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26962,786,'Sensor Strength Rig II','This rig increases the ship\'s sensor strength to make it more resistant to being jammed at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,0,NULL,0),(26963,787,'Sensor Strength Rig II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26964,774,'Shield Transporter Rig I','This ship modification is designed to increase shield capacity at the expense of increased signature radius.\r\r\n\r\r\nNote: Does not work on capital sized modules',200,5,0,1,NULL,0.0000,0,NULL,0),(26965,787,'Shield Transporter Rig I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26966,774,'Shield Transporter Rig II','This ship modification is designed to increase shield capacity at the expense of increased signature radius.\r\r\n\r\r\nNote: Does not work on capital sized modules',200,5,0,1,NULL,0.0000,0,NULL,0),(26967,787,'Shield Transporter Rig II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(26968,226,'Fortified Drone Bunker','A Drone Bunker',100000,100000000,0,1,4,0.0000,0,NULL,0),(26969,668,'Amarr Slaver Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(26970,668,'Amarr Slave Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(26971,604,'Blood Raider Slave Transport Ship','Convoys are a common sight in the universe of EVE, ferrying goods from one place to another. Convoys usually have armed escorts, so attacking them is risky.',112000000,1120000,3200,1,4,0.0000,0,NULL,0),(26972,186,'Faction Drone Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(26973,789,'Domination Wang Chunger','Scuttling from Heaven the Domination Commanders pursue a secret agenda as dark and sinister as their reputation. Threat level: Super Uber Deadly.',1910000,19100,120,1,2,0.0000,0,NULL,0),(26974,314,'Antiviral Drugs','Antiviral Drugs are in constant demand everywhere and new, more potent versions, are always made available to counter new viral strains.',5,0.2,0,1,NULL,325.0000,1,NULL,0),(26975,306,'Cargo Warehouse - Crates of Synthetic Oil','This is a standard storage facility.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(26976,306,'Cargo Warehouse - Spiced Wine','This is a standard storage facility.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(26977,306,'Cargo Warehouse - Crates of Silicate Glass','This is a standard storage facility.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(26978,306,'Cargo Warehouse - Quafe Ultra','This is a standard storage facility.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(26983,1122,'Civilian Salvager','A specialized scanner used to detect salvageable items in ship wrecks.',0,5,0,1,NULL,51464.0000,0,NULL,0),(26984,1123,'Civilian Salvager Blueprint',' ',0,0.01,0,1,4,332640.0000,1,NULL,0),(26998,283,'Hejilmar the Slave','Hejilmar was recently released from the clutches of Amarrian slavelords.',150,3,0,1,NULL,0.0000,1,NULL,0),(27001,669,'Stolen Imperial Deacon','A destroyer of the Amarr empire.\r\r\n',2860000,28600,235,1,4,0.0000,0,NULL,0),(27014,538,'Civilian Data Analyzer','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,51464.0000,0,NULL,0),(27015,917,'Civilian Data Analyzer Blueprint',' ',0,0.01,0,1,NULL,332640.0000,0,NULL,0),(27019,538,'Civilian Relic Analyzer','A simple scanning device designed for analyzing both terran archaeological structures and ruins floating in space. ',0,5,0,1,NULL,51464.0000,0,NULL,0),(27020,917,'Civilian Relic Analyzer Blueprint',' ',0,0.01,0,1,NULL,332640.0000,0,NULL,0),(27021,332,'Perpetual Motion Unit I','The mere existence of this unit is a major vexation to physicists everywhere. That said, it doesn\'t do much at all for the pilot: It operates as a closed system, and any attempt at a breach or internal inspection will ruin the mechanism. It has no effect on any part of a ship\'s operation.',0,100,0,1,NULL,0.0000,0,NULL,0),(27022,356,'Perpetual Motion Unit I Blueprint',' ',0,0.01,0,1,NULL,64500.0000,0,NULL,0),(27023,332,'Perpetual Motion Unit II','The mere existence of this unit is a major vexation to physicists everywhere. That said, it doesn\'t do much at all for the pilot: It operates as a closed system, and any attempt at a breach or internal inspection will ruin the mechanism. It has no effect on any part of a ship\'s operation.',0,100,0,1,NULL,0.0000,0,NULL,0),(27024,356,'Perpetual Motion Unit II Blueprint',' ',0,0.01,0,1,NULL,64500.0000,0,NULL,0),(27025,333,'Datacore - Basic Civilian Tech','This datacore is a minor storehouse of information, containing a fair portion of mankind\'s collected knowledge in the field of ordinary civilian technology.',1,1,0,1,NULL,0.0000,0,NULL,0),(27026,716,'Civilian Data Interface','Designed to work with the basic technologies. It does however not work with the more advanced technologies.',0,1,0,1,NULL,0.0000,0,NULL,0),(27027,356,'Civilian Data Interface Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(27028,462,'Chondrite','This ore is of interest only to civilian and rookie pilot mining operations.',4000,0.1,0,333,NULL,1000.0000,0,NULL,0),(27029,18,'Chalcopyrite','This mineral is of interest only to civilian and rookie pilot factory production.',0,0.01,0,1,NULL,2.0000,0,NULL,0),(27038,526,'Clay Pigeon','A small pigeon statue made out of astral clay.',50,1,0,1,NULL,2222.0000,1,NULL,0),(27039,356,'Clay Pigeon Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(27041,186,'Minmatar Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27042,186,'Minmatar Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27043,186,'Minmatar Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27044,186,'Khanid Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27045,186,'Khanid Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27046,186,'Khanid Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27047,186,'Caldari Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27048,186,'Caldari Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27049,186,'Caldari Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27050,186,'Amarr Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27051,186,'Amarr Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27052,186,'Amarr Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27053,186,'Gallente Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27054,186,'Gallente Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27055,186,'Gallente Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27056,186,'Thukker Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27057,186,'Thukker Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27058,186,'Thukker Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27059,333,'Datacore - Elementary Civilian Tech','This datacore is a minor storehouse of information, containing a fair portion of mankind\'s collected knowledge in the field of ordinary civilian technology.',1,1,0,1,NULL,0.0000,0,NULL,0),(27060,186,'Mordu Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27061,186,'Mordu Medium Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27062,186,'Mordu Small Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27063,319,'Repair Outpost_Weak','Due to their amazing cost-effectiveness and the speed at which they can be built, these repair outposts are seeing greater and greater use among travelers who need to be able to stay mobile in dangerous territory.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(27064,773,'Capital Auxiliary Nano Pump I','This ship modification is designed to increase a ship\'s armor repairer repair amount at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(27065,787,'Capital Auxiliary Nano Pump I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1719,0),(27066,773,'Capital Nanobot Accelerator II','This ship modification is designed to reduce a ship\'s armor repair cycle duration at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(27067,787,'Capital Nanobot Accelerator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(27068,773,'Small Remote Repair Augmentor I','This ship modification is designed to reduce the capacitor need for a ship\'s remote armor repair modules at the expense of max velocity.\r\r\n',200,5,0,1,NULL,0.0000,1,1206,0),(27069,787,'Small Remote Repair Augmentor I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1203,0),(27070,738,'Inherent Implants \'Noble\' Repair Systems RS-601','A neural Interface upgrade that boosts the pilot\'s skill in operating armor/hull repair modules.\r\r\n\r\r\n1% reduction in repair systems duration.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,200000.0000,1,1514,0),(27071,738,'Inherent Implants \'Noble\' Remote Armor Repair Systems RA-701','A neural Interface upgrade that boosts the pilot\'s skill in the operation of remote armor repair systems. \r\r\n\r\r\n1% reduced capacitor need for remote armor repair system modules.',0,1,0,1,NULL,0.0000,1,1515,0),(27072,738,'Inherent Implants \'Noble\' Mechanic MC-801','A neural Interface upgrade that boosts the pilot\'s skill at maintaining the mechanical components and structural integrity of a spaceship.\r\r\n\r\r\n1% bonus to hull hp.',0,1,0,1,NULL,200000.0000,1,1516,0),(27073,738,'Inherent Implants \'Noble\' Repair Proficiency RP-901','A neural Interface upgrade for analyzing and repairing starship damage.\r\r\n\r\r\n1% bonus to repair system repair amount.\r\r\n\r\r\nNote: This implant has no effect on remote armor repair modules or capital sized modules.',0,1,0,1,NULL,0.0000,1,1517,0),(27074,738,'Inherent Implants \'Noble\' Hull Upgrades HG-1001','A neural Interface upgrade that boosts the pilot\'s skill at maintaining their ship\'s midlevel defenses.\r\r\n\r\r\n1% bonus to armor hit points.',0,1,0,1,NULL,200000.0000,1,1518,0),(27075,742,'Eifyr and Co. \'Gunslinger\' Motion Prediction MR-701','An Eifyr and Co. gunnery hardwiring designed to enhance turret tracking.\r\r\n\r\r\n1% bonus to turret tracking speed.',0,1,0,1,NULL,200000.0000,1,1499,0),(27076,742,'Zainou \'Deadeye\' Sharpshooter ST-901','A Zainou gunnery hardwiring designed to enhance optimal range.\r\r\n\r\r\n1% bonus to turret optimal range.',0,1,0,1,NULL,200000.0000,1,1501,0),(27077,742,'Inherent Implants \'Lancer\' Gunnery RF-901','An Inherent Implants gunnery hardwiring designed to enhance turret rate of fire.\r\r\n\r\r\n1% bonus to all turret rate of fire.',0,1,0,1,NULL,200000.0000,1,1501,0),(27078,742,'Zainou \'Deadeye\' Trajectory Analysis TA-701','A Zainou gunnery hardwiring designed to enhance falloff range.\r\r\n\r\r\n1% bonus to turret falloff.',0,1,0,1,NULL,200000.0000,1,1499,0),(27079,742,'Inherent Implants \'Lancer\' Controlled Bursts CB-701','An Inherent Implants gunnery hardwiring designed to enhance turret energy management.\r\r\n\r\r\n1% reduction in all turret capacitor need.',0,1,0,1,NULL,200000.0000,1,1499,0),(27080,742,'Zainou \'Gnome\' Weapon Upgrades WU-1001','A neural Interface upgrade that lowers turret CPU needs.\r\r\n\r\r\n1% reduction in the CPU required by turrets.',0,1,0,1,NULL,200000.0000,1,1502,0),(27081,742,'Eifyr and Co. \'Gunslinger\' Surgical Strike SS-901','An Eifyr and Co. gunnery hardwiring designed to enhance skill with all turrets.\r\r\n\r\r\n1% bonus to all turret damages.',0,1,0,1,NULL,200000.0000,1,1501,0),(27082,742,'Inherent Implants \'Lancer\' Small Energy Turret SE-601','An Inherent Implants gunnery hardwiring designed to enhance skill with small energy turrets.\r\r\n\r\r\n1% bonus to small energy turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(27083,742,'Zainou \'Deadeye\' Small Hybrid Turret SH-601','A Zainou gunnery hardwiring designed to enhance skill with small hybrid turrets.\r\r\n\r\r\n1% bonus to small hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(27084,742,'Eifyr and Co. \'Gunslinger\' Small Projectile Turret SP-601','An Eifyr and Co. gunnery hardwiring designed to enhance skill with small projectile turrets.\r\r\n\r\r\n1% bonus to small projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1498,0),(27085,742,'Inherent Implants \'Lancer\' Medium Energy Turret ME-801','An Inherent Implants gunnery hardwiring designed to enhance skill with medium energy turrets.\r\r\n\r\r\n1% bonus to medium energy turret damage.',0,1,0,1,NULL,200000.0000,1,1500,0),(27086,742,'Zainou \'Deadeye\' Medium Hybrid Turret MH-801','A Zainou gunnery hardwiring designed to enhance skill with medium hybrid turrets.\r\r\n\r\r\n1% bonus to medium hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1500,0),(27087,742,'Eifyr and Co. \'Gunslinger\' Medium Projectile Turret MP-801','An Eifyr and Co. gunnery hardwiring designed to enhance skill with medium projectile turrets.\r\r\n\r\r\n1% bonus to medium projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1500,0),(27088,742,'Inherent Implants \'Lancer\' Large Energy Turret LE-1001','An Inherent Implants gunnery hardwiring designed to enhance skill with large energy turrets.\r\r\n\r\r\n1% bonus to large energy turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(27089,742,'Zainou \'Deadeye\' Large Hybrid Turret LH-1001','A Zainou gunnery hardwiring designed to enhance skill with large hybrid turrets.\r\r\n\r\r\n1% bonus to large hybrid turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(27090,742,'Eifyr and Co. \'Gunslinger\' Large Projectile Turret LP-1001','An Eifyr and Co. gunnery hardwiring designed to enhance skill with large projectile turrets.\r\r\n\r\r\n1% bonus to large projectile turret damage.',0,1,0,1,NULL,200000.0000,1,1502,0),(27091,746,'Zainou \'Gnome\' Launcher CPU Efficiency LE-601','1% reduction in the CPU need of missile launchers.',0,1,0,1,NULL,0.0000,1,1493,0),(27092,746,'Zainou \'Deadeye\' Missile Bombardment MB-701','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n1% bonus to all missiles\' maximum flight time.',0,1,0,1,NULL,200000.0000,1,1494,0),(27093,746,'Zainou \'Deadeye\' Missile Projection MP-701','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n1% bonus to all missiles\' maximum velocity.',0,1,0,1,NULL,200000.0000,1,1494,0),(27094,746,'Zainou \'Deadeye\' Guided Missile Precision GP-801','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n1% reduced factor of signature radius for all missile explosions.',0,1,0,1,NULL,200000.0000,1,1495,0),(27095,746,'Zainou \'Deadeye\' Target Navigation Prediction TN-901','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n1% decrease in factor of target\'s velocity for all missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(27096,746,'Zainou \'Deadeye\' Rapid Launch RL-1001','A Zainou missile hardwiring designed to enhance skill with missiles.\r\r\n\r\r\n1% bonus to all missile launcher rate of fire.',0,1,0,1,NULL,200000.0000,1,1497,0),(27097,747,'Eifyr and Co. \'Rogue\' Navigation NN-601','A Eifyr and Co hardwiring designed to enhance pilot navigation skill.\r\r\n\r\r\n1% bonus to ship velocity.',0,1,0,1,NULL,200000.0000,1,1489,0),(27098,747,'Eifyr and Co. \'Rogue\' Fuel Conservation FC-801','Improved control over afterburner energy consumption.\r\r\n\r\r\n1% reduction in afterburner capacitor needs.',0,1,0,1,NULL,200000.0000,1,1491,0),(27099,747,'Eifyr and Co. \'Rogue\' Evasive Maneuvering EM-701','A neural interface upgrade designed to enhance pilot Maneuvering skill.\r\r\n\r\r\n1% bonus to ship agility.',0,1,0,1,NULL,200000.0000,1,1490,0),(27100,747,'Eifyr and Co. \'Rogue\' High Speed Maneuvering HS-901','Improves the performance of microwarpdrives.\r\r\n\r\r\n1% reduction in capacitor need of modules requiring High Speed Maneuvering.',0,1,0,1,NULL,200000.0000,1,1492,0),(27101,747,'Eifyr and Co. \'Rogue\' Acceleration Control AC-601','Improves speed boosting velocity.\r\r\n\r\r\n1% bonus to afterburner and microwarpdrive speed increase.',0,1,0,1,NULL,0.0000,1,1489,0),(27102,1229,'Inherent Implants \'Highwall\' Mining MX-1001','A neural Interface upgrade that boosts the pilot\'s skill at mining.\r\r\n\r\r\n1% bonus to mining yield.',0,1,0,1,NULL,21504.0000,1,1767,0),(27103,1229,'Inherent Implants \'Yeti\' Ice Harvesting IH-1001','A neural Interface upgrade that boosts the pilot\'s skill at mining ice.\r\r\n\r\r\n1% decrease in ice harvester cycle time.',0,1,0,1,NULL,21504.0000,1,1767,0),(27104,749,'Zainou \'Gnome\' Shield Upgrades SU-601','A neural Interface upgrade that reduces the shield upgrade module power needs.\r\r\n\r\r\n1% reduction in power grid needs of modules requiring the Shield Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1480,0),(27105,749,'Zainou \'Gnome\' Shield Management SM-701','Improved skill at regulating shield capacity.\r\r\n\r\r\n1% bonus to shield capacity.',0,1,0,1,NULL,200000.0000,1,1481,0),(27106,749,'Zainou \'Gnome\' Shield Emission Systems SE-801','A neural Interface upgrade that reduces the capacitor need for shield emission system modules such as shield transfer array.\r\r\n\r\r\n1% reduction in capacitor need of modules requiring the Shield Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1482,0),(27107,749,'Zainou \'Gnome\' Shield Operation SP-901','A neural Interface upgrade that boosts the recharge rate of the shields of the pilots ship.\r\r\n\r\r\n1% boost to shield recharge rate.',0,1,0,1,NULL,200000.0000,1,1483,0),(27108,746,'Zainou \'Snapshot\' Light Missiles LM-903','A neural interface upgrade that boosts the pilot\'s skill with light missiles.\r\r\n\r\r\n3% bonus to damage of light missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(27109,746,'Zainou \'Snapshot\' Heavy Assault Missiles AM-703','A neural interface upgrade that boosts the pilot\'s skill with heavy assault missiles.\r\r\n\r\r\n3% bonus to heavy assault missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(27110,747,'Eifyr and Co. \'Rogue\' Afterburner AB-610','A neural interface upgrade that boosts the pilot\'s skill with afterburners.\r\r\n\r\r\n10% bonus to the duration of afterburners.',0,1,0,1,NULL,200000.0000,1,1489,0),(27111,747,'Eifyr and Co. \'Rogue\' Afterburner AB-602','A neural interface upgrade that boosts the pilot\'s skill with afterburners.\r\r\n\r\r\n2% bonus to the duration of afterburners.',0,1,0,1,NULL,200000.0000,1,1489,0),(27112,747,'Eifyr and Co. \'Rogue\' Warp Drive Operation WD-610','A neural interface upgrade that boosts the pilot\'s skill at warp drive operation.\r\r\n\r\r\n10% reduction in the capacitor need of warp drive.',0,1,0,1,NULL,200000.0000,1,1489,0),(27113,747,'Eifyr and Co. \'Rogue\' Warp Drive Operation WD-602','A neural interface upgrade that boosts the pilot\'s skill at warp drive operation.\r\r\n\r\r\n2% reduction in the capacitor need of warp drive.',0,1,0,1,NULL,200000.0000,1,1489,0),(27114,747,'Eifyr and Co. \'Rogue\' Warp Drive Speed WS-615','A neural interface upgrade that boosts the pilot\'s skill at warp navigation.\r\r\n\r\r\n15% bonus to ships warp speed.',0,1,0,1,NULL,200000.0000,1,1489,0),(27115,747,'Eifyr and Co. \'Rogue\' Warp Drive Speed WS-605','A neural interface upgrade that boosts the pilot\'s skill at warp navigation.\r\r\n\r\r\n5% bonus to ships warp speed.',0,1,0,1,NULL,200000.0000,1,1489,0),(27116,741,'Inherent Implants \'Squire\' Capacitor Management EM-805','A neural interface upgrade that boosts the pilot\'s skill at energy management.\r\r\n\r\r\n5% bonus to ships capacitor capacity.',0,1,0,1,NULL,200000.0000,1,1509,0),(27117,741,'Inherent Implants \'Squire\' Capacitor Management EM-801','A neural interface upgrade that boosts the pilot\'s skill at energy management.\r\r\n\r\r\n1% bonus to ships capacitor capacity.',0,1,0,1,NULL,200000.0000,1,1509,0),(27118,741,'Inherent Implants \'Squire\' Capacitor Systems Operation EO-605','A neural interface upgrade that boosts the pilot\'s skill at energy systems operation.\r\r\n\r\r\n5% reduction in capacitor recharge time.',0,1,0,1,NULL,200000.0000,1,1507,0),(27119,741,'Inherent Implants \'Squire\' Capacitor Systems Operation EO-601','A neural interface upgrade that boosts the pilot\'s skill at energy systems operation.\r\r\n\r\r\n1% reduction in capacitor recharge time.',0,1,0,1,NULL,200000.0000,1,1507,0),(27120,741,'Inherent Implants \'Squire\' Capacitor Emission Systems ES-701','A neural interface upgrade that boosts the pilot\'s skill with energy emission systems.\r\r\n\r\r\n1% reduction in capacitor need of modules requiring the Capacitor Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(27121,741,'Inherent Implants \'Squire\' Capacitor Emission Systems ES-705','A neural interface upgrade that boosts the pilot\'s skill with energy emission systems.\r\r\n\r\r\n5% reduction in capacitor need of modules requiring the Capacitor Emission Systems skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(27122,741,'Inherent Implants \'Squire\' Energy Pulse Weapons EP-705','A neural interface upgrade that boosts the pilot\'s skill with energy pulse weapons.\r\r\n\r\r\n5% reduction in the cycle time of modules requiring the Energy Pulse Weapons skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(27123,741,'Inherent Implants \'Squire\' Energy Pulse Weapons EP-701','A neural interface upgrade that boosts the pilot\'s skill with energy pulse weapons.\r\r\n\r\r\n1% reduction in the cycle time of modules requiring the Energy Pulse Weapons skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(27124,741,'Inherent Implants \'Squire\' Energy Grid Upgrades EU-705','A neural interface upgrade that boosts the pilot\'s skill with energy grid upgrades.\r\r\n\r\r\n5% reduction in CPU need of modules requiring the Energy Grid Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(27125,741,'Inherent Implants \'Squire\' Energy Grid Upgrades EU-701','A neural interface upgrade that boosts the pilot\'s skill with energy grid upgrades.\r\r\n\r\r\n1% reduction in CPU need of modules requiring the Energy Grid Upgrades skill.',0,1,0,1,NULL,200000.0000,1,1508,0),(27126,741,'Inherent Implants \'Squire\' Power Grid Management EG-605','A neural interface upgrade that boosts the pilot\'s skill at engineering.\r\r\n\r\r\n5% bonus to the power grid output of your ship.',0,1,0,1,NULL,200000.0000,1,1507,0),(27127,741,'Inherent Implants \'Squire\' Power Grid Management EG-601','A neural interface upgrade that boosts the pilot\'s skill at engineering.\r\r\n\r\r\n1% bonus to the power grid output of your ship.',0,1,0,1,NULL,200000.0000,1,1507,0),(27128,741,'Zainou \'Gypsy\' Electronics Upgrades EU-605','A neural interface upgrade that boosts the pilot\'s skill with electronics upgrades.\r\r\n\r\r\n5% reduction in CPU need of modules requiring the Electronics Upgrade skill.',0,1,0,1,NULL,200000.0000,1,1507,0),(27129,741,'Zainou \'Gypsy\' Electronics Upgrades EU-601','A neural interface upgrade that boosts the pilot\'s skill with electronics upgrades.\r\r\n\r\r\n1% reduction in CPU need of modules requiring the Electronics Upgrade skill.',0,1,0,1,NULL,200000.0000,1,1507,0),(27130,1228,'Zainou \'Gypsy\' Signature Analysis SA-705','A neural interface upgrade that boosts the pilot\'s skill at operating targeting systems.\r\r\n\r\r\n5% bonus to ships scan resolution.',0,1,0,1,NULL,10752.0000,1,1765,0),(27131,1228,'Zainou \'Gypsy\' Signature Analysis SA-701','A neural interface upgrade that boosts the pilot\'s skill at operating targeting systems.\r\r\n\r\r\n1% bonus to ships scan resolution.',0,1,0,1,NULL,10752.0000,1,1765,0),(27142,741,'Zainou \'Gypsy\' CPU Management EE-605','A neural interface upgrade that boosts the pilot\'s skill at electronics.\r\r\n\r\r\n5% bonus to the CPU output.',0,1,0,1,NULL,200000.0000,1,1507,0),(27143,741,'Zainou \'Gypsy\' CPU Management EE-601','A neural interface upgrade that boosts the pilot\'s skill at electronics.\r\r\n\r\r\n1% bonus to the CPU output.',0,1,0,1,NULL,200000.0000,1,1507,0),(27147,1231,'Eifyr and Co. \'Alchemist\' Biology BY-805','A neural Interface upgrade that boost the pilot\'s skill at handling boosters. \r\r\n\r\r\n5% bonus to attribute booster duration.',0,1,0,1,NULL,21504.0000,1,1775,0),(27148,1231,'Eifyr and Co. \'Alchemist\' Biology BY-810','A neural Interface upgrade that boost the pilot\'s skill at handling boosters. \r\r\n\r\r\n10% bonus to attribute booster duration.',0,1,0,1,NULL,21504.0000,1,1775,0),(27149,1229,'Inherent Implants \'Highwall\' Mining Upgrades MU-1003','A neural Interface upgrade that boosts the pilot\'s skill at mining.\r\r\n\r\r\n3% reduction in CPU penalty of mining upgrade modules.',0,1,0,1,NULL,21504.0000,1,1767,0),(27150,1229,'Inherent Implants \'Highwall\' Mining Upgrades MU-1005','A neural Interface upgrade that boosts the pilot\'s skill at mining.\r\r\n\r\r\n5% reduction in CPU penalty of mining upgrade modules.',0,1,0,1,NULL,21504.0000,1,1767,0),(27151,1229,'Inherent Implants \'Highwall\' Mining Upgrades MU-1001','A neural Interface upgrade that boosts the pilot\'s skill at mining.\r\r\n\r\r\n1% reduction in CPU penalty of mining upgrade modules.',0,1,0,1,NULL,21504.0000,1,1767,0),(27152,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPA-1','A neural Interface upgrade that boosts the pilots social skills. 3% Bonus to NPC agent, corporation and faction standing increase.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27153,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPB-1','A neural Interface upgrade that boosts the pilots social skills. 3% additional pay for agent missions.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27154,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPC-1','A neural Interface upgrade that boosts the pilots social skills. 2% Bonus to effective standing towards friendly NPC Corporations.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27155,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPD-1','A neural Interface upgrade that boosts the pilots social skills. Improves agent effective quality. 0.2 Bonus to effective standing towards hostile Agents.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27156,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPE-1','A neural Interface upgrade that boosts the pilots social skills. 3% Bonus to effective security rating increase.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27157,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPA-0','A neural Interface upgrade that boosts the pilots social skills. 1% Bonus to NPC agent, corporation and faction standing increase.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27158,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPA-2','A neural Interface upgrade that boosts the pilots social skills. 5% Bonus to NPC agent, corporation and faction standing increase.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27159,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPB-2','A neural Interface upgrade that boosts the pilots social skills. 5% additional pay for agent missions.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27160,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPB-0','A neural Interface upgrade that boosts the pilots social skills. 1% additional pay for agent missions.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27161,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPC-2','A neural Interface upgrade that boosts the pilots social skills. 4% Bonus to effective standing towards friendly NPC Corporations.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27162,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPC-0','A neural Interface upgrade that boosts the pilots social skills. 1% Bonus to effective standing towards friendly NPC Corporations.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27163,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPD-2','A neural Interface upgrade that boosts the pilots social skills. Improves agent effective quality. 0.4 Bonus to effective standing towards hostile Agents.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27164,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPD-0','A neural Interface upgrade that boosts the pilots social skills. Improves agent effective quality. 0.1 Bonus to effective standing towards hostile Agents.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27165,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPE-2','A neural Interface upgrade that boosts the pilots social skills. 5% Bonus to effective security rating increase.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27166,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPE-0','A neural Interface upgrade that boosts the pilots social skills. 1% Bonus to effective security rating increase.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27167,743,'Zainou \'Beancounter\' Industry BX-802','A neural Interface upgrade that boosts the pilots manufacturing skills.\r\r\n\r\r\n2% reduction in manufacturing time.',0,1,0,1,NULL,200000.0000,1,1504,0),(27169,1229,'Zainou \'Beancounter\' Reprocessing RX-802','A neural Interface upgrade that boosts the pilots reprocessing skills.\r\r\n\r\r\n2% bonus to ore and ice reprocessing yield.',0,1,0,1,NULL,21504.0000,1,1768,0),(27170,743,'Zainou \'Beancounter\' Industry BX-801','A neural Interface upgrade that boosts the pilots manufacturing skills.\r\r\n\r\r\n1% reduction in manufacturing time.',0,1,0,1,NULL,200000.0000,1,1504,0),(27171,743,'Zainou \'Beancounter\' Industry BX-804','A neural Interface upgrade that boosts the pilots manufacturing skills.\r\r\n\r\r\n4% reduction in manufacturing time.',0,1,0,1,NULL,200000.0000,1,1504,0),(27174,1229,'Zainou \'Beancounter\' Reprocessing RX-804','A neural Interface upgrade that boosts the pilots reprocessing skills.\r\r\n\r\r\n4% bonus to ore and ice reprocessing yield.',0,1,0,1,NULL,21504.0000,1,1768,0),(27175,1229,'Zainou \'Beancounter\' Reprocessing RX-801','A neural Interface upgrade that boosts the pilots reprocessing skills.\r\r\n\r\r\n1% bonus to ore and ice reprocessing yield.',0,1,0,1,NULL,21504.0000,1,1768,0),(27176,748,'Zainou \'Beancounter\' Metallurgy MY-703','A neural Interface upgrade that boosts the pilots research skills.\r\r\n\r\r\n3% bonus to material efficiency research speed.',0,1,0,1,NULL,200000.0000,1,1485,0),(27177,748,'Zainou \'Beancounter\' Research RR-603','A neural Interface upgrade that boosts the pilots research skills.\r\r\n\r\r\n3% bonus to blueprint manufacturing time research.',0,1,0,1,NULL,200000.0000,1,1484,0),(27178,748,'Zainou \'Beancounter\' Science SC-803','A neural Interface upgrade that boosts the pilots research skills.\r\r\n\r\r\n3% bonus to blueprint copying speed.',0,1,0,1,NULL,200000.0000,1,1486,0),(27179,748,'Zainou \'Beancounter\' Research RR-605','A neural Interface upgrade that boosts the pilots research skills.\r\r\n\r\r\n5% bonus to blueprint manufacturing time research.',0,1,0,1,NULL,200000.0000,1,1484,0),(27180,748,'Zainou \'Beancounter\' Research RR-601','A neural Interface upgrade that boosts the pilots research skills.\r\r\n\r\r\n1% bonus to blueprint manufacturing time research.',0,1,0,1,NULL,200000.0000,1,1484,0),(27181,748,'Zainou \'Beancounter\' Metallurgy MY-705','A neural Interface upgrade that boosts the pilots research skills.\r\r\n\r\r\n5% bonus to material efficiency research speed.',0,1,0,1,NULL,200000.0000,1,1485,0),(27182,748,'Zainou \'Beancounter\' Metallurgy MY-701','A neural Interface upgrade that boosts the pilots research skills.\r\r\n\r\r\n1% bonus to material efficiency research speed.',0,1,0,1,NULL,200000.0000,1,1485,0),(27184,748,'Zainou \'Beancounter\' Science SC-805','A neural Interface upgrade that boosts the pilots research skills.\r\r\n\r\r\n5% bonus to blueprint copying speed.',0,1,0,1,NULL,200000.0000,1,1486,0),(27185,748,'Zainou \'Beancounter\' Science SC-801','A neural Interface upgrade that boosts the pilots research skills.\r\r\n\r\r\n1% bonus to blueprint copying speed.',0,1,0,1,NULL,200000.0000,1,1486,0),(27186,1230,'Poteque \'Prospector\' Astrometric Pinpointing AP-606','A neural Interface upgrade that boosts the pilots scanning skills.\r\r\n\r\r\n6% reduction in maximum scan deviation.',0,1,0,1,NULL,21504.0000,1,1770,0),(27187,1230,'Poteque \'Prospector\' Astrometric Acquisition AQ-706','A neural Interface upgrade that boosts the pilots scanning skills.\r\r\n\r\r\n6% reduction in probe scanning time.',0,1,0,1,NULL,21504.0000,1,1771,0),(27188,1230,'Poteque \'Prospector\' Astrometric Rangefinding AR-806','A neural Interface upgrade that boosts the pilots scanning skills.\r\r\n\r\r\n6% stronger scanning strength with scan probes.',0,1,0,1,NULL,21504.0000,1,1772,0),(27190,1230,'Poteque \'Prospector\' Astrometric Pinpointing AP-610','A neural Interface upgrade that boosts the pilots scanning skills.\r\r\n\r\r\n10% reduction in maximum scan deviation.',0,1,0,1,NULL,21504.0000,1,1770,0),(27191,1230,'Poteque \'Prospector\' Astrometric Pinpointing AP-602','A neural Interface upgrade that boosts the pilots scanning skills.\r\r\n\r\r\n2% reduction in maximum scan deviation.',0,1,0,1,NULL,21504.0000,1,1770,0),(27192,1230,'Poteque \'Prospector\' Astrometric Acquisition AQ-710','A neural Interface upgrade that boosts the pilots scanning skills.\r\r\n\r\r\n10% reduction in probe scanning time.',0,1,0,1,NULL,21504.0000,1,1771,0),(27193,1230,'Poteque \'Prospector\' Astrometric Acquisition AQ-702','A neural Interface upgrade that boosts the pilots scanning skills.\r\r\n\r\r\n2% reduction in probe scanning time.',0,1,0,1,NULL,21504.0000,1,1771,0),(27194,1230,'Poteque \'Prospector\' Astrometric Rangefinding AR-810','A neural Interface upgrade that boosts the pilots scanning skills.\r\r\n\r\r\n10% stronger scanning strength with scan probes.',0,1,0,1,NULL,21504.0000,1,1772,0),(27195,1230,'Poteque \'Prospector\' Astrometric Rangefinding AR-802','A neural Interface upgrade that boosts the pilots scanning skills.\r\r\n\r\r\n2% stronger scanning strength with scan probes.',0,1,0,1,NULL,21504.0000,1,1772,0),(27196,1230,'Poteque \'Prospector\' Archaeology AC-905','A neural Interface upgrade that boosts the pilots exploration skills.\r\r\n\r\r\n+5 Virus Coherence bonus for Relic Analyzers.',0,1,0,1,NULL,21504.0000,1,1773,0),(27197,1230,'Poteque \'Prospector\' Hacking HC-905','A neural Interface upgrade that boosts the pilots exploration skills.\r\r\n\r\r\n+5 Virus Coherence bonus for Data Analyzers.',0,1,0,1,NULL,21504.0000,1,1773,0),(27198,1230,'Poteque \'Prospector\' Salvaging SV-905','A neural Interface upgrade that boosts the pilots exploration skills.\r\r\n\r\r\n5% increase in chance of salvage retrieval.',0,1,0,1,NULL,21504.0000,1,1773,0),(27202,186,'Convoy Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27203,283,'Production Assistant','This individual, dishevelled and exhausted, is responsible for seeing to completion various niggling tasks relegated by superiors. And, of course, he or she serves as a scapegoat in case a task goes horrendously wrong.',85,3,0,1,NULL,0.0000,1,NULL,0),(27204,746,'Hardwiring - Zainou \'Sharpshooter\' ZMX100','A Zainou missile hardwiring designed to enhance skill with missiles. 3% bonus to citadel torpedo damage.',0,1,0,1,NULL,200000.0000,1,NULL,0),(27205,746,'Hardwiring - Zainou \'Sharpshooter\' ZMX1000','A Zainou missile hardwiring designed to enhance skill with missiles. 5% bonus to citadel torpedo damage.',0,1,0,1,NULL,200000.0000,1,NULL,0),(27206,746,'Hardwiring - Zainou \'Sharpshooter\' ZMX10','A Zainou missile hardwiring designed to enhance skill with missiles. 1% bonus to citadel torpedo damage.',0,1,0,1,NULL,200000.0000,1,NULL,0),(27223,741,'Inherent Implants \'Sergeant\' XE4','A neural interface upgrade that boosts the pilot\'s skill with energy emission systems.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27224,740,'Zainou \'Gypsy\' Target Painting TG-903','A neural interface upgrade that boosts the pilot\'s skill at target painting.\r\r\n\r\r\n3% reduction in capacitor need of modules requiring the Target Painting skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(27225,740,'Zainou \'Gypsy\' Electronic Warfare EW-905','A neural interface upgrade that boosts the pilot\'s skill at electronic warfare.\r\r\n\r\r\n5% reduction in ECM and ECM Burst module capacitor need.',0,1,0,1,NULL,200000.0000,1,1513,0),(27226,740,'Zainou \'Gypsy\' Electronic Warfare EW-901','A neural interface upgrade that boosts the pilot\'s skill at electronic warfare.\r\r\n\r\r\n1% reduction in ECM and ECM Burst module capacitor need.',0,1,0,1,NULL,200000.0000,1,1513,0),(27227,1228,'Zainou \'Gypsy\' Long Range Targeting LT-805','A neural interface upgrade that boosts the pilot\'s skill at long range targeting.\r\r\n\r\r\n5% bonus to max targeting range.',0,1,0,1,NULL,21504.0000,1,1766,0),(27229,1228,'Zainou \'Gypsy\' Long Range Targeting LT-801','A neural interface upgrade that boosts the pilot\'s skill at long range targeting.\r\r\n\r\r\n1% bonus to max targeting range.',0,1,0,1,NULL,21504.0000,1,1766,0),(27230,740,'Zainou \'Gypsy\' Propulsion Jamming PJ-805','A neural interface upgrade that boosts the pilot\'s skill at propulsion jamming.\r\r\n\r\r\n5% reduction in capacitor need for modules requiring Propulsion Jamming skill.',0,1,0,1,NULL,200000.0000,1,1512,0),(27231,740,'Zainou \'Gypsy\' Propulsion Jamming PJ-801','A neural interface upgrade that boosts the pilot\'s skill at propulsion jamming.\r\r\n\r\r\n1% reduction in capacitor need for modules requiring Propulsion Jamming skill.',0,1,0,1,NULL,200000.0000,1,1512,0),(27232,740,'Zainou \'Gypsy\' Sensor Linking SL-905','A neural interface upgrade that boosts the pilot\'s skill at sensor linking.\r\r\n\r\r\n5% reduction in capacitor need of modules requiring the Sensor Linking skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(27233,740,'Zainou \'Gypsy\' Sensor Linking SL-901','A neural interface upgrade that boosts the pilot\'s skill at sensor linking.\r\r\n\r\r\n1% reduction in capacitor need of modules requiring the Sensor Linking skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(27234,740,'Zainou \'Gypsy\' Weapon Disruption WD-905','A neural interface upgrade that boosts the pilot\'s skill at weapon disruption.\r\r\n\r\r\n5% reduction in capacitor need of modules requiring the Weapon Disruption skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(27235,740,'Zainou \'Gypsy\' Weapon Disruption WD-901','A neural interface upgrade that boosts the pilot\'s skill at weapon disruption.\r\r\n\r\r\n1% reduction in capacitor need of modules requiring the Weapon Disruption skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(27236,740,'Zainou \'Gypsy\' Target Painting TG-905','A neural interface upgrade that boosts the pilot\'s skill at target painting.\r\r\n\r\r\n5% reduction in capacitor need of modules requiring the Target Painting skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(27237,740,'Zainou \'Gypsy\' Target Painting TG-901','A neural interface upgrade that boosts the pilot\'s skill at target painting.\r\r\n\r\r\n1% reduction in capacitor need of modules requiring the Target Painting skill.',0,1,0,1,NULL,200000.0000,1,1513,0),(27238,1229,'Eifyr and Co. \'Alchemist\' Gas Harvesting GH-803','A neural Interface upgrade that boosts the pilot\'s skill at gas harvesting.\r\r\n\r\r\n3% reduction to gas cloud harvester cycle time.',0,1,0,1,NULL,21504.0000,1,1768,0),(27239,1229,'Eifyr and Co. \'Alchemist\' Gas Harvesting GH-805','A neural Interface upgrade that boosts the pilot\'s skill at gas harvesting.\r\r\n\r\r\n5% reduction to gas cloud harvester cycle time.',0,1,0,1,NULL,21504.0000,1,1768,0),(27240,1229,'Eifyr and Co. \'Alchemist\' Gas Harvesting GH-801','A neural Interface upgrade that boosts the pilot\'s skill at gas harvesting.\r\r\n\r\r\n1% reduction to gas cloud harvester cycle time.',0,1,0,1,NULL,21504.0000,1,1768,0),(27243,746,'Zainou \'Snapshot\' Defender Missiles DM-805','A neural interface upgrade that boosts the pilot\'s skill with defender missiles.\r\r\n\r\r\n5% bonus to the velocity of defender missiles.',0,1,0,1,NULL,200000.0000,1,1495,0),(27244,746,'Zainou \'Snapshot\' Defender Missiles DM-801','A neural interface upgrade that boosts the pilot\'s skill with defender missiles.\r\r\n\r\r\n1% bonus to the velocity of defender missiles.',0,1,0,1,NULL,200000.0000,1,1495,0),(27245,746,'Zainou \'Snapshot\' Heavy Assault Missiles AM-705','A neural interface upgrade that boosts the pilot\'s skill with heavy assault missiles.\r\r\n\r\r\n5% bonus to heavy assault missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(27246,746,'Zainou \'Snapshot\' Heavy Assault Missiles AM-701','A neural interface upgrade that boosts the pilot\'s skill with heavy assault missiles.\r\r\n\r\r\n1% bonus to heavy assault missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(27247,746,'Zainou \'Snapshot\' FOF Explosion Radius FR-1005','A neural interface upgrade that boosts the pilot\'s skill with auto-target missiles.\r\r\n\r\r\n5% bonus to explosion radius of auto-target missiles.',0,1,0,1,NULL,200000.0000,1,1497,0),(27249,746,'Zainou \'Snapshot\' FOF Explosion Radius FR-1001','A neural interface upgrade that boosts the pilot\'s skill with auto-target missiles.\r\r\n\r\r\n1% bonus to explosion radius of auto-target missiles.',0,1,0,1,NULL,200000.0000,1,1497,0),(27250,746,'Zainou \'Snapshot\' Heavy Missiles HM-705','A neural interface upgrade that boosts the pilot\'s skill with heavy missiles.\r\r\n\r\r\n5% bonus to heavy missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(27251,746,'Zainou \'Snapshot\' Heavy Missiles HM-701','A neural interface upgrade that boosts the pilot\'s skill with heavy missiles.\r\r\n\r\r\n1% bonus to heavy missile damage.',0,1,0,1,NULL,200000.0000,1,1494,0),(27252,746,'Zainou \'Snapshot\' Light Missiles LM-905','A neural interface upgrade that boosts the pilot\'s skill with light missiles.\r\r\n\r\r\n5% bonus to damage of light missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(27253,746,'Zainou \'Snapshot\' Light Missiles LM-901','A neural interface upgrade that boosts the pilot\'s skill with light missiles.\r\r\n\r\r\n1% bonus to damage of light missiles.',0,1,0,1,NULL,200000.0000,1,1496,0),(27254,746,'Zainou \'Snapshot\' Rockets RD-905','A neural interface upgrade that boosts the pilot\'s skill with rockets.\r\r\n\r\r\n5% bonus to the damage of rockets.',0,1,0,1,NULL,200000.0000,1,1496,0),(27255,746,'Zainou \'Snapshot\' Rockets RD-901','A neural interface upgrade that boosts the pilot\'s skill with rockets.\r\r\n\r\r\n1% bonus to the damage of rockets.',0,1,0,1,NULL,200000.0000,1,1496,0),(27256,746,'Zainou \'Snapshot\' Torpedoes TD-605','A neural interface upgrade that boosts the pilot\'s skill with torpedoes.\r\r\n\r\r\n5% bonus to the damage of torpedoes.',0,1,0,1,NULL,200000.0000,1,1493,0),(27257,746,'Zainou \'Snapshot\' Torpedoes TD-601','A neural interface upgrade that boosts the pilot\'s skill with torpedoes.\r\r\n\r\r\n1% bonus to the damage of torpedoes.',0,1,0,1,NULL,200000.0000,1,1493,0),(27258,746,'Zainou \'Snapshot\' Cruise Missiles CM-605','A neural interface upgrade that boosts the pilot\'s skill with cruise missiles.\r\r\n\r\r\n5% bonus to the damage of cruise missiles.',0,1,0,1,NULL,200000.0000,1,1493,0),(27259,746,'Zainou \'Snapshot\' Cruise Missiles CM-601','A neural interface upgrade that boosts the pilot\'s skill with cruise missiles.\r\r\n\r\r\n1% bonus to the damage of cruise missiles.',0,1,0,1,NULL,200000.0000,1,1493,0),(27260,1230,'Poteque \'Prospector\' Environmental Analysis EY-1005','A neural interface upgrade that boosts the pilot\'s skill at environmental analysis.\r\r\n\r\r\n5% reduction in cycle time of salvage, hacking and archaeology modules.\r\r\n+5 Virus Coherence bonus for Data and Relic Analyzers.\r\r\n',0,1,0,1,NULL,21504.0000,1,1774,0),(27264,748,'Hardwiring - Zainou \'Beancounter\' CI-1','A neural Interface upgrade that boost the pilot\'s skill at invention.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27265,748,'Hardwiring - Poteque Pharmaceuticals \'Draftsman\' GI-1','A defunct interface which does not work is being recalled by Poteque corporation.  ',0,1,0,1,NULL,25000000.0000,0,NULL,0),(27267,748,'Hardwiring - Zainou \'Beancounter\' CI-2','A neural Interface upgrade that boost the pilot\'s skill at invention.',0,1,0,1,NULL,200000.0000,0,NULL,0),(27268,748,'Hardwiring - Poteque Pharmaceuticals \'Draftsman\' GI-2','A defunct interface which does not work is being recalled by Poteque corporation. ',0,1,0,1,NULL,200000000.0000,0,NULL,0),(27269,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPA-X','TEST IMPLANT',0,1,0,1,NULL,200000.0000,0,NULL,0),(27270,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPB-X','TEST IMPLANT',0,1,0,1,NULL,200000.0000,0,NULL,0),(27271,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPC-X','TEST IMPLANT',0,1,0,1,NULL,200000.0000,0,NULL,0),(27272,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPD-X','TEST IMPLANT',0,1,0,1,NULL,200000.0000,0,NULL,0),(27273,750,'Hardwiring - Poteque Pharmaceuticals \'Consul\' PPE-X','TEST IMPLANT',0,1,0,1,NULL,200000.0000,0,NULL,0),(27274,526,'Villard Wheel','This item is an integral component of perpetual motion units. If the wheel ever stops spinning, the entire unit will grind to a halt.',500000,25000,0,1,NULL,0.0000,1,NULL,0),(27275,306,'Civilian Transport Ship Wreck','The remnants of a transport ship lost in battle.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(27276,521,'Black Box','The black box contains the last communication from a space ship as well as various data regarding its destruction. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(27277,1207,'Data Storage Device','If you have the right equipment you might be able to hack into this container and get some valuable information.',10000,27500,2700,1,1,0.0000,0,NULL,0),(27278,1207,'Ancient Ship Structure','This piece of floating rubble looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(27279,494,'Flimsy Pirate Base','A pirate base with fragile defenses.',1000000,150,8850,1,NULL,0.0000,0,NULL,0),(27280,383,'Angel Basic Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27281,383,'Blood Basic Defense Battery','This Light missile Sentry will Launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27282,383,'Tower Basic Sentry Angel','Angel sentry gun',1000,1000,1000,1,2,0.0000,0,NULL,0),(27283,383,'Tower Basic Sentry Bloodraider','Blood Raider sentry gun.',1000,1000,1000,1,4,0.0000,0,NULL,0),(27284,383,'Tower Basic Sentry Guristas','Guristas sentry gun.',1000,1000,1000,1,1,0.0000,0,NULL,0),(27285,383,'Tower Basic Sentry Serpentis','Serpentis sentry gun.',1000,1000,1000,1,8,0.0000,0,NULL,0),(27286,186,'Pirate Drone Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27287,818,'Pirate Capsule','This is an escape capsule which is released upon the destruction of ones ship.',32000,1000,0,1,NULL,0.0000,0,NULL,0),(27288,306,'Habitation_Module_Container','A hotel, looks like it has been abandoned.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(27290,319,'Minmatar Starbase Control Tower_Tough_Good Loot_testing','The Matari aren\'t really that high-tech, preferring speed rather than firepower or involved technology. Unfortunately that doesn\'t apply very well to stationary objects, much to the liking of the Amarr Empire.\r\r\n\r\r\nAmarrians call it a scrapheap of epic proportions. But don\'t underestimate these structures. Minmatar commanders usually have the last laugh when it comes to combat.',100000,1150,8850,1,2,0.0000,0,NULL,0),(27292,494,'Unstable Particle Acceleration Superstructure','This particle accelerator is on the brink of destruction.  Electronic particles ooze from its hull, filling the surrounding void and causing the structure to illuminate with an eerie glow.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(27293,805,'Brute Render Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: High',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27294,526,'Christer Fuglesang\'s Medal','A medal of honor awarded by the esteemed CONCORD operative, Christer Fuglesang.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(27295,829,'Angel Resilient Destroyer','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,2,0.0000,0,NULL,0),(27296,829,'Blood Resilient Destroyer','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2860000,28600,235,1,4,0.0000,0,NULL,0),(27297,829,'Guristas Resilient Destroyer','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1650000,16500,235,1,1,0.0000,0,NULL,0),(27298,829,'Serpentis Resilient Destroyer','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',2650000,26500,235,1,8,0.0000,0,NULL,0),(27299,31,'Civilian Amarr Shuttle','Amarr Shuttle',1600000,5000,10,1,4,5556.0000,0,NULL,0),(27300,111,'Civilian Amarr Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(27301,31,'Civilian Caldari Shuttle','Caldari Shuttle',1600000,5000,10,1,1,5556.0000,0,NULL,0),(27302,111,'Civilian Caldari Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(27303,31,'Civilian Gallente Shuttle','Gallente Shuttle',1600000,5000,10,1,8,5556.0000,0,NULL,0),(27304,111,'Civilian Gallente Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(27305,31,'Civilian Minmatar Shuttle','Minmatar Shuttle',1600000,5000,10,1,2,5556.0000,0,NULL,0),(27306,111,'Civilian Minmatar Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(27308,306,'Abandoned Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this old wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(27309,1162,'Station Warehouse Container Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1008,0),(27313,387,'Guristas Inferno Rocket','A small rocket with a plasma warhead.  ',100,0.005,0,100,NULL,290.0000,1,999,0),(27315,387,'Caldari Navy Inferno Rocket','A small rocket with a plasma warhead.  ',100,0.005,0,100,NULL,290.0000,1,999,0),(27317,387,'Dread Guristas Inferno Rocket','A small rocket with a plasma warhead.  ',100,0.005,0,100,NULL,290.0000,1,999,0),(27319,387,'Guristas Mjolnir Rocket','A small rocket with an EMP warhead. ',100,0.005,0,100,NULL,392.0000,1,999,0),(27321,387,'Caldari Navy Mjolnir Rocket','A small rocket with an EMP warhead. ',100,0.005,0,100,NULL,392.0000,1,999,0),(27323,387,'Dread Guristas Mjolnir Rocket','A small rocket with an EMP warhead. ',100,0.005,0,100,NULL,392.0000,1,999,0),(27325,387,'Guristas Nova Rocket','A small rocket with a nuclear warhead.',100,0.005,0,100,NULL,200.0000,1,999,0),(27327,387,'Caldari Navy Nova Rocket','A small rocket with a nuclear warhead.',100,0.005,0,100,NULL,200.0000,1,999,0),(27329,387,'Dread Guristas Nova Rocket','A small rocket with a nuclear warhead.',100,0.005,0,100,NULL,200.0000,1,999,0),(27331,387,'Guristas Scourge Rocket','A small rocket with a piercing warhead.',100,0.005,0,100,NULL,270.0000,1,999,0),(27333,387,'Caldari Navy Scourge Rocket','A small rocket with a piercing warhead.',100,0.005,0,100,NULL,270.0000,1,999,0),(27335,387,'Dread Guristas Scourge Rocket','A small rocket with a piercing warhead.',100,0.005,0,100,NULL,270.0000,1,999,0),(27337,89,'Guristas Mjolnir Torpedo','An ultra-heavy EMP missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,36168.0000,1,1000,0),(27339,89,'Caldari Navy Mjolnir Torpedo','An ultra-heavy EMP missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,36168.0000,1,1000,0),(27341,89,'Dread Guristas Mjolnir Torpedo','An ultra-heavy EMP missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,36168.0000,1,1000,0),(27343,89,'Guristas Scourge Torpedo','An ultra-heavy piercing missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,32424.0000,1,1000,0),(27345,89,'Caldari Navy Scourge Torpedo','An ultra-heavy piercing missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,32424.0000,1,1000,0),(27347,89,'Dread Guristas Scourge Torpedo','An ultra-heavy piercing missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,32424.0000,1,1000,0),(27349,89,'Guristas Inferno Torpedo','An ultra-heavy plasma missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,35746.0000,1,1000,0),(27351,89,'Caldari Navy Inferno Torpedo','An ultra-heavy plasma missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,35746.0000,1,1000,0),(27353,384,'Guristas Scourge Light Missile','From its humble beginnings in tiny Minmatar design labs, the Scourge light missile has quickly established itself throughout the star cluster as a premier missile for light launchers.',700,0.015,0,100,NULL,546.0000,1,998,0),(27355,89,'Dread Guristas Inferno Torpedo','An ultra-heavy plasma missile. While it is a slow projectile, its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,35746.0000,1,1000,0),(27357,89,'Guristas Nova Torpedo','An ultra-heavy nuclear missile. While it is a slow projectile, its sheer damage potential is simply staggering.      ',1500,0.1,0,100,NULL,28458.0000,1,1000,0),(27359,89,'Caldari Navy Nova Torpedo','An ultra-heavy nuclear missile. While it is a slow projectile, its sheer damage potential is simply staggering.     ',1500,0.1,0,100,NULL,28458.0000,1,1000,0),(27361,384,'Caldari Navy Scourge Light Missile','From its humble beginnings in tiny Minmatar design labs, the Scourge light missile has quickly established itself throughout the star cluster as a premier missile for light launchers.',700,0.015,0,100,NULL,546.0000,1,998,0),(27363,89,'Dread Guristas Nova Torpedo','An ultra-heavy nuclear missile. While it is a slow projectile, its sheer damage potential is simply staggering.   ',1500,0.1,0,100,NULL,28458.0000,1,1000,0),(27365,384,'Dread Guristas Scourge Light Missile','From its humble beginnings in tiny Minmatar design labs, the Scourge light missile has quickly established itself throughout the star cluster as a premier missile for light launchers.',700,0.015,0,100,NULL,546.0000,1,998,0),(27367,384,'Guristas Inferno Light Missile','The explosion the Inferno light missile creates upon impact is stunning enough for any display of fireworks - just ten times more deadly.',700,0.015,0,100,NULL,692.0000,1,998,0),(27369,384,'Dread Guristas Inferno Light Missile','The explosion the Inferno light missile creates upon impact is stunning enough for any display of fireworks - just ten times more deadly.',700,0.015,0,100,NULL,692.0000,1,998,0),(27371,384,'Caldari Navy Inferno Light Missile','The explosion the Inferno light missile creates upon impact is stunning enough for any display of fireworks - just ten times more deadly.',700,0.015,0,100,NULL,692.0000,1,998,0),(27373,386,'Guristas Mjolnir Cruise Missile','The mother of all missiles, the Mjolnir cruise missile delivers a tremendous payload, guaranteed to get its victims acquainted with their personal god in a quick, but painful manner.',1250,0.05,0,100,NULL,16216.0000,1,1001,0),(27375,384,'Dread Guristas Nova Light Missile','The Nova light missile is a tiny nuclear projectile based on a classic Minmatar design that has been in use since the early days of the Minmatar Resistance.',700,0.015,0,100,NULL,428.0000,1,998,0),(27377,386,'Caldari Navy Mjolnir Cruise Missile','The mother of all missiles, the Mjolnir cruise missile delivers a tremendous payload, guaranteed to get its victims acquainted with their personal god in a quick, but painful manner.',1250,0.05,0,100,NULL,16216.0000,1,1001,0),(27379,384,'Guristas Nova Light Missile','The Nova light missile is a tiny nuclear projectile based on a classic Minmatar design that has been in use since the early days of the Minmatar Resistance.',700,0.015,0,100,NULL,428.0000,1,998,0),(27381,384,'Caldari Navy Nova Light Missile','The Nova light missile is a tiny nuclear projectile based on a classic Minmatar design that has been in use since the early days of the Minmatar Resistance.',700,0.015,0,100,NULL,428.0000,1,998,0),(27383,384,'Guristas Mjolnir Light Missile','An advanced missile with a volatile payload of magnetized plasma, the Mjolnir light missile is specifically engineered to take down shield systems.',700,0.015,0,100,NULL,828.0000,1,998,0),(27385,384,'Dread Guristas Mjolnir Light Missile','An advanced missile with a volatile payload of magnetized plasma, the Mjolnir light missile is specifically engineered to take down shield systems.',700,0.015,0,100,NULL,828.0000,1,998,0),(27387,384,'Caldari Navy Mjolnir Light Missile','An advanced missile with a volatile payload of magnetized plasma, the Mjolnir light missile is specifically engineered to take down shield systems.',700,0.015,0,100,NULL,828.0000,1,998,0),(27389,386,'Dread Guristas Mjolnir Cruise Missile','The mother of all missiles, the Mjolnir cruise missile delivers a tremendous payload, guaranteed to get its victims acquainted with their personal god in a quick, but painful manner.',1250,0.05,0,100,NULL,16216.0000,1,1001,0),(27391,386,'Guristas Scourge Cruise Missile','The first Minmatar-made large missile. Constructed of reactionary alloys, the Scourge cruise missile is built to get to the target. Guidance and propulsion systems are of Gallente origin and were initially used in drones, making this a nimble projectile despite its heavy payload.',1250,0.05,0,100,NULL,10550.0000,1,1001,0),(27393,772,'Guristas Nova Heavy Assault Missile','A nuclear warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,2166.0000,1,1003,0),(27395,386,'Caldari Navy Scourge Cruise Missile','The first Minmatar-made large missile. Constructed of reactionary alloys, the Scourge cruise missile is built to get to the target. Guidance and propulsion systems are of Gallente origin and were initially used in drones, making this a nimble projectile despite its heavy payload.',1250,0.05,0,100,NULL,10550.0000,1,1001,0),(27397,772,'Dread Guristas Nova Heavy Assault Missile','A nuclear warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,2166.0000,1,1003,0),(27399,386,'Dread Guristas Scourge Cruise Missile','The first Minmatar-made large missile. Constructed of reactionary alloys, the Scourge cruise missile is built to get to the target. Guidance and propulsion systems are of Gallente origin and were initially used in drones, making this a nimble projectile despite its heavy payload.',1250,0.05,0,100,NULL,10550.0000,1,1001,0),(27401,772,'Caldari Navy Nova Heavy Assault Missile','A nuclear warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,2166.0000,1,1003,0),(27403,772,'Guristas Inferno Heavy Assault Missile','A plasma warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,3176.0000,1,1003,0),(27405,772,'Caldari Navy Inferno Heavy Assault Missile','A plasma warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,3176.0000,1,1003,0),(27407,772,'Dread Guristas Inferno Heavy Assault Missile','A plasma warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,3176.0000,1,1003,0),(27409,386,'Guristas Inferno Cruise Missile','An Amarr creation with powerful capabilities, the Inferno cruise missile was for a long time confined solely to the Amarr armed forces, but exports began some years ago and the missile is now found throughout the universe.',1250,0.05,0,100,NULL,13436.0000,1,1001,0),(27411,772,'Guristas Scourge Heavy Assault Missile','A kinetic warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,2680.0000,1,1003,0),(27413,772,'Caldari Navy Scourge Heavy Assault Missile','A kinetic warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,2680.0000,1,1003,0),(27415,772,'Dread Guristas Scourge Heavy Assault Missile','A kinetic warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,2680.0000,1,1003,0),(27417,772,'Guristas Mjolnir Heavy Assault Missile','An EMP warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,3776.0000,1,1003,0),(27419,772,'Caldari Navy Mjolnir Heavy Assault Missile','An EMP warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,3776.0000,1,1003,0),(27421,772,'Dread Guristas Mjolnir Heavy Assault Missile','An EMP warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,3776.0000,1,1003,0),(27423,386,'Caldari Navy Inferno Cruise Missile','An Amarr creation with powerful capabilities, the Inferno cruise missile was for a long time confined solely to the Amarr armed forces, but exports began some years ago and the missile is now found throughout the universe.',1250,0.05,0,100,NULL,13436.0000,1,1001,0),(27425,386,'Dread Guristas Inferno Cruise Missile','An Amarr creation with powerful capabilities, the Inferno cruise missile was for a long time confined solely to the Amarr armed forces, but exports began some years ago and the missile is now found throughout the universe.',1250,0.05,0,100,NULL,13436.0000,1,1001,0),(27427,386,'Guristas Nova Cruise Missile','A very basic missile for large launchers with reasonable payload. Utilizes the now substandard technology of bulls-eye guidance systems.',1250,0.05,0,100,NULL,8046.0000,1,1001,0),(27429,386,'Caldari Navy Nova Cruise Missile','A very basic missile for large launchers with reasonable payload. Utilizes the now substandard technology of bulls-eye guidance systems.',1250,0.05,0,100,NULL,8046.0000,1,1001,0),(27431,386,'Dread Guristas Nova Cruise Missile','A very basic missile for large launchers with reasonable payload. Utilizes the now substandard technology of bulls-eye guidance systems.',1250,0.05,0,100,NULL,8046.0000,1,1001,0),(27433,385,'Guristas Mjolnir Heavy Missile','First introduced by the armaments lab of the Wiyrkomi Corporation, the Mjolnir heavy missile is a solid investment with a large payload and steady performance.',1000,0.03,0,100,NULL,3776.0000,1,1002,0),(27435,385,'Caldari Navy Mjolnir Heavy Missile','First introduced by the armaments lab of the Wiyrkomi Corporation, the Mjolnir heavy missile is a solid investment with a large payload and steady performance.',1000,0.03,0,100,NULL,3776.0000,1,1002,0),(27437,385,'Dread Guristas Mjolnir Heavy Missile','First introduced by the armaments lab of the Wiyrkomi Corporation, the Mjolnir heavy missile is a solid investment with a large payload and steady performance.',1000,0.03,0,100,NULL,3776.0000,1,1002,0),(27439,385,'Guristas Scourge Heavy Missile','The Scourge heavy missile is an old relic from the Caldari-Gallente War that is still in widespread use because of its low price and versatility.',1000,0.03,0,100,NULL,2664.0000,1,1002,0),(27441,385,'Caldari Navy Scourge Heavy Missile','The Scourge heavy missile is an old relic from the Caldari-Gallente War that is still in widespread use because of its low price and versatility.',1000,0.03,0,100,NULL,2664.0000,1,1002,0),(27443,385,'Dread Guristas Scourge Heavy Missile','The Scourge heavy missile is an old relic from the Caldari-Gallente War that is still in widespread use because of its low price and versatility.',1000,0.03,0,100,NULL,2664.0000,1,1002,0),(27445,385,'Guristas Inferno Heavy Missile','Originally designed as a \'finisher\' - the killing blow to a crippled ship - the Inferno heavy missile has since gone through various technological upgrades. The latest version has a lighter payload than the original, but much improved guidance systems.',1000,0.03,0,100,NULL,3176.0000,1,1002,0),(27447,385,'Caldari Navy Inferno Heavy Missile','Originally designed as a \'finisher\' - the killing blow to a crippled ship - the Inferno heavy missile has since gone through various technological upgrades. The latest version has a lighter payload than the original, but much improved guidance systems.',1000,0.03,0,100,NULL,3176.0000,1,1002,0),(27449,385,'Dread Guristas Inferno Heavy Missile','Originally designed as a \'finisher\' - the killing blow to a crippled ship - the Inferno heavy missile has since gone through various technological upgrades. The latest version has a lighter payload than the original, but much improved guidance systems.',1000,0.03,0,100,NULL,3176.0000,1,1002,0),(27451,385,'Guristas Nova Heavy Missile','The be-all and end-all of medium-sized missiles, the Nova heavy missile is a must for those who want a guaranteed kill no matter the cost.',1000,0.03,0,100,NULL,2166.0000,1,1002,0),(27453,385,'Caldari Navy Nova Heavy Missile','The be-all and end-all of medium-sized missiles, the Nova heavy missile is a must for those who want a guaranteed kill no matter the cost.',1000,0.03,0,100,NULL,2166.0000,1,1002,0),(27455,385,'Dread Guristas Nova Heavy Missile','The be-all and end-all of medium-sized missiles, the Nova heavy missile is a must for those who want a guaranteed kill no matter the cost.',1000,0.03,0,100,NULL,2166.0000,1,1002,0),(27457,396,'Blood Mjolnir F.O.F. Cruise Missile I','An Amarr cruise missile with an EMP warhead and automatic guidance system.',1250,0.05,0,100,NULL,15000.0000,0,NULL,0),(27459,396,'Imperial Navy Mjolnir Auto-Targeting Cruise Missile I','An Amarr cruise missile with an EMP warhead and automatic guidance system.',1250,0.05,0,100,NULL,16216.0000,1,1192,0),(27461,396,'Dark Blood Mjolnir F.O.F. Cruise Missile I','An Amarr cruise missile with an EMP warhead and automatic guidance system.',1250,0.05,0,100,NULL,15000.0000,0,NULL,0),(27463,396,'Guristas Scourge F.O.F. Cruise Missile I','A Caldari cruise missile with a graviton warhead and automatic guidance system.',1250,0.05,0,100,1,12500.0000,0,NULL,0),(27465,396,'Caldari Navy Scourge Auto-Targeting Cruise Missile I','A Caldarian cruise missile with a graviton warhead and automatic guidance system.',1250,0.05,0,100,1,10550.0000,1,1192,0),(27467,396,'Dread Guristas Scourge F.O.F. Cruise Missile I','A Caldari cruise missile with a graviton warhead and automatic guidance system.',1250,0.05,0,100,1,10000.0000,0,NULL,0),(27469,396,'Shadow Inferno F.O.F. Cruise Missile I','A Gallente cruise missile with a plasma warhead and automatic guidance system ',1250,0.05,0,100,NULL,12500.0000,0,NULL,0),(27471,396,'Federation Navy Inferno Auto-Targeting Cruise Missile I','A Gallente cruise missile with a plasma warhead and automatic guidance system.',1250,0.05,0,100,NULL,13436.0000,1,1192,0),(27473,396,'Guardian Inferno F.O.F. Cruise Missile I','A Gallente cruise missile with a plasma warhead and automatic guidance system ',1250,0.05,0,100,NULL,12500.0000,0,NULL,0),(27475,396,'Arch Angel Nova F.O.F. Cruise Missile I','A Minmatar cruise missile with a nuclear warhead and automatic guidance system.',1250,0.05,0,100,NULL,7500.0000,0,NULL,0),(27477,396,'Republic Fleet Nova Auto-Targeting Cruise Missile I','A Minmatar cruise missile with a nuclear warhead and automatic guidance system.',1250,0.05,0,100,NULL,8046.0000,1,1192,0),(27479,396,'Domination Nova F.O.F. Cruise Missile I','A Minmatar cruise missile with a nuclear warhead and automatic guidance system.',1250,0.05,0,100,NULL,7500.0000,0,NULL,0),(27481,395,'Blood Mjolnir F.O.F. Heavy Missile I','An Amarr heavy missile with an EMP warhead and automatic guidance system.',1000,0.03,0,100,NULL,3500.0000,0,NULL,0),(27483,395,'Imperial Navy Mjolnir Auto-Targeting Heavy Missile I','An Amarr heavy missile with an EMP warhead and automatic guidance system.',1000,0.03,0,100,NULL,3776.0000,1,1192,0),(27485,395,'Dark Blood Mjolnir F.O.F. Heavy Missile I','An Amarr heavy missile with an EMP warhead and automatic guidance system.',1000,0.03,0,100,NULL,3500.0000,0,NULL,0),(27487,395,'Guristas Scourge F.O.F. Heavy Missile I','A Caldarian heavy missile with a graviton warhead and automatic guidance system.',1000,0.03,0,100,NULL,2500.0000,0,NULL,0),(27489,395,'Caldari Navy Scourge Auto-Targeting Heavy Missile I','A Caldarian heavy missile with a graviton warhead and automatic guidance system.',1000,0.03,0,100,NULL,2664.0000,1,1192,0),(27491,395,'Dread Guristas Scourge F.O.F. Heavy Missile I','A Caldarian heavy missile with a graviton warhead and automatic guidance system.',1000,0.03,0,100,NULL,2500.0000,0,NULL,0),(27493,395,'Shadow Inferno F.O.F. Heavy Missile I','A Gallente heavy missile with a plasma warhead and automatic guidance system.',1000,0.03,0,100,NULL,3000.0000,0,NULL,0),(27495,395,'Federation Navy Inferno Auto-Targeting Heavy Missile I','A Gallente heavy missile with a plasma warhead and automatic guidance system.',1000,0.03,0,100,NULL,3176.0000,1,1192,0),(27497,395,'Guardian Inferno F.O.F. Heavy Missile I','A Gallente heavy missile with a plasma warhead and automatic guidance system.',1000,0.03,0,100,NULL,3000.0000,0,NULL,0),(27499,395,'Arch Angel Nova F.O.F. Heavy Missile I','A Minmatar heavy missile with a nuclear warhead and automatic guidance system.',1000,0.03,0,100,2,2000.0000,0,NULL,0),(27501,395,'Republic Fleet Nova Auto-Targeting Heavy Missile I','A Minmatar heavy missile with a nuclear warhead and automatic guidance system.',1000,0.03,0,100,2,2166.0000,1,1192,0),(27503,395,'Domination Nova F.O.F. Heavy Missile I','A Minmatar heavy missile with a nuclear warhead and automatic guidance system.',1000,0.03,0,100,2,2000.0000,0,NULL,0),(27505,394,'Blood Mjolnir F.O.F. Light Missile I','An Amarr light missile with an EMP warhead and automatic guidance system.',700,0.015,0,100,4,750.0000,0,NULL,0),(27507,394,'Imperial Navy Mjolnir Auto-Targeting Light Missile I','An Amarr light missile with an EMP warhead and automatic guidance system.',700,0.015,0,100,4,828.0000,1,1192,0),(27509,394,'Dark Blood Mjolnir F.O.F. Light Missile I','An Amarr light missile with an EMP warhead and automatic guidance system.',700,0.015,0,100,4,750.0000,0,NULL,0),(27511,394,'Guristas Scourge F.O.F. Light Missile I','A Caldarian light missile with a graviton warhead and automatic guidance system.',700,0.015,0,100,NULL,500.0000,0,NULL,0),(27513,394,'Caldari Navy Scourge Auto-Targeting Light Missile I','A Caldarian light missile with a graviton warhead and automatic guidance system.',700,0.015,0,100,NULL,546.0000,1,1192,0),(27515,394,'Dread Guristas Scourge F.O.F. Light Missile I','A Caldarian light missile with a graviton warhead and automatic guidance system.',700,0.015,0,100,NULL,500.0000,0,NULL,0),(27517,394,'Shadow Inferno F.O.F. Light Missile I','A Gallente light missile with a plasma warhead and automatic guidance system.',700,0.015,0,100,8,624.0000,0,NULL,0),(27519,394,'Federation Navy Inferno Auto-Targeting Light Missile I','A Gallente light missile with a plasma warhead and automatic guidance system.',700,0.015,0,100,8,692.0000,1,1192,0),(27521,394,'Guardian Inferno F.O.F. Light Missile I','A Gallente light missile with a plasma warhead and automatic guidance system.',700,0.015,0,100,8,624.0000,0,NULL,0),(27523,394,'Arch Angel Nova F.O.F. Light Missile I','A Minmatar light missile with a nuclear warhead and automatic guidance system.',700,0.015,0,100,NULL,370.0000,0,NULL,0),(27525,394,'Republic Fleet Nova Auto-Targeting Light Missile I','A Minmatar light missile with a nuclear warhead and automatic guidance system.',700,0.015,0,100,NULL,428.0000,1,1192,0),(27527,394,'Domination Nova F.O.F. Light Missile I','A Minmatar light missile with a nuclear warhead and automatic guidance system.',700,0.015,0,100,NULL,370.0000,0,NULL,0),(27530,365,'Blood Control Tower','The Blood Control Tower is an enhanced version of the Amarr control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n50% bonus to Energy Sentry Optimal Range\r\n25% bonus to Energy Sentry Damage\r\n50% bonus to Silo Cargo Capacity',200000000,8000,140000,1,4,400000000.0000,1,478,0),(27532,365,'Dark Blood Control Tower','The Dark Blood Control Tower is a special enhanced version of the Amarrian control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Energy Sentry Optimal Range\r\r\n25% bonus to Energy Sentry Damage\r\r\n50% bonus to Silo Cargo Capacity',200000000,8000,140000,1,4,400000000.0000,1,478,0),(27533,365,'Guristas Control Tower','The Guristas Control Tower is an enhanced version of the Caldari control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n25% bonus to Missile Battery Rate of Fire\r\n50% bonus to Missile Velocity\r\n-75% bonus to ECM Jammer Battery Target Cycling Speed',200000000,8000,140000,1,1,400000000.0000,1,478,0),(27535,365,'Dread Guristas Control Tower','The Dread Guristas Control Tower is a special enhanced version of the Caldari control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Missile Battery Rate of Fire\r\r\n50% bonus to Missile Velocity\r\r\n-75% bonus to ECM Jammer Battery Target Cycling Speed',200000000,8000,140000,1,1,400000000.0000,1,478,0),(27536,365,'Serpentis Control Tower','The Serpentis Control Tower is an enhanced version of the Gallente control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n25% bonus to Hybrid Sentry Damage\r\n100% bonus to Silo Cargo Capacity',200000000,8000,140000,1,8,400000000.0000,1,478,0),(27538,365,'Shadow Control Tower','The Shadow Control Tower is a special enhanced version of the Gallente control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Hybrid Sentry Damage\r\r\n100% bonus to Silo Cargo Capacity',200000000,8000,140000,1,8,400000000.0000,1,478,0),(27539,365,'Angel Control Tower','The Angel Control Tower is an enhanced version of the Matari control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n50% bonus to Projectile Sentry Optimal Range\r\n50% bonus to Projectile Sentry Fall Off Range\r\n25% bonus to Projectile Sentry RoF',200000000,8000,140000,1,2,400000000.0000,1,478,0),(27540,365,'Domination Control Tower','The Domination Control Tower is a special enhanced version of the Matari control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Projectile Sentry Optimal Range\r\r\n50% bonus to Projectile Sentry Fall Off Range\r\r\n25% bonus to Projectile Sentry RoF',200000000,8000,140000,1,2,400000000.0000,1,478,0),(27542,449,'Serpentis Large Blaster Battery','Fires a barrage of extra large hybrid slugs at those the Control Tower deems its enemies. Only effective at fairly close ranges, but extremely deadly in terms of sheer damage output. ',100000000,5000,2400,1,NULL,10000000.0000,1,595,0),(27544,449,'Shadow Large Blaster Battery','Fires a barrage of extra large hybrid slugs at those the Control Tower deems its enemies. Only effective at fairly close ranges, but extremely deadly in terms of sheer damage output. ',100000000,5000,2400,1,NULL,10000000.0000,1,595,0),(27545,449,'Serpentis Large Railgun Battery','Fires a barrage of extra large hybrid slugs at those the Control Tower deems its enemies. Provides high damage output and is effective at long ranges.',100000000,5000,400,1,NULL,12500000.0000,1,595,0),(27547,449,'Shadow Large Railgun Battery','Fires a barrage of extra large hybrid slugs at those the Control Tower deems its enemies. Provides high damage output and is effective at long ranges.',100000000,5000,400,1,NULL,12500000.0000,1,595,0),(27548,430,'Blood Large Pulse Laser Battery','Fires a pulsed energy beam using extra large sized frequency crystals at those the Control Tower deems its enemies. Effective at fairly long ranges, tracks moderately fast and has a higher rate of fire than its beam laser counterpart. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,5000,2,1,NULL,10000000.0000,1,596,0),(27550,430,'Dark Blood Large Pulse Laser Battery','Fires a pulsed energy beam using extra large sized frequency crystals at those the Control Tower deems its enemies. Effective at fairly long ranges, tracks moderately fast and has a higher rate of fire than its beam laser counterpart. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,5000,2,1,NULL,10000000.0000,1,596,0),(27551,430,'Blood Large Beam Laser Battery','Fires a deep modulated energy beam using extra large sized frequency crystals at those the Control Tower deems its enemies. Effective at very long ranges, but tracks slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,5000,1,1,NULL,12500000.0000,1,596,0),(27553,430,'Dark Blood Large Beam Laser Battery','Fires a deep modulated energy beam using extra large sized frequency crystals at those the Control Tower deems its enemies. Effective at very long ranges, but tracks slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,5000,1,1,NULL,12500000.0000,1,596,0),(27554,426,'Angel Large AutoCannon Battery','Fires a barrage of extra large projectiles at those the Control Tower deems its enemies. Maintains a consistent spread of fire and is able to track the faster-moving targets, but lacks the sheer bludgeoning force of its artillery counterpart.',50000000,5000,2500,1,NULL,10000000.0000,1,594,0),(27556,426,'Domination Large AutoCannon Battery','Fires a barrage of extra large projectiles at those the Control Tower deems its enemies. Maintains a consistent spread of fire and is able to track the faster-moving targets, but lacks the sheer bludgeoning force of its artillery counterpart.',50000000,5000,2500,1,NULL,10000000.0000,1,594,0),(27557,426,'Angel Large Artillery Battery','Fires a barrage of extra large projectiles at those the Control Tower deems its enemies. Extremely effective at long-range bombardment and hits hard, but lacks the speed to track fast and up-close targets.   ',50000000,5000,165,1,NULL,12500000.0000,1,594,0),(27559,426,'Domination Large Artillery Battery','Fires a barrage of extra large projectiles at those the Control Tower deems its enemies. Extremely effective at long-range bombardment and hits hard, but lacks the speed to track fast and up-close targets.   ',50000000,5000,165,1,NULL,12500000.0000,1,594,0),(27560,417,'Guristas Citadel Torpedo Battery','A torpedo launcher capable of firing the most powerful type of torpedo ever invented. A volley of these deathbringers can make piecemeal of most anything that floats in space.',50000000,5000,4500,1,NULL,12500000.0000,1,479,0),(27562,417,'Dread Guristas Citadel Torpedo Battery','A torpedo launcher capable of firing the most powerful type of torpedo ever invented. A volley of these deathbringers can make piecemeal of most anything that floats in space.',50000000,5000,4500,1,NULL,12500000.0000,1,479,0),(27563,443,'Serpentis Warp Disruption Battery','Deployable warp jamming structure.',100000000,4000,0,1,NULL,5000000.0000,1,481,0),(27565,443,'Shadow Warp Disruption Battery','Deployable warp jamming structure.',100000000,4000,0,1,NULL,5000000.0000,1,481,0),(27567,443,'Serpentis Warp Scrambling Battery','Deployable warp jamming structure.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(27569,443,'Shadow Warp Scrambling Battery','Deployable warp jamming structure.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(27570,441,'Angel Stasis Webification Battery','The webifier\'s big brother. Designed to protect structures from fast-moving ships by making them into slow-moving ships.',100000000,4000,0,1,NULL,5000000.0000,1,481,0),(27573,441,'Domination Stasis Webification Battery','The webifier\'s big brother. Designed to protect structures from fast-moving ships by making them into slow-moving ships.',100000000,4000,0,1,NULL,5000000.0000,1,481,0),(27574,439,'Guristas Ion Field Projection Battery','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(27576,439,'Dread Guristas Ion Field Projection Battery','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(27577,439,'Guristas Phase Inversion Battery','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(27579,439,'Dread Guristas Phase Inversion Battery','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(27580,439,'Guristas Spatial Destabilization Battery','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(27582,439,'Dread Guristas Spatial Destabilization Battery','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(27583,439,'Guristas White Noise Generation Battery','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(27585,439,'Dread Guristas White Noise Generation Battery','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',100000000,4000,0,1,NULL,2500000.0000,1,481,0),(27589,365,'Blood Control Tower Medium','The Blood Control Tower is an enhanced version of the Amarr control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n50% bonus to Energy Sentry Optimal Range\r\n25% bonus to Energy Sentry Damage\r\n50% bonus to Silo Cargo Capacity',200000000,4000,70000,1,4,200000000.0000,1,478,0),(27591,365,'Dark Blood Control Tower Medium','The Dark Blood Control Tower is a special enhanced version of the Amarrian control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Energy Sentry Optimal Range\r\r\n25% bonus to Energy Sentry Damage\r\r\n50% bonus to Silo Cargo Capacity',200000000,4000,70000,1,4,200000000.0000,1,478,0),(27592,365,'Blood Control Tower Small','The Blood Control Tower is an enhanced version of the Amarr control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n50% bonus to Energy Sentry Optimal Range\r\n25% bonus to Energy Sentry Damage\r\n50% bonus to Silo Cargo Capacity',200000000,2000,35000,1,4,100000000.0000,1,478,0),(27594,365,'Dark Blood Control Tower Small','The Blood Control Tower is an enhanced version of the Amarr control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n50% bonus to Energy Sentry Optimal Range\r\n25% bonus to Energy Sentry Damage\r\n50% bonus to Silo Cargo Capacity',200000000,2000,35000,1,4,100000000.0000,1,478,0),(27595,365,'Guristas Control Tower Medium','The Guristas Control Tower is an enhanced version of the Caldari control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n25% bonus to Missile Battery Rate of Fire\r\n50% bonus to Missile Velocity\r\n-75% bonus to Electronic Warfare Battery Target Cycling Speed',200000000,4000,70000,1,1,200000000.0000,1,478,0),(27597,365,'Dread Guristas Control Tower Medium','The Dread Guristas Control Tower is a special enhanced version of the Caldari control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Missile Battery Rate of Fire\r\r\n50% bonus to Missile Velocity\r\r\n-75% bonus to Electronic Warfare Battery Target Cycling Speed',200000000,4000,70000,1,1,200000000.0000,1,478,0),(27598,365,'Guristas Control Tower Small','The Guristas Control Tower is an enhanced version of the Caldari control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n25% bonus to Missile Battery Rate of Fire\r\n50% bonus to Missile Velocity\r\n-75% bonus to Electronic Warfare Battery Target Cycling Speed',200000000,2000,35000,1,1,100000000.0000,1,478,0),(27600,365,'Dread Guristas Control Tower Small','The Dread Guristas Control Tower is a special enhanced version of the Caldari control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Missile Battery Rate of Fire\r\r\n50% bonus to Missile Velocity\r\r\n-75% bonus to Electronic Warfare Battery Target Cycling Speed',200000000,2000,35000,1,1,100000000.0000,1,478,0),(27601,365,'Serpentis Control Tower Medium','The Serpentis Control Tower is an enhanced version of the Gallente control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\n\r\nRacial Bonuses:\r\n25% bonus to Hybrid Sentry Damage\r\n100% bonus to Silo Cargo Capacity',200000000,4000,70000,1,8,200000000.0000,1,478,0),(27603,365,'Shadow Control Tower Medium','The Shadow Control Tower is a special enhanced version of the Gallente control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Hybrid Sentry Damage\r\r\n100% bonus to Silo Cargo Capacity',200000000,4000,70000,1,8,200000000.0000,1,478,0),(27604,365,'Serpentis Control Tower Small','The Serpentis Control Tower is an enhanced version of the Gallente control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n25% bonus to Hybrid Sentry Damage\r\n100% bonus to Silo Cargo Capacity',200000000,2000,35000,1,8,100000000.0000,1,478,0),(27606,365,'Shadow Control Tower Small','The Shadow Control Tower is a special enhanced version of the Gallente control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n25% bonus to Hybrid Sentry Damage\r\r\n100% bonus to Silo Cargo Capacity',200000000,2000,35000,1,8,100000000.0000,1,478,0),(27607,365,'Angel Control Tower Medium','The Angel Control Tower is an enhanced version of the Matari control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n50% bonus to Projectile Sentry Optimal Range\r\n50% bonus to Projectile Sentry Fall Off Range\r\n25% bonus to Projectile Sentry RoF',200000000,4000,70000,1,2,200000000.0000,1,478,0),(27609,365,'Domination Control Tower Medium','The Domination Control Tower is a special enhanced version of the Matari control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Projectile Sentry Optimal Range\r\r\n50% bonus to Projectile Sentry Fall Off Range\r\r\n25% bonus to Projectile Sentry RoF',200000000,4000,70000,1,2,200000000.0000,1,478,0),(27610,365,'Angel Control Tower Small','The Angel Control Tower is an enhanced version of the Matari control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n50% bonus to Projectile Sentry Optimal Range\r\n50% bonus to Projectile Sentry Fall Off Range\r\n25% bonus to Projectile Sentry RoF',200000000,2000,35000,1,2,100000000.0000,1,478,0),(27612,365,'Domination Control Tower Small','The Domination Control Tower is a special enhanced version of the Matari control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Projectile Sentry Optimal Range\r\r\n50% bonus to Projectile Sentry Fall Off Range\r\r\n25% bonus to Projectile Sentry RoF',200000000,2000,35000,1,2,100000000.0000,1,478,0),(27613,449,'Serpentis Medium Blaster Battery','Fires a barrage of large hybrid slugs at those the Control Tower deems its enemies. Only effective at fairly close ranges, but very deadly in terms of sheer damage output. ',100000000,1000,960,1,8,2000000.0000,1,595,0),(27615,449,'Shadow Medium Blaster Battery','Fires a barrage of large hybrid slugs at those the Control Tower deems its enemies. Only effective at fairly close ranges, but very deadly in terms of sheer damage output. ',100000000,1000,960,1,8,2000000.0000,1,595,0),(27616,449,'Serpentis Medium Railgun Battery','Fires a barrage of large hybrid slugs at those the Control Tower deems its enemies. Provides high damage output and is effective at long ranges.',100000000,1000,160,1,1,2500000.0000,1,595,0),(27618,449,'Shadow Medium Railgun Battery','Fires a barrage of large hybrid slugs at those the Control Tower deems its enemies. Provides high damage output and is effective at long ranges.',100000000,1000,160,1,1,2500000.0000,1,595,0),(27619,449,'Serpentis Small Blaster Battery','Fires a barrage of medium hybrid slugs at those the Control Tower deems its enemies. Only effective at fairly close ranges, but deadly in terms of sheer damage output. ',100000000,500,720,1,8,400000.0000,1,595,0),(27621,449,'Shadow Small Blaster Battery','Fires a barrage of medium hybrid slugs at those the Control Tower deems its enemies. Only effective at fairly close ranges, but deadly in terms of sheer damage output. ',100000000,500,720,1,8,400000.0000,1,595,0),(27622,449,'Serpentis Small Railgun Battery','Fires a barrage of medium hybrid slugs at those the Control Tower deems its enemies. Provides high damage output and is effective at long ranges.',100000000,500,120,1,1,500000.0000,1,595,0),(27624,449,'Shadow Small Railgun Battery','Fires a barrage of medium hybrid slugs at those the Control Tower deems its enemies. Provides high damage output and is effective at long ranges.',100000000,500,120,1,1,500000.0000,1,595,0),(27625,430,'Blood Medium Beam Laser Battery','Fires a deep modulated energy beam using large sized frequency crystals at those the Control Tower deems its enemies. Effective at long ranges, but tracks relatively slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,1000,2,1,4,2500000.0000,1,596,0),(27627,430,'Dark Blood Medium Beam Laser Battery','Fires a deep modulated energy beam using large sized frequency crystals at those the Control Tower deems its enemies. Effective at long ranges, but tracks relatively slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,1000,2,1,4,2500000.0000,1,596,0),(27628,430,'Blood Medium Pulse Laser Battery','Fires a pulsed energy beam using large sized frequency crystals at those the Control Tower deems its enemies. Effective at fairly long ranges, tracks fast and has a higher rate of fire than its beam laser counterpart. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,1000,4,1,4,2000000.0000,1,596,0),(27630,430,'Dark Blood Medium Pulse Laser Battery','Fires a pulsed energy beam using large sized frequency crystals at those the Control Tower deems its enemies. Effective at fairly long ranges, tracks fast and has a higher rate of fire than its beam laser counterpart. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,1000,4,1,4,2000000.0000,1,596,0),(27631,430,'Blood Small Beam Laser Battery','Fires a deep modulated energy beam using medium sized frequency crystals at those the Control Tower deems its enemies. Effective at relatively long ranges, but tracks fairly slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,500,3,1,4,500000.0000,1,596,0),(27633,430,'Dark Blood Small Beam Laser Battery','Fires a deep modulated energy beam using medium sized frequency crystals at those the Control Tower deems its enemies. Effective at relatively long ranges, but tracks fairly slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,500,3,1,4,500000.0000,1,596,0),(27634,430,'Blood Small Pulse Laser Battery','Fires a pulsed energy beam using medium sized frequency crystals at those the Control Tower deems its enemies. Effective only at relatively short range, but tracks very fast and has a higher rate of fire than any other laser battery. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,500,6,1,4,400000.0000,1,596,0),(27636,430,'Dark Blood Small Pulse Laser Battery','Fires a pulsed energy beam using medium sized frequency crystals at those the Control Tower deems its enemies. Effective only at relatively short range, but tracks very fast and has a higher rate of fire than any other laser battery. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,500,6,1,4,400000.0000,1,596,0),(27638,417,'Guristas Cruise Missile Battery','A launcher array designed to fit cruise missiles. Fires at those the Control Tower deems its enemies.\r\r\n',50000000,500,3500,1,NULL,500000.0000,1,479,0),(27640,417,'Dread Guristas Cruise Missile Battery','A launcher array designed to fit cruise missiles. Fires at those the Control Tower deems its enemies.\r\r\n',50000000,500,3500,1,NULL,500000.0000,1,479,0),(27641,417,'Guristas Torpedo Battery','A launcher array designed to fit torpedos. Fires at those the Control Tower deems its enemies.\r\r\n',50000000,1000,4500,1,NULL,2500000.0000,1,479,0),(27643,417,'Dread Guristas Torpedo Battery','A launcher array designed to fit torpedos. Fires at those the Control Tower deems its enemies.\r\r\n',50000000,1000,4500,1,NULL,2500000.0000,1,479,0),(27644,426,'Angel Medium Artillery Battery','Fires a barrage of large projectiles at those the Control Tower deems its enemies. Very effective at long-range bombardment and packs a punch, but lacks the speed to track fast and up-close targets effectively. ',50000000,1000,65,1,2,2500000.0000,1,594,0),(27646,426,'Domination Medium Artillery Battery','Fires a barrage of large projectiles at those the Control Tower deems its enemies. Very effective at long-range bombardment and packs a punch, but lacks the speed to track fast and up-close targets effectively. ',50000000,1000,65,1,2,2500000.0000,1,594,0),(27647,426,'Angel Medium AutoCannon Battery','Fires a barrage of large projectiles at those the Control Tower deems its enemies. Maintains a consistent spread of fire and is able to track fast-moving targets, but lacks some of the power of its artillery counterpart.',50000000,1000,1000,1,2,2000000.0000,1,594,0),(27649,426,'Domination Medium AutoCannon Battery','Fires a barrage of large projectiles at those the Control Tower deems its enemies. Maintains a consistent spread of fire and is able to track fast-moving targets, but lacks some of the power of its artillery counterpart.',50000000,1000,1000,1,2,2000000.0000,1,594,0),(27650,426,'Angel Small Artillery Battery','Fires a barrage of medium projectiles at those the Control Tower deems its enemies. Effective at long-range bombardment and can do some damage, but lacks the speed to track the fastest targets.',50000000,500,50,1,2,500000.0000,1,594,0),(27652,426,'Domination Small Artillery Battery','Fires a barrage of medium projectiles at those the Control Tower deems its enemies. Effective at long-range bombardment and can do some damage, but lacks the speed to track the fastest targets.',50000000,500,50,1,2,500000.0000,1,594,0),(27653,426,'Angel Small AutoCannon Battery','Fires a barrage of medium projectiles at those the Control Tower deems its enemies. Maintains a very rapid spread of fire and is able to track the fastest targets at close ranges, but lacks some of the punch evidenced by its artillery counterpart.',50000000,500,750,1,2,400000.0000,1,594,0),(27655,426,'Domination Small AutoCannon Battery','Fires a barrage of medium projectiles at those the Control Tower deems its enemies. Maintains a very rapid spread of fire and is able to track the fastest targets at close ranges, but lacks some of the punch evidenced by its artillery counterpart.',50000000,500,750,1,2,400000.0000,1,594,0),(27656,835,'Foundation Upgrade Platform','The Foundation upgrade platform is the first level of available upgrade platforms for deep-space outposts. It allows for the installation of 1 Tier 1 outpost improvement.',0,750000,7500000,1,NULL,2000000000.0000,1,1027,0),(27657,535,'Foundation Upgrade Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27658,835,'Pedestal Upgrade Platform','The Pedestal upgrade platform is the second level of available upgrade platforms for deep-space outposts. It allows for the installation of 1 Tier 1 improvement and 1 Tier 2 improvement.\r\r\n\r\r\nNote: A Foundation outpost upgrade is a prerequisite for the installation of the Pedestal upgrade.',0,750000,7500000,1,NULL,4000000000.0000,1,1027,0),(27659,535,'Pedestal Upgrade Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27660,835,'Monument Upgrade Platform','The Monument upgrade platform is the third and highest level of available upgrade platforms for deep-space outposts. It allows for the installation of 1 Tier 1 improvement, 1 Tier 2 improvement and 1 Tier 3 improvement.\r\r\n\r\r\nNote: The Foundation and Pedestal outpost upgrades are prerequisites for the installation of the Monument upgrade.',0,750000,7500000,1,NULL,8000000000.0000,1,1027,0),(27661,535,'Monument Upgrade Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27662,836,'Amarr Basic Outpost Factory Platform','A basic upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech I ships to 40%.',0,750000,7500000,1,4,500000000.0000,1,1866,0),(27663,535,'Amarr Basic Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27664,836,'Amarr Advanced Outpost Factory Platform','An advanced upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech I ships to 60%.',0,750000,7500000,1,4,2000000000.0000,1,1866,0),(27665,535,'Amarr Advanced Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27666,836,'Amarr Outpost Factory Platform','An intermediate upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech I ships to 50%.',0,750000,7500000,1,4,1000000000.0000,1,1866,0),(27667,535,'Amarr Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27668,383,'Amarr Energy Neutralizer Sentry I','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27669,383,'Amarr Energy Neutralizer Sentry II','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27670,383,'Amarr Energy Neutralizer Sentry III','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27672,837,'Energy Neutralizing Battery','Like an Energy Neutralizer only bigger and nastier.',100000000,4000,0,1,NULL,5000000.0000,1,1009,0),(27673,838,'Cynosural Generator Array','Stationary Cynosural Generator, for rapid relocation of jump-capable vessels.',100000000,4000,0,1,NULL,20000000.0000,1,1013,0),(27674,839,'Cynosural System Jammer','Creates a system-wide inhibitor field which prevents cynosural generators except covert cynosural generators from functioning.  ',100000000,4000,0,1,NULL,8000000.0000,1,1012,0),(27675,709,'System Scanning Array','Recent necessary changes to various capsuleer protocols have rendered these structures non-functional and obsolete.\r\r\n\r\r\nThe empire corporations who originally sold this structure have reached a deal with CONCORD to buy back all remaining examples.\r\r\n\r\r\nCBD Corporation, Ducia Foundry, Material Acquisition, Minmatar Mining Corporation and Outer Ring Excavations are all now buying these structures at prices similar to the original retail price.',100000000,4000,0,1,NULL,2500000.0000,1,1010,0),(27676,840,'Structure Repair Array','Used to repair structures under attack',200000000,4000,20000,1,NULL,2819328.0000,0,NULL,0),(27677,841,'Angel Control Tower Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27678,842,'Remote ECM Burst I','Emits an area-of-effect electronic burst, centered on the designated target, which has a chance to momentarily disrupt the target locks of any ship within range, including ships normally immune to all forms of electronic warfare.\r\r\n\r\r\nNote: Only Supercarriers can fit modules of this type. Only one module of this type can be fit per Supercarrier.',5000,4000,0,1,NULL,72505546.0000,1,678,0),(27679,160,'Remote ECM Burst I Blueprint',' ',0,0.01,0,1,NULL,51000000.0000,1,1568,0),(27680,841,'Angel Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27681,841,'Angel Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27682,841,'Blood Control Tower Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27684,841,'Blood Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27685,841,'Blood Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27688,841,'Dark Blood Control Tower Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27689,841,'Dark Blood Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27690,841,'Dark Blood Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27694,841,'Domination Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27695,841,'Domination Control Tower Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27696,841,'Domination Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27697,841,'Guristas Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27698,841,'Guristas Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27699,841,'Guristas Control Tower Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27703,841,'Dread Guristas Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27704,841,'Dread Guristas Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27705,841,'Dread Guristas Control Tower Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27706,841,'Serpentis Control Tower Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27707,841,'Serpentis Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27708,841,'Serpentis Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27712,841,'Shadow Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27713,841,'Shadow Control Tower Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27714,841,'Shadow Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27717,865,'Imperial Redeemer','Mounting border tensions have prompted the Empire to begin deployment of Archon-class carriers. These vessels have been tasked with both resupplying the frontlines as well as patrolling the borders using their Fighter units.',1012500000,13950000,3300,1,4,0.0000,0,NULL,0),(27719,866,'State Izanaki','Mounting border tensions have prompted the State to begin deployment of Chimera-class carriers. These vessels have been tasked with both resupplying the frontlines as well as patrolling the borders using their Fighter units.',1080000000,11925000,3475,1,1,0.0000,0,NULL,0),(27720,867,'Federation Themis','Mounting border tensions have prompted the Federation to begin deployment of Thanatos-class carriers. These vessels have been tasked with both resupplying the frontlines as well as patrolling the borders using their Fighter units.',1057500000,13095000,3500,1,8,0.0000,0,NULL,0),(27721,868,'Republic Harkal','Mounting border tensions have prompted the Republic to begin deployment of Nidhoggur-class carriers. These vessels have been tasked with both resupplying the frontlines as well as patrolling the borders using their Fighter units.',922500000,11250000,3375,1,2,0.0000,0,NULL,0),(27722,844,'Sentient Alvus Queen','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(27723,844,'Sentient Alvus Controller','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(27724,844,'Sentient Alvus Creator','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(27725,844,'Sentient Alvus Ruler','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(27726,844,'Sentient Domination Alvus','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(27727,844,'Sentient Matriarch Alvus','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(27728,844,'Sentient Patriarch Alvus','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(27729,844,'Sentient Spearhead Alvus','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(27730,844,'Sentient Supreme Alvus Parasite','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(27731,844,'Sentient Swarm Preserver Alvus','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(27732,843,'Sentient Crippler Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27733,843,'Sentient Defeater Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27734,843,'Sentient Enforcer Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27735,843,'Sentient Exterminator Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27736,843,'Sentient Siege Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27737,843,'Sentient Striker Alvatis','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very high',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27738,845,'Sentient Annihilator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27739,845,'Sentient Atomizer Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27740,845,'Sentient Bomber Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27741,845,'Sentient Destructor Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27742,845,'Sentient Devastator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27743,845,'Sentient Disintegrator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27744,845,'Sentient Nuker Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27745,845,'Sentient Violator Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27746,845,'Sentient Viral Infector Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Extreme',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27747,845,'Sentient Wrecker Alvum','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Significant',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27748,846,'Sentient Dismantler Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27749,846,'Sentient Marauder Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27750,846,'Sentient Predator Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27751,846,'Sentient Ripper Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27752,846,'Sentient Shatter Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27753,846,'Sentient Shredder Alvior','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27754,847,'Sentient Barracuda Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27755,847,'Sentient Decimator Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27756,847,'Sentient Devilfish Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27757,847,'Sentient Hunter Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27758,847,'Sentient Infester Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27759,847,'Sentient Raider Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27760,847,'Sentient Render Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27761,847,'Sentient Silverfish Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Moderate',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27762,847,'Sentient Splinter Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Very low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27763,847,'Sentient Sunder Alvi','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Low',100000,60,1200,1,NULL,0.0000,0,NULL,0),(27765,383,'TEST ICON Amarr Carrier','A powerful Archon-class carrier of the Amarr Empire. Threat level: OMGWTFH4X!\r\r\n',1012500000,13950000,3300,1,4,0.0000,0,NULL,0),(27766,430,'Sansha Large Beam Laser Battery','Fires a deep modulated energy beam using extra large sized frequency crystals at those the Control Tower deems its enemies. Effective at very long ranges, but tracks slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,5000,1,1,NULL,12500000.0000,1,596,0),(27767,430,'Sansha Large Pulse Laser Battery','Fires a pulsed energy beam using extra large sized frequency crystals at those the Control Tower deems its enemies. Effective at fairly long ranges, tracks moderately fast and has a higher rate of fire than its beam laser counterpart. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,5000,2,1,NULL,10000000.0000,1,596,0),(27768,430,'Sansha Medium Beam Laser Battery','Fires a deep modulated energy beam using large sized frequency crystals at those the Control Tower deems its enemies. Effective at long ranges, but tracks relatively slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,1000,2,1,4,2500000.0000,1,596,0),(27769,430,'Sansha Medium Pulse Laser Battery','Fires a pulsed energy beam using large sized frequency crystals at those the Control Tower deems its enemies. Effective at fairly long ranges, tracks fast and has a higher rate of fire than its beam laser counterpart. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,1000,4,1,4,2000000.0000,1,596,0),(27770,430,'Sansha Small Beam Laser Battery','Fires a deep modulated energy beam using medium sized frequency crystals at those the Control Tower deems its enemies. Effective at relatively long ranges, but tracks fairly slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,500,3,1,4,500000.0000,1,596,0),(27771,430,'Sansha Small Pulse Laser Battery','Fires a pulsed energy beam using medium sized frequency crystals at those the Control Tower deems its enemies. Effective only at relatively short range, but tracks very fast and has a higher rate of fire than any other laser battery. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,500,6,1,4,400000.0000,1,596,0),(27772,430,'True Sansha Large Beam Laser Battery','Fires a deep modulated energy beam using extra large sized frequency crystals at those the Control Tower deems its enemies. Effective at very long ranges, but tracks slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,5000,1,1,NULL,12500000.0000,1,596,0),(27773,430,'True Sansha Large Pulse Laser Battery','Fires a pulsed energy beam using extra large sized frequency crystals at those the Control Tower deems its enemies. Effective at fairly long ranges, tracks moderately fast and has a higher rate of fire than its beam laser counterpart. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,5000,2,1,NULL,10000000.0000,1,596,0),(27774,430,'True Sansha Medium Beam Laser Battery','Fires a deep modulated energy beam using large sized frequency crystals at those the Control Tower deems its enemies. Effective at long ranges, but tracks relatively slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,1000,2,1,4,2500000.0000,1,596,0),(27775,430,'True Sansha Medium Pulse Laser Battery','Fires a pulsed energy beam using large sized frequency crystals at those the Control Tower deems its enemies. Effective at fairly long ranges, tracks fast and has a higher rate of fire than its beam laser counterpart. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,1000,4,1,4,2000000.0000,1,596,0),(27776,430,'True Sansha Small Beam Laser Battery','Fires a deep modulated energy beam using medium sized frequency crystals at those the Control Tower deems its enemies. Effective at relatively long ranges, but tracks fairly slowly and has a low rate of fire. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,500,3,1,4,500000.0000,1,596,0),(27777,430,'True Sansha Small Pulse Laser Battery','Fires a pulsed energy beam using medium sized frequency crystals at those the Control Tower deems its enemies. Effective only at relatively short range, but tracks very fast and has a higher rate of fire than any other laser battery. Note: Placing a new type of crystal into the crystal compartment will result in the destruction of the crystal being replaced.',100000000,500,6,1,4,400000.0000,1,596,0),(27778,440,'Serpentis Sensor Dampening Battery','Deployable structure that cycle dampens enemy sensors.',100000000,4000,0,1,NULL,1250000.0000,1,481,0),(27779,440,'Shadow Sensor Dampening Battery','Deployable structure that cycle dampens enemy sensors.',100000000,4000,0,1,NULL,1250000.0000,1,481,0),(27780,365,'Sansha Control Tower','The Sansha Control Tower is an enhanced version of the Amarr control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n50% bonus to Energy Sentry Optimal Range\r\n25% bonus to Energy Sentry Damage\r\n50% bonus to Silo Cargo Capacity',200000000,8000,140000,1,4,400000000.0000,1,478,0),(27781,841,'Sansha Control Tower Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27782,365,'Sansha Control Tower Medium','The Sanshas Control Tower is an enhanced version of the Amarr control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n50% bonus to Energy Sentry Optimal Range\r\n25% bonus to Energy Sentry Damage\r\n50% bonus to Silo Cargo Capacity',200000000,4000,70000,1,4,200000000.0000,1,478,0),(27783,841,'Sansha Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27784,365,'Sansha Control Tower Small','The Sanshas Control Tower is an enhanced version of the Amarr control tower utilizing the latest frontier design techniques to increase its defenses and efficiency.\r\n\r\nRacial Bonuses:\r\n50% bonus to Energy Sentry Optimal Range\r\n25% bonus to Energy Sentry Damage\r\n50% bonus to Silo Cargo Capacity',200000000,2000,35000,1,4,100000000.0000,1,478,0),(27785,841,'Sansha Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27786,365,'True Sansha Control Tower','The True Sansha Control Tower is a special enhanced version of the Amarrian control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Energy Sentry Optimal Range\r\r\n25% bonus to Energy Sentry Damage\r\r\n50% bonus to Silo Cargo Capacity',200000000,8000,140000,1,4,400000000.0000,1,478,0),(27787,841,'True Sansha Control Tower Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27788,365,'True Sansha Control Tower Medium','The True Sansha Control Tower is a special enhanced version of the Amarrian control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Energy Sentry Optimal Range\r\r\n25% bonus to Energy Sentry Damage\r\r\n50% bonus to Silo Cargo Capacity',200000000,4000,70000,1,4,200000000.0000,1,478,0),(27789,841,'True Sansha Control Tower Medium Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27790,365,'True Sansha Control Tower Small','The True Sansha Control Tower is a special enhanced version of the Amarrian control tower utilizing the latest in cutting edge design techniques.\r\r\n\r\r\nRacial Bonuses:\r\r\n50% bonus to Energy Sentry Optimal Range\r\r\n25% bonus to Energy Sentry Damage\r\r\n50% bonus to Silo Cargo Capacity',200000000,2000,35000,1,4,100000000.0000,1,478,0),(27791,841,'True Sansha Control Tower Small Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27792,383,'Caldari Energy Neutralizer Sentry I','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27793,383,'Caldari Energy Neutralizer Sentry II','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27794,383,'Caldari Energy Neutralizer Sentry III','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27795,383,'Gallente Energy Neutralizer Sentry I','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27796,383,'Gallente Energy Neutralizer Sentry II','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27797,383,'Gallente Energy Neutralizer Sentry III','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27798,383,'Minmatar Energy Neutralizer Sentry I','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27799,383,'Minmatar Energy Neutralizer Sentry II','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27800,383,'Minmatar Energy Neutralizer Sentry III','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27801,185,'Petty Thief','This is an outlaw vessel that thrives by preying on the weak and unwary. Threat level: Very low',2112000,21120,100,1,2,0.0000,0,NULL,0),(27802,306,'Mission Hacking Can','If you have the right equipment you might be able to hack into the databank and get some valuable information.\r\r\nRequires Hacking module.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(27803,314,'Massive Sealed Cargo Containers','These colossal containers are fitted with a password-protected security lock.',20000,2000,0,1,NULL,100.0000,1,NULL,0),(27804,306,'Mission Hacking Can 1','If you have the right equipment you might be able to hack into the databank and get some valuable information.\r\r\nRequires Hacking module.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(27807,853,'Sansha Large Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27808,853,'Sansha Large Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27809,853,'Sansha Medium Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27810,853,'Sansha Medium Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27811,853,'Sansha Small Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27812,853,'Sansha Small Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27813,853,'True Sansha Small Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27814,853,'True Sansha Small Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27815,853,'True Sansha Medium Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27816,853,'True Sansha Medium Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27817,853,'True Sansha Large Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27818,853,'True Sansha Large Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27819,853,'Blood Large Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27820,853,'Blood Large Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27821,853,'Blood Medium Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27822,853,'Blood Medium Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27823,853,'Blood Small Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27824,853,'Blood Small Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27825,853,'Dark Blood Large Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27826,853,'Dark Blood Large Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27827,853,'Dark Blood Medium Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27828,853,'Dark Blood Medium Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27829,853,'Dark Blood Small Beam Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27830,853,'Dark Blood Small Pulse Laser Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27831,854,'Angel Large Artillery Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27832,854,'Angel Large Autocannon Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27833,854,'Angel Medium Autocannon Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27834,854,'Angel Small Autocannon Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27835,854,'Angel Medium Artillery Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27836,854,'Angel Small Artillery Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27837,854,'Domination Small Artillery Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27838,854,'Domination Medium Artillery Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27839,854,'Domination Large Artillery Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27840,854,'Domination Large Autocannon Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27841,854,'Domination Medium Autocannon Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27842,854,'Domination Small Autocannon Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27843,855,'Serpentis Large Railgun Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27844,855,'Serpentis Medium Railgun Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27845,855,'Serpentis Small Railgun Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27846,855,'Serpentis Small Blaster Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27847,855,'Serpentis Medium Blaster Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27848,855,'Serpentis Large Blaster Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27849,855,'Shadow Large Blaster Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27850,855,'Shadow Large Railgun Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27851,855,'Shadow Medium Railgun Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27852,855,'Shadow Medium Blaster Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27853,855,'Shadow Small Blaster Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27854,855,'Shadow Small Railgun Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27855,837,'Sansha Energy Neutralizing Battery','An enhanced version of the Imperial Navy Energy Neutralizing Array.',100000000,4000,0,1,NULL,5000000.0000,1,1009,0),(27856,837,'True Sansha Energy Neutralizing Battery','An enhanced version of the Imperial Navy Energy Neutralizing Array.',100000000,4000,0,1,NULL,5000000.0000,1,1009,0),(27857,837,'Blood Energy Neutralizing Battery','An enhanced version of the Imperial Navy Energy Neutralizing Array.',100000000,4000,0,1,NULL,5000000.0000,1,1009,0),(27858,837,'Dark Blood Energy Neutralizing Battery','An enhanced version of the Imperial Navy Energy Neutralizing Array.',100000000,4000,0,1,NULL,5000000.0000,1,1009,0),(27859,856,'Guristas Ion Field Projection Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27860,856,'Guristas White Noise Generation Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27861,856,'Guristas Spatial Destabilization Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27862,856,'Guristas Phase Inversion Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27863,856,'Dread Guristas Phase Inversion Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27864,856,'Dread Guristas Ion Field Projection Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27865,856,'Dread Guristas Spatial Destabilization Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27866,856,'Dread Guristas White Noise Generation Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27867,857,'Serpentis Warp Scrambling Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27868,857,'Serpentis Warp Disruption Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27869,857,'Shadow Warp Disruption Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27870,857,'Shadow Warp Scrambling Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27871,858,'Angel Stasis Webification Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27872,858,'Domination Stasis Webification Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27873,859,'Serpentis Sensor Dampening Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27874,859,'Shadow Sensor Dampening Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27875,860,'Blood Energy Neutralizing Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27876,860,'Dark Blood Energy Neutralizing Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27877,860,'Sansha Energy Neutralizing Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27878,860,'True Sansha Energy Neutralizing Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27879,319,'Gallente Station 150k','Docking has been prohibited into this station without proper authorization.',0,0,0,1,8,0.0000,0,NULL,0),(27880,319,'Minmatar Station 150k','Docking has been prohibited into this station without proper authorization.',0,0,0,1,2,0.0000,0,NULL,0),(27881,319,'Caldari Station 150k','Docking has been prohibited into this station without proper authorization.',0,0,0,1,1,0.0000,0,NULL,0),(27882,319,'Amarr Station 150k','Docking has been prohibited into this station without proper authorization.',0,0,0,1,4,0.0000,0,NULL,0),(27883,387,'Sansha Mjolnir Rocket','A small rocket with an EMP warhead. ',100,0.005,0,100,NULL,350.0000,0,NULL,0),(27884,387,'True Sansha Mjolnir Rocket','A small rocket with an EMP warhead. ',100,0.005,0,100,NULL,350.0000,0,NULL,0),(27885,384,'Sansha Sabretooth Light Missile','Light assault missile. An advanced missile with a volatile payload of magnetized plasma, the Sabretooth is a multi-purpose missile specifically engineered to take down shield systems.',700,0.015,0,100,NULL,750.0000,0,NULL,0),(27886,384,'True Sansha Sabretooth Light Missile','Light assault missile. An advanced missile with a volatile payload of magnetized plasma, the Sabretooth is a multi-purpose missile specifically engineered to take down shield systems.',700,0.015,0,100,NULL,750.0000,0,NULL,0),(27887,772,'Sansha Mjolnir Assault Missile','An EMP warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,3500.0000,0,NULL,0),(27888,772,'True Sansha Mjolnir Heavy Assault Missile','An EMP warhead designed for use with heavy assault launchers. Heavy assault missiles can be fired at a greater rate than heavy missiles, at the expense of effective range.',1000,0.015,0,100,NULL,3500.0000,0,NULL,0),(27889,385,'Sansha Thunderbolt Heavy Missile','Recently introduced by the armaments lab of the Wiyrkomi Corporation, the Thunderbolt is a solid investment with a large payload and steady performance.',1000,0.03,0,100,NULL,3500.0000,0,NULL,0),(27890,385,'True Sansha Thunderbolt Heavy Missile','Recently introduced by the armaments lab of the Wiyrkomi Corporation, the Thunderbolt is a solid investment with a large payload and steady performance.',1000,0.03,0,100,NULL,3500.0000,0,NULL,0),(27891,89,'Sansha Mjolnir Torpedo','An ultra-heavy EMP missile. Slow and dumb but its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,35000.0000,0,NULL,0),(27892,89,'True Sansha Mjolnir Torpedo','An ultra-heavy EMP missile. Slow and dumb but its sheer damage potential is simply staggering.',1500,0.1,0,100,NULL,35000.0000,0,NULL,0),(27893,386,'Sansha Paradise Cruise Missile','Extra heavy assault missile. The mother of all missiles, the Paradise delivers a tremendous payload, guaranteed to get its victims acquainted with their personal god in a quick, but painful manner.',1250,0.05,0,100,NULL,15000.0000,0,NULL,0),(27894,386,'True Sansha Paradise Cruise Missile','Extra heavy assault missile. The mother of all missiles, the Paradise delivers a tremendous payload, guaranteed to get its victims acquainted with their personal god in a quick, but painful manner.',1250,0.05,0,100,NULL,15000.0000,0,NULL,0),(27897,707,'Jump Bridge','Jump Bridges allow corporations to link two Starbases in nearby systems and establish an artificial jump corridor, granting instantaneous transit capability between the two.\r\r\n\r\r\nJump Bridges have a defined maximum range and cannot link to other Bridges outside this range. It is recommended that corporations check that their intended anchoring locations are in range of each other before purchasing the necessary structures.',25000000,100000,60000,1,NULL,100000000.0000,1,1011,0),(27898,861,'Imperial Fighter','These ships are detached from nearby Carrier-class ships. Their small size and manoeuvrability, combined with state-of-the-art weaponry make them a threat to even the biggest of ships.',12000,5000,1200,1,4,0.0000,0,NULL,0),(27899,861,'State Fighter','These ships are detached from nearby Carrier-class ships. Their small size and manoeuvrability, combined with state-of-the-art weaponry make them a threat to even the biggest of ships.',12000,5000,1200,1,1,0.0000,0,NULL,0),(27900,861,'Federation Fighter','These ships are detached from nearby Carrier-class ships. Their small size and manoeuvrability, combined with state-of-the-art weaponry make them a threat to even the biggest of ships.',12000,5000,1200,1,8,0.0000,0,NULL,0),(27901,861,'Republic Fighter','These ships are detached from nearby Carrier-class ships. Their small size and manoeuvrability, combined with state-of-the-art weaponry make them a threat to even the biggest of ships.',12000,5000,1200,1,2,0.0000,0,NULL,0),(27902,1210,'Remote Hull Repair Systems','Operation of remote hull repair systems. 5% reduced capacitor need for remote hull repair system modules per skill level.',0,0.01,0,1,NULL,100000.0000,1,1745,0),(27904,585,'Large Remote Hull Repairer I','This module uses nano-assemblers to repair damage done to the hull of the Target ship.',20,50,0,1,NULL,50046.0000,1,1062,0),(27905,870,'Large Remote Hull Repairer I Blueprint',' ',0,0.01,0,1,NULL,3000000.0000,1,1538,0),(27906,272,'Tactical Logistics Reconfiguration','Skill at the operation of triage modules. 25-unit reduction in strontium clathrate consumption amount for module activation per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,25000000.0000,1,367,0),(27911,272,'Projected Electronic Counter Measures','Operation of projected ECM jamming systems. Each skill level gives a 5% reduction in module activation time. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,12000000.0000,1,367,0),(27912,90,'Concussion Bomb','Radiates an omnidirectional pulse upon detonation that causes kinetic damage to surrounding vessels. The bomb employs an advanced armor hardening system which makes it highly resistant to kinetic damage, thus enabling delivery of multiple bombs to a given target area.',1000,75,0,20,NULL,27096088.0000,1,1015,0),(27913,172,'Concussion Bomb Blueprint',' ',1,0.01,0,1,NULL,200000000.0000,1,1016,0),(27914,862,'Bomb Launcher I','A missile launcher bay module facilitating bomb preparation, and deployment. \r\r\n\r\r\nBomb Launchers can only be equipped by Stealth Bombers and each bomber can only equip one bomb launcher. \r\r\n',0,50,150,1,NULL,3434260.0000,1,1014,0),(27915,136,'Bomb Launcher I Blueprint',' ',0,0.01,0,1,NULL,19000000.0000,1,1019,0),(27916,90,'Scorch Bomb','Radiates an omnidirectional pulse upon detonation that causes thermal damage to surrounding vessels. The bomb employs an advanced armor hardening system which makes it highly resistant to thermal damage, thus enabling delivery of multiple bombs to a given target area.',1000,75,0,20,NULL,26624614.0000,1,1015,0),(27917,172,'Scorch Bomb Blueprint',' ',1,0.01,0,1,NULL,200000000.0000,1,1016,0),(27918,90,'Shrapnel Bomb','Radiates an omnidirectional pulse upon detonation that causes explosive damage to surrounding vessels. The bomb employs an advanced armor hardening system which makes it highly resistant to explosive damage, thus enabling delivery of multiple bombs to a given target area.',1000,75,0,20,NULL,26987744.0000,1,1015,0),(27919,172,'Shrapnel Bomb Blueprint',' ',1,0.01,0,1,NULL,200000000.0000,1,1016,0),(27920,90,'Electron Bomb','Radiates an omnidirectional pulse upon detonation that causes EM damage to surrounding vessels. The bomb employs an advanced armor hardening system which makes it highly resistant to EM damage, thus enabling delivery of multiple bombs to a given target area.',1000,75,0,20,NULL,26236342.0000,1,1015,0),(27921,172,'Electron Bomb Blueprint',' ',1,0.01,0,1,NULL,200000000.0000,1,1016,0),(27922,863,'Lockbreaker Bomb','Emits random electronic bursts which have a chance of momentarily disrupting target locks on ships within range.',1000,75,0,20,NULL,21537360.0000,1,1015,0),(27923,172,'Lockbreaker Bomb Blueprint',' ',1,0.01,0,1,NULL,150000000.0000,1,1016,0),(27924,864,'Void Bomb','Radiates an omnidirectional pulse upon detonation that neutralizes a portion of the energy in the surrounding vessels.',1000,75,0,20,NULL,21537360.0000,1,1015,0),(27925,172,'Void Bomb Blueprint',' ',1,0.01,0,1,NULL,150000000.0000,1,1016,0),(27926,186,'Mission Caldari Carrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27927,186,'Mission Amarr Carrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27928,186,'Mission Minmatar Carrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27929,186,'Mission Gallente Carrier Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(27930,585,'Medium Remote Hull Repairer I','This module uses nano-assemblers to repair damage done to the hull of the Target ship.',20,10,0,1,NULL,41684.0000,1,1061,0),(27931,870,'Medium Remote Hull Repairer I Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,1538,0),(27932,585,'Small Remote Hull Repairer I','This module uses nano-assemblers to repair damage done to the hull of the Target ship.',20,5,0,1,NULL,34716.0000,1,1060,0),(27933,870,'Small Remote Hull Repairer I Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,1538,0),(27934,585,'Capital Remote Hull Repairer I','This module uses nano-assemblers to repair damage done to the hull of the Target ship.\r\r\n\r\r\nNote: May only be fitted to capital class ships.',20,4000,0,1,4,34177156.0000,1,1063,0),(27935,870,'Capital Remote Hull Repairer I Blueprint',' ',0,0.01,0,1,NULL,25000000.0000,1,1538,0),(27936,1210,'Capital Remote Hull Repair Systems','Operation of capital class remote hull repair systems. 5% reduced capacitor need for capital class remote hull repair system modules per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,10000000.0000,1,1745,0),(27937,836,'Caldari Basic Outpost Factory Platform','A basic upgrade to Caldari Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and gives a manufacturing time reduction on all Tech II components of 20%.',0,750000,7500000,1,1,500000000.0000,1,1867,0),(27938,535,'Caldari Basic Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27939,836,'Gallente Basic Outpost Factory Platform','A basic upgrade to Gallente Outpost manufacturing capabilities. Gives a manufacturing time reduction on all Capital Construction Components of 20%.',0,750000,7500000,1,8,500000000.0000,1,1868,0),(27940,535,'Gallente Basic Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27941,836,'Minmatar Basic Outpost Factory Platform','A basic upgrade to Minmatar Outpost manufacturing capabilities. Gives a manufacturing time reduction on all Modules of 20%.',0,750000,7500000,1,2,500000000.0000,1,1869,0),(27942,535,'Minmatar Basic Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27944,871,'Guristas Citadel Torpedo Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27945,871,'Guristas Torpedo Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27946,871,'Guristas Cruise Missile Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27947,871,'Dread Guristas Cruise Missile Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27948,871,'Dread Guristas Torpedo Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27949,871,'Dread Guristas Citadel Torpedo Battery Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(27951,515,'Triage Module I','An electronic interface designed to augment and enhance a carrier\'s defenses and logistical abilities. Through a series of electromagnetic polarity field shifts, the triage module diverts energy from the ship\'s propulsion and warp systems to lend additional power to its defensive and logistical capabilities.\r\r\n\r\r\nThis results in a great increase in the carrier\'s ability to provide aid to members of its fleet, as well as a greatly increased rate of defensive self-sustenance. Due to the ionic flux created by the triage module, remote effects like warp scrambling et al. will not affect the ship while in triage mode.\r\r\n\r\r\nThis also means that friendly remote effects will not work while in triage mode either. The flux only disrupts incoming effects, however, meaning the carrier can still provide aid to its cohorts. Sensor strength and targeting capabilities are also significantly boosted. In addition, the lack of power to locomotion systems means that neither standard propulsion nor warp travel are available to the ship, nor is the carrier able to dock until out of triage mode. Finally, any drones or fighters currently in space will be abandoned when the module is activated.\r\r\n\r\r\nNote: A triage module requires Strontium Clathrates to run and operate effectively. Only one triage module can be run at any given time, so fitting more than one has no practical use. The remote repair module bonuses are only applied to capital sized modules. The amount of shield boosting gained from the Triage Module is subject to a stacking penalty when used with other similar modules that affect the same attribute on the ship.\r\r\n\r\r\nThis module can only be fit on Carriers.',1,4000,0,1,NULL,66169610.0000,1,801,0),(27952,516,'Triage Module I Blueprint',' ',0,0.01,0,1,NULL,522349680.0000,1,343,0),(27953,383,'Drone Energy Neutralizer Sentry I','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27954,383,'Drone Energy Neutralizer Sentry II','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27955,383,'Drone Energy Neutralizer Sentry III','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27956,383,'Drone Stasis Tower','Rogue Drone stasis web sentry',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(27957,836,'Caldari Outpost Factory Platform','An intermediate upgrade to Caldari Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech II components to 40%.',0,750000,7500000,1,1,1000000000.0000,1,1867,0),(27958,535,'Caldari Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27959,836,'Caldari Advanced Outpost Factory Platform','An advanced upgrade to Caldari Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech II components to 60%.',0,750000,7500000,1,1,2000000000.0000,1,1867,0),(27960,535,'Caldari Advanced Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27961,836,'Amarr Basic Outpost Plant Platform','A basic upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech II ships to 40%.',0,750000,7500000,1,4,500000000.0000,1,1866,0),(27962,535,'Amarr Basic Outpost Plant Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27963,836,'Amarr Outpost Plant Platform','An intermediate upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech II ships to 50%.',0,750000,7500000,1,4,1000000000.0000,1,1866,0),(27964,535,'Amarr Outpost Plant Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27965,836,'Amarr Advanced Outpost Plant Platform','An advanced upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech II ships to 60%.',0,750000,7500000,1,4,2000000000.0000,1,1866,0),(27966,535,'Amarr Advanced Outpost Plant Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27967,836,'Gallente Outpost Factory Platform','An intermediate upgrade to Gallente Outpost manufacturing capabilities. Increases the manufacturing time reduction on all Capital Construction Components to 40%.',0,750000,7500000,1,8,1000000000.0000,1,1868,0),(27968,535,'Gallente Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27969,836,'Gallente Advanced Outpost Factory Platform','An advanced upgrade to Gallente Outpost manufacturing capabilities. Increases the manufacturing time reduction on all Capital Construction Components to 60%.',0,750000,7500000,1,8,2000000000.0000,1,1868,0),(27970,535,'Gallente Advanced Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27971,836,'Minmatar Outpost Factory Platform','An intermediate upgrade to Minmatar Outpost manufacturing capabilities. Increases the manufacturing time reduction on all Modules to 40%.',0,750000,7500000,1,2,1000000000.0000,1,1869,0),(27972,535,'Minmatar Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27973,836,'Minmatar Advanced Outpost Factory Platform','An advanced upgrade to Minmatar Outpost manufacturing capabilities. Increases the manufacturing time reduction on all Modules to 60%.',0,750000,7500000,1,2,2000000000.0000,1,1869,0),(27974,535,'Minmatar Advanced Outpost Factory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27975,836,'Gallente Outpost Plant Platform','An intermediate upgrade to Gallente Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,750000,7500000,1,8,1000000000.0000,1,1868,0),(27976,535,'Gallente Outpost Plant Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27977,836,'Gallente Advanced Outpost Plant Platform','An advanced upgrade to Gallente Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,750000,7500000,1,8,2000000000.0000,1,1868,0),(27978,535,'Gallente Advanced Outpost Plant Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27979,836,'Minmatar Outpost Plant Platform','An intermediate upgrade to Minmatar Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,750000,7500000,1,2,1000000000.0000,1,1869,0),(27980,535,'Minmatar Outpost Plant Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27981,836,'Minmatar Advanced Outpost Plant Platform','An advanced upgrade to Minmatar Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,750000,7500000,1,2,2000000000.0000,1,1869,0),(27982,535,'Minmatar Advanced Outpost Plant Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27983,836,'Gallente Basic Outpost Plant Platform','A basic upgrade to Gallente Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,750000,7500000,1,8,500000000.0000,1,1868,0),(27984,535,'Gallente Basic Outpost Plant Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27985,836,'Minmatar Basic Outpost Plant Platform','A basic upgrade to Minmatar Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,750000,7500000,1,2,500000000.0000,1,1869,0),(27986,535,'Minmatar Basic Outpost Plant Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27987,836,'Amarr Basic Outpost Laboratory Platform','A basic upgrade to Amarr Outpost research capabilities. Gives a 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and gives a research time reduction on all PE research of 20%.',0,750000,7500000,1,4,500000000.0000,1,1866,0),(27988,535,'Amarr Basic Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27989,836,'Amarr Outpost Laboratory Platform','An intermediate upgrade to Amarr Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and increases the research time reduction on all PE research to 40%.',0,750000,7500000,1,4,1000000000.0000,1,1866,0),(27990,535,'Amarr Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27991,836,'Amarr Advanced Outpost Laboratory Platform','An advanced upgrade to Amarr Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and increases the research time reduction on all PE research to 60%.',0,750000,7500000,1,4,2000000000.0000,1,1866,0),(27992,535,'Amarr Advanced Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27993,836,'Caldari Basic Outpost Laboratory Platform','A basic upgrade to Caldari Outpost research capabilities.  Gives a 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type).',0,750000,7500000,1,1,500000000.0000,1,1867,0),(27994,535,'Caldari Basic Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27995,836,'Caldari Outpost Laboratory Platform','An intermediate upgrade to Caldari Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and increases the research time reduction on all ME, PE and Copy research to 40%.',0,750000,7500000,1,1,1000000000.0000,1,1867,0),(27996,535,'Caldari Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27997,836,'Caldari Advanced Outpost Laboratory Platform','An advanced upgrade to Caldari Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and increases the research time reduction on all ME, PE and Copying research to 50%.',0,750000,7500000,1,1,2000000000.0000,1,1867,0),(27998,535,'Caldari Advanced Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(27999,836,'Caldari Basic Outpost Research Facility Platform','A basic upgrade to Caldari Outpost research capabilities. Gives a 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and gives a research time reduction on all Invention research of 20%.',0,750000,7500000,1,1,500000000.0000,1,1867,0),(28000,535,'Caldari Basic Outpost Research Facility Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28001,836,'Caldari Outpost Research Facility Platform','An intermediate upgrade to Caldari Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and increases the research time reduction on all Invention research to 40%.',0,750000,7500000,1,1,1000000000.0000,1,1867,0),(28002,535,'Caldari Outpost Research Facility Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28003,836,'Caldari Advanced Outpost Research Facility Platform','An advanced upgrade to Caldari Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and gives a research time reduction on all Invention research of 60%.',0,750000,7500000,1,1,2000000000.0000,1,1867,0),(28004,535,'Caldari Advanced Outpost Research Facility Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28005,836,'Gallente Basic Outpost Laboratory Platform','A basic upgrade to Gallente Outpost research capabilities. Gives a 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and gives a research time reduction on all Copying research of 20%.',0,750000,7500000,1,8,500000000.0000,1,1868,0),(28006,535,'Gallente Basic Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28007,836,'Gallente Outpost Laboratory Platform','An intermediate upgrade to Gallente Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and increases the research time reduction on all Copying research to 40%.',0,750000,7500000,1,8,1000000000.0000,1,1868,0),(28008,535,'Gallente Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28009,836,'Gallente Advanced Outpost Laboratory Platform','An advanced upgrade to Gallente Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and increases the research time reduction on all Copying research to 60%.',0,750000,7500000,1,8,2000000000.0000,1,1868,0),(28010,535,'Gallente Advanced Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28011,836,'Minmatar Basic Outpost Laboratory Platform','A basic upgrade to Minmatar Outpost research capabilities. Gives a 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and gives a research time reduction on all ME research of 20%.',0,750000,7500000,1,2,500000000.0000,1,1869,0),(28012,535,'Minmatar Basic Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28013,836,'Minmatar Outpost Laboratory Platform','An intermediate upgrade to Minmatar Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and increases the research time reduction on all ME research to 40%.',0,750000,7500000,1,2,1000000000.0000,1,1869,0),(28014,535,'Minmatar Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28015,836,'Minmatar Advanced Outpost Laboratory Platform','An advanced upgrade to Minmatar Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and increases the research time reduction on all ME research to 60%.',0,750000,7500000,1,2,2000000000.0000,1,1869,0),(28016,535,'Minmatar Advanced Outpost Laboratory Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28017,836,'Amarr Basic Outpost Refinery Platform','Installs a basic refinery into Amarr Outposts. Increases ore and ice reprocessing efficiency to 52%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,4,500000000.0000,1,1866,0),(28018,535,'Amarr Basic Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28019,836,'Amarr Outpost Refinery Platform','An intermediate upgrade to Amarr Outpost refining capabilities. Increases ore and ice reprocessing efficiency to 54%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,4,1000000000.0000,1,1866,0),(28020,535,'Amarr Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28021,836,'Amarr Advanced Outpost Refinery Platform','An advanced upgrade to Amarr Outpost reprocessing capabilities. Increases ore and ice reprocessing efficiency to 57%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,4,2000000000.0000,1,1866,0),(28022,535,'Amarr Advanced Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28023,836,'Caldari Basic Outpost Refinery Platform','Installs a basic refinery into Caldari Outposts. Increases ore and ice reprocessing efficiency to 52%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,1,500000000.0000,1,1867,0),(28024,535,'Caldari Basic Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28025,836,'Caldari Outpost Refinery Platform','An intermediate upgrade to Caldari Outpost refining facilities. Increases ore and ice reprocessing efficiency to 54%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,1,1000000000.0000,1,1867,0),(28026,535,'Caldari Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28027,836,'Caldari Advanced Outpost Refinery Platform','An advanced upgrade to Caldari Outpost refining facilities. Increases ore and ice reprocessing efficiency to 57%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,1,2000000000.0000,1,1867,0),(28028,535,'Caldari Advanced Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28029,836,'Gallente Basic Outpost Refinery Platform','Installs a basic refinery into Gallente Outposts. Increases ore and ice reprocessing efficiency to 52%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,8,500000000.0000,1,1868,0),(28030,535,'Gallente Basic Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28031,836,'Gallente Outpost Refinery Platform','An intermediate upgrade to Gallente Outpost refining facilities. Increases ore and ice reprocessing efficiency to 54%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,8,1000000000.0000,1,1868,0),(28032,535,'Gallente Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28033,836,'Gallente Advanced Outpost Refinery Platform','An advanced upgrade to Gallente Outpost refining facilities. Increases ore and ice reprocessing efficiency to 57%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,8,2000000000.0000,1,1868,0),(28034,535,'Gallente Advanced Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28035,836,'Minmatar Basic Outpost Refinery Platform','A basic upgrade to Minmatar Outpost refining facilities. Increases ore and ice reprocessing efficiency to 54%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,2,500000000.0000,1,1869,0),(28036,535,'Minmatar Basic Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28037,836,'Minmatar Outpost Refinery Platform','An intermediate upgrade to Minmatar Outpost refining facilities. Increases ore and ice reprocessing efficiency to 57%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,2,1000000000.0000,1,1869,0),(28038,535,'Minmatar Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28039,836,'Minmatar Advanced Outpost Refinery Platform','An advanced upgrade to Minmatar Outpost refining facilities. Increases ore and ice reprocessing efficiency to 60%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,750000,7500000,1,2,2000000000.0000,1,1869,0),(28040,535,'Minmatar Advanced Outpost Refinery Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28041,836,'Amarr Basic Outpost Office Platform','A basic upgrade to Amarr Outpost office facilities. Gives an additional ten office slots.',0,750000,7500000,1,4,500000000.0000,1,1866,0),(28042,535,'Amarr Basic Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28043,836,'Amarr Outpost Office Platform','An intermediate upgrade to Amarr Outpost office facilities. Gives an additional fifteen office slots.',0,750000,7500000,1,4,1000000000.0000,1,1866,0),(28044,535,'Amarr Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28045,836,'Amarr Advanced Outpost Office Platform','An advanced upgrade to Amarr Outpost office facilities. Gives an additional twenty office slots.',0,750000,7500000,1,4,2000000000.0000,1,1866,0),(28046,535,'Amarr Advanced Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28047,836,'Caldari Basic Outpost Office Platform','A basic upgrade to Caldari Outpost office facilities. Gives an additional ten office slots.',0,750000,7500000,1,1,500000000.0000,1,1867,0),(28048,535,'Caldari Basic Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28049,836,'Caldari Outpost Office Platform','An intermediate upgrade to Caldari Outpost office facilities. Gives an additional fifteen office slots.',0,750000,7500000,1,1,1000000000.0000,1,1867,0),(28050,535,'Caldari Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28051,836,'Caldari Advanced Outpost Office Platform','An advanced upgrade to Caldari Outpost office facilities. Gives an additional twenty office slots.',0,750000,7500000,1,1,2000000000.0000,1,1867,0),(28052,535,'Caldari Advanced Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28053,836,'Gallente Basic Outpost Office Platform','A basic upgrade to Gallente Outpost office facilities. Gives an additional twelve office slots.',0,750000,7500000,1,8,500000000.0000,1,1868,0),(28054,535,'Gallente Basic Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28055,836,'Gallente Outpost Office Platform','An intermediate upgrade to Gallente Outpost office facilities. Gives an additional twenty four office slots.',0,750000,7500000,1,8,1000000000.0000,1,1868,0),(28056,535,'Gallente Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28057,836,'Gallente Advanced Outpost Office Platform','An advanced upgrade to Gallente Outpost office facilities. Gives an additional thirty six office slots.',0,750000,7500000,1,8,2000000000.0000,1,1868,0),(28058,535,'Gallente Advanced Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28059,836,'Minmatar Basic Outpost Office Platform','A basic upgrade to Minmatar Outpost office facilities. Gives an additional seven office slots.',0,750000,7500000,1,2,500000000.0000,1,1869,0),(28060,535,'Minmatar Basic Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28061,836,'Minmatar Outpost Office Platform','An intermediate upgrade to Minmatar Outpost office facilities. Gives an additional ten office slots.',0,750000,7500000,1,2,1000000000.0000,1,1869,0),(28062,535,'Minmatar Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28063,836,'Minmatar Advanced Outpost Office Platform','An advanced upgrade to Minmatar Outpost office facilities. Gives an additional fifteen office slots.',0,750000,7500000,1,2,2000000000.0000,1,1869,0),(28064,535,'Minmatar Advanced Outpost Office Platform Blueprint',' ',0,0.01,0,1,NULL,1500000000.0000,0,NULL,0),(28065,319,'Remote Cloaking Array','This heavily shielded structure remotely emits a cloaking field over far away structures, hiding them from sight.',100,100,0,1,NULL,0.0000,0,NULL,0),(28066,226,'Amarr Battlestation Ruins','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(28070,226,'Caldari Station Ruins - Massive','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(28071,226,'Minmatar Trade Station Ruins - Large','Ruins.',0,0,0,1,NULL,0.0000,0,NULL,0),(28073,256,'Bomb Deployment','Basic operation of bomb delivery systems. 10% reduction of Bomb Launcher reactivation delay per skill level.',0,0.01,0,1,NULL,8000000.0000,1,373,0),(28074,366,'Pathfinder Gate','The Pathfinder Gate is a gizmo first produced by Kaalakiota corporation, as a handy navigational device in space that directs travelers to areas within and around the solarsystem.  It was originally created for tourist attractions as a quick and easy way to navigate between important sites within a solar-system.\r\r\n<br><br>\r\r\nHowever recently it has become quite popular within military and pirate circles, as a way to limit the risk of losing highly-sensitive coordinates to the enemy.  Instead of handing out bookmarks to every ship in the fleet, there would be a single Pathfinder Gate which would direct the ships from a common meetingplace.  That way keeping the coordinates hidden would be that much simpler, as well as preventing hackers from uncovering the coordinates by breaking into a computer mainframe of a ship of the fleet.\r\r\n<br><br>\r\r\nYou must approach the Pathfinder Gate before you can activate it.',0,0,0,1,NULL,0.0000,0,NULL,0),(28076,872,'Amarr Advanced Outpost Factory','An advanced upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech I ships to 60%.',0,1,0,1,4,1702171823.0000,1,NULL,0),(28077,872,'Amarr Advanced Outpost Plant','An advanced upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech II ships to 60%.',0,1,0,1,4,1702171823.0000,1,NULL,0),(28078,872,'Amarr Advanced Outpost Laboratory','An advanced upgrade to Amarr Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and increases the research time reduction on all PE research to 60%.',0,1,0,1,4,1702171823.0000,1,NULL,0),(28079,872,'Amarr Advanced Outpost Office','An advanced upgrade to Amarr Outpost office facilities. Gives an additional twenty office slots.',0,1,0,1,4,1702171823.0000,1,NULL,0),(28080,872,'Amarr Advanced Outpost Refinery','An advanced upgrade to Amarr Outpost reprocessing capabilities. Increases ore and ice reprocessing efficiency to 57%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,1702171823.0000,1,NULL,0),(28081,872,'Amarr Basic Outpost Factory','A basic upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech I ships to 40%.',0,1,0,1,4,425551432.0000,1,NULL,0),(28082,872,'Amarr Basic Outpost Plant','A basic upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech II ships to 40%.',0,1,0,1,4,1702171823.0000,1,NULL,0),(28083,872,'Amarr Basic Outpost Laboratory','A basic upgrade to Amarr Outpost research capabilities. Gives a 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and gives a research time reduction on all PE research of 20%.',0,1,0,1,4,425551432.0000,1,NULL,0),(28084,872,'Amarr Basic Outpost Office','A basic upgrade to Amarr Outpost office facilities. Gives an additional ten office slots.',0,1,0,1,4,425551432.0000,1,NULL,0),(28085,872,'Amarr Basic Outpost Refinery','Installs a basic refinery into Amarr Outposts. Increases ore and ice reprocessing efficiency to 52%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,425551432.0000,1,NULL,0),(28086,872,'Amarr Outpost Factory','An intermediate upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech I ships to 50%.',0,1,0,1,4,851100171.0000,1,NULL,0),(28087,872,'Amarr Outpost Plant','An intermediate upgrade to Amarr Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech II ships to 50%.',0,1,0,1,4,851100171.0000,1,NULL,0),(28088,872,'Amarr Outpost Laboratory','An intermediate upgrade to Amarr Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and increases the research time reduction on all PE research to 40%.',0,1,0,1,4,851100171.0000,1,NULL,0),(28089,872,'Amarr Outpost Office','An intermediate upgrade to Amarr Outpost office facilities. Gives an additional fifteen office slots.',0,1,0,1,4,851100171.0000,1,NULL,0),(28090,872,'Amarr Outpost Refinery','An intermediate upgrade to Amarr Outpost refining capabilities. Increases ore and ice reprocessing efficiency to 54%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,851100171.0000,1,NULL,0),(28091,872,'Caldari Advanced Outpost Factory','An advanced upgrade to Caldari Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech II components to 60%.',0,1,0,1,4,1683617576.0000,1,NULL,0),(28092,872,'Caldari Advanced Outpost Laboratory','An advanced upgrade to Caldari Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and increases the research time reduction on all ME, PE and Copying research to 50%.',0,1,0,1,4,1683617576.0000,1,NULL,0),(28093,872,'Caldari Advanced Outpost Research Facility','An advanced upgrade to Caldari Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and gives a research time reduction on all Invention research of 60%.',0,1,0,1,4,1683617576.0000,1,NULL,0),(28094,872,'Caldari Advanced Outpost Office','An advanced upgrade to Caldari Outpost office facilities. Gives an additional twenty office slots.',0,1,0,1,4,1683617576.0000,1,NULL,0),(28095,872,'Caldari Advanced Outpost Refinery','An advanced upgrade to Caldari Outpost refining facilities. Increases ore and ice reprocessing efficiency to 57%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,1683617576.0000,1,NULL,0),(28096,872,'Caldari Basic Outpost Factory','A basic upgrade to Caldari Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and gives a manufacturing time reduction on all Tech II components of 20%.',0,1,0,1,4,420921150.0000,1,NULL,0),(28097,872,'Caldari Basic Outpost Laboratory','A basic upgrade to Caldari Outpost research capabilities.  Gives a 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type).',0,1,0,1,4,420921150.0000,1,NULL,0),(28098,872,'Caldari Basic Outpost Research Facility','A basic upgrade to Caldari Outpost research capabilities. Gives a 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and gives a research time reduction on all Invention research of 20%.',0,1,0,1,4,420921150.0000,1,NULL,0),(28099,872,'Caldari Basic Outpost Office','A basic upgrade to Caldari Outpost office facilities. Gives an additional ten office slots.',0,1,0,1,4,420921150.0000,1,NULL,0),(28100,872,'Caldari Basic Outpost Refinery','Installs a basic refinery into Caldari Outposts. Increases ore and ice reprocessing efficiency to 52%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,420921150.0000,1,NULL,0),(28101,872,'Caldari Outpost Factory','An intermediate upgrade to Caldari Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type) and increases the manufacturing time reduction on all Tech II components to 40%.',0,1,0,1,4,841842300.0000,1,NULL,0),(28102,872,'Caldari Outpost Laboratory','An intermediate upgrade to Caldari Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and increases the research time reduction on all ME, PE and Copy research to 40%.',0,1,0,1,4,841842300.0000,1,NULL,0),(28103,872,'Caldari Outpost Research Facility','An intermediate upgrade to Caldari Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and increases the research time reduction on all Invention research to 40%.',0,1,0,1,4,841842300.0000,1,NULL,0),(28104,872,'Caldari Outpost Office','An intermediate upgrade to Caldari Outpost office facilities. Gives an additional fifteen office slots.',0,1,0,1,4,841842300.0000,1,NULL,0),(28105,872,'Caldari Outpost Refinery','An intermediate upgrade to Caldari Outpost refining facilities. Increases ore and ice reprocessing efficiency to 54%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,841842300.0000,1,NULL,0),(28106,872,'Gallente Advanced Outpost Factory','An advanced upgrade to Gallente Outpost manufacturing capabilities. Increases the manufacturing time reduction on all Capital Construction Components to 60%.',0,1,0,1,4,1403018549.0000,1,NULL,0),(28107,872,'Gallente Advanced Outpost Plant','An advanced upgrade to Gallente Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,1,0,1,4,1403018549.0000,1,NULL,0),(28108,872,'Gallente Advanced Outpost Laboratory','An advanced upgrade to Gallente Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and increases the research time reduction on all Copying research to 60%.',0,1,0,1,4,1403018549.0000,1,NULL,0),(28109,872,'Gallente Advanced Outpost Office','An advanced upgrade to Gallente Outpost office facilities. Gives an additional thirty six office slots.',0,1,0,1,4,1403018549.0000,1,NULL,0),(28110,872,'Gallente Advanced Outpost Refinery','An advanced upgrade to Gallente Outpost refining facilities. Increases ore and ice reprocessing efficiency to 57%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,1403018549.0000,1,NULL,0),(28111,872,'Gallente Basic Outpost Factory','A basic upgrade to Gallente Outpost manufacturing capabilities. Gives a manufacturing time reduction on all Capital Construction Components of 20%.',0,1,0,1,4,350760372.0000,1,NULL,0),(28112,872,'Gallente Basic Outpost Plant','A basic upgrade to Gallente Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,1,0,1,4,350760372.0000,1,NULL,0),(28113,872,'Gallente Basic Outpost Laboratory','A basic upgrade to Gallente Outpost research capabilities. Gives a 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and gives a research time reduction on all Copying research of 20%.',0,1,0,1,4,350760372.0000,1,NULL,0),(28114,872,'Gallente Basic Outpost Office','A basic upgrade to Gallente Outpost office facilities. Gives an additional twelve office slots.',0,1,0,1,4,350760372.0000,1,NULL,0),(28115,872,'Gallente Basic Outpost Refinery','Installs a basic refinery into Gallente Outposts. Increases ore and ice reprocessing efficiency to 52%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,350760372.0000,1,NULL,0),(28116,872,'Gallente Outpost Factory','An intermediate upgrade to Gallente Outpost manufacturing capabilities. Increases the manufacturing time reduction on all Capital Construction Components to 40%.',0,1,0,1,4,701515024.0000,1,NULL,0),(28117,872,'Gallente Outpost Plant','An intermediate upgrade to Gallente Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,1,0,1,4,701515024.0000,1,NULL,0),(28118,872,'Gallente Outpost Laboratory','An intermediate upgrade to Gallente Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy, Invention jobs (stacks with all other improvements of the same type) and increases the research time reduction on all Copying research to 40%.',0,1,0,1,4,701515024.0000,1,NULL,0),(28119,872,'Gallente Outpost Office','An intermediate upgrade to Gallente Outpost office facilities. Gives an additional twenty four office slots.',0,1,0,1,4,701515024.0000,1,NULL,0),(28120,872,'Gallente Outpost Refinery','An intermediate upgrade to Gallente Outpost refining facilities. Increases ore and ice reprocessing efficiency to 54%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,701515024.0000,1,NULL,0),(28121,872,'Minmatar Advanced Outpost Factory','An advanced upgrade to Minmatar Outpost manufacturing capabilities. Increases the manufacturing time reduction on all Modules to 60%.',0,1,0,1,4,1983932072.0000,1,NULL,0),(28122,872,'Minmatar Advanced Outpost Plant','An advanced upgrade to Minmatar Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,1,0,1,4,1983932072.0000,1,NULL,0),(28123,872,'Minmatar Advanced Outpost Laboratory','An advanced upgrade to Minmatar Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and increases the research time reduction on all ME research to 60%.',0,1,0,1,4,1983932072.0000,1,NULL,0),(28124,872,'Minmatar Advanced Outpost Office','An advanced upgrade to Minmatar Outpost office facilities. Gives an additional fifteen office slots.',0,1,0,1,4,1983932072.0000,1,NULL,0),(28125,872,'Minmatar Advanced Outpost Refinery','An advanced upgrade to Minmatar Outpost refining facilities. Increases ore and ice reprocessing efficiency to 60%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,1983932072.0000,1,NULL,0),(28126,872,'Minmatar Basic Outpost Factory','A basic upgrade to Minmatar Outpost manufacturing capabilities. Gives a manufacturing time reduction on all Modules of 20%.',0,1,0,1,4,495994559.0000,1,NULL,0),(28127,872,'Minmatar Basic Outpost Plant','A basic upgrade to Minmatar Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,1,0,1,4,495994559.0000,1,NULL,0),(28128,872,'Minmatar Basic Outpost Laboratory','A basic upgrade to Minmatar Outpost research capabilities. Gives a 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and gives a research time reduction on all ME research of 20%.',0,1,0,1,4,495994559.0000,1,NULL,0),(28129,872,'Minmatar Basic Outpost Office','A basic upgrade to Minmatar Outpost office facilities. Gives an additional seven office slots.',0,1,0,1,4,495994559.0000,1,NULL,0),(28130,872,'Minmatar Basic Outpost Refinery','A basic upgrade to Minmatar Outpost refining facilities. Increases ore and ice reprocessing efficiency to 54%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,495994559.0000,1,NULL,0),(28131,872,'Minmatar Outpost Factory','An intermediate upgrade to Minmatar Outpost manufacturing capabilities. Increases the manufacturing time reduction on all Modules to 40%.',0,1,0,1,4,991974185.0000,1,NULL,0),(28132,872,'Minmatar Outpost Plant','An intermediate upgrade to Minmatar Outpost manufacturing capabilities. Gives 1% Material Efficiency reduction to all manufacturing jobs (stacks with all other improvements of the same type).',0,1,0,1,4,991974185.0000,1,NULL,0),(28133,872,'Minmatar Outpost Laboratory','An intermediate upgrade to Minmatar Outpost research capabilities. Gives an additional 10% cost reduction to Material Efficiency, Time Efficiency, Copy jobs (stacks with all other improvements of the same type) and increases the research time reduction on all ME research to 40%.',0,1,0,1,4,991974185.0000,1,NULL,0),(28134,872,'Minmatar Outpost Office','An intermediate upgrade to Minmatar Outpost office facilities. Gives an additional ten office slots.',0,1,0,1,4,991974185.0000,1,NULL,0),(28135,872,'Minmatar Outpost Refinery','An intermediate upgrade to Minmatar Outpost refining facilities. Increases ore and ice reprocessing efficiency to 57%.\r\r\n\r\r\nNote: does not affect anything else but the two groups mentioned above.',0,1,0,1,4,991974185.0000,1,NULL,0),(28136,802,'Drone Battleship Boss lvl5','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(28137,283,'Citizens','This is a group of civilian citizens.',400,1000,0,1,8,0.0000,1,NULL,0),(28138,306,'Citizen Quarters','This temporary structure is made to house The Seven\'s hostages until they are ready to be transported to a more secure location.',10000,1200,1000,1,NULL,0.0000,0,NULL,0),(28139,383,'Angel Energy Neutralizer Sentry I','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28140,383,'Blood Energy Neutralizer Sentry I','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28141,383,'Guristas Energy Neutralizer Sentry I','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28142,383,'Sansha Energy Neutralizer Sentry I','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28143,383,'Serpentis Energy Neutralizer Sentry I','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28144,383,'Angel Energy Neutralizer Sentry II','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28145,383,'Blood Energy Neutralizer Sentry II','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28146,383,'Guristas Energy Neutralizer Sentry II','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28147,383,'Sansha Energy Neutralizer Sentry II','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28148,383,'Serpentis Energy Neutralizer Sentry II','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28149,383,'Blood Energy Neutralizer Sentry III','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28150,383,'Angel Energy Neutralizer Sentry III','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28151,383,'Guristas Energy Neutralizer Sentry III','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28152,383,'Sansha Energy Neutralizer Sentry III','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28153,383,'Serpentis Energy Neutralizer Sentry III','This sentry tower will disrupt the capacitor core of any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28155,874,'Fitting Service','When operational, the Fitting Service allows capsuleers to customize and change the modules attached to their ships while docked in this station.',1,1,0,1,8,0.0000,0,NULL,0),(28156,874,'Reprocessing Service','When operational, the Reprocessing Service allows capsuleers to break down ore, items and scrap into potentially valuable raw materials while docked in this station.',1,1,0,1,2,0.0000,0,NULL,0),(28157,874,'Factory Service','When operational, the Factory Service allows capsuleers to manufacture items and ships at this station.',1,1,0,1,4,0.0000,0,NULL,0),(28158,874,'Cloning Service','When operational, the Cloning Service allows capsuleers to use this station as their medical clone home location.',1,1,0,1,16,0.0000,0,NULL,0),(28159,874,'Repair Service','When operational, the Repair Service allows capsuleers to repair their ships and modules while docked in this station.',1,1,0,1,8,0.0000,0,NULL,0),(28160,875,'Federation Freighter','The large navy forces of the Empires regularly use freighters to transport a wide variety of military items and personnel en masse.  Such vulnerable ships are usually heavily guarded as they traverse the space lanes.',1175000000,17550000,750000,1,8,0.0000,0,NULL,0),(28161,875,'State Freighter','The large navy forces of the Empires regularly use freighters to transport a wide variety of military items and personnel en masse.  Such vulnerable ships are usually heavily guarded as they traverse the space lanes.',1200000000,16250000,785000,1,1,0.0000,0,NULL,0),(28162,875,'Republic Freighter','The large navy forces of the Empires regularly use freighters to transport a wide variety of military items and personnel en masse.  Such vulnerable ships are usually heavily guarded as they traverse the space lanes.',1025000000,15500000,720000,1,2,0.0000,0,NULL,0),(28163,875,'Imperial Freighter','The large navy forces of the Empires regularly use freighters to transport a wide variety of military items and personnel en masse.  Such vulnerable ships are usually heavily guarded as they traverse the space lanes.',1125000000,18500000,735000,1,4,0.0000,0,NULL,0),(28164,1216,'Thermodynamics','Advanced understanding of the laws of thermodynamics. Allows you to deliberately overheat a ship\'s modules in order to push them beyond their intended limit. Also gives you the ability to frown in annoyance whenever you hear someone mention a perpetual motion unit. Reduces heat damage by 5% per level.',0,0.01,0,1,NULL,4500000.0000,1,368,0),(28166,874,'Laboratory Service','When operational, the Laboratory Service allows capsuleers to conduct research and invention operations at this station.',1,1,0,1,1,0.0000,0,NULL,0),(28167,667,'Imperial Templar Judgment','This variant of the frontline battleship of the Amarr Empire has been heavily modified with only one purpose in mind: Destruction.  It has been supplemented with decks of top-of the-line-fire control systems, and its entire power distribution structure has been redesigned to provide as much power as possible to its weapons, resulting in a truly fearsome battleship.',20500000,1100000,525,1,4,0.0000,0,NULL,0),(28168,667,'Imperial Templar Diviner','This variant of the frontline battleship of the Amarr Empire constitutes a substantial redesign with much of the traditional command and control systems having been subsumed by decks of electronic warfare support.  These ships are becoming more and more popular in the Empire navies, as their ability to wreak havoc and confusion upon enemy fleet formations become increasingly essential.',20500000,1100000,525,1,4,0.0000,0,NULL,0),(28169,666,'Imperial Templar Phalanx','This variant of the frontline battlecruiser of the Amarr Empire has been heavily modified with only one purpose in mind: Destruction.  It has been supplemented with decks of top-of the-line-fire control systems, and its entire power distribution structure has been redesigned to provide as much power as possible to its weapons, resulting in a truly fearsome battleship.',13500000,130000,350,1,4,0.0000,0,NULL,0),(28170,666,'Imperial Templar Seer','This variant of the frontline battlecruiser of the Amarr Empire constitutes a substantial redesign with much of the traditional command and control systems having been subsumed by decks of electronic warfare support.  These ships are becoming more and more popular in the Empire navies, as their ability to wreak havoc and confusion upon enemy fleet formations become increasingly essential.',13500000,130000,350,1,4,0.0000,0,NULL,0),(28171,674,'State Shukuro Nagashin','This variant of the frontline battleship of the Caldari State has been heavily modified with only one purpose in mind: Destruction.  It has been supplemented with decks of top-of the-line-fire control systems, and its entire power distribution structure has been redesigned to provide as much power as possible to its weapons, resulting in a truly fearsome battleship.',20500000,1080000,625,1,1,0.0000,0,NULL,0),(28172,672,'State Shukuro Seki','This variant of the frontline battlecruiser of the Caldari State has been heavily modified with only one purpose in mind: Destruction.  It has been supplemented with decks of top-of the-line-fire control systems, and its entire power distribution structure has been redesigned to provide as much power as possible to its weapons, resulting in a truly fearsome battleship.',14000000,140000,345,1,1,0.0000,0,NULL,0),(28173,672,'State Shukuro Gassin','This variant of the frontline battlecruiser of the Caldari State constitutes a substantial redesign with much of the traditional command and control systems having been subsumed by decks of electronic warfare support.  These ships are becoming more and more popular in the Empire navies, as their ability to wreak havoc and confusion upon enemy fleet formations become increasingly essential.',14000000,140000,345,1,1,0.0000,0,NULL,0),(28174,674,'State Shukuro Turushima','This variant of the frontline battleship of the Caldari State constitutes a substantial redesign with much of the traditional command and control systems having been subsumed by decks of electronic warfare support.  These ships are becoming more and more popular in the Empire navies, as their ability to wreak havoc and confusion upon enemy fleet formations become increasingly essential.',20500000,1080000,625,1,1,0.0000,0,NULL,0),(28175,681,'Federation Praktor Diablic','This variant of the frontline battlecruiser of the Gallente Federation has been heavily modified with only one purpose in mind: Destruction.  It has been supplemented with decks of top-of the-line-fire control systems, and its entire power distribution structure has been redesigned to provide as much power as possible to its weapons, resulting in a truly fearsome vessel.',13250000,150000,400,1,8,0.0000,0,NULL,0),(28176,681,'Federation Praktor Erenus','This variant of the frontline battlecruiser of the Gallente Federation constitutes a substantial redesign with much of the traditional command and control systems having been subsumed by decks of electronic warfare support.  These ships are becoming more and more popular in the Empire navies, as their ability to wreak havoc and confusion upon enemy fleet formations become increasingly essential.',13250000,150000,400,1,8,0.0000,0,NULL,0),(28177,680,'Federation Praktor Polemo','This variant of the frontline battleship of the Gallente Federation has been heavily modified with only one purpose in mind: Destruction.  It has been supplemented with decks of top-of the-line-fire control systems, and its entire power distribution structure has been redesigned to provide as much power as possible to its weapons, resulting in a truly fearsome battleship.',19000000,1140000,675,1,8,0.0000,0,NULL,0),(28178,680,'Federation Praktor Dionia','This variant of the frontline battleship of the Gallente Federation constitutes a substantial redesign with much of the traditional command and control systems having been subsumed by decks of electronic warfare support.  These ships are becoming more and more popular in the Empire navies, as their ability to wreak havoc and confusion upon enemy fleet formations become increasingly essential.',19000000,1140000,675,1,8,0.0000,0,NULL,0),(28179,685,'Republic Tribal Caluka','This variant of the frontline battlecruiser of the Minmatar Republic has been heavily modified with only one purpose in mind: Destruction.  It has been supplemented with decks of top-of the-line-fire control systems, and its entire power distribution structure has been redesigned to provide as much power as possible to its weapons, resulting in a truly fearsome battleship.',12500000,120000,475,1,2,0.0000,0,NULL,0),(28180,685,'Republic Tribal Vorshud','This variant of the frontline battlecruiser of the Minmatar Republic constitutes a substantial redesign with much of the traditional command and control systems having been subsumed by decks of electronic warfare support.  These ships are becoming more and more popular in the Empire navies, as their ability to wreak havoc and confusion upon enemy fleet formations become increasingly essential.',12500000,120000,475,1,2,0.0000,0,NULL,0),(28181,706,'Republic Tribal Kinai','This variant of the frontline battleship of the Minmatar Republic has been heavily modified with only one purpose in mind: Destruction.  It has been supplemented with decks of top-of the-line-fire control systems, and its entire power distribution structure has been redesigned to provide as much power as possible to its weapons, resulting in a truly fearsome battleship.',19000000,850000,550,1,2,0.0000,0,NULL,0),(28182,706,'Republic Tribal Akila ','This variant of the frontline battleship of the Minmatar Republic constitutes a substantial redesign with much of the traditional command and control systems having been subsumed by decks of electronic warfare support.  These ships are becoming more and more popular in the Empire navies, as their ability to wreak havoc and confusion upon enemy fleet formations become increasingly essential.',19000000,850000,550,1,2,0.0000,0,NULL,0),(28183,876,'Rank 1 Upgrade','An advanced upgrade to Amarr Outpost manufacturing capabilities. Gives an additional nine factory slots and increases the manufacturing time reduction on all Tech I ships to 60%',0,1,0,1,4,424145182.0000,1,NULL,0),(28184,876,'Rank 2 Upgrade','An advanced upgrade to Amarr Outpost manufacturing capabilities. Gives an additional nine factory slots and increases the manufacturing time reduction on all Tech I ships to 60%',0,1,0,1,4,848287671.0000,1,NULL,0),(28185,876,'Rank 3 Upgrade','An advanced upgrade to Amarr Outpost manufacturing capabilities. Gives an additional nine factory slots and increases the manufacturing time reduction on all Tech I ships to 60%',0,1,0,1,4,1696546823.0000,1,NULL,0),(28190,526,'MicroLink Encoder/Decoder','A device used to encode and decode microlink messages.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(28191,877,'Target Painting Battery','Deployable structure that target paints enemy targets.',100000000,4000,0,1,NULL,128.0000,0,NULL,0),(28197,640,'Heavy Armor Maintenance Bot II','Armor Maintenance Drone',3000,25,0,1,NULL,361832.0000,1,842,0),(28198,1144,'Heavy Armor Maintenance Bot II Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,NULL,0),(28199,640,'Heavy Shield Maintenance Bot II','Shield Maintenance Drone',3000,25,0,1,NULL,360802.0000,1,842,0),(28200,1144,'Heavy Shield Maintenance Bot II Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,NULL,0),(28201,640,'Light Armor Maintenance Bot II','Armor Maintenance Drone',3000,5,0,1,NULL,57922.0000,1,842,0),(28202,1144,'Light Armor Maintenance Bot II Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,NULL,0),(28203,640,'Light Shield Maintenance Bot II','Shield Maintenance Drone',3000,5,0,1,NULL,122428.0000,1,842,0),(28204,1144,'Light Shield Maintenance Bot II Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,NULL,0),(28205,640,'Medium Armor Maintenance Bot II','Armor Maintenance Drone',3000,10,0,1,NULL,239092.0000,1,842,0),(28206,1144,'Medium Armor Maintenance Bot II Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,NULL,0),(28207,640,'Medium Shield Maintenance Bot II','Shield Maintenance Drone',3000,10,0,1,NULL,238062.0000,1,842,0),(28208,1144,'Medium Shield Maintenance Bot II Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,NULL,0),(28209,100,'Warden II','Sentry Drone',12000,25,0,1,1,444408.0000,1,911,0),(28210,176,'Warden II Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,1,NULL,0),(28211,100,'Garde II','Sentry Drone',12000,25,0,1,8,444408.0000,1,911,0),(28212,176,'Garde II Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,1,NULL,0),(28213,100,'Curator II','Sentry Drone',12000,25,0,1,4,444408.0000,1,911,0),(28214,176,'Curator II Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,1,NULL,0),(28215,100,'Bouncer II','Sentry Drone',12000,25,0,1,2,444408.0000,1,911,0),(28216,176,'Bouncer II Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,1,NULL,0),(28221,186,'Rogue Large Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(28222,186,'Rogue Medium Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(28223,186,'Rogue Small Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(28224,306,'Mission Hacking Can 2','This communications hub is locked with an electronic security system. You will need a Data Analyzer to open it.',10000,27500,2700,1,1,0.0000,0,NULL,0),(28227,319,'Mining Outpost_event','Mining Outpost',0,1,0,1,NULL,0.0000,0,NULL,0),(28228,319,'Listening Post_event','Listening Post',100000,1150,8850,1,1,0.0000,0,NULL,0),(28231,409,'Republic Fleet Navy Rear-Admiral Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,2,5000000.0000,1,736,0),(28234,319,'Fuel Fump_event','Reinforced Fuel Dump',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(28235,319,'Supply Depot_event','Supply Depot',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(28236,409,'Federation Navy Fleet Rear-Admiral Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,5000000.0000,1,734,0),(28237,409,'Caldari Navy Fleet Rear-Admiral Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,8,5000000.0000,1,732,0),(28238,409,'Imperial Navy Fleet Rear-Admiral Insignia','Identification tags such as these may prove valuable if handed to the proper organization.',0.1,0.1,0,1,4,5000000.0000,1,730,0),(28246,319,'Prison_event','Prison',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(28247,319,'Angel Battlestation_event','Reinforced Angel Station.\r\r\n\r\r\nLittle is known about what exactly goes on in here.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(28248,319,'Blood Raider Battlestation_event','This gigantic suprastructure is one of the military installations of the Blood Raiders pirate corporation. ',100000,100000000,10000,1,4,0.0000,0,NULL,0),(28249,319,'Gallente Station_event','Docking has been prohibited for capsuleers into this station until the system has been given the all clear by CONCORD.',0,0,0,1,8,0.0000,0,NULL,0),(28250,319,'Caldari Station_event','Docking has been prohibited into this station until the all clear has been given by the manager.',0,0,0,1,8,0.0000,0,NULL,0),(28251,319,'Minmatar Station_event','Docking has been prohibited into this station without proper authorization.',0,0,0,1,2,0.0000,0,NULL,0),(28252,319,'Sansha Battlestation_event','This gigantic warstation is one of the military installations of Sansha\'s slumbering nation.  It is known to be able to hold a massive number of Sansha vessels, but strange whispers hint at darker things than mere warfare going on underneath its jagged exterior.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(28254,319,'Guristas Station_event','This gigantic suprastructure is one of the military installations of the Guristas pirate corporation. Even for its size it has no commercial station services or docking bays to receive guests.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(28255,186,'Mission Faction Freighter Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(28256,314,'Alliance Tournament Cup','Passed on to the winners after every tournament, the magnificent Alliance Tournament cup is perhaps the most coveted prize in New Eden.\r\r\n\r\r\nGlory and fame await the holders, who had to defeat the competition posed by the elite combat teams of their opponents in the one of the most gruelling, bloody and exciting tournaments in existence. \r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//632866070>Band of Brothers</url>\r\r\nYear 107 - 1st Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//632866070>Band of Brothers</url>\r\r\nYear 107 - 2nd Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//632866070>Band of Brothers</url>\r\r\nYear 108 - 3rd Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//1399057309>HUN Reloaded</url>\r\r\nYear 109 - 4th Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//1438160193>Ev0ke</url>\r\r\nYear 110 - 5th Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//386292982>Pandemic Legion</url> Year 111 - 6th Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//386292982>Pandemic Legion</url> Year 111 - 7th Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//386292982>Pandemic Legion</url> Year 112 - 8th Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//551692893>HYDRA RELOADED</url> Year 113 - 9th Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//99001968>Verge of Collapse</url> Year 114 - 10th Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//386292982>Pandemic Legion</url> Year 115 - 11th Alliance Tournament Winners</div>\r\r\n\r\r\n<div style=\"text-align:center;\"><url=showinfo:16159//99004300>The Camel Empire</url> Year 116 - 12th Alliance Tournament Winners</div>',1,0.1,0,1,4,0.0000,1,NULL,0),(28257,314,'Alliance Tournament Gold Medal','Awarded to the capsuleers who fought and defeated their opponents in a series of gruelling and murderous fights to claim their place as winners of the great Alliance Tournament.  The holder of this Alliance Tournament medal can truly claim to be among the true elite, the best of the best.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(28258,319,'Research Station','This gigantic superstructure is a research station. Due to the nature of the research this station does not offer commercial station services or docking bays and does not receive guests.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(28259,306,'colins test Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this old hulk.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28260,474,'Zbikoki\'s Hacker Card','This is a passkey used to enter the off-limit Research Zone room.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(28261,274,'Tax Evasion','Knowledge of the SCC tax regime and the ability to utilize that to one\'s own advantage.\r\r\n\r\r\n2% reduction in SCC tax per level. \r\r\n\r\r\nNote: This skill does not apply to taxes imposed by player corporations.',0,0.01,0,1,NULL,6000000.0000,0,NULL,0),(28262,100,'\'Integrated\' Acolyte','Light Scout Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.\r\r\n',3000,5,0,1,4,2094.0000,1,837,0),(28263,176,'\'Integrated\' Acolyte Blueprint',' ',0,0.01,0,1,NULL,200000.0000,1,NULL,0),(28264,100,'\'Augmented\' Acolyte','Light Scout Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.\r\r\n',3000,5,0,1,4,47142.0000,1,837,0),(28265,176,'\'Augmented\' Acolyte Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(28266,100,'\'Integrated\' Berserker','Heavy Attack Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.\r\r\n',10000,25,0,1,2,51744.0000,1,839,0),(28267,176,'\'Integrated\' Berserker Blueprint',' ',0,0.01,0,1,NULL,4000000.0000,1,NULL,0),(28268,100,'\'Augmented\' Berserker','Heavy Attack Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.\r\r\n',10000,25,0,1,2,297640.0000,1,839,0),(28269,176,'\'Augmented\' Berserker Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(28270,100,'\'Integrated\' Hammerhead','Medium Scout Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.\r\r\n',5000,10,0,1,8,23610.0000,1,838,0),(28271,176,'\'Integrated\' Hammerhead Blueprint',' ',0,0.01,0,1,NULL,1800000.0000,1,NULL,0),(28272,100,'\'Augmented\' Hammerhead','Medium Scout Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.\r\r\n',5000,10,0,1,8,139762.0000,1,838,0),(28273,176,'\'Augmented\' Hammerhead Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(28274,100,'\'Integrated\' Hobgoblin','Light Scout Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.\r\r\n',3000,5,0,1,8,2610.0000,1,837,0),(28275,176,'\'Integrated\' Hobgoblin Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,NULL,0),(28276,100,'\'Augmented\' Hobgoblin','Light Scout Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.\r\r\n',3000,5,0,1,8,47658.0000,1,837,0),(28277,176,'\'Augmented\' Hobgoblin Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(28278,100,'\'Integrated\' Hornet','Light Scout Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.\r\r\n',3500,5,0,1,1,3164.0000,1,837,0),(28279,176,'\'Integrated\' Hornet Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,NULL,0),(28280,100,'\'Augmented\' Hornet','Light Scout Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.\r\r\n',3500,5,0,1,1,48212.0000,1,837,0),(28281,176,'\'Augmented\' Hornet Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(28282,100,'\'Integrated\' Infiltrator','Medium Scout Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.\r\r\n',6000,10,0,1,4,20794.0000,1,838,0),(28283,176,'\'Integrated\' Infiltrator Blueprint',' ',0,0.01,0,1,NULL,1700000.0000,1,NULL,0),(28284,100,'\'Augmented\' Infiltrator','Medium Scout Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.\r\r\n',6000,10,0,1,4,143090.0000,1,838,0),(28285,176,'\'Augmented\' Infiltrator Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(28286,100,'\'Integrated\' Ogre','Heavy Attack Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.',12000,25,0,1,8,106788.0000,1,839,0),(28287,176,'\'Integrated\' Ogre Blueprint',' ',0,0.01,0,1,NULL,7000000.0000,1,NULL,0),(28288,100,'\'Augmented\' Ogre','Heavy Attack Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.\r\r\n',12000,25,0,1,8,229804.0000,1,839,0),(28289,176,'\'Augmented\' Ogre Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(28290,100,'\'Integrated\' Praetor','Heavy Attack Drone.  \r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.',10000,25,0,1,4,88424.0000,1,839,0),(28291,176,'\'Integrated\' Praetor Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,1,NULL,0),(28292,100,'\'Augmented\' Praetor','Heavy Attack Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.',10000,25,0,1,4,317936.0000,1,839,0),(28293,176,'\'Augmented\' Praetor Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(28294,100,'\'Integrated\' Valkyrie','Medium Scout Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.\r\r\n',5000,10,0,1,2,16392.0000,1,838,0),(28295,176,'\'Integrated\' Valkyrie Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,NULL,0),(28296,100,'\'Augmented\' Valkyrie','Medium Scout Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.\r\r\n',5000,10,0,1,2,140736.0000,1,838,0),(28297,176,'\'Augmented\' Valkyrie Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28298,100,'\'Integrated\' Vespa','Medium Scout Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.\r\r\n',5000,10,0,1,1,21406.0000,1,838,0),(28299,176,'\'Integrated\' Vespa Blueprint',' ',0,0.01,0,1,NULL,1600000.0000,1,NULL,0),(28300,100,'\'Augmented\' Vespa','Medium Scout Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.\r\r\n',5000,10,0,1,1,141654.0000,1,838,0),(28301,176,'\'Augmented\' Vespa Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28302,100,'\'Integrated\' Warrior','Light Scout Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.\r\r\n',4000,5,0,1,2,4230.0000,1,837,0),(28303,176,'\'Integrated\' Warrior Blueprint',' ',0,0.01,0,1,NULL,400000.0000,1,NULL,0),(28304,100,'\'Augmented\' Warrior','Light Scout Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.\r\r\n',4000,5,0,1,2,49278.0000,1,837,0),(28305,176,'\'Augmented\' Warrior Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(28306,100,'\'Integrated\' Wasp','Heavy Attack Drone\r\r\n\r\r\nThis particular model has had multiple components from rogue drones incorporated into its design, enhancing its performance.',10000,25,0,1,1,74430.0000,1,839,0),(28307,176,'\'Integrated\' Wasp Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,NULL,0),(28308,100,'\'Augmented\' Wasp','Heavy Attack Drone\r\r\n\r\r\nThis drone has been augmented with so many rogue drone parts that it is unrecognizable from its original design.  This new hybrid has a fearsome firepower.',10000,25,0,1,1,310086.0000,1,839,0),(28309,176,'\'Augmented\' Wasp Blueprint',' ',0,0.01,0,1,NULL,9999999.0000,1,NULL,0),(28314,404,'Reception Center','A facility for reception of recently freed slaves for treatment.',100000000,4000,20000,1,NULL,20000000.0000,0,NULL,0),(28315,404,'Holding Pen','A facility for reception of recently captured livestock for blessing.',100000000,4000,20000,1,NULL,20000000.0000,0,NULL,0),(28316,404,'Slave Pen','A facility for containment of recently processed slaves',100000000,4000,20000,1,NULL,20000000.0000,0,NULL,0),(28317,404,'Freedom Hospital','A facility for treatment of recent slaves freed of their vitoc dependency. ',100000000,4000,20000,1,NULL,20000000.0000,0,NULL,0),(28318,438,'Trauma Treatment Facility','A facility which helps free recently freed slaves of their vitoc dependency and helps them regain their free will.',100000000,4000,1,1,NULL,12500000.0000,0,NULL,0),(28319,438,'Vitoc Injection Center','A facility which processes recently captured livestock for preparation to be sold on to Holders.',100000000,4000,1,1,NULL,12500000.0000,0,NULL,0),(28320,881,'Basic Freedom Program ',' ',0,1,0,1,NULL,0.0000,1,NULL,0),(28324,83,'Republic Fleet Carbonized Lead L','Large Projectile Ammo. This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.025,0,100,NULL,2210.0000,1,987,0),(28325,165,'Republic Fleet Carbonized Lead L Blueprint',' ',0,0.01,0,1,NULL,200000.0000,0,NULL,0),(28326,83,'Republic Fleet Carbonized Lead M','Medium Projectile Ammo. This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.05,0.0125,0,100,NULL,848.0000,1,988,0),(28327,165,'Republic Fleet Carbonized Lead M Blueprint',' ',0,0.01,0,1,NULL,80000.0000,0,NULL,0),(28328,83,'Republic Fleet Carbonized Lead S','Small Projectile Ammo. This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem. \r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',0.01,0.0025,0,100,NULL,222.0000,1,989,0),(28329,165,'Republic Fleet Carbonized Lead S Blueprint',' ',0,0.01,0,1,NULL,20000.0000,0,NULL,0),(28330,83,'Republic Fleet Carbonized Lead XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. This ammo uses a simple lead slug encased in a hard shell of crystalline carbon. It is fairly cheap and works very well against most armors. Shields, however, are a problem.\r\r\n\r\r\n60% increased optimal range.\r\r\n5% increased tracking speed.',1,0.125,0,100,NULL,22210.0000,1,1006,0),(28331,165,'Republic Fleet Carbonized Lead XL Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,0,NULL,0),(28332,83,'Republic Fleet Depleted Uranium L','Large Projectile Ammo. Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.025,0,100,NULL,5556.0000,1,987,0),(28333,165,'Republic Fleet Depleted Uranium L Blueprint',' ',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28334,83,'Republic Fleet Depleted Uranium M','Medium Projectile Ammo. Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.0125,0,100,NULL,2236.0000,1,988,0),(28335,165,'Republic Fleet Depleted Uranium M Blueprint',' ',0,0.01,0,1,NULL,205000.0000,0,NULL,0),(28336,83,'Republic Fleet Depleted Uranium S','Small projectile Ammo. Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead. \r\r\n\r\r\n20% tracking speed bonus.',0.01,0.0025,0,100,NULL,524.0000,1,989,0),(28337,165,'Republic Fleet Depleted Uranium S Blueprint',' ',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(28338,83,'Republic Fleet Depleted Uranium XL','Extra Large Projectile Ammo. Can be used only by starbase defense batteries and capital ships like dreadnoughts. Very commonly used by Minmatar pilots, this ammo is incendiary and also has great penetration. Just be careful handling it unless you want to wake up with an extra toe on your forehead.\r\r\n\r\r\n20% tracking speed bonus.',1,0.125,0,100,NULL,55556.0000,1,1006,0),(28339,165,'Republic Fleet Depleted Uranium XL Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,0,NULL,0),(28340,319,'Drug Lab','Carving out asteroids to act as habitats for miners and manufacturers is a cheap and efficient way to quickly cash in on the insatiable needs of the space industry.',1000000,0,0,1,4,0.0000,0,NULL,0),(28351,413,'Design Laboratory','Portable laboratory facilities, anchorable within control tower fields. This structure has copying and invention activities.\r\r\n\r\r\nActivity bonuses:\r\r\n40% reduction in copy activity required time\r\r\n50% reduction in invention required time',100000000,3000,25000,1,NULL,150000000.0000,1,933,0),(28352,883,'Rorqual','The Rorqual was conceived and designed by Outer Ring Excavations in response to a growing need for capital industry platforms with the ability to support and sustain large-scale mining operations in uninhabited areas of space.\r\r\n\r\r\nTo that end, the Rorqual\'s primary strength lies in its ability to grind raw ores into particles of smaller size than possible before, while still maintaining their distinctive molecular structure. This means the vessel is able to carry vast amounts of ore in compressed form.\r\r\n\r\r\nAdditionally, the Rorqual is able to fit a capital tractor beam unit, capable of pulling in cargo containers from far greater distances and at far greater speeds than smaller beams can. It also possesses a sizeable drone bay, jump drive capability and the capacity to fit a clone vat bay. This combination of elements makes the Rorqual the ideal nexus to build deep space mining operations around.\r\r\n\r\r\nDue to its specialization towards industrial operations, its ship maintenance bay is able to accommodate only industrial ships, mining barges and their tech 2 variants',1180000000,14500000,40000,1,128,2386833996.0000,1,1048,0),(28353,944,'Rorqual Blueprint',' ',0,0.01,0,1,NULL,3000000000.0000,1,1046,0),(28356,885,'Cosmic Anomaly','A cosmic signature.',0,1,0,1,NULL,0.0000,0,NULL,0),(28359,314,'Alliance Tournament Silver Medal','The great Alliance Tournament silver medal. So close, and yet so far. Second place in the Alliance Tournament signifies many things to many people. It does, however, stand for one undeniable truth: the holder kicked several metric tons of arse to get it.\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(28360,314,'Alliance Tournament Bronze Medal','The great Alliance Tournament bronze medal. No capsuleer aims for it, and no one glorifies in it. Some call its holders the worst of the best, but there are victories to be gained even in loss. While glory may elude the holder, honor and respect do not.\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(28361,886,'Drone Synaptic Relay Wiring','The relay wiring of a rogue drones synaptic system, these wires allow for a much higher flow of power and information than standard empire technology has yet to achieve.  ',0.5,0.01,0,1,NULL,0.0000,1,1906,0),(28362,886,'Drone Capillary Fluid','The same fluid that flows through rogue drone relays, this substance is an amalgamation of various chemical compounds that many scientists theorize to be akin to the life blood of a rogue drone.  \r\r\n\r\r\nWhatever the reason, the fluid combined with synaptic relays allows for an astonishingly high flow of data.',1,0.02,0,1,NULL,0.0000,1,1906,0),(28363,886,'Drone Cerebral Fragment','A fragment of a rogue drones cerebral cortex.',1,0.03,0,1,NULL,0.0000,1,1906,0),(28364,886,'Drone Tactical Limb','A multipurpose limb of a rogue drone which, in combat models, is a mount for the primary weapon.  The modular design of such limbs allows for them to be incorporated into standard drone designs with some ingenuity.',2,0.07,0,1,NULL,0.0000,1,1906,0),(28365,886,'Drone Epidermal Shielding Chunk','A chunk of the epidermal shielding from a rogue drone, while being both more durable and resistant than standard drone shielding, it is also thinner and more flexible forming, as it does, the skin of a rogue drone.',5,0.1,0,1,NULL,0.0000,1,1906,0),(28366,886,'Drone Coronary Unit','The beating heart of a rogue drone, this power unit is a marvel of technology providing a greater size/power ratio than is currently achievable by modern designs. With some clever tinkering it is possible to adapt this to interface with current drone technology.',2,0.08,0,1,NULL,0.0000,1,1906,0),(28367,450,'Compressed Arkonor','The rarest and most sought-after ore in the known universe. A sizable nugget of this can sweep anyone from rags to riches in no time. Arkonor has the largest amount of megacyte of any ore, and also contains some mexallon and tritanium.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,8.8,0,1,4,2745440.0000,1,512,0),(28368,888,'Compressed Arkonor Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28369,54,'Miner II (China)','Has an improved technology beam, making the extraction process more efficient. Useful for extracting all but the rarest ore.',0,5,0,1,NULL,79128.0000,0,NULL,0),(28373,1218,'Ore Compression',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(28374,257,'Capital Industrial Ships','Skill at operating Capital Industrial Ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,500000000.0000,1,377,0),(28375,771,'Republic Fleet Heavy Assault Missile Launcher','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,1.005,1,NULL,41700.0000,1,974,0),(28376,136,'Republic Fleet Heavy Assault Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,NULL,0),(28377,771,'Caldari Navy Heavy Assault Missile Launcher','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,1.125,1,NULL,41700.0000,1,974,0),(28378,136,'Caldari Navy Heavy Assault Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,NULL,0),(28379,771,'Domination Heavy Assault Missile Launcher','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,1.005,1,NULL,41700.0000,1,974,0),(28380,136,'Domination Heavy Assault Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,300000.0000,0,NULL,0),(28381,771,'Dread Guristas Heavy Assault Missile Launcher','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,1.125,1,NULL,41700.0000,1,974,0),(28382,136,'Dread Guristas Heavy Assault Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,300000.0000,0,NULL,0),(28383,771,'True Sansha Heavy Assault Missile Launcher','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,1.005,1,NULL,41700.0000,1,974,0),(28384,136,'True Sansha Heavy Assault Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,300000.0000,0,NULL,0),(28385,450,'Compressed Crimson Arkonor','While fairly invisible to all but the most experienced miners, there are significant molecular differences between arkonor and its crimson counterpart, so-named because of the blood-red veins running through it.\r\r\n\r\r\nThe rarest and most sought-after ore in the known universe. A sizable nugget of this can sweep anyone from rags to riches in no time. Arkonor has the largest amount of megacyte of any ore, and also contains some mexallon and tritanium.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,8.8,0,1,4,2882712.0000,1,512,0),(28386,888,'Compressed Crimson Arkonor Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28387,450,'Compressed Prime Arkonor','Prime arkonor is the rarest of the rare; the king of ores. Giving a 10% greater mineral yield than regular arkonor, this is the stuff that makes billionaires out of people lucky enough to stumble upon a vein.\r\r\n\r\r\nThe rarest and most sought-after ore in the known universe. A sizable nugget of this can sweep anyone from rags to riches in no time. Arkonor has the largest amount of megacyte of any ore, and also contains some mexallon and tritanium.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,8.8,0,1,4,3019984.0000,1,512,0),(28388,451,'Compressed Bistot','Bistot is a very valuable ore as it holds large portions of two of the rarest minerals in the universe, zydrine and megacyte. It also contains a decent amount of pyerite.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,4.4,0,1,4,1836800.0000,1,514,0),(28389,451,'Compressed Monoclinic Bistot','Monoclinic bistot is a variant of bistot with a slightly different crystal structure. It is highly sought-after, as it gives a slightly higher yield than its straightforward counterpart.\r\r\n\r\r\nBistot is a very valuable ore as it holds large portions of two of the rarest minerals in the universe, zydrine and megacyte. It also contains a decent amount of pyerite.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,4.4,0,1,4,2020480.0000,1,514,0),(28390,451,'Compressed Triclinic Bistot','Bistot with a triclinic crystal system occurs very rarely under natural conditions, but is highly popular with miners due to its extra-high concentrations of the zydrine and megacyte minerals.\r\r\n\r\r\nBistot is a very valuable ore as it holds large portions of two of the rarest minerals in the universe, zydrine and megacyte. It also contains a decent amount of pyerite.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,4.4,0,1,4,1929664.0000,1,514,0),(28391,452,'Compressed Crokite','Crokite is a very heavy ore that is always in high demand because it has the largest ratio of nocxium for any ore in the universe. Valuable deposits of zydrine and tritanium can also be found within this rare ore.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,7.81,0,1,4,707600.0000,1,521,0),(28392,452,'Compressed Crystalline Crokite','Crystalline crokite is the stuff of legend in 0.0 space. Not only does it give a 10% greater yield than regular crokite, but chunks of the rock glitter beautifully in just the right light, making crystalline crokite popular as raw material for jewelry.\r\r\n\r\r\nCrokite is a very heavy ore that is always in high demand because it has the largest ratio of nocxium for any ore in the universe. Valuable deposits of zydrine and tritanium can also be found within this rare ore.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,7.81,0,1,4,779384.0000,1,521,0),(28393,452,'Compressed Sharp Crokite','In certain belts, environmental conditions will carve sharp, jagged edges into crokite rocks, resulting in the formation of sharp crokite.\r\r\n\r\r\nCrokite is a very heavy ore that is always in high demand because it has the largest ratio of nocxium for any ore in the universe. Valuable deposits of zydrine and tritanium can also be found within this rare ore.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,7.81,0,1,4,743492.0000,1,521,0),(28394,453,'Compressed Dark Ochre','Considered a worthless ore for years, dark ochre was ignored by most miners until improved reprocessing techniques managed to extract the huge amount of isogen inside it. Dark ochre also contains useful amounts of tritanium and nocxium.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,4.2,0,1,4,286240.0000,1,522,0),(28395,453,'Compressed Obsidian Ochre','Obsidian ochre, the most valuable member of the dark ochre family, was only first discovered a decade ago. The sleek black surface of this ore managed to reflect scanning waves, making obsidian ochre asteroids almost invisible. Advances in scanning technology revealed these beauties at last.\r\r\n\r\r\nConsidered a worthless ore for years, dark ochre was ignored by most miners until improved reprocessing techniques managed to extract the huge amount of isogen inside it. Dark ochre also contains useful amounts of tritanium and nocxium.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,4.2,0,1,4,314864.0000,1,522,0),(28396,453,'Compressed Onyx Ochre','Shiny black nuggets of onyx ochre look very nice and are occasionally used in ornaments. But the great amount of isogen is what miners are really after. Like in all else, good looks are only an added bonus. \r\r\n\r\r\nConsidered a worthless ore for years, dark ochre was ignored by most miners until improved reprocessing techniques managed to extract the huge amount of isogen inside it. Dark ochre also contains useful amounts of tritanium and nocxium.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,4.2,0,1,4,300552.0000,1,522,0),(28397,467,'Compressed Gneiss','Gneiss is a popular ore type because it holds significant volumes of three heavily used minerals, increasing its utility value. It has a quite a bit of mexallon as well as some pyerite and isogen.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,1.8,0,1,4,132800.0000,1,525,0),(28398,467,'Compressed Iridescent Gneiss','Gneiss is often the first major league ore that up and coming miners graduate to. Finding the more expensive variation of Gneiss, called Iridescent Gneiss, is a major coup for these miners.\r\r\n\r\r\nGneiss is a popular ore type because it holds significant volumes of three heavily used minerals, increasing its utility value. It has a quite a bit of mexallon as well as some pyerite and isogen.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,1.8,0,1,4,139440.0000,1,525,0),(28399,467,'Compressed Prismatic Gneiss','Prismatic Gneiss has fracturized molecule-structure, which explains its unique appearance. It is the most sought after member of the Gneiss family, as it yields 10% more than common Gneiss.\r\r\n\r\r\nGneiss is a popular ore type because it holds significant volumes of three heavily used minerals, increasing its utility value. It has a quite a bit of mexallon as well as some pyerite and isogen.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,1.8,0,1,4,146080.0000,1,525,0),(28400,454,'Compressed Glazed Hedbergite','Asteroids containing this shiny ore were formed in intense heat, such as might result from a supernova. The result, known as glazed hedbergite, is a more concentrated form of hedbergite that has 10% higher yield.\r\r\n\r\r\nHedbergite is sought after for its high concentration of nocxium and isogen. However hedbergite also yields some  pyerite and zydrine.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.47,0,1,4,136288.0000,1,527,0),(28401,454,'Compressed Hedbergite','Hedbergite is sought after for its high concentration of nocxium and isogen. However hedbergite also yields some  pyerite and zydrine.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.47,0,1,4,123712.0000,1,527,0),(28402,454,'Compressed Vitric Hedbergite','When asteroids containing hedbergite pass close to suns or other sources of intense heat can cause the hedbergite to glassify. The result is called vitric hedbergite and has 5% better yield than normal hedbergite. \r\r\n\r\r\nHedbergite is sought after for its high concentration of nocxium and isogen. However hedbergite also yields some  pyerite and zydrine.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.47,0,1,4,130000.0000,1,527,0),(28403,455,'Compressed Hemorphite','With a large portion of nocxium, hemorphite is always a good find. It is common enough that even novice miners can expect to run into it. Hemorphite also has a bit of tritanium, isogen and zydrine.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.86,0,1,4,109360.0000,1,528,0),(28404,455,'Compressed Radiant Hemorphite','Hemorphite exists in many different color variations. Interestingly, the more colorful it becomes, the better yield it has. Radiant hemorphite has 10% better yield than its more bland brother.\r\r\n\r\r\nWith a large portion of nocxium, hemorphite is always a good find. It is common enough that even novice miners can expect to run into it. Hemorphite also has a bit of tritanium, isogen and zydrine.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.86,0,1,4,121320.0000,1,528,0),(28405,455,'Compressed Vivid Hemorphite','Hemorphite exists in many different color variations. Interestingly, the more colorful it becomes, the better yield it has. Vivid hemorphite has 5% better yield than its more bland brother.\r\r\n\r\r\nWith a large portion of nocxium, hemorphite is always a good find. It is common enough that even novice miners can expect to run into it. Hemorphite also has a bit of tritanium, isogen and zydrine.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.86,0,1,4,115340.0000,1,528,0),(28406,456,'Compressed Jaspet','Jaspet has three valuable mineral types, making it easy to sell. It has a large portion of mexallon plus some nocxium and zydrine.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.15,0,1,4,65984.0000,1,529,0),(28407,456,'Compressed Pristine Jaspet','Pristine Jaspet is very rare, which is not so surprising when one considers that it is formed when asteroids collide with comets or ice moons. It has 10% better yield than normal Jaspet.\r\r\n\r\r\nJaspet has three valuable mineral types, making it easy to sell. It has a large portion of mexallon plus some nocxium and zydrine.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.15,0,1,4,73248.0000,1,529,0),(28408,456,'Compressed Pure Jaspet','Pure Jaspet is popular amongst corporate miners who are looking for various minerals for manufacturing, rather than mining purely for profit.\r\r\n\r\r\nJaspet has three valuable mineral types, making it easy to sell. It has a large portion of mexallon plus some nocxium and zydrine.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.15,0,1,4,68608.0000,1,529,0),(28409,457,'Compressed Fiery Kernite','Known as Rage Stone to veteran miners after a discovery of a particularly rich vein of it caused a bar brawl of epic proportions in the Intaki Syndicate. It has a 10% higher yield than basic kernite.\r\r\n\r\r\nKernite is a fairly common ore type that yields a large amount of mexallon. Besides mexallon the kernite also has a bit of tritanium and isogen. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.19,0,1,NULL,28648.0000,1,523,0),(28410,457,'Compressed Kernite','Kernite is a fairly common ore type that yields a large amount of mexallon. Besides mexallon the kernite also has a bit of tritanium and isogen.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.19,0,1,NULL,25964.0000,1,523,0),(28411,457,'Compressed Luminous Kernite','Prophets tell of the mystical nature endowed in luminous kernite. To the rest of us, it\'s an average looking ore that has 5% more yield than normal kernite and can make you rich if you mine it 24/7 and live to be very old.\r\r\n\r\r\nKernite is a fairly common ore type that yields a large amount of mexallon. Besides mexallon the kernite also has a bit of tritanium and isogen. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.19,0,1,NULL,27322.0000,1,523,0),(28412,468,'Compressed Magma Mercoxit','Though it floats through the frigid depths of space, magma mercoxit\'s striking appearance and sheen gives it the impression of bubbling magma. If this visual treasure wasn\'t enticing enough, the 5% higher yield certainly attracts admirers.\r\r\n\r\r\nMercoxit is a very dense ore that must be mined using specialized deep core mining techniques. It contains massive amounts of the extraordinary morphite mineral but few other minerals of note.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.1,0,1,NULL,10321920.0000,1,530,0),(28413,468,'Compressed Mercoxit','Mercoxit is a very dense ore that must be mined using specialized deep core mining techniques. It contains massive amounts of the extraordinary morphite mineral but few other minerals of note.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.1,0,1,NULL,9830400.0000,1,530,0),(28414,468,'Compressed Vitreous Mercoxit','Vitreous mercoxit gleams in the dark, like a siren of myth. Found only in rare clusters in space vitreous mercoxit is very rare, but very valuable, due to its much higher 10% yield.  \r\r\n\r\r\nMercoxit is a very dense ore that must be mined using specialized deep core mining techniques. It contains massive amounts of the extraordinary Morphite mineral but few other minerals of note.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.1,0,1,NULL,10813440.0000,1,530,0),(28415,469,'Compressed Golden Omber','Golden Omber spurred one of the largest gold rushes in the early days of space faring, when isogen was the king of minerals. The 10% extra yield it offers over common Omber was all it took to make it the most sought after ore for a few years.\r\r\n\r\r\nOmber is a common ore that is still an excellent ore for novice miners as it has a sizeable portion of isogen, as well as some tritanium and pyerite. A few trips of mining this and a novice is quick to rise in status. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.07,0,1,NULL,12524.0000,1,526,0),(28416,469,'Compressed Omber','Omber is a common ore that is still an excellent ore for novice miners as it has a sizeable portion of isogen, as well as some tritanium and pyerite. A few trips of mining this and a novice is quick to rise in status. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.07,0,1,NULL,11322.0000,1,526,0),(28417,469,'Compressed Silvery Omber','Silvery Omber was first discovered some fifty years ago in an asteroid belt close to a large moon. The luminescence from the moon made this uncommon cousin of normal Omber seem silvery in appearance, hence the name.\r\r\n\r\r\nOmber is a common ore that is still an excellent ore for novice miners as it has a sizeable portion of isogen, as well as some tritanium and pyerite. A few trips of mining this and a novice is quick to rise in status. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.07,0,1,NULL,11988.0000,1,526,0),(28418,461,'Compressed Bright Spodumain','Spodumain is occasionally found with crystalline traces in its outer surface. Known as bright spodumain, the crystal adds considerable value to an already valuable mineral.  \r\r\n\r\r\nSpodumain is amongst the most desirable ore types around, as it contains high volumes of the four most heavily demanded minerals. Huge volumes of tritanium and pyerite, as well as moderate amounts of mexallon and isogen can be obtained by refining these rocks.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,28,0,1,4,349928.0000,1,517,0),(28419,461,'Compressed Gleaming Spodumain','Once in a while Spodumain is found with crystalline veins running through it. The 10% increased value this yields puts a gleam in the eye of any miner lucky enough to find it.\r\r\n\r\r\nSpodumain is amongst the most desirable ore types around, as it contains high volumes of the four most heavily demanded minerals. Huge volumes of tritanium and pyerite, as well as moderate amounts of mexallon and isogen can be obtained by refining these rocks.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,28,0,1,4,366520.0000,1,517,0),(28420,461,'Compressed Spodumain','Spodumain is amongst the most desirable ore types around, as it contains high volumes of the four most heavily demanded minerals. Huge volumes of tritanium and pyerite, as well as moderate amounts of mexallon and isogen can be obtained by refining these rocks.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,28,0,1,4,333200.0000,1,517,0),(28421,458,'Compressed Azure Plagioclase','Azure plagioclase was made infamous in the melancholic song prose Miner Blues by the Gallentean folk singer Jaroud Dertier three decades ago.\r\r\n\r\r\nPlagioclase is not amongst the most valuable ore types around, but it contains a large amount of pyerite and is thus always in constant demand. It also yields some tritanium and mexallon. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.15,0,1,NULL,5634.0000,1,516,0),(28422,458,'Compressed Plagioclase','Plagioclase is not amongst the most valuable ore types around, but it contains a large amount of pyerite and is thus always in constant demand. It also yields some tritanium and mexallon.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.15,0,1,NULL,5342.0000,1,516,0),(28423,458,'Compressed Rich Plagioclase','With rich plagioclase, having 10% better yield than the normal one, miners can finally regard plagioclase as a mineral that provides a noteworthy profit.\r\r\n\r\r\nPlagioclase is not amongst the most valuable ore types around, but it contains a large amount of pyerite and is thus always in constant demand. It also yields some tritanium and mexallon.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.15,0,1,NULL,5892.0000,1,516,0),(28424,459,'Compressed Pyroxeres','Pyroxeres is an interesting ore type, as it is very plain in most respects except one - deep core reprocessing yields a little bit of nocxium, increasing its value considerably. It also has a large portion of tritanium and some pyerite and mexallon. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.16,0,1,NULL,5062.0000,1,515,0),(28425,459,'Compressed Solid Pyroxeres','Solid Pyroxeres, sometimes called the Flame of Dam\'Torsad, is a relative of normal Pyroxeres. The Flame has 5% higher yield than its more common cousin. \r\r\n\r\r\nPyroxeres is an interesting ore type, as it is very plain in most respects except one - deep core reprocessing yields a little bit of nocxium, increasing its value considerably. It also has a large portion of tritanium and some pyerite and mexallon. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.16,0,1,NULL,5202.0000,1,515,0),(28426,459,'Compressed Viscous Pyroxeres','Viscous Pyroxeres is the secret behind the success of ORE in the early days. ORE has since then moved into more profitable minerals, but Viscous Pyroxeres still holds a special place in the hearts of all miners dreaming of becoming the next mining moguls of EVE.\r\r\n\r\r\nPyroxeres is an interesting ore type, as it is very plain in most respects except one - deep core reprocessing yields a little bit of nocxium, increasing its value considerably. It also has a large portion of tritanium and some pyerite and mexallon.\r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.16,0,1,NULL,5310.0000,1,515,0),(28427,460,'Compressed Condensed Scordite','Condensed Scordite is a close cousin of normal Scordite, but with 5% better yield. The increase may seem insignificant, but matters greatly to new miners where every ISK counts.\r\r\n\r\r\nScordite is amongst the most common ore types in the known universe. It has a large portion of tritanium plus a fair bit of pyerite. Good choice for those starting their mining careers. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.19,0,1,NULL,2184.0000,1,519,0),(28428,460,'Compressed Massive Scordite','Massive Scordite was the stuff of legend in the early days of space exploration. Though it has long since been taken over in value by other ores it still has a special place in the hearts of veteran miners.\r\r\n\r\r\nScordite is amongst the most common ore types in the known universe. It has a large portion of tritanium plus a fair bit of pyerite. Good choice for those starting their mining careers. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.19,0,1,NULL,2282.0000,1,519,0),(28429,460,'Compressed Scordite','Scordite is amongst the most common ore types in the known universe. It has a large portion of tritanium plus a fair bit of pyerite. Good choice for those starting their mining careers. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',1e35,0.19,0,1,NULL,2076.0000,1,519,0),(28430,462,'Compressed Concentrated Veldspar','Clusters of veldspar, called concentrated veldspar, are sometimes found in areas where normal veldspar is already in abundance.\r\r\n\r\r\nThe most common ore type in the known universe, veldspar can be found almost everywhere. It is still in constant demand as it holds a large portion of the much-used tritanium mineral. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',4000,0.15,0,1,NULL,872.0000,1,518,0),(28431,462,'Compressed Dense Veldspar','In asteroids above average size, the intense pressure can weld normal veldspar into what is known as dense veldspar, increasing the yield by 10%. \r\r\n\r\r\nThe most common ore type in the known universe, veldspar can be found almost everywhere. It is still in constant demand as it holds a large portion of the much-used tritanium mineral. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',4000,0.15,0,1,NULL,914.0000,1,518,0),(28432,462,'Compressed Veldspar','The most common ore type in the known universe, veldspar can be found almost everywhere. It is still in constant demand as it holds a large portion of the much-used tritanium mineral. \r\r\n\r\r\nThis ore is a compressed and much more dense version of the original ore.',4000,0.15,0,1,NULL,830.0000,1,518,0),(28433,465,'Compressed Blue Ice','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. Due to its unique chemical composition and the circumstances under which it forms, blue ice contains more oxygen isotopes than any other ice asteroid.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,105000.0000,1,1855,0),(28434,465,'Compressed Clear Icicle','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. These crystalline formations can be found scattered around many an ice field, and are known as the universe\'s primary source of helium isotopes.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,519000.0000,1,1855,0),(28435,465,'Compressed Dark Glitter','Dark glitter is one of the rarest of the interstellar ices, formed only in areas with large amounts of residual electrical current.  Little is known about the exact way in which it comes into being; the staggering amount of liquid ozone to be found inside one of these rocks makes it an intriguing mystery for stellar physicists and chemists alike.  In addition, it contains large amounts of heavy water and a decent measure of strontium clathrates.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,2141000.0000,1,1855,0),(28436,465,'Compressed Enriched Clear Icicle','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. These crystalline formations can be found scattered around many an ice field and are known as the universe\'s primary source of helium isotopes.  Due to environmental factors, this fragment\'s isotope deposits have become even richer than its regular counterparts\'.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,643000.0000,1,1855,0),(28437,465,'Compressed Gelidus','Fairly rare and very valuable, Gelidus-type ice formations are a large-scale source of strontium clathrates, one of the rarest ice solids found in the universe, in addition to which they contain unusually large concentrations of heavy water and liquid ozone.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,1140000.0000,1,1855,0),(28438,465,'Compressed Glacial Mass','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. Glacial masses are known to contain hydrogen isotopes in abundance, in addition to smatterings of heavy water and liquid ozone.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,105000.0000,1,1855,0),(28439,465,'Compressed Glare Crust','In areas with high concentrations of electromagnetic activity, ice formations such as this one, containing large amounts of heavy water and liquid ozone, are spontaneously formed during times of great electric flux.  Glare crust also contains a small amount of strontium clathrates.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,2107000.0000,1,1855,0),(28440,465,'Compressed Krystallos','The universe\'s richest known source of strontium clathrates, Krystallos ice formations are formed only in areas where a very particular combination of environmental factors are at play. Krystallos compounds also include quite a bit of liquid ozone.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,1037000.0000,1,1855,0),(28441,465,'Compressed Pristine White Glaze','When star fusion processes occur near high concentrations of silicate dust, such as those found in interstellar ice fields, the substance known as White Glaze is formed. While White Glaze generally is extremely high in nitrogen-14 and other stable nitrogen isotopes, a few rare fragments, such as this one, have stayed free of radioactive contaminants and are thus richer in isotopes than their more impure counterparts.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.\r\r\n',1000,100,0,1,NULL,160000.0000,1,1855,0),(28442,465,'Compressed Smooth Glacial Mass','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. Glacial masses are known to contain hydrogen isotopes in abundance, but the high surface diffusion on this particular mass means it has considerably more than its coarser counterparts.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,160000.0000,1,1855,0),(28443,465,'Compressed Thick Blue Ice','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. Due to its unique chemical composition and the circumstances under which it forms, blue ice will, under normal circumstances, contain more oxygen isotopes than any other ice asteroid. This particular formation is an old one and therefore contains even more than its less mature siblings.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.\r\r\n',1000,100,0,1,NULL,160000.0000,1,1855,0),(28444,465,'Compressed White Glaze','When star fusion processes occur near high concentrations of silicate dust, such as those found in interstellar ice fields, the substance known as White Glaze is formed. White Glaze is extremely high in nitrogen-14 and other stable nitrogen isotopes, and is thus a necessity for the sustained operation of certain kinds of control tower.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,105000.0000,1,1855,0),(28448,888,'Compressed Prime Arkonor Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28449,888,'Compressed Bistot Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28450,888,'Compressed Monoclinic Bistot Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28451,888,'Compressed Triclinic Bistot Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28452,888,'Compressed Crokite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28453,888,'Compressed Crystalline Crokite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28454,888,'Compressed Sharp Crokite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28455,888,'Compressed Dark Ochre Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28456,888,'Compressed Obsidian Ochre Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28457,888,'Compressed Onyx Ochre Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28458,888,'Compressed Gneiss Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28459,888,'Compressed Iridescent Gneiss Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28460,888,'Compressed Prismatic Gneiss Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28461,888,'Compressed Hedbergite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28462,888,'Compressed Glazed Hedbergite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28463,888,'Compressed Vitric Hedbergite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28464,888,'Compressed Hemorphite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28465,888,'Compressed Radiant Hemorphite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28466,888,'Compressed Vivid Hemorphite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(28467,888,'Compressed Jaspet Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28468,888,'Compressed Pristine Jaspet Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28469,888,'Compressed Pure Jaspet Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28470,888,'Compressed Kernite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28471,888,'Compressed Fiery Kernite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28472,888,'Compressed Luminous Kernite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28473,888,'Compressed Magma Mercoxit Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1250000.0000,0,NULL,0),(28474,888,'Compressed Mercoxit Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1250000.0000,0,NULL,0),(28475,888,'Compressed Vitreous Mercoxit Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1250000.0000,0,NULL,0),(28476,888,'Compressed Omber Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28477,888,'Compressed Golden Omber Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28478,888,'Compressed Silvery Omber Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28479,888,'Compressed Azure Plagioclase Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28480,888,'Compressed Plagioclase Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28481,888,'Compressed Rich Plagioclase Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28482,888,'Compressed Pyroxeres Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28483,888,'Compressed Solid Pyroxeres Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28484,888,'Compressed Viscous Pyroxeres Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28485,888,'Compressed Condensed Scordite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28486,888,'Compressed Massive Scordite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28487,888,'Compressed Scordite Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28488,888,'Compressed Bright Spodumain Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28489,888,'Compressed Gleaming Spodumain Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28490,888,'Compressed Spodumain Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28491,888,'Compressed Concentrated Veldspar Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28492,888,'Compressed Dense Veldspar Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28493,888,'Compressed Veldspar Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28494,890,'Compressed Blue Ice Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28495,890,'Compressed Clear Icicle Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28496,890,'Compressed Dark Glitter Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28497,890,'Compressed Enriched Clear Icicle Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28498,890,'Compressed Gelidus Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28499,890,'Compressed Glacial Mass Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28500,890,'Compressed Glare Crust Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28501,890,'Compressed Krystallos Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28502,890,'Compressed Pristine White Glaze Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28503,890,'Compressed Smooth Glacial Mass Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28504,890,'Compressed Thick Blue Ice Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28505,890,'Compressed White Glaze Blueprint','Note: This blueprint can only be used with the Rorqual Capital Industrial Ships assembly lines.',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(28506,821,'Drone Commandeered Battleship Deluxe','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(28507,821,'Swarm Parasite Worker Deluxe','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(28508,495,'Swarm Defense Battery Deluxe','This missile Sentry will launch missiles at any target it considers to be a threat. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28509,821,'Supreme Hive Defender Deluxe','Rogue drones are hi-tech drones that have the ability to manufacture themselves. Rogue drone hives can be found throughout the universe of EVE and are a constant menace to space travelers. Threat level: Deadly',21000000,1010000,950,1,8,0.0000,0,NULL,0),(28510,495,'Kuari Strain Mother','This gargantuan mother drone holds the central CPU, controlling the rogue drones throughout the sector. ',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28511,507,'Khanid Navy Rocket Launcher','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.',0,5,0.2813,1,NULL,3336.0000,1,639,0),(28512,136,'Khanid Navy Rocket Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28513,508,'Khanid Navy Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.',0,20,2.3,1,4,20580.0000,1,NULL,0),(28514,65,'Khanid Navy Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,24988.0000,1,683,0),(28515,145,'Khanid Navy Stasis Webifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28516,52,'Khanid Navy Warp Disruptor','Disrupts the target ship\'s navigation computer which prevents it from warping.',0,5,0,1,NULL,47476.0000,1,1935,0),(28517,132,'Khanid Navy Warp Disruptor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28518,52,'Khanid Navy Warp Scrambler','Disrupts the target ship\'s navigation computer which prevents it from warping or using a microwarpdrive.',0,5,0,1,NULL,47476.0000,1,1936,0),(28519,132,'Khanid Navy Warp Scrambler Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28520,98,'Khanid Navy Adaptive Nano Plating','This cutting edge system is the most versatile nano plating around. It has the ability to instantly adapt to any attack. However, it is somewhat less effective than a specialized plating. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,8304.0000,1,1670,0),(28521,163,'Khanid Navy Adaptive Nano Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28522,328,'Khanid Navy Armor EM Hardener','An enhanced version of the standard EM armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,225690.0000,1,1681,0),(28523,348,'Khanid Navy Armor EM Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28524,328,'Khanid Navy Armor Explosive Hardener','An enhanced version of the standard explosive armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,397768.0000,1,1680,0),(28525,348,'Khanid Navy Armor Explosive Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28526,328,'Khanid Navy Armor Kinetic Hardener','An enhanced version of the standard kinetic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,340756.0000,1,1679,0),(28527,348,'Khanid Navy Armor Kinetic Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28528,328,'Khanid Navy Armor Thermic Hardener','An enhanced version of the standard Thermic armor plating. Uses advanced magnetic field generators to strengthen the Nanobot Plating integrity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,277634.0000,1,1678,0),(28529,348,'Khanid Navy Armor Thermic Hardener Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28530,43,'Khanid Navy Cap Recharger','Increases the capacitor recharge rate.',1,5,0,1,NULL,33662.0000,1,665,0),(28531,123,'Khanid Navy Cap Recharger Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28532,767,'Khanid Navy Capacitor Power Relay','Increases capacitor recharge rate at the expense of shield boosting.',20,5,0,1,NULL,10656.0000,1,667,0),(28533,137,'Khanid Navy Capacitor Power Relay Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28534,326,'Khanid Navy Energized Adaptive Nano Membrane','An enhanced version of the standard Adaptive Nano armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,120202.0000,1,1686,0),(28535,163,'Khanid Navy Energized Adaptive Nano Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28536,326,'Khanid Navy Energized Kinetic Membrane','A enhanced version of the standard Magnetic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1685,0),(28537,163,'Khanid Navy Energized Kinetic Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28538,326,'Khanid Navy Energized Explosive Membrane','A enhanced version of the standard Reactive  armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1682,0),(28539,163,'Khanid Navy Energized Explosive Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28540,326,'Khanid Navy Energized EM Membrane','A enhanced version of the standard Reflective armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1684,0),(28541,163,'Khanid Navy Energized EM Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28542,326,'Khanid Navy Energized Thermic Membrane','A enhanced version of the standard Thermic armor plating. Uses advanced magnetic Field generators to strengthen the Nanobot Plating integrity. Penalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,90452.0000,1,1683,0),(28543,163,'Khanid Navy Energized Thermic Membrane Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28544,62,'Khanid Navy Large Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,50,0,1,4,39996.0000,1,1051,0),(28545,72,'Khanid Navy Large EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,50,0,1,NULL,347216.0000,1,381,0),(28546,152,'Khanid Navy Large EMP Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28547,98,'Khanid Navy Kinetic Plating','This plating utilizes a magnetic field to deflect kinetic attacks. Grants a bonus to kinetic resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1666,0),(28548,163,'Khanid Navy Kinetic Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28549,62,'Khanid Navy Medium Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,10,0,1,4,19916.0000,1,1050,0),(28550,72,'Khanid Navy Medium EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',100,10,0,1,NULL,43770.0000,1,383,0),(28551,152,'Khanid Navy Medium EMP Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28552,98,'Khanid Navy Explosive Plating','An array of microscopic reactive bombs that are exploded to counter explosive damage. Grants a bonus to explosive resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1667,0),(28553,163,'Khanid Navy Explosive Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28554,98,'Khanid Navy EM Plating','An array of microscopic reactive prisms that disperse electromagnetic radiation. Grants a bonus to EM resistance.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1668,0),(28555,163,'Khanid Navy EM Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28556,62,'Khanid Navy Small Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship.',500,5,0,1,4,9996.0000,1,1049,0),(28557,72,'Khanid Navy Small EMP Smartbomb','Radiates an omnidirectional pulse from the ship that causes EM damage to surrounding vessels.',10,5,0,1,NULL,62370.0000,1,382,0),(28558,152,'Khanid Navy Small EMP Smartbomb Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(28559,98,'Khanid Navy Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1665,0),(28560,163,'Khanid Navy Thermic Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28561,285,'Khanid Navy Co-Processor','Increases CPU output.',0,5,0,1,NULL,16428.0000,1,676,0),(28562,346,'Khanid Navy Co-Processor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28563,367,'Khanid Navy Ballistic Control System','A computer system designed for monitoring and guiding missiles in flight, thus allowing for superior effectiveness and lethality. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,85006.0000,1,645,0),(28564,400,'Khanid Navy Ballistic Control System Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28565,771,'Khanid Navy Heavy Assault Missile Launcher','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations. ',0,10,1.125,1,NULL,41700.0000,1,974,0),(28566,136,'Khanid Navy Heavy Assault Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,300000.0000,1,NULL,0),(28571,383,'Damaged Sentinel Angel','This battle-station has been damaged or been worn out from overuse and lack of maintenance.  It is still functional, but not at its full capacity.',1000,1000,1000,1,2,0.0000,0,NULL,0),(28572,383,'Damaged Sentinel Bloodraider','This battle-station has been damaged or been worn out from overuse and lack of maintenance.  It is still functional, but not at its full capacity.',1000,1000,1000,1,4,0.0000,0,NULL,0),(28573,383,'Damaged Sentinel Sansha','This battle-station has been damaged or been worn out from overuse and lack of maintenance.  It is still functional, but not at its full capacity.',1000,1000,1000,1,4,0.0000,0,NULL,0),(28574,383,'Damaged Sentinel Serpentis','This battle-station has been damaged or been worn out from overuse and lack of maintenance.  It is still functional, but not at its full capacity.',1000,1000,1000,1,8,0.0000,0,NULL,0),(28575,383,'Damaged Sentinel Chimera Strain Mother','This Drone station has several formidable defensive systems. It appears to be damaged and not functioning up to its full potential.',1000,1000,1000,1,NULL,0.0000,0,NULL,0),(28576,546,'Mining Laser Upgrade II','Increases the yield on mining lasers, but causes them to use up more CPU.',1,5,0,1,NULL,253496.0000,1,935,0),(28577,1139,'Mining Laser Upgrade II Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,NULL,0),(28578,546,'Ice Harvester Upgrade II','Decreases the cycle time on Ice Harvester but causes them to use up more CPU.',1,5,0,1,NULL,253496.0000,1,935,0),(28579,1139,'Ice Harvester Upgrade II Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,NULL,0),(28582,319,'Hydrochloric Acid Manufacturing Plant','A Hydrochloric Acid manufacturing plant.',1000000,150,8850,1,NULL,0.0000,0,NULL,0),(28583,515,'Industrial Core I','An electronic interface designed to facilitate the deployment of the Rorqual into its industrial configuration. Whilst in the deployed configuration, energy is channelled to special assembly lines which can compress asteroid ore and ice.\r\r\n\r\r\nNote: can only be fitted on the Rorqual ORE capital ship.',1,4000,0,1,NULL,52926494.0000,1,801,0),(28584,516,'Industrial Core I Blueprint',' ',0,0.01,0,1,NULL,522349680.0000,1,343,0),(28585,1218,'Industrial Reconfiguration','Skill at the operation of industrial core modules. 50-unit reduction in heavy water consumption amount for module activation per skill level.',0,0.01,0,1,NULL,25000000.0000,1,1323,0),(28603,186,'Rorqual Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(28604,272,'Tournament Observation','Skill at observating tournaments. +2 extra targets per skill level, up to the ship\'s maximum allowed number of targets locked.',0,0.01,0,1,NULL,500000.0000,0,NULL,0),(28605,891,'Design Laboratory Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1359,0),(28606,941,'Orca','The Orca was developed as a joint venture between Outer Ring Excavations and Deep Core Mining Inc as a vessel to help meet the demands of New Eden\'s industry and provide a flexible platform from which mining operations can be more easily managed.\r\r\n\r\r\nThe Orca uses much of the technology developed by ORE for the Rorqual and integrated with the latest advancements from Deep Core Mining research division has developed a vessel which offers a diverse role to all sizes of operations and needs. ',250000000,10250000,30000,1,128,610774740.0000,1,1048,0),(28607,945,'Orca Blueprint',' ',0,0.01,0,1,NULL,900000000.0000,1,1046,0),(28608,319,'Asteroid Station - 1 - Strong HP','Dark and ominous metal structures jut outwards from this crumbled asteroid. Scanners indicate a distant powersource far within the adamant rock.',1000000,100000000,10000,1,NULL,0.0000,0,NULL,0),(28609,257,'Heavy Interdiction Cruisers','Skill for operation of Heavy Interdiction Cruisers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,32000000.0000,1,377,0),(28612,892,'Planet Satellite','A satellite deployed into low orbit of a planet to allow focused scanning for resources.',1,30,0,1,NULL,227328.0000,0,NULL,0),(28613,918,'Planet Satellite Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,0,NULL,0),(28615,257,'Electronic Attack Ships','Skill for the operation of Electronic Attack Frigates. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,4000000.0000,1,377,0),(28616,319,'Gallentean Laboratory w/scientists','Equally equipped for scientific observation and entertainment of all sorts, these multi-purpose structures, while not quite big enough to be classified as stations, nonetheless see quite a bit of use by both tourists and professionals.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(28617,462,'Banidine','A variant of the common ore Veldspar, Banidine is found in far lesser abundance - which causes no problems for miners since the latter ore is virtually worthless, being riddled with impurities.\r\r\n',4000,0.1,0,1,NULL,0.0000,1,NULL,0),(28618,459,'Augumene','Despite its resemblance to common Pyroxeres, Augumene ore in its raw form is both rare and highly toxic to humans. Thus, while it is also a source of many of the minerals found in Pyroxeres ore, Augumene is generally considered virtually worthless due to the dangers posed by its handling. ',1e35,0.3,0,1,NULL,0.0000,1,NULL,0),(28619,469,'Mercium','The rare mineral Mercium is thought to be closely related to Omber, varying slightly in chemical composition; in fact, these ores were classified as separate types only recently. However, current refining technologies have been found to do irreparable damage to Mercium ore, rendering it unusable for all practical purposes. ',1e35,0.6,0,1,NULL,0.0000,1,NULL,0),(28620,457,'Lyavite','Lyavite is a relatively rare ore quite similar in some respects to Kernite. However, due to the circumstances under which this ore is formed, it is highly unstable when refined; this quality renders it worthless to all but the most desperate of miners. ',1e35,1.2,0,1,NULL,0.0000,1,NULL,0),(28621,456,'Pithix','Pithix (sometimes spelled Pythix), sister ore to Jaspet, also contains a myriad of mineral types, but is found only in asteroids of a certain age; this oddity, combined with the fact that current Pithix refining methods are quite inefficient, makes the ore little more than a minor curiosity to the scientific community as a whole. ',1e35,2,0,1,NULL,0.0000,1,NULL,0),(28622,467,'Green Arisite','Green Arisite is a close cousin to Gneiss, although it is much less commonly found in known space. It is not at all valuable to miners or refiners, however, since its byproducts tend to foul up refining equipment, thus requiring exorbitant maintenance costs. ',1e35,5,0,1,NULL,0.0000,1,NULL,0),(28623,453,'Oeryl','Very similar in composition to Dark Ochre, Oeryl has come into the spotlight only since advanced refining techniques have made Dark Ochre highly sought after for its high isogen content. While refining processes for Oeryl remain utterly ineffective, making this ore worthless to most manufacturers, scientists believe it may become equally as valuable as its Ochre counterpart given a few years of research. ',1e35,8,0,1,4,0.0000,1,NULL,0),(28624,452,'Geodite','Geodite ore used to be common, but was mined heavily in the early years of interstellar industry, before the discovery of Crokite. The quality of nocxium taken from Geodite is very poor by today\'s refining standards, making the ore nearly worthless.',1e35,16,0,1,4,0.0000,1,NULL,0),(28625,450,'Polygypsum','The rarest and most valuable ore in the known universe, Arkonor, has a less well known cousin called Polygypsum. While the two are very similar in chemical composition, the latter is quite unstable, having a tendency to ignite when handled roughly. While posing little danger to a spacecraft, which is built to withstand tremendous heat, this property makes the ore too dangerous under any other circumstances - such as in the business of refining. ',1e35,16,0,1,NULL,0.0000,1,NULL,0),(28626,468,'Zuthrine','Zuthrine is one of the most dense ores in known space, a close relative of Mercoxit, it also contains enormous amounts of Morphite.  It is found only in the very core of asteriods it requires specialized deep core mining techniques to extract.',1e35,40,0,1,NULL,0.0000,1,NULL,0),(28627,465,'Azure Ice','Interstellar ices are formed by the accretion of gas molecules onto silicate dust particles. Azure ice forms under the same circumstances as \"blue ice,\" but due to its slightly different chemical composition, it contains substantially fewer oxygen isotopes by volume than its blue cousin, rendering it a \"lesser\" material.',1000,1000,0,1,NULL,0.0000,1,NULL,0),(28628,465,'Crystalline Icicle','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. These crystalline formations can be found scattered around many stellar ice fields, but \"crystalline icicles\" have a very low isotope count compared to other minable ices, making it relatively worthless. It\'s simply \"space ice.\" ',1000,1000,0,1,NULL,0.0000,1,NULL,0),(28629,711,'Gamboge Cytoserocin','Cytoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. It is used in electronics and weapon manufacturing, as well as the production of high-grade combat boosters. Cytoserocin can only be found in a few areas, such as interstellar gas clouds out in low security and 0.0 space.  ',0,10,0,1,NULL,0.0000,1,NULL,0),(28630,711,'Chartreuse Cytoserocin','Cytoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. It is used in electronics and weapon manufacturing, as well as the production of high-grade combat boosters. Cytoserocin can only be found in a few areas, such as interstellar gas clouds out in low security and 0.0 space.  ',0,10,0,1,NULL,0.0000,1,NULL,0),(28631,272,'Imperial Navy Security Clearance','Fake skill that specifies the owners security clearance for Imperial Navy facilities (e.g. acceleration gates).',0,0.01,0,1,NULL,0.0000,0,NULL,0),(28646,658,'Covert Cynosural Field Generator I','Generates an undetectable cynosural field which only Black Ops jump drives can lock on to.\r\r\n\r\r\nNote: can only be fitted on Black Ops, Blockade Runners, Covert Ops, Etana, Prospect, Stealth Bombers and Force Recon Ships, as well as Strategic Cruisers equipped with Covert Reconfiguration Subsystems.',0,25,0,1,NULL,15153312.0000,1,1641,0),(28647,532,'Covert Cynosural Field Generator I Blueprint',' ',0,0.01,0,1,NULL,31372640.0000,1,799,0),(28650,897,'Covert Cynosural Field I','A precise frequency energy field, used as a target beacon for jumpdrives.',1,5,0,1,NULL,32136.0000,0,NULL,0),(28651,532,'Covert Cynosural Field I Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(28652,590,'Covert Jump Portal Generator I','A piece of machinery designed to allow a black ops vessel to create a bridge between systems without the use of a stargate, allowing its companions access through vast tracts of space to join it on the battlefield.<br>\r\r\nNote: Can only be fitted on Black Ops.<br>\r\r\nJump Portal Generators use the same isotopes as your ships jump drive to jump other ships through the portal. You will need sufficient fuel in your holds in order to allow ships in your fleet to use the jump portal when it is activated.',1,125,0,1,NULL,42054002.0000,1,1640,0),(28653,516,'Covert Jump Portal Generator I Blueprint',' ',0,0.01,0,1,NULL,481455760.0000,1,799,0),(28654,899,'Warp Disruption Field Generator I','The field generator projects a warp disruption sphere centered upon the ship for its entire duration.  The field prevents any warping or jump drive activation within its area of effect.\r\n\r\nThe generator has several effects upon the parent ship whilst active.  It increases its signature radius and agility whilst penalizing the velocity bonus of any afterburner or microwarpdrive modules. It also prevents any friendly remote effects from being rendered to the parent ship.  \r\n\r\nThis module\'s effect can be modified with scripts.\r\n\r\nNote: can only be fitted on the Heavy Interdiction Cruisers.',0,50,1,1,NULL,4358968.0000,1,1085,0),(28655,132,'Warp Disruption Field Generator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1572,0),(28656,257,'Black Ops','Skill for the operation of Black Ops. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,64000000.0000,1,377,0),(28659,900,'Paladin','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today s warship technology. While being thick-skinned, hard-hitting monsters on their own, they are also able to use Bastion technology. Similar in effect to capital reconfiguration technology, when activated the Bastion module provides immunity to electronic warfare and the ability to withstand enormous amounts of punishment, at the cost of being stationary.\r\r\n\r\r\nDeveloper: Carthum Conglomerate \r\r\n\r\r\nCarthum ships are the very embodiment of the Amarrian warfare philosophy. Possessing sturdy armor and advanced weapon systems, they provide a nice mix of offense and defense.',92245000,495000,1125,1,4,396902230.0000,1,1081,0),(28660,107,'Paladin Blueprint',' ',0,0.01,0,1,NULL,1800000000.0000,1,NULL,0),(28661,900,'Kronos','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today s warship technology. While being thick-skinned, hard-hitting monsters on their own, they are also able to use Bastion technology. Similar in effect to capital reconfiguration technology, when activated the Bastion module provides immunity to electronic warfare and the ability to withstand enormous amounts of punishment, at the cost of being stationary.\r\r\n\r\r\nDeveloper: Duvolle Labs\r\r\n\r\r\nDuvolle Labs manufactures sturdy ships with a good mix of offensive and defensive capabilities. Since the company is one of New Eden\'s foremost manufacturers of particle blasters, its ships tend to favor turrets and thus have somewhat higher power output than normal.',93480000,486000,1275,1,8,388186218.0000,1,1083,0),(28662,107,'Kronos Blueprint',' ',0,0.01,0,1,NULL,1760000000.0000,1,NULL,0),(28665,900,'Vargur','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today s warship technology. While being thick-skinned, hard-hitting monsters on their own, they are also able to use Bastion technology. Similar in effect to capital reconfiguration technology, when activated the Bastion module provides immunity to electronic warfare and the ability to withstand enormous amounts of punishment, at the cost of being stationary.\r\r\n\r\r\nDeveloper: Boundless Creation\r\r\n\r\r\nBoundless Creation\'s ships are based on the Brutor Tribe\'s philosophy of warfare: simply fit as much firepower onto your ship as possible. Defense systems and electronics arrays therefore take a back seat to sheer annihilative potential.',96520000,450000,1150,1,2,384259210.0000,1,1084,0),(28666,107,'Vargur Blueprint',' ',0,0.01,0,1,NULL,1450000000.0000,1,NULL,0),(28667,257,'Marauders','Skill for the operation of Marauders. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,64000000.0000,1,377,0),(28668,916,'Nanite Repair Paste','A thick, heavy liquid, typically stored in tanks or container systems intended for liquids. It is composed of billions of nanites that can be programmed to repair damaged ship modules on the fly. The paste is simply applied to the damaged area, and the nanites meld into an exact copy of the damaged area, thus effecting repairs upon the module. This is a one-time process, as the nanites use themselves up along with the trace elements mixed into their carrier fluid.\r\r\n\r\r\nThe Repair Paste is generally only used for emergency on-site repairs. It is then recommended to have the damaged components looked at by a certified technician at first opportunity.',2500,0.01,0,10,NULL,6500.0000,1,1103,0),(28670,303,'Synth Blue Pill Booster','This booster relaxes a pilot\'s ability to control certain shield functions, among other things. It creates a temporary feeling of euphoria that counteracts the unpleasantness inherent in activating shield boosters, and permits the pilot to force the boosters to better performance without suffering undue pain.',1,1,0,1,NULL,16384.0000,1,977,0),(28671,718,'Synth Blue Pill Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28672,303,'Synth Crash Booster','This booster quickens a pilot\'s reactions, pushing him into the delicate twitch territory inhabited by the best missile marksmen. Any missile he launches at his hapless victims will hit its mark with that much more precision, although the pilot may be too busy grinding his teeth to notice.',1,1,0,1,NULL,16384.0000,1,977,0),(28673,718,'Synth Crash Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28674,303,'Synth Drop Booster','This booster throws a pilot into temporary dementia, making every target feel like a monstrous threat that must be destroyed at all cost. The pilot manages to force his turrets into better tracking, though it may take a while before he stops wanting to kill everything in sight.',1,1,0,1,NULL,16384.0000,1,977,0),(28675,718,'Synth Drop Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28676,303,'Synth Exile Booster','This booster hardens a pilot\'s resistance to attacks, letting him withstand their impact to a greater extent. The discomfort of having his armor reduced piecemeal remains unaltered, but the pilot is filled with such a surge of rage that he bullies through it like a living tank.',1,1,0,1,NULL,16384.0000,1,977,0),(28677,718,'Synth Exile Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28678,303,'Synth Frentix Booster','This strong concoction of painkillers helps the pilot block out all inessential thought processes (along with the occasional needed one) and to focus his attention completely on the task at hand. When that task is to hit a target, it certainly makes for better aim, though it does tend to make one\'s extremities go numb for short periods.',1,1,0,1,NULL,16384.0000,1,977,0),(28679,718,'Synth Frentix Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28680,303,'Synth Mindflood Booster','This booster relaxant allows the pilot to control his ship more instinctively and expend less energy in doing so. This in turn lets the ship utilize more of its resources for mechanical functions, most notably its capacitor, rather than constantly having to compensate for the usual exaggerated motions of a stressed pilot.',1,1,0,1,NULL,16384.0000,1,977,0),(28681,718,'Synth Mindflood Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28682,303,'Synth X-Instinct Booster','This energizing booster grants its user a vastly improved economy of effort when parsing the data streams needed to sustain space flight. The main benefits of this lie not in improved performance but less waste of transmission and extraneous micromaneuvers, making the pilot\'s ship sleeker in performance and harder to detect. The booster\'s only major drawback is the crazed notion that the pilot\'s inventory would look so much better if merely rearranged ONE MORE TIME.',1,1,0,1,NULL,16384.0000,1,977,0),(28683,718,'Synth X-Instinct Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28684,303,'Synth Sooth Sayer Booster','This booster induces a trancelike state whereupon the pilot is able to sense the movement of faraway items without all the usual static flooding the senses. Being in a trance helps the pilot hit those moving items with better accuracy, although he has to be careful not to start hallucinating.',1,1,0,1,NULL,16384.0000,1,977,0),(28685,718,'Synth Sooth Sayer Booster Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(28686,712,'Pure Synth Blue Pill Booster','Synth Blue Pill compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(28687,712,'Pure Synth Crash Booster','Synth Crash compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(28688,712,'Pure Synth Drop Booster','Synth Drop compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(28689,712,'Pure Synth Exile Booster','Synth Exile compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(28690,712,'Pure Synth Frentix Booster','Synth Frentix compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(28691,712,'Pure Synth Mindflood Booster','Synth Mindflood compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(28692,712,'Pure Synth Sooth Sayer Booster','Synth Sooth Sayer compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(28693,712,'Pure Synth X-Instinct Booster','Synth X-Instinct compound in its uncut form, ready to be processed into the final version of the combat booster.',0,1,0,1,NULL,0.0000,1,1858,0),(28694,711,'Amber Mykoserocin','Mykoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. The crystals are commonly used in electronics and weapon manufacturing, as well as the creation of legalized Synth booster variants. Mykoserocin can only be found in abundance in a few areas, such as interstellar gas clouds within high security space. ',0,10,0,1,NULL,0.0000,1,983,0),(28695,711,'Azure Mykoserocin','Mykoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. The crystals are commonly used in electronics and weapon manufacturing, as well as the creation of legalized Synth booster variants. Mykoserocin can only be found in abundance in a few areas, such as interstellar gas clouds within high security space. ',0,10,0,1,NULL,0.0000,1,983,0),(28696,711,'Celadon Mykoserocin','Mykoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. The crystals are commonly used in electronics and weapon manufacturing, as well as the creation of legalized Synth booster variants. Mykoserocin can only be found in abundance in a few areas, such as interstellar gas clouds within high security space. ',0,10,0,1,NULL,0.0000,1,983,0),(28697,711,'Golden Mykoserocin','Mykoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. The crystals are commonly used in electronics and weapon manufacturing, as well as the creation of legalized Synth booster variants. Mykoserocin can only be found in abundance in a few areas, such as interstellar gas clouds within high security space. ',0,10,0,1,NULL,0.0000,1,983,0),(28698,711,'Lime Mykoserocin','Mykoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. The crystals are commonly used in electronics and weapon manufacturing, as well as the creation of legalized Synth booster variants. Mykoserocin can only be found in abundance in a few areas, such as interstellar gas clouds within high security space. ',0,10,0,1,NULL,0.0000,1,983,0),(28699,711,'Malachite Mykoserocin','Mykoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. The crystals are commonly used in electronics and weapon manufacturing, as well as the creation of legalized Synth booster variants. Mykoserocin can only be found in abundance in a few areas, such as interstellar gas clouds within high security space. ',0,10,0,1,NULL,0.0000,1,983,0),(28700,711,'Vermillion Mykoserocin','Mykoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. The crystals are commonly used in electronics and weapon manufacturing, as well as the creation of legalized Synth booster variants. Mykoserocin can only be found in abundance in a few areas, such as interstellar gas clouds within high security space. ',0,10,0,1,NULL,0.0000,1,983,0),(28701,711,'Viridian Mykoserocin','Mykoserocin is a crystalline compound formed by intense pressure deep within large asteroids and moons. The crystals are commonly used in electronics and weapon manufacturing, as well as the creation of legalized Synth booster variants. Mykoserocin can only be found in abundance in a few areas, such as interstellar gas clouds within high security space. ',0,10,0,1,NULL,0.0000,1,983,0),(28702,661,'Synth Blue Pill Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(28703,661,'Synth Crash Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(28704,661,'Synth Drop Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(28705,661,'Synth Exile Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(28706,661,'Synth Frentix Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(28707,661,'Synth Mindflood Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(28708,661,'Synth Sooth Sayer Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(28709,661,'Synth X-Instinct Booster Reaction',' ',0,1,0,1,NULL,0.0000,1,1852,0),(28710,900,'Golem','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today s warship technology. While being thick-skinned, hard-hitting monsters on their own, they are also able to use Bastion technology. Similar in effect to capital reconfiguration technology, when activated the Bastion module provides immunity to electronic warfare and the ability to withstand enormous amounts of punishment, at the cost of being stationary.\r\r\n\r\r\nDeveloper: Lai Dai \r\r\n\r\r\nLai Dai have always favored a balanced approach to their mix of on-board systems, leading to a line-up of versatile ships but providing very little in terms of tactical specialization.',94335000,486000,1225,1,1,395370454.0000,1,1082,0),(28711,107,'Golem Blueprint',' ',0,0.01,0,1,NULL,1650000000.0000,1,NULL,0),(28729,201,'Legion ECM Ion Field Projector','Projects a low intensity field of ionized particles to disrupt the effectivenes of enemy sensors. Very effective against Magnetometric-based sensors. ',0,5,0,1,NULL,29504.0000,1,715,0),(28730,130,'Legion ECM Ion Field Projector Blueprint',' ',0,0.01,0,1,NULL,200000.0000,0,NULL,0),(28731,201,'Legion ECM Multispectral Jammer','An advanced multipurpose jamming system designed to offer blanket protection against all forms of targeting. Not as effective as the more specialized systems but is still effective against less advanced targeting systems. ',0,5,0,1,NULL,33024.0000,1,719,0),(28732,130,'Legion ECM Multispectral Jammer Blueprint',' ',0,0.01,0,1,NULL,296960.0000,0,NULL,0),(28733,201,'Legion ECM Phase Inverter','Analyzes incoming targeting signals and attempts to counter them by emitting an out-of-phase signal back. Great against Ladar targeting systems.',0,5,0,1,NULL,29504.0000,1,716,0),(28734,130,'Legion ECM Phase Inverter Blueprint',' ',0,0.01,0,1,NULL,200000.0000,0,NULL,0),(28735,201,'Legion ECM Spatial Destabilizer','Projects random bursts of gravitons that disrupt accurate targeting. As expected this system works best against Gravimetric targeting systems.',0,5,0,1,NULL,29504.0000,1,717,0),(28736,130,'Legion ECM Spatial Destabilizer Blueprint',' ',0,0.01,0,1,NULL,200000.0000,0,NULL,0),(28737,201,'Legion ECM White Noise Generator','Disrupts enemy targeting by generating a field of random sensor noise. Works especially well against Radar systems.',0,5,0,1,NULL,29504.0000,1,718,0),(28738,130,'Legion ECM White Noise Generator Blueprint',' ',0,0.01,0,1,NULL,200000.0000,0,NULL,0),(28739,766,'Thukker Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,9920.0000,1,658,0),(28740,339,'Thukker Micro Auxiliary Power Core','Supplements the main Power core providing more power',0,5,0,1,NULL,166790.0000,1,660,0),(28741,352,'Thukker Micro Auxiliary Power Core Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,0,NULL,0),(28742,38,'Thukker Small Shield Extender','Increases the maximum strength of the shield.',0,5,0,1,NULL,5320.0000,1,605,0),(28743,118,'Thukker Small Shield Extender Blueprint',' ',0,0.01,0,1,NULL,49920.0000,0,NULL,0),(28744,38,'Thukker Large Shield Extender','Increases the maximum strength of the shield.',0,20,0,1,NULL,34710.0000,1,608,0),(28745,118,'Thukker Shield Extender I Blueprint',' ',0,0.01,0,1,NULL,312420.0000,0,NULL,0),(28746,38,'Thukker Medium Shield Extender','Increases the maximum strength of the shield.',0,10,0,1,NULL,13924.0000,1,606,0),(28747,118,'Thukker Medium Shield Extender Blueprint',' ',0,0.01,0,1,NULL,124740.0000,0,NULL,0),(28748,54,'ORE Deep Core Mining Laser','A basic mining laser for deep core mining ore such as mercoxit. Very inefficient but does get the job done ... eventually',0,5,0,1,NULL,388878.0000,1,1039,0),(28749,134,'ORE Deep Core Mining Laser Blueprint',' ',0,0.01,0,1,NULL,3500000.0000,0,NULL,0),(28750,54,'ORE Miner','Basic mining laser. Extracts common ore quickly, but has difficulty with the more rare types.',0,5,0,1,NULL,10304.0000,1,1039,0),(28751,134,'ORE Miner Blueprint',' ',0,0.01,0,1,NULL,92720.0000,0,NULL,0),(28752,464,'ORE Ice Harvester','A unit used to extract valuable materials from ice asteroids. Used on Mining barges and Exhumers.\r\r\n',0,5,0,1,NULL,2237400.0000,1,1038,0),(28753,490,'ORE Ice Harvester Blueprint',' ',0,0.01,0,1,NULL,15003680.0000,0,NULL,0),(28754,464,'ORE Strip Miner','A bulk ore extractor designed for use on Mining Barges and Exhumers.',0,5,0,1,NULL,2514732.0000,1,1040,0),(28755,490,'ORE Strip Miner Blueprint',' ',0,0.01,0,1,NULL,16130080.0000,0,NULL,0),(28756,481,'Sisters Expanded Probe Launcher','Launcher for <a href=showinfo:30013>Core Scanner Probes</a> and <a href=showinfo:30028>Combat Scanner Probes</a>.\r\r\n\r\r\n<a href=showinfo:30013>Core Scanner Probes</a> are used to scan down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a> in space.\r\r\n<a href=showinfo:30028>Combat Scanner Probes</a> are used to scan down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a>, starships, structures and drones.\r\r\n\r\r\nNote: Only one scan probe launcher can be fitted per ship.\r\r\n\r\r\n10% bonus to strength of scan probes.',0,5,8,1,NULL,6670.0000,1,712,0),(28757,918,'Sisters Expanded Probe Launcher Blueprint',' ',0,0.01,0,1,NULL,60000.0000,0,NULL,0),(28758,481,'Sisters Core Probe Launcher','Launcher for <a href=showinfo:30013>Core Scanner Probes</a>, which are used to scan down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a> in space.\r\r\n\r\r\nNote: Only one scan probe launcher can be fitted per ship.\r\r\n\r\r\n10% bonus to strength of scan probes.',0,5,0.8,1,NULL,6670.0000,1,712,0),(28759,918,'Sisters Core Probe Launcher Blueprint',' ',0,0.01,0,1,NULL,60000.0000,0,NULL,0),(28766,972,'Sisters Observator Deep Space Probe','The deep-space probe uses directional measurements of the red shifting of scan signatures due to space-time expansion to give very coarse scanning of objects up to interstellar ranges. You only need one such probe for analysis, and it scans everything within 1000AU.',1,0.125,0,1,NULL,17670.0000,0,NULL,0),(28768,972,'Sisters Radar Quest Probe','Lith probes pick up the diffraction of quasar emissions around large stationary objects in space, and utilize the resultant interference to estimate the distance at which the objects lie. The Quest probe is the longest-distance lith probe available.',1,1.25,0,1,NULL,4646.0000,0,NULL,0),(28770,361,'Syndicate Mobile Large Warp Disruptor','A Large deployable self powered unit that prevents warping within its area of effect. ',0,585,0,1,NULL,17974064.0000,1,NULL,0),(28771,371,'Syndicate Mobile Large Warp Disruptor Blueprint',' ',0,0.01,0,1,NULL,119764480.0000,0,NULL,0),(28772,361,'Syndicate Mobile Medium Warp Disruptor','A Medium deployable self powered unit that prevents warping within its area of effect. ',0,195,0,1,NULL,4495646.0000,1,NULL,0),(28773,371,'Syndicate Mobile Medium Warp Disruptor Blueprint',' ',0,0.01,0,1,NULL,29941120.0000,0,NULL,0),(28774,361,'Syndicate Mobile Small Warp Disruptor','A small deployable self powered unit that prevents warping within its area of effect. ',0,65,0,1,NULL,1119940.0000,1,NULL,0),(28775,371,'Syndicate Mobile Small Warp Disruptor Blueprint',' ',0,0.01,0,1,NULL,7485280.0000,0,NULL,0),(28776,769,'Syndicate Reactor Control Unit','Boosts power core output.',20,5,0,1,NULL,10976.0000,1,659,0),(28777,137,'Syndicate Reactor Control Unit Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(28778,329,'Syndicate 100mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,23886.0000,1,1672,0),(28779,349,'Syndicate 100mm Steel Plates Blueprint',' ',0,0.01,0,1,4,200000.0000,0,NULL,0),(28780,329,'Syndicate 1600mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,4,832436.0000,1,1676,0),(28781,349,'Syndicate 1600mm Steel Plates Blueprint',' ',0,0.01,0,1,4,7000000.0000,0,NULL,0),(28782,329,'Syndicate 200mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,101624.0000,0,1673,0),(28783,349,'Syndicate 200mm Steel Plates Blueprint',' ',0,0.01,0,1,4,800000.0000,0,NULL,0),(28784,329,'Syndicate 400mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,198230.0000,1,1674,0),(28785,349,'Syndicate 400mm Steel Plates Blueprint',' ',0,0.01,0,1,4,1600000.0000,0,NULL,0),(28786,329,'Syndicate 800mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,4,466500.0000,1,1675,0),(28787,349,'Syndicate 800mm Steel Plates Blueprint',' ',0,0.01,0,1,4,4000000.0000,0,NULL,0),(28788,737,'Syndicate Gas Cloud Harvester','The Syndicate harvester arose out of a joint research project undertaken by dozens of Station owners across the region. The residents and industrialists of Syndicate appreciated, more than most, the latent potential of the underground booster industry. Although their modified harvesters offered no improvements in yield, they were easier for newer pilots to fit. Their investment in more accessible harvesting technology paid off, when eventually the empires quietly backpedalled and legalized the production and sale of Synth boosters. ',0,5,0,1,NULL,2417838.0000,1,1037,0),(28789,134,'Syndicate Gas Cloud Harvester Blueprint',' ',0,0.01,0,1,NULL,40000000.0000,0,NULL,0),(28790,300,'Mid-grade Centurion Alpha','This ocular filter has been modified by Mordus scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors and Target Painters\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Centurion implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(28791,300,'Mid-grade Centurion Beta','This memory augmentation has been modified by Mordus scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors and Target Painters\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Centurion implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(28792,300,'Mid-grade Centurion Delta','This cybernetic subprocessor has been modified by Mordus scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors and Target Painters\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Centurion implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(28793,300,'Mid-grade Centurion Epsilon','This social adaptation chip has been modified by Mordus scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors and Target Painters\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Centurion implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(28794,300,'Mid-grade Centurion Gamma','This neural boost has been modified by Mordus scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors and Target Painters\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Centurion implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(28795,300,'Mid-grade Centurion Omega','This implant does nothing in and of itself, but when used in conjunction with other Centurion implants it will boost their effect. \r\r\n\r\r\n25% bonus to the strength of all Centurion implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(28796,300,'Mid-grade Nomad Alpha','This ocular filter has been modified by Thukker scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% bonus to agility\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Nomad implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(28797,300,'Mid-grade Nomad Beta','This memory augmentation has been modified by Thukker scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% bonus to agility\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Nomad implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(28798,300,'Mid-grade Nomad Delta','This cybernetic subprocessor has been modified by Thukker scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% bonus to agility\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Nomad implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(28799,300,'Mid-grade Nomad Epsilon','This social adaptation chip has been modified by Thukker scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to agility\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Nomad implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(28800,300,'Mid-grade Nomad Gamma','This neural boost has been modified by Thukker scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to agility\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Nomad implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(28801,300,'Mid-grade Nomad Omega','This implant does nothing in and of itself, but when used in conjunction with other Nomad implants it will boost their effect. \r\r\n\r\r\n25% bonus to the strength of all Nomad implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(28802,300,'Mid-grade Harvest Alpha','This ocular filter has been modified by ORE scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% bonus to the range to all mining lasers\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Harvest implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(28803,300,'Mid-grade Harvest Beta','This memory augmentation has been modified by ORE scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% bonus to the range to all mining lasers\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Harvest implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(28804,300,'Mid-grade Harvest Delta','This cybernetic subprocessor has been modified by ORE scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% bonus to the range to all mining lasers\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Harvest implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(28805,300,'Mid-grade Harvest Epsilon','This social adaptation chip has been modified by ORE scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to the range to all mining lasers\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Harvest implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(28806,300,'Mid-grade Harvest Gamma','This neural boost has been modified by ORE scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to the range to all mining lasers\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Harvest implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(28807,300,'Mid-grade Harvest Omega','This implant does nothing in and of itself, but when used in conjunction with other Harvest implants it will boost their effect. \r\r\n\r\r\n25% bonus to the strength of all Harvest implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(28808,300,'Mid-grade Virtue Alpha','This ocular filter has been modified by Sisters of Eve scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% bonus to scan strength of probes\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Virtue implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(28809,300,'Mid-grade Virtue Beta','This memory augmentation has been modified by Sisters of Eve scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% bonus to scan strength of probes\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Virtue implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(28810,300,'Mid-grade Virtue Delta','This cybernetic subprocessor has been modified by Sisters of Eve scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% bonus to scan strength of probes\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Virtue implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(28811,300,'Mid-grade Virtue Epsilon','This social adaptation chip has been modified by Sisters of Eve scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to scan strength of probes\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Virtue implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(28812,300,'Mid-grade Virtue Gamma','This neural boost has been modified by Sisters of Eve scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to scan strength of probes\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Virtue implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(28813,300,'Mid-grade Virtue Omega','This implant does nothing in and of itself, but when used in conjunction with other Virtue implants it will boost their effect. \r\r\n\r\r\n25% bonus to the strength of all Virtue implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(28814,300,'Mid-grade Edge Alpha','This ocular filter has been modified by Syndicate scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% reduction to booster side effects\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Edge implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(28815,300,'Mid-grade Edge Beta','This memory augmentation has been modified by Syndicate scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% reduction to booster side effects\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Edge implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(28816,300,'Mid-grade Edge Delta','This cybernetic subprocessor has been modified by Syndicate scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +3 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% reduction to booster side effects\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Edge implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(28817,300,'Mid-grade Edge Epsilon','This social adaptation chip has been modified by Syndicate scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% reduction to booster side effects\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Edge implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(28818,300,'Mid-grade Edge Gamma','This neural boost has been modified by Syndicate scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +3 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% reduction to booster side effects\r\r\n\r\r\nSet Effect: 10% bonus to the strength of all Edge implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(28819,300,'Mid-grade Edge Omega','This implant does nothing in and of itself, but when used in conjunction with other Edge implants it will boost their effect. \r\r\n\r\r\n25% bonus to the strength of all Edge implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(28823,306,'Damaged Escape Pod','This Escape Pod has been damaged and has lost its ability to maneuver, as well as its warp capability.',10000,1200,1400,1,NULL,0.0000,0,NULL,0),(28826,817,'Opux Luxury Yacht - Level 1','Normally used by the entertainment industry in pleasure tours for wealthy Gallente citizens, this particular Opux Luxury Yacht cruiser is used as a private ship.',13075000,115000,1750,1,8,0.0000,0,NULL,0),(28827,314,'Encrypted Data Crystals','These crystals contain data of some sort, but have apparently been encrypted using advanced methods, making the information inaccessible to all but the most skilled hackers. ',50,1,0,1,NULL,80.0000,1,NULL,0),(28828,314,'Quafe Unleashed formula','These encoded reports contain highly sensitive information from the Quafe corporation regarding the chemical makeup of their new product, Quafe Unleashed.',1,0.1,0,1,NULL,30.0000,1,NULL,0),(28829,314,'Ancient Amarrian Relic','This relic from Old Amarr is of great value to Lord Horowan, patriarch of one of the oldest noble families in the Empire and liegeman of House Tash-Murkon. \r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(28830,314,'Brutor Tribe Roster','These data logs, precious to any Minmatar but especially to a member of the Brutor Tribe, hold information on the history and lineage of that tribe\'s members from over a century ago. ',1,0.2,0,1,NULL,0.0000,1,NULL,0),(28832,283,'Stranded Pilot','This simple starship pilot, lacking the pod and other resources of a capsuleer, has been forced to eject from his ship in a mundane escape pod. ',80,1,0,1,NULL,0.0000,1,NULL,0),(28833,314,'Ishukone Corporate Records','These encoded reports hold extremely sensitive information regarding Ishukone Corporation holdings and infrastructure.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(28834,314,'Federation Court Logs','These reports hold data of utmost importance to Federation Judicial Services. ',10,1,0,1,NULL,0.0000,1,NULL,0),(28835,283,'Professor Kajurei Delainen','This odd little man is possibly the most well-respected particle physicist of the current age, and is also considered a foremost expert in Artificial Intelligence. He is perhaps most famous for his establishment of the \"Seven Pillars of Artificial Intelligence\" theory, published almost 14 years ago.',65,1,0,1,NULL,0.0000,1,NULL,0),(28836,314,'Letters of Bishop Dalamaid','The letters of Bishop Dalamaid have been the subject of volumes of intellectual discourse. The primary contention of the letters, that true saintly martyrdom is an impossibility for anyone even aware of the concept of sainthood, has gone through various levels of favor over the generations. <br><br>\r\r\n\r\r\nLetters XIII through XV include a few juicy morsels about a prostitution ring that was run illegally from a monastery of one of the more prestigious orders in Dalamaid\'s time.',25,0.5,0,1,NULL,0.0000,1,NULL,0),(28837,526,'Achuran White Song Birds','A single male White Song bird. The female seems to have died, perhaps due to the stress of recent events. <br><br>\r\r\nThe White Song was once the symbol of the Achura\'s Imperial line. Only government buildings were allowed to keep White Songs in captivity. It was said that when the last White Song left the Royal Tower, the Achura Empire would die. The Achura Empire died first, but the White Song is still regarded with great reverence. ',0.02,0.01,0,1,NULL,0.0000,1,NULL,0),(28838,526,'Armor of Rouvenor','Rouvenor is supposedly a mythical hero-king of Garoun, the temporal paradise that has been the subject of poetry, story, and song for centuries. If legends are to be believed, this armor was worn by Rouvenor when he faced the seven armies of Morthane. <br><br>\r\r\nStrangely, a few of the gold accents are turning slightly green.',35,1,0,1,NULL,0.0000,1,NULL,0),(28839,319,'Blood Raider Cathedral (weak)','This impressive structure operates as a place for religious practice and the throne of a high ranking member within the clergy.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(28840,1194,'Magic Crystal Ball','Allows you to see into <i>the future</i>, albeit rather murkily.\r\r\n\r\r\nWarning: Side-effects may include speculation, jumping to conclusions, overanalysis, misunderstandings, unwarranted assumptions, endless discussions, baseless concerns, undue panic, virtual stampedes, threadnaughts, premature pod ejection and unneeded stress. USE WITH CAUTION.',1,1,0,1,NULL,0.0000,1,1661,0),(28841,306,'Cargo Container - Encoded Data Chip','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28842,283,'Amarr Sympathizer','This Minmatar politician pleads his innocence whenever you look his way. He claims that he has been framed, that everything has been a complex scheme to discredit his family. His tattoos mark him as not as a Nefantar, but as one of the member tribes of the Republic. His body is heavily bruised, but whether the injuries are from the Amarr agents or the Minmatar guards is hard to tell. Perhaps only the Republic courts can decide his innocence. ',85,1,0,1,NULL,0.0000,1,NULL,0),(28843,314,'Altered Datacore - Mechanical Engineering','This datacore has been altered and thus rendered useless for manufacturing purposes. It has value only as a reference tool. ',0.75,0.1,0,1,NULL,0.0000,1,NULL,0),(28844,902,'Rhea','It wasn\'t long after the Thukkers began deploying their jump capable freighters that other corporations saw the inherent tactical value of such ships.  After extended negotiations, Ishukone finally closed a deal exchanging undisclosed technical data for the core innovations underpinning the original Thukker Tribes design allowing them to rapidly bring to the market the largest jump capable freighter of them all, the Rhea, a true behemoth of the stars.\r\r\n\r\r\nDeveloper : Ishukone\r\r\n\r\r\nIshukone, always striving to be ahead of the competition, have proved themselves to be one of the most adept starship designers in the State.  A surprising majority of the Caldari Fleets ships of the line were created by their designers.  Respected and feared by their peers Ishukone remain amongst the very top of the Caldari corporate machine.\r\r\n\r\r\n',960000000,16250000,144000,1,1,2629585776.0000,1,1091,0),(28845,525,'Rhea Blueprint',' ',0,0.01,0,1,NULL,2000000000.0000,1,NULL,0),(28846,902,'Nomad','There is continuing speculation as to how exactly the Thukkers manage to move their vast caravans throughout space relatively undetected, but their expertise with jump drive technology became glaringly apparent when they created the Nomad.  Now seeing widespread service with roving Thukker outrider detachments, the Nomad is rapidly becoming an essential part of Thukker life away from the great caravans.\r\r\n\r\r\nDeveloper : Thukker Mix\r\r\n\r\r\nThukkers spend their entire lives forever wandering the infinite in their vast caravans.  As such their technology is based as much upon necessity as their ingenious ability to tinker.  Their ship designs therefore tend to based upon the standard empire templates but extensively modified for the Thukkers unique needs.  \r\r\n',820000000,15500000,132000,1,2,2637164950.0000,1,1093,0),(28847,525,'Nomad Blueprint',' ',0,0.01,0,1,NULL,1850000000.0000,1,NULL,0),(28848,902,'Anshar','CreoDron surprised many by their quick conception of the Anshar, a stark diversification from their usual drone centric ship designs. The Anshar\'s specially-developed cargo-manipulation drones allowed CreoDron to optimize their loading algorithms and fully utilize every nook and cranny of the ship\'s spacious interior, ensuring it more than holds its own amongst its peers.  \r\r\n\r\r\nDeveloper : CreoDron\r\r\n\r\r\nAs the largest drone developer and manufacturer in space, CreoDron has a vested interest in drone carriers but has recently begun to expand their design focus and employ drone techniques on whole other levels which has led some to question where this leap in technology came from.\r\r\n',940000000,17550000,137500,1,8,2647652552.0000,1,1092,0),(28849,525,'Anshar Blueprint',' ',0,0.01,0,1,NULL,1950000000.0000,1,NULL,0),(28850,902,'Ark','At the end of days when they descend\r\r\nWatch for the coming of the Ark\r\r\nFor within it\r\r\nSalvation is carried.\r\r\n\r\r\n<i>-The Scriptures, Apocalypse Verses 32:6</i>\r\r\n\r\r\nDeveloper : Carthum Conglomerate\r\r\n\r\r\nCarthum ships are the very embodiment of the Amarrian warfare philosophy. Possessing sturdy armor and advanced weapon systems they provide a nice mix of offense and defense. On the other hand, their electronics and shield systems tend to be rather limited.\r\r\n\r\r\n',900000000,18500000,135000,1,4,2648737382.0000,1,1090,0),(28851,525,'Ark Blueprint',' ',0,0.01,0,1,NULL,1900000000.0000,1,NULL,0),(28852,306,'Ancient Starbase Ruins','Ruins.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28854,319,'Communications Tower','Communications Tower.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(28859,306,'Cargo Container - Ancient Amarrian Relic','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28860,306,'Cargo Container - Ishukone Corporate Records','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28861,306,'Cargo Container - Federation Court Logs','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28862,306,'Cargo Container - Brutor Tribe Roster','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28863,821,'Hashi Keptzh','<font color=yellow>Subject:</font> Hashi Keptzh (ID: Pilot of modified Machariel)<br>\r\r\n<font color=yellow>Military Specifications:</font> Domination Commander <br>\r\r\n<font color=yellow>Additional Intelligence:</font> \"Hashi Keptzh? This guy shouldn\'t be too tough. He\'s just a battleship. Get him down. Holy--did he just shoot you? What the hell is this guy flying? Returning fire. Look at his tank! Stop that, you can salvage after the op. <br>\"He\'s tearing through my drones! Warp! Warp! Warp!\" <br>\r\r\n<i>Unidentified capsuleer transmission during encounter with Hashi Keptzh.</i><br><i>Authorized for capsuleer dissemination.</i>  \r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(28864,821,'Uehiro Katsen','<font color=yellow>Subject:</font> Uehiro Katsen (ID: Pilot of modified Vindicator)<br>\r\r\n<font color=yellow>Military Specifications:</font> Serpentis Commander <br>\r\r\n<font color=yellow>Additional Intelligence:</font>Encounters with Uehiro Katsen have occurred with consistent frequency since YC 109. Every engagement has proven Katsen\'s vessel to be extremely resilient and armed beyond standard Serpentis fittings. Numerous capsuleers have reported success in eliminating the subject, yet the time between sightings is sometimes as low as several hours. It is unknown whether Katsen is himself an unregistered capsuleer, or merely a pseudonym worn by multiple crews.<br>\r\r\n<i>Agent Cotlamaert Loffeuron, <a href=showinfo:2//1000121>FIO</a>.</i><br><i>Authorized for capsuleer dissemination.</i>  \r\r\n',17500000,1140000,480,1,8,0.0000,0,NULL,0),(28865,314,'Hive Mind CPU','This cumbersome, alien-looking device, throbbing with light and humming faintly, apparently contains the mind of Professor Kajurei Delainen, somehow fused with the AI of his rogue drone nanites. ',70,5,0,1,NULL,0.0000,1,NULL,0),(28866,314,'Rogue Drone A.I. Core','A tiny chip with a modified silicon-extract wafer forming the base for an integrated circuit. The chip stores the code for the drone\'s bizarre artificial intelligence. ',0.01,0.01,0,1,NULL,0.0000,1,NULL,0),(28867,530,'Inexplicable Drone Junk','Alloys and special materials used in the manufacture of modules based on Ancient technology.',150,20,0,1,NULL,0.0000,1,NULL,0),(28868,314,'Small Warded Container','This small sealed container has been modified with state-of-the-art security measures to prevent ship-to-ship scanning of its contents.',75,5,0,1,NULL,100.0000,1,NULL,0),(28869,283,'Amarrian Double-Agent','A spy ostensibly working for the Amarr Empire, but who in fact is a sympathizer with and an agent for the Minmatar Republic.',80,1,0,1,NULL,0.0000,1,NULL,0),(28870,314,'AIMEDs','On most stations, robotic AI Medical Doctors (AIMEDs, more commonly known as \"AI Docs\" or just \"AIDs\") are much more common than human medical practitioners, and much more affordable. ',5000,25,0,1,NULL,100.0000,1,NULL,0),(28871,1207,'Angel Narcotics Storage Facility','This modified habitat module is being used as storage facility for various items that the pirate factions use for drug manufacturing.  Usually heavily guarded this would undoubtedly reap a bounty with a bit of hacking once past the security.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28872,1207,'Angel Chemical Laboratory ','This mobile laboratory can be moved and anchored with relative ease, and also tailored towards certain specialties which has led many pirate factions using them in places where creating a fully fledged static facility would be a massive liability.\r\r\n\r\r\nThis particular one is being used a chemical research laboratory and is liable to contain some useful items for the entrepreneur after a small amount of hacking.\r\r\n',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28873,1207,'Guristas Narcotics Storage Facility','This modified habitat module is being used as storage facility for various items that the pirate factions use for drug manufacturing.  Usually heavily guarded this would undoubtedly reap a bounty with a bit of hacking once past the security.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28874,1207,'Guristas Chemical Laboratory ','This mobile laboratory can be moved and anchored with relative ease, and also tailored towards certain specialties which has led many pirate factions using them in places where creating a fully fledged static facility would be a massive liability.\r\r\n\r\r\nThis particular one is being used a chemical research laboratory and is liable to contain some useful items for the entrepreneur after a small amount of hacking.\r\r\n',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28875,1207,'Serpentis Narcotics Storage Facility','This modified habitat module is being used as storage facility for various items that the pirate factions use for drug manufacturing.  Usually heavily guarded this would undoubtedly reap a bounty with a bit of hacking once past the security.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28876,1207,'Serpentis Chemical Laboratory ','This mobile laboratory can be moved and anchored with relative ease, and also tailored towards certain specialties which has led many pirate factions using them in places where creating a fully fledged static facility would be a massive liability.\r\r\n\r\r\nThis particular one is being used a chemical research laboratory and is liable to contain some useful items for the entrepreneur after a small amount of hacking.\r\r\n',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28877,1207,'Sansha Narcotics Storage Facility','This modified habitat module is being used as storage facility for various items that the pirate factions use for drug manufacturing.  Usually heavily guarded this would undoubtedly reap a bounty with a bit of hacking once past the security.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28878,1207,'Blood Raider Chemical Laboratory ','This mobile laboratory can be moved and anchored with relative ease, and also tailored towards certain specialties which has led many pirate factions using them in places where creating a fully fledged static facility would be a massive liability.\r\r\n\r\r\nThis particular one is being used a chemical research laboratory and is liable to contain some useful items for the entrepreneur after a small amount of hacking.\r\r\n',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28879,1216,'Nanite Operation','Skill at operating nanites. 5% reduction in nanite consumption per level.',0,0.01,0,1,NULL,1000000.0000,1,368,0),(28880,1216,'Nanite Interfacing','Improved control of general-purpose repair nanites, usually deployed in a paste form. 20% increase in damaged module repair amount per second.',0,0.01,0,1,NULL,5000000.0000,1,368,0),(28881,1207,'Metadrones - LM-A-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28882,1207,'Metadrones - LM-A-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28883,1207,'Metadrones - LMH-A-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28884,404,'Expanded Silo','A larger version of the standard silo used to store or provide resources.',100000000,8000,40000,1,NULL,30000000.0000,0,NULL,0),(28885,306,'Wrecked Science Vessel','If you have the right equipment you might be able to hack into this container and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(28886,283,'Prisoner','Transporting prisoners is a task that requires trust and loyalty from the sovereign empire\'s legislative arm, yet it is generally one of the least sought-after jobs in the known universe.',80,1,0,1,NULL,100.0000,1,NULL,0),(28888,904,'Mining Laser Optimization I',' ',200,5,0,1,NULL,0.0000,0,NULL,0),(28889,787,'Mining Laser Optimization I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(28890,904,'Mining Laser Optimization II',' ',200,5,0,1,NULL,0.0000,0,NULL,0),(28891,787,'Mining Laser Optimization II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(28892,904,'Mining Laser Range I',' ',200,5,0,1,NULL,0.0000,0,NULL,0),(28893,787,'Mining Laser Range I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(28894,904,'Mining Laser Range II',' ',200,5,0,1,NULL,0.0000,0,NULL,0),(28895,787,'Mining Laser Range II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(28896,314,'Router Encryption Key','This datacore looks harmless. You find it hard to believe that such a small thing holds the secret to controlling what so many people believe. ',0.75,0.1,0,1,NULL,0.0000,1,NULL,0),(28897,314,'Food-Borne Toxin','This virulent toxin, when placed into many kinds of food or drink, is virtually undetectable save by the most advanced microbiological scanning technology... which is generally available only to the very wealthy.',5,0.2,0,1,NULL,0.0000,1,NULL,0),(28902,1207,'Metadrones - MH-A-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28904,1207,'Metadrones - MH-A-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28905,1207,'Metadrones - LMH-A-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28906,1207,'Metadrones - MH-A-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28907,1207,'Metadrones - LMH-A-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28908,1207,'Metadrones - LM-C-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28909,1207,'Metadrones - LM-C-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28911,1207,'Metadrones - MH-C-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28912,1207,'Metadrones - MH-C-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28914,1207,'Metadrones - LMH-C-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28915,1207,'Metadrones - LMH-C-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28917,1207,'Metadrones - LM-G-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28918,1207,'Metadrones - LM-G-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28920,1207,'Metadrones - MH-G-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28921,1207,'Metadrones - MH-G-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28923,1207,'Metadrones - LMH-G-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28924,1207,'Metadrones - LMH-G-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28927,1207,'Metadrones - LM-M-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28928,1207,'Metadrones - LM-M-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28930,1207,'Metadrones - MH-M-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28931,1207,'Metadrones - MH-M-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28933,1207,'Metadrones - LMH-M-1 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28934,1207,'Metadrones - LMH-M-1 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28936,1207,'Metadrones - LM-A-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28937,1207,'Metadrones - LM-A-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28938,1207,'Metadrones - LMH-A-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28939,1207,'Metadrones - MH-A-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28940,1207,'Metadrones - MH-A-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28941,1207,'Metadrones - MH-A-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28942,1207,'Metadrones - LMH-A-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28943,1207,'Metadrones - LMH-A-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28944,1207,'Metadrones - LM-A-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28945,1207,'Metadrones - LM-C-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28946,1207,'Metadrones - LM-C-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28948,1207,'Metadrones - MH-C-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28949,1207,'Metadrones - MH-C-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28951,1207,'Metadrones - LMH-C-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28952,1207,'Metadrones - LMH-C-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28954,306,'Metadrones - LM-G-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28955,1207,'Metadrones - LM-G-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28957,1207,'Metadrones - MH-G-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28958,1207,'Metadrones - MH-G-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28960,1207,'Metadrones - LMH-G-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28961,1207,'Metadrones - LMH-G-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28963,306,'Metadrones - LM-M-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28964,1207,'Metadrones - LM-M-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28966,1207,'Metadrones - MH-M-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28967,1207,'Metadrones - MH-M-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28969,1207,'Metadrones - LMH-M-2 - B','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28970,1207,'Metadrones - LMH-M-2 - N','Containment facilities like this exist throughout known space, usually serving as high security prisons. This one, however, appears to have been heavily reinforced.\r\r\n\r\r\nThere are multiple breaches in the hull, but they appear to originate from within the structure rather than without. Which begs the question; what kinds of monstrosities were being held inside?\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28972,314,'Cryogenic Stasis Capsule','This cryo capsule is fitted with a password-protected security lock to protect its occupant.',400,25,0,1,NULL,100.0000,1,NULL,0),(28973,314,'Dem\'s Galactical Botanical','This book is unprecedented in the depth of analysis offered by Ukraris Dem, easily the most noted morpho-botanist of the latter past century. ',2,0.1,0,1,NULL,0.0000,1,NULL,0),(28974,1040,'Vaccines','Living creatures can be trained to defend themselves from harmful diseases by introducing a minute sample of pathological strains, tremendously improving their immune systems and allowing them to endure prolonged exposure to harmful contagions.',0,6,0,1,NULL,1.0000,1,1336,0),(28975,314,'Cargo Manifest','These complicated data sheets may mean little to the layman\'s eye, but they contain a great deal of information about trade routes, taxes, and other arcane business data.',1,0.5,0,1,NULL,100.0000,1,NULL,0),(28976,1207,'Metadrones - LM-C-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28977,1207,'Metadrones - LM-G-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28978,1207,'Metadrones - LM-M-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28979,1207,'Metadrones - LM-C-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28980,306,'Metadrones - LM-G-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28981,306,'Metadrones - LM-M-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28982,1207,'Metadrones - LMH-C-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28983,1207,'Metadrones - LMH-G-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28984,1207,'Metadrones - LMH-M-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28985,1207,'Metadrones - LMH-C-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28986,1207,'Metadrones - LMH-G-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28987,1207,'Metadrones - LMH-M-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28988,1207,'Metadrones - MH-C-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28989,1207,'Metadrones - MH-G-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28990,1207,'Metadrones - MH-M-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28991,1207,'Metadrones - MH-C-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28992,1207,'Metadrones - MH-G-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28993,1207,'Metadrones - MH-M-2 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28994,1207,'Metadrones - LM-A-1 - F','This listing husk of a research station hangs in space; bodies litter the numerous breaches in the superstructure, illustrating what must have been a horrific attack.\r\r\n\r\r\nBetrayed by the play of shadows and light, glimpses of activity can be observed, although no biological life could have possibly survived such devastation.\r\r\n',10000,25000,2500,1,NULL,0.0000,0,NULL,0),(28995,283,'Prop Comedian','Somebody has to like it.',600,3,0,1,NULL,0.0000,1,NULL,0),(28996,314,'Fraudulent Pax Amarria','This Pax Amarria binding hides a heretical manuscript.',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(28998,495,'Angel Fleet Outpost','One of the many quarters of the Angel fleet.',0,0,0,1,2,0.0000,0,NULL,0),(28999,907,'Optimal Range Script','Originally used by the adolescent hacker group The \'Fendahlian Collective\' to break pass high tech security firmware, these script packs contain intricate code which modify the inherent behavior of certain modules by directly inserting commands into the firmware. The applications of such technology was not lost on the major players and the kids who invented it now head their own research divisions.\r\r\n\r\r\nThis script can be loaded into a tracking computer or tracking link module to increase the module\'s optimal range bonus at the expense of its tracking speed bonus.',1,1,0,1,NULL,22432.0000,1,1094,0),(29000,912,'Optimal Range Script Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1105,0),(29001,907,'Tracking Speed Script','Originally used by the adolescent hacker group The \'Fendahlian Collective\' to break past high tech security firmware, these script packs contain intricate code which modify the inherent behavior of certain modules by directly inserting commands into the firmware. The applications of such technology was not lost on the major players and the kids who invented it now head their own research divisions.\r\r\n\r\r\nThis script can be loaded into a tracking computer or tracking link module to increase the module\'s tracking speed bonus at the expense of its optimal range bonus.',1,1,0,1,NULL,22432.0000,1,1094,0),(29002,912,'Tracking Speed Script Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1105,0),(29003,908,'Focused Warp Disruption Script','Originally used by the adolescent hacker group The \'Fendahlian Collective\' to break past high tech security firmware, these script packs contain intricate code which modify the inherent behavior of certain modules by directly inserting commands into the firmware. The applications of such technology was not lost on the major players and the kids who invented it now head their own research divisions.\r\r\n\r\r\nThis script can be loaded into a warp disruption field generator to focus its effect upon a single ship much like a standard warp disruptor. This allows the module to scramble ships of any size, including ships normally immune to all forms of electronic warfare.',1,1,0,1,NULL,346192.0000,1,1094,0),(29004,912,'Focused Warp Disruption Script Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1105,0),(29005,909,'Optimal Range Disruption Script','Originally used by the adolescent hacker group The \'Fendahlian Collective\' to break pass high tech security firmware, these script packs contain intricate code which modify the inherent behavior of certain modules by directly inserting commands into the firmware. The applications of such technology was not lost on the major players and the kids who invented it now head their own research divisions.\r\r\n\r\r\nThis script can be loaded into a tracking disruptor module to increase the module\'s optimal range effect at the expense of its tracking speed effect.\r\r\n\r\r\n',1,1,0,1,NULL,22432.0000,1,1094,0),(29006,912,'Optimal Range Disruption Script Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1105,0),(29007,909,'Tracking Speed Disruption Script','Originally used by the adolescent hacker group The \'Fendahlian Collective\' to break pass high tech security firmware, these script packs contain intricate code which modify the inherent behavior of certain modules by directly inserting commands into the firmware. The applications of such technology was not lost on the major players and the kids who invented it now head their own research divisions.\r\r\n\r\r\nThis script can be loaded into a tracking disruptor module to increase the module\'s tracking speed effect at the expense of its optimal range effect.',1,1,0,1,NULL,22432.0000,1,1094,0),(29008,912,'Tracking Speed Disruption Script Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1105,0),(29009,910,'Targeting Range Script','Originally used by the adolescent hacker group The \'Fendahlian Collective\' to alter high tech security firmware, these script packs contain intricate code which modify the inherent behavior of certain modules by directly inserting commands into the firmware. The applications of such technology was not lost on the major players and the kids who invented it now head their own research divisions.\r\r\n\r\r\nThis script can be loaded into a sensor booster or remote sensor booster module to increase the module\'s targeting range bonus at the expense of the locking speed bonus.',1,1,0,1,NULL,22432.0000,1,1094,0),(29010,912,'Targeting Range Script Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1105,0),(29011,910,'Scan Resolution Script','Originally used by the adolescent hacker group \'The Fendahlian Collective\' to break past high tech security firmware, these script packs contain intricate code which modify the inherent behavior of certain modules by directly inserting commands into the firmware. The applications of such technology was not lost on the major players and the kids who invented it now head their own research divisions.\r\r\n\r\r\nThis script can be loaded into a sensor booster or remote sensor booster module to increase the module\'s locking speed bonus at the expense of the targeting range bonus.',1,1,0,1,NULL,22432.0000,1,1094,0),(29012,912,'Scan Resolution Script Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1105,0),(29013,911,'Scan Resolution Dampening Script','Originally used by the adolescent hacker group The \'Fendahlian Collective\' to break past high tech security firmware, these script packs contain intricate code which modify the inherent behavior of certain modules by directly inserting commands into the firmware. The applications of such technology was not lost on the major players and the kids who invented it now head their own research divisions.\r\r\n\r\r\nThis script can be loaded into a remote sensor dampener module to increase the module\'s targeting speed effect at the expense of its targeting range effect.',1,1,0,1,NULL,22432.0000,1,1094,0),(29014,912,'Scan Resolution Dampening Script Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1105,0),(29015,911,'Targeting Range Dampening Script','Originally used by the adolescent hacker group The \'Fendahlian Collective\' to break past high tech security firmware, these script packs contain intricate code which modify the inherent behavior of certain modules by directly inserting commands into the firmware. The applications of such technology was not lost on the major players and the kids who invented it now head their own research divisions.\r\r\n\r\r\nThis script can be loaded into a remote sensor dampener module to increase the module\'s targeting range effect at the expense of its targeting speed effect.',1,1,0,1,NULL,22432.0000,1,1094,0),(29016,912,'Targeting Range Dampening Script Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,1,1105,0),(29019,818,'Sagacious Path Fighter','A frigate of the Sagacious Path, a branch of the Achur monks.',2025000,20250,235,1,1,0.0000,0,NULL,0),(29020,495,'Serpentis Fleet Outpost','One of the many quarters of the Serpentis fleet.',1000,1000,1000,1,8,0.0000,0,NULL,0),(29021,495,'Guristas Fleet Outpost','This battlestation is defended by high ranking Gurista officers.',1000,1000,1000,1,1,0.0000,0,NULL,0),(29022,495,'Blood Raider Fleet Outpost','One of the many quarters of the Blood Raider fleet.',1000,1000,1000,1,4,0.0000,0,NULL,0),(29023,495,'Sansha Fleet Outpost','One of the many quarters of the Sansha fleet.',1000,1000,1000,1,4,0.0000,0,NULL,0),(29024,817,'Scope Reporter','This reporter for The Scope is flying a Gallente Cruiser, so he is undoubtedly prepared for combat.',11300000,113000,235,1,8,0.0000,0,NULL,0),(29025,861,'Outpost Defender','These variants of the standard fighter design are most commonly based off static structures, where they serve as a powerful line of defense.',12000,5000,1200,1,4,0.0000,0,NULL,0),(29026,314,'Insta-Lock','A new type of construction component, the Insta-Lock fuses structural components together almost instantaneously.',1,0.5,0,1,NULL,0.0000,1,NULL,0),(29029,257,'Jump Freighters','Skill for operation of Jump Freighters. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,100000000.0000,1,377,0),(29030,526,'7th Fleet Data Fragment','This chip contains a highly-encrypted data fragment retrived from a 7th Fleet field-spec mainframe. It would be impossible to tell what it originally contained - or how much of the data is still intact - without access to the original encryption key or some serious military-grade codebreaking hardware.',1,1,0,1,4,0.0000,0,NULL,0),(29031,319,'7th Fleet Mobile Command Post','Essentially an extensively modified Starbase Control Tower, this Navy-issue Command Post has been further modified to meet the 7th Fleet\'s specific needs. Each Command Post is capable of running Fleet operations for an entire system, and contains FTL comms equipment, a field-spec mainframe and full command-and-control facilities. ',100000,100000000,10000,1,4,0.0000,0,NULL,0),(29033,186,'Amarr Elite Freighter Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,735000,735000,1,NULL,0.0000,0,NULL,0),(29034,186,'Caldari Elite Freighter Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,785000,785000,1,NULL,0.0000,0,NULL,0),(29035,186,'Gallente Elite Freighter Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,750000,750000,1,NULL,0.0000,0,NULL,0),(29036,186,'Minmatar Elite Freighter Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,720000,720000,1,NULL,0.0000,0,NULL,0),(29039,913,'Capital Antimatter Reactor Unit','Power Core component used primarily in Amarr ships. A component in various other technology as well.    ',1,10,0,1,4,272890.0000,1,1884,0),(29040,914,'Capital Antimatter Reactor Unit Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1587,0),(29041,913,'Capital Crystalline Carbonide Armor Plate','Armor Component used primarily in Gallente ships.  A component in various other technology as well.    ',1,10,0,1,8,55560.0000,1,1886,0),(29042,914,'Capital Crystalline Carbonide Armor Plate Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1589,0),(29043,913,'Capital Deflection Shield Emitter','Shield Component used primarily in Minmatar ships. A component in various other technology as well.    ',1,10,0,1,2,100500.0000,1,1887,0),(29044,914,'Capital Deflection Shield Emitter Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1590,0),(29045,913,'Capital Electrolytic Capacitor Unit','Capacitor component used primarily in Minmatar ships. A component in various other technology as well.    ',1,10,0,1,2,362450.0000,1,1887,0),(29046,914,'Capital Electrolytic Capacitor Unit Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1590,0),(29047,913,'Capital EM Pulse Generator','Weapon Component used primarily in Amarr Missiles. A component in various other technology as well.  ',1,10,0,1,4,77820.0000,1,1884,0),(29048,914,'Capital EM Pulse Generator Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1587,0),(29049,913,'Capital Fernite Carbide Composite Armor Plate','Armor Component used primarily in Minmatar ships. A component in various other technology as well.    ',1,10,0,1,2,55560.0000,1,1887,0),(29050,914,'Capital Fernite Carbide Composite Armor Plate Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1590,0),(29051,913,'Capital Fusion Reactor Unit','Power Core component used primarily in Gallente ships. A component in various other technology as well.    ',1,10,0,1,8,272890.0000,1,1886,0),(29052,914,'Capital Fusion Reactor Unit Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1589,0),(29053,913,'Capital Fusion Thruster','Propulsion Component used primarily in Amarr ships. A component in various other technology as well.  ',1,10,0,1,4,93630.0000,1,1884,0),(29054,914,'Capital Fusion Thruster Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1587,0),(29055,913,'Capital Gravimetric Sensor Cluster','Sensor Component used primarily in Caldari ships. A component in various other technology as well.  ',1,10,0,1,1,86240.0000,1,1885,0),(29056,914,'Capital Gravimetric Sensor Cluster Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1588,0),(29057,913,'Capital Graviton Pulse Generator','Weapon Component used primarily in Caldari Missiles. A component in various other technology as well.  ',1,10,0,1,1,77820.0000,1,1885,0),(29058,914,'Capital Graviton Pulse Generator Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1588,0),(29059,913,'Capital Graviton Reactor Unit','Power Core component used primarily in Caldari ships. A component in various other technology as well.',1,10,0,1,1,272890.0000,1,1885,0),(29060,914,'Capital Graviton Reactor Unit Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1588,0),(29061,913,'Capital Ion Thruster','Propulsion Component used primarily in Gallente ships. A component in various other technology as well.  ',1,10,0,1,8,93630.0000,1,1886,0),(29062,914,'Capital Ion Thruster Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1589,0),(29063,913,'Capital Laser Focusing Crystals','Weapon Component used primarily in Lasers. A component in various other technology as well.  ',1,10,0,1,4,232660.0000,1,1884,0),(29064,914,'Capital Laser Focusing Crystals Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1587,0),(29065,913,'Capital Ladar Sensor Cluster','Sensor Component used primarily in Minmatar ships. A component in various other technology as well.    ',1,10,0,1,2,86240.0000,1,1887,0),(29066,914,'Capital Ladar Sensor Cluster Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1590,0),(29067,913,'Capital Linear Shield Emitter','Shield Component used primarily in Amarr ships. A component in various other technology as well.    ',1,10,0,1,4,100500.0000,1,1884,0),(29068,914,'Capital Linear Shield Emitter Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1587,0),(29069,913,'Capital Magnetometric Sensor Cluster','Sensor Component used primarily in Gallente ships. A component in various other technology as well.  ',1,10,0,1,8,86240.0000,1,1886,0),(29070,914,'Capital Magnetometric Sensor Cluster Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1589,0),(29071,913,'Capital Magpulse Thruster','Propulsion Component used primarily in Caldari ships. A component in various other technology as well.',1,10,0,1,1,93630.0000,1,1885,0),(29072,914,'Capital Magpulse Thruster Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1588,0),(29073,913,'Capital Nanoelectrical Microprocessor','CPU Component used primarily in Amarr ships. A component in various other technology as well.   ',1,10,0,1,4,142670.0000,1,1884,0),(29074,914,'Capital Nanoelectrical Microprocessor Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1587,0),(29075,913,'Capital Nanomechanical Microprocessor','CPU Component used primarily in Minmatar ships. A component in various other technology as well.      ',1,10,0,1,2,142670.0000,1,1887,0),(29076,914,'Capital Nanomechanical Microprocessor Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1590,0),(29077,913,'Capital Nuclear Pulse Generator','Weapon Component used primarily in Minmatar Missiles. A component in various other technology as well.  ',1,10,0,1,2,77820.0000,1,1887,0),(29078,914,'Capital Nuclear Pulse Generator Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1590,0),(29079,913,'Capital Nuclear Reactor Unit','Power Core component used primarily in Minmatar ships. A component in various other technology as well.    ',1,10,0,1,2,272890.0000,1,1887,0),(29080,914,'Capital Nuclear Reactor Unit Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1590,0),(29081,913,'Capital Oscillator Capacitor Unit','Capacitor component used primarily in Gallente ships. A component in various other technology as well.    ',1,10,0,1,8,362450.0000,1,1886,0),(29082,914,'Capital Oscillator Capacitor Unit Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1589,0),(29083,913,'Capital Particle Accelerator Unit','Weapon Component used primarily in Blasters. A component in various other technology as well.  ',1,10,0,1,8,232660.0000,1,1886,0),(29084,914,'Capital Particle Accelerator Unit Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1589,0),(29085,913,'Capital Photon Microprocessor','CPU Component used primarily in Gallente ships. A component in various other technology as well.    ',1,10,0,1,8,142670.0000,1,1886,0),(29086,914,'Capital Photon Microprocessor Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1589,0),(29087,913,'Capital Plasma Pulse Generator','Weapon Component used primarily in Gallente Missiles. A component in various other technology as well.  ',1,10,0,1,8,77820.0000,1,1886,0),(29088,914,'Capital Plasma Pulse Generator Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1589,0),(29089,913,'Capital Plasma Thruster','Propulsion Component used primarily in Minmatar ships as well as some propulsion tech. A component in various other technology as well.  ',1,10,0,1,2,93630.0000,1,1887,0),(29090,914,'Capital Plasma Thruster Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1590,0),(29091,913,'Capital Pulse Shield Emitter','Shield Component used primarily in Gallente ships. A component in various other technology as well.   ',1,10,0,1,8,100500.0000,1,1886,0),(29092,914,'Capital Pulse Shield Emitter Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1589,0),(29093,913,'Capital Quantum Microprocessor','CPU Component used primarily in Caldari ships. A component in various other technology as well.    ',1,10,0,1,1,142670.0000,1,1885,0),(29094,914,'Capital Quantum Microprocessor Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1588,0),(29095,913,'Capital Radar Sensor Cluster','Sensor Component used primarily in Amarr ships. A component in various other technology as well.    ',1,10,0,1,4,86240.0000,1,1884,0),(29096,914,'Capital Radar Sensor Cluster Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1587,0),(29097,913,'Capital Scalar Capacitor Unit','Capacitor component used primarily in Caldari ships. A component in various other technology as well.    ',1,10,0,1,1,362450.0000,1,1885,0),(29098,914,'Capital Scalar Capacitor Unit Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1588,0),(29099,913,'Capital Superconductor Rails','Weapon Component used primarily in Railguns. A component in various other technology as well.  ',1,10,0,1,1,232660.0000,1,1885,0),(29100,914,'Capital Superconductor Rails Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1588,0),(29101,913,'Capital Sustained Shield Emitter','Shield Component used primarily in Caldari ships. A component in various other technology as well.    ',1,10,0,1,1,100500.0000,1,1885,0),(29102,914,'Capital Sustained Shield Emitter Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1588,0),(29103,913,'Capital Tesseract Capacitor Unit','Capacitor component used primarily in Amarr ships. A component in various other technology as well.  ',1,10,0,1,4,362450.0000,1,1884,0),(29104,914,'Capital Tesseract Capacitor Unit Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1587,0),(29105,913,'Capital Thermonuclear Trigger Unit','Weapon Component used primarily in Cannons. A component in various other technology as well.  ',1,10,0,1,2,232660.0000,1,1887,0),(29106,914,'Capital Thermonuclear Trigger Unit Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1590,0),(29107,913,'Capital Titanium Diborite Armor Plate','Armor Component used primarily in Caldari ships. A component in various other technology as well.    ',1,10,0,1,1,55560.0000,1,1885,0),(29108,914,'Capital Titanium Diborite Armor Plate Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1588,0),(29109,913,'Capital Tungsten Carbide Armor Plate','Armor Component used primarily in Amarr ships. A component in various other technology as well.    ',1,10,0,1,4,55560.0000,1,1884,0),(29110,914,'Capital Tungsten Carbide Armor Plate Blueprint',' ',0,0.01,0,1,NULL,15000000.0000,1,1587,0),(29113,903,'Ancient Compressed Blue Ice','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles.  Due to its unique chemical composition and the circumstances under which it forms, blue ice contains more oxygen isotopes than any other ice asteroid.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,76000.0000,0,NULL,0),(29115,903,'Ancient Compressed Clear Icicle','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. These crystalline formations can be found scattered around many an ice field, and are known as the universe\'s primary source of helium isotopes.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,376000.0000,0,NULL,0),(29117,903,'Ancient Compressed Dark Glitter','Dark glitter is one of the rarest of the interstellar ices, formed only in areas with large amounts of residual electrical current.  Little is known about the exact way in which it comes into being; the staggering amount of liquid ozone to be found inside one of these rocks makes it an intriguing mystery for stellar physicists and chemists alike.  In addition, it contains large amounts of heavy water and a decent measure of strontium clathrates.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,1550000.0000,0,NULL,0),(29119,903,'Ancient Compressed Enriched Clear Icicle','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles. These crystalline formations can be found scattered around many an ice field and are known as the universe\'s primary source of helium isotopes.  Due to environmental factors, this fragment\'s isotope deposits have become even richer than its regular counterparts\'.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,475000.0000,0,NULL,0),(29121,903,'Ancient Compressed Gelidus','Fairly rare and very valuable, Gelidus-type ice formations are a large-scale source of strontium clathrates, one of the rarest ice solids found in the universe, in addition to which they contain unusually large concentrations of heavy water and liquid ozone.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,825000.0000,0,NULL,0),(29123,903,'Ancient Compressed Glacial Mass','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles.  Glacial masses are known to contain hydrogen isotopes in abundance, in addition to smatterings of heavy water and liquid ozone.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,76000.0000,0,NULL,0),(29125,903,'Ancient Compressed Glare Crust','In areas with high concentrations of electromagnetic activity, ice formations such as this one, containing large amounts of heavy water and liquid ozone, are spontaneously formed during times of great electric flux.  Glare crust also contains a small amount of strontium clathrates.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,1525000.0000,0,NULL,0),(29127,903,'Ancient Compressed Krystallos','The universe\'s richest known source of strontium clathrates, Krystallos ice formations are formed only in areas where a very particular combination of environmental factors are at play.  Krystallos compounds also include quite a bit of liquid ozone.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,450000.0000,0,NULL,0),(29129,903,'Ancient Compressed Pristine White Glaze','When star fusion processes occur near high concentrations of silicate dust, such as those found in interstellar ice fields, the substance known as White Glaze is formed.  While White Glaze generally is extremely high in nitrogen-14 and other stable nitrogen isotopes, a few rare fragments, such as this one, have stayed free of radioactive contaminants and are thus richer in isotopes than their more impure counterparts.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.\r\r\n',1000,100,0,1,NULL,116000.0000,0,NULL,0),(29131,903,'Ancient Compressed Smooth Glacial Mass','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles.  Glacial masses are known to contain hydrogen isotopes in abundance, but the high surface diffusion on this particular mass means it has considerably more than its coarser counterparts.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,116000.0000,0,NULL,0),(29133,903,'Ancient Compressed Thick Blue Ice','Interstellar ices are formed by accretion of gas molecules onto silicate dust particles.  Due to its unique chemical composition and the circumstances under which it forms, blue ice will, under normal circumstances, contain more oxygen isotopes than any other ice asteroid.  This particular formation is an old one and therefore contains even more than its less mature siblings.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.\r\r\n',1000,100,0,1,NULL,116000.0000,0,NULL,0),(29135,903,'Ancient Compressed White Glaze','When star fusion processes occur near high concentrations of silicate dust, such as those found in interstellar ice fields, the substance known as White Glaze is formed.  White Glaze is extremely high in nitrogen-14 and other stable nitrogen isotopes, and is thus a necessity for the sustained operation of certain kinds of control tower.\r\r\n\r\r\nThis ore has been compressed into a much more dense version.',1000,100,0,1,NULL,76000.0000,0,NULL,0),(29137,314,'Caldari Traitor\'s DNA','DNA samples are any of various nucleic acids that are usually the molecular basis of heredity, are localized especially in cell nuclei, and are constructed of a double helix held together by hydrogen bonds between purine and pyrimidine bases which project inward from two chains containing alternate links of deoxyribose and phosphate.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29138,23,'Clone Grade Tau',' ',0,1,0,1,NULL,21000000.0000,0,NULL,0),(29139,23,'Clone Grade Upsilon',' ',0,1,0,1,NULL,31500000.0000,0,NULL,0),(29140,23,'Clone Grade Phi',' ',0,1,0,1,NULL,45500000.0000,0,NULL,0),(29141,23,'Clone Grade Chi',' ',0,1,0,1,NULL,63000000.0000,0,NULL,0),(29142,23,'Clone Grade Psi',' ',0,1,0,1,NULL,84000000.0000,0,NULL,0),(29143,23,'Clone Grade Omega',' ',0,1,0,1,NULL,105000000.0000,0,NULL,0),(29144,927,'Federation Industrial','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',11750000,275000,6000,1,8,0.0000,0,NULL,0),(29145,927,'Imperial Industrial','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',13500000,260000,5100,1,4,0.0000,0,NULL,0),(29146,927,'Republic Industrial','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',12500000,255000,5625,1,2,0.0000,0,NULL,0),(29147,927,'State Industrial','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',13500000,270000,5250,1,1,0.0000,0,NULL,0),(29148,14,'Corpse Female',' ',80,2,0,1,NULL,0.0000,1,NULL,0),(29149,319,'Stationary Pleasure Yacht','A luxurious pleasure yacht.',13075000,115000,3200,1,NULL,0.0000,0,NULL,0),(29150,369,'Encrypted Ship Log','This otherwise rather generic ship log has been well encrypted. Your ship\'s computers are unable to access its data. ',1,1,0,1,NULL,380.0000,1,NULL,0),(29157,226,'Wrecked Revelation','This Revelation has seen better days, generally the ones in which it was still in one piece.',0,0,0,1,4,0.0000,0,NULL,0),(29158,226,'Wrecked Archon','One doesn\'t need to be an insurance inspector to know that this ship is a write-off. The huge holes in the superstructure are a dead giveaway.',0,0,0,1,4,0.0000,0,NULL,0),(29159,226,'Wrecked Battleship','This used to be a battleship of some description, although time has clearly not been kind to it - its original form is now completely unidentifiable.',0,0,0,1,4,0.0000,0,NULL,0),(29160,226,'Wrecked Cruiser','A proud spacefaring vessel reduced to a pile of generic scrap. Not exactly what the captain was hoping would happen, but that\'s life for you.',0,0,0,1,4,0.0000,0,NULL,0),(29161,226,'Wrecked Frigate','A small crumpled tangle of structural beams and fragments of electronics is all that remains of this frigate',0,0,0,1,4,0.0000,0,NULL,0),(29162,314,'Privateer Commander\'s Head','It\'s... well, it\'s a head. In a jar. And it once belonged to a privateer commander. (The head, not the jar. The jar was yours. Or, well, it was given to you, so it was kind of yours. Anyway, you put the head in it.) ',10,0.25,0,1,NULL,0.0000,1,NULL,0),(29165,319,'Amarr Tactical Relay','This structure acts as a relay station for the Amarr Empire\'s operations in this structure, collecting, receiving and transmitting battlefield intelligence.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(29166,319,'Amarr Tactical Supply Station','This structure is a tactical supply station for the Amarr Empire. It acts as a logistical depot for military operations throughout the system.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(29167,319,'Amarr Tactical Command Post','This structure forms part of the primary command net for this system, co-ordinating all Amarr Empire military operations.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(29168,319,'Amarr Tactical Support Center','This multi-purpose structure acts as temporary housing for all kinds of Amarr Empire personnel in their efforts to secure this system.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(29169,319,'Caldari Tactical Command Post','This structure forms part of the primary command net for this system, co-ordinating all Caldari State military operations.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(29170,319,'Gallente Tactical Command Post','This structure forms part of the primary command net for this system, co-ordinating all Gallente Federation military operations.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(29171,319,'Minmatar Tactical Command Post','This structure forms part of the primary command net for this system, co-ordinating all Minmatar Republic military operations.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(29172,319,'Caldari Tactical Relay','This structure acts as a relay station for the Caldari State\'s operations in this structure, collecting, receiving and transmitting battlefield intelligence.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(29173,319,'Gallente Tactical Relay','This structure acts as a relay station for the Gallente Federation\'s operations in this structure, collecting, receiving and transmitting battlefield intelligence.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(29174,319,'Minmatar Tactical Relay','This structure acts as a relay station for the Minmatar Republic\'s operations in this structure, collecting, receiving and transmitting battlefield intelligence.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(29175,319,'Caldari Tactical Support Center','This multi-purpose structure acts as temporary housing for all kinds of Caldari State personnel in their efforts to secure this system.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(29176,319,'Gallente Tactical Support Center','This multi-purpose structure acts as temporary housing for all kinds of Gallente Federation personnel in their efforts to secure this system.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(29177,319,'Minmatar Tactical Support Center','This multi-purpose structure acts as temporary housing for all kinds of Minmatar Republic personnel in their efforts to secure this system.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(29178,319,'Caldari Tactical Supply Station','This structure is a tactical supply station for the Caldari State. It acts as a logistical depot for military operations throughout the system.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(29179,319,'Gallente Tactical Supply Station','This structure is a tactical supply station for the Gallente Federation. It acts as a logistical depot for military operations throughout the system.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(29180,319,'Minmatar Tactical Supply Station','This structure is a tactical supply station for the Minmatar Republic. It acts as a logistical depot for military operations throughout the system.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(29181,306,'Cargo Container - Tactical Information I','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29182,306,'Cargo Container - Tactical Information II','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29183,306,'Cargo Container - Tactical Information III','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29184,306,'Cargo Container - Tactical Information IV','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29185,526,'Tactical Information I','These data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.\r\r\nThey appear to be encrypted military documents.',1,10,0,1,NULL,0.0000,1,NULL,0),(29186,526,'Tactical Information II','These data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.\r\r\nThey appear to be encrypted military documents.',1,20,0,1,NULL,0.0000,1,NULL,0),(29187,526,'Tactical Information III','These data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.\r\r\nThey appear to be encrypted military documents.',1,40,0,1,NULL,0.0000,1,NULL,0),(29188,526,'Tactical Information IV','These data sheets may mean little to the layman\'s eye, but can prove valuable in the right hands.\r\r\nThey appear to be encrypted military documents.',1,80,0,1,NULL,0.0000,1,NULL,0),(29189,319,'Subspace Beacon','This subspace beacon is protected by a powerful shield generator.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(29190,306,'Wreck W/ 23 Survivors','This wreck appears to have twenty three survivors in it',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29191,283,'Survivor','This unfortunate but hardy individual has survived a terrible ordeal. His wounds are both physical and emotional, but he seems determined to live on. ',80,1,0,1,NULL,0.0000,1,NULL,0),(29193,920,'Electronic Effect Beacon','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(29200,687,'Athran Agent','The Athran Brotherhood is a group of Khanid secessionists with headquarters located on the Khanid homeworld of Amarr Prime.',1740000,17400,220,1,4,0.0000,0,NULL,0),(29201,687,'Athran Operative','The Athran Brotherhood is a group of Khanid secessionists with headquarters located on the Khanid homeworld of Amarr Prime.',1000000,28100,120,1,4,0.0000,0,NULL,0),(29202,314,'Modified Augumene Antidote','This serum alters the DNA of any Matari so that he or she becomes immune to the deleterious effects of modified Augumene.',5,5,0,1,NULL,325.0000,1,NULL,0),(29203,314,'Minmatar DNA','This DNA sample was extracted from the remains of a Matari individual who died as a result of a severe allergic reaction to Augumene ore refined using an experimental method. Further research into this particular refining method has been terminated.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29204,178,'Modified Augumene Antidote Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(29205,314,'Corporations for the Rest of Us','This book appears similar in design to the educational manuals (skill books) popular among capsuleers. This book is a collection of half-hearted aphorisms and childish business-sense to a capsuleer, but then maybe it would be helpful to the plebes of the universe. ',1,0.1,0,1,NULL,3328.0000,1,NULL,0),(29206,526,'Device','This is a thing. It does stuff. ',1,1,0,1,NULL,0.0000,1,NULL,0),(29207,922,'10km Amarr Capture Point','This object registers the presence of ships within 10km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29208,226,'Fortified Billboard','Concord Billboards keep you updated, bringing you the latest news and bounty information.',100,1,1000,1,4,0.0000,0,NULL,0),(29209,319,'Billboard','Concord Billboards keep you updated, bringing you the latest news and bounty information.',100,1,1000,1,4,0.0000,0,NULL,0),(29211,314,'Faulty Suntendi Virtu-Real Implant','This implant has proven unreliable at best. Due to an unforeseen complication, the implant can cause some hosts to emit erratic and intense bio-electric pulses capable of damaging nearby audiovisual technology.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29212,306,'Suntendi Research Outpost','This is a high tech research outpost.',100000,1150,8850,1,8,0.0000,0,NULL,0),(29213,306,'Habitation Module w/4xScientists','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000,10000,1,8,0.0000,0,NULL,0),(29214,306,'Quarantine Station Ruins','Ruins',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29215,804,'Unidentified Spacecraft','This strange ship is quite unlike anything you or your ship\'s targeting computer has seen before. You might take it for some kind of rogue drone, save that your ship\'s scanners clearly indicate life signs aboard it.',100000,60,1200,1,NULL,0.0000,0,NULL,0),(29216,283,'Heiress','The heir to a vast fortune: what she wants, she gets.',54,1,0,1,NULL,0.0000,1,NULL,0),(29217,526,'Hard Currency','Useful for shady dealings.',10,1,0,1,NULL,0.0000,1,NULL,0),(29219,283,'Miniature Slaver','For those not interested in the risk or effort of cultivating the vicious slaver hound, there is the miniature slaver: a small yappy-type dog bred from the physically and mentally stunted of the litter.',2,0.01,0,1,NULL,3000.0000,1,NULL,0),(29226,526,'Basic Robotics','Automated mechanical devices built for industrial use.',2500,2,0,1,NULL,1588.0000,1,NULL,0),(29227,356,'Basic Robotics Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(29228,697,'Concord Battleship','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',20500000,1080000,400,1,NULL,0.0000,0,NULL,0),(29229,283,'Amarr Diplomat','This man is an officially sanctioned representative of the Amarr Empire. ',90,1,0,1,NULL,100.0000,1,NULL,0),(29230,306,'Cargo Container - Dolls','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29233,675,'Caldari State Shuttle','A Caldari state shuttle',1600000,5000,10,1,1,0.0000,0,NULL,0),(29234,1007,'Amarr Frigate Vessel','A frigate of the Amarr Empire.\r\r\n',2820000,24398,235,1,4,0.0000,0,NULL,0),(29235,1006,'Amarr Cruiser Vessel','A cruiser of the Amarr Empire.\r\r\n',11500000,115000,465,1,4,0.0000,0,NULL,0),(29236,924,'Amarr Battleship Vessel','A battleship of the Amarr Empire.\r\r\n',20500000,1100000,235,1,4,0.0000,0,NULL,0),(29237,924,'Caldari Battleship Vessel','A battleship of the Caldari State.\r\r\n',21000000,1040000,235,1,1,0.0000,0,NULL,0),(29238,1006,'Caldari Cruiser Vessel','A cruiser of the Caldari State.\r\r\n',10700000,107000,850,1,1,0.0000,0,NULL,0),(29239,1007,'Caldari Frigate Vessel','A frigate of the Caldari State.\r\r\n',1500100,15001,45,1,1,0.0000,0,NULL,0),(29240,924,'Gallente Battleship Vessel','A battleship of the Gallente Federation.\r\r\n',19000000,1010000,480,1,8,0.0000,0,NULL,0),(29241,1006,'Gallente Cruiser Vessel','A cruiser of the Gallente Federation.\r\r\n',11300000,113000,235,1,8,0.0000,0,NULL,0),(29242,1007,'Gallente Frigate Vessel','A frigate of the Gallente Federation.\r\r\n',2450000,24500,60,1,8,0.0000,0,NULL,0),(29243,924,'Minmatar Battleship Vessel','A battleship of the Minmatar Republic.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(29244,1006,'Minmatar Cruiser Vessel','A cruiser of the Minmatar Republic.\r\r\n',9900000,99000,1900,1,2,0.0000,0,NULL,0),(29245,1007,'Minmatar Frigate Vessel','A frigate of the Minmatar Republic.',2112000,21120,100,1,2,0.0000,0,NULL,0),(29246,526,'Corpse of Enlil Bel','Not a doll.',80,1,0,1,NULL,0.0000,1,NULL,0),(29247,24,'Loyalty Points','Loyalty points are rewarded to capsuleers for successfully completing missions for a corporation, which can be redeemed for special items from that corporation.\r\r\n\r\r\nTo see your current amount of loyalty points, open your journal and click on the Loyalty Points tab.\r\r\n\r\r\nTo spend them, open the LP Store in any station owned by a corporation with which you have loyalty points.\r\r\n\r\r\nFor more information, please refer to the EVElopedia article about <a href=\"evebrowser: http://wiki.eveonline.com/en/wiki/Loyalty_point\">loyalty points</a>.',0,0,0,1,NULL,0.0000,0,NULL,0),(29248,25,'Magnate','This Magnate-class frigate is one of the most decoratively designed ship classes in the Amarr Empire,  considered to be a pet project for a small, elite group of royal ship engineers for over a decade. The frigate\'s design has gone through several stages over the past decade, and new models of the Magnate appear every few years. The most recent versions of this ship   the Silver Magnate and the Gold Magnate   debuted as rewards in the Amarr Championships in YC105, though the original Magnate design is still a popular choice among Amarr pilots. ',1072000,22100,400,1,4,321786.0000,1,72,0),(29249,105,'Magnate Blueprint',' ',0,0.01,0,1,NULL,2775000.0000,1,272,0),(29250,226,'Fortified Large EM Forcefield','An antimatter generator powered by tachyonic crystals, creating a perfect defensive circle of electro-magnetic radiance.',100000,100000000,0,1,4,0.0000,0,NULL,0),(29251,226,'Fortified Starbase Explosion Dampening Array','Boosts the control tower\'s shield resistance against explosive damage.',4000,4000,0,1,4,0.0000,0,NULL,0),(29253,283,'Political Envoy','Harumph!',90,2,0,1,NULL,0.0000,1,NULL,0),(29262,319,'Fuel Depot','This depot contains fuel for the surrounding structures.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(29263,283,'Geeral Tash-Murkon','A notable heir of the Tash-Murkon dynasty, Geeral is effectively one of the richest men in the galaxy. Moreover, he is 178th in line for the imperial throne   yet he has apparently turned traitor. More fool he.',90,1.5,0,1,NULL,0.0000,1,NULL,0),(29266,31,'Apotheosis','\"For you, children, on your fifth birthday. May your next five years be as full of promise and hope, and may you one day walk with us as equals among the stars.\"\r\r\n\r\r\n<br><br><i>Idmei Sver, Society of Conscious Thought, on the fifth anniversary of the Capsuleer Era.</i>',1600000,17400,10,1,16,0.0000,1,1618,0),(29267,111,'Apotheosis Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,NULL,0),(29268,314,'Major Effects','The effects of a Major.',1,0.2,0,1,NULL,0.0000,0,NULL,0),(29269,283,'Major\'s Son','The son of a prominent major.',80,1,0,1,NULL,0.0000,1,NULL,0),(29272,314,'Air Show Entrance Badge','This badge signifies that the owner is qualified to participate in an air show.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29278,314,'Physical Samples','A sampling of various types of organic matter that has been exposed to some unusual cosmic radiation.',1,1,0,1,NULL,0.0000,1,NULL,0),(29279,226,'Station - Caldari','Docking into this Caldari station without proper authorization has been prohibited.',0,0,0,1,1,0.0000,0,NULL,0),(29283,283,'Troubled Miner','A sturdy miner.',100,2,0,1,NULL,0.0000,1,NULL,0),(29284,314,'Central Data Core','This bulky component is the substratal databank for all information transferred via computers linked to a station\'s dataweb. ',3500,5,0,1,NULL,100.0000,1,NULL,0),(29285,526,'Insorum Components','These are the raw chemical components used to make insorzapine bisulfate, an unstable reactive mutagen binder with uses that include negating the effects of Vitoc. This compound is also dangerously lethal.',1,1,0,1,NULL,0.0000,1,NULL,0),(29286,925,'Amarr Infrastructure Hub','This structure serves as the central command post for this system. Whoever controls this Infrastructure Hub can exert system-wide military control.',1000000,0,0,1,4,600000.0000,0,NULL,0),(29289,306,'Zainou Biotech Convoy Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this old wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29290,927,'Imperial Courier','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',13500000,260000,5100,1,4,0.0000,0,NULL,0),(29291,927,'State Courier','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',13500000,270000,5250,1,1,0.0000,0,NULL,0),(29292,927,'Federation Courier','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',11750000,275000,6000,1,8,0.0000,0,NULL,0),(29293,927,'Republic Courier','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',12500000,255000,5625,1,2,0.0000,0,NULL,0),(29294,283,'Smugglers','These shady individuals were caught transporting contraband.',600,300,0,1,NULL,0.0000,1,NULL,0),(29296,310,'Novice Military Beacon','This beacon marks a novice military location. The entry gate is likely configured to admit only Tech I frigates.',1,1,0,1,NULL,0.0000,0,NULL,0),(29297,310,'Small Military Beacon','This beacon marks a small military location. The entry gate is likely configured to admit Tech I frigates, Tech II frigates, Tech I destroyers, Tech II destroyers and Tech III destroyers.',1,1,0,1,4,0.0000,0,NULL,0),(29298,310,'Medium Military Beacon','This beacon marks a medium military location. The entry gate is likely configured to admit Tech I and Tech II frigates, Tech I and Tech II destroyers and Tech I and Tech II cruisers.',1,1,0,1,NULL,0.0000,0,NULL,0),(29299,310,'Core Military Beacon','This beacon marks a major military location. The entry gate is likely configured to admit all non-capital vessels.',1,1,0,1,NULL,0.0000,0,NULL,0),(29300,310,'Large Military Beacon','This beacon marks a large free-standing military location with no acceleration gate',1,1,0,1,NULL,0.0000,0,NULL,0),(29301,319,'Caldari Bunker','A small bunker, there for accommodation and increased mobility of troops and other personnel. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(29302,925,'Caldari Infrastructure Hub','This structure serves as the central command post for this system. Whoever controls this Infrastructure Hub can exert system-wide military control.',1000000,0,0,1,1,600000.0000,0,NULL,0),(29303,925,'Gallente Infrastructure Hub','This structure serves as the central command post for this system. Whoever controls this Infrastructure Hub can exert system-wide military control.',1000000,0,0,1,8,600000.0000,0,NULL,0),(29304,925,'Minmatar Infrastructure Hub','This structure serves as the central command post for this system. Whoever controls this infrastructure hub can exert system-wide military control.',1000000,0,0,1,2,600000.0000,0,NULL,0),(29310,922,'20km Amarr Capture Point','This object registers the presence of ships within 20km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29311,922,'30km Amarr Capture Point','This object registers the presence of ships within 30km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29312,922,'40km Capture Point','This object registers the presence of ships within 40km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29313,922,'50km Capture Point','This object registers the presence of ships within 50km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29314,922,'60km Capture Point','This object registers the presence of ships within 60km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29315,922,'70km Capture Point','This object registers the presence of ships within 70km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29316,922,'80km Capture Point','This object registers the presence of ships within 80km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29317,922,'90km Capture Point','This object registers the presence of ships within 90km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29318,922,'100km Capture Point','This object registers the presence of ships within 100km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29321,314,'Broken Mining Equipment','This large container is fitted with a password-protected security lock. It is filled with broken parts needed to rebuild manual surface-mining drills. ',700,40,0,1,NULL,0.0000,1,NULL,0),(29323,15,'Ishukone Corporation Headquarters',' ',0,1,0,1,1,0.0000,0,NULL,0),(29324,306,'Cargo Container - Broken Mining Equipment','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29325,319,'Starbase Auxiliary Power Array II','These arrays provide considerable added power output, allowing for an increased number of deployable structures in the starbase\'s field of operation.',100,100,0,1,NULL,0.0000,0,NULL,0),(29328,31,'Amarr Media Shuttle','Modified shuttle used by the Amarr media to report on events.',1600000,5000,0,1,4,5556.0000,0,NULL,0),(29329,111,'Amarr Media Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(29330,31,'Caldari Media Shuttle','Modified shuttle used by the Caldari media to report on events.',1600000,5000,0,1,1,5556.0000,0,NULL,0),(29331,111,'Caldari Media Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(29332,31,'Gallente Media Shuttle','Modified shuttle used by the Gallente media to report on events.',1600000,5000,0,1,8,5556.0000,0,NULL,0),(29333,111,'Gallente Media Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(29334,31,'Minmatar Media Shuttle','Modified shuttle used by the Minmatar media to report on events.',1600000,5000,0,1,2,5556.0000,0,NULL,0),(29335,111,'Minmatar Media Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,0,NULL,0),(29336,26,'Scythe Fleet Issue','The Scythe Fleet Issue is a throwback to earlier days of Minmatar ship design, when the scarcity of resources meant that a single ship needed to be able to do almost everything. While often dubbed a \"mini-Typhoon\" for this reason, this versatile gunboat nonetheless has nowhere near the defensive capabilities of its larger ancestor. What it does bring to the table, however, is unparalleled agility and unpredictability. A squadron of these ships can be an immense thorn in the side of even the most able and well-equipped fleet commander.',10910000,89000,440,1,2,10801294.0000,1,1370,0),(29337,26,'Augoror Navy Issue','The Navy-issued version of the Augoror cruiser is an extremely resilient piece of hardware able to provide very good support in fleet battles, but it is also a relatively nimble cruiser ideally suited for escort duties as well as smaller skirmishes.  Created to fill a void within the ranks of the traditionally slow and lumbering Amarrian fleet, this vessel has fit in perfectly.',10650000,101000,480,1,4,11134410.0000,1,1370,0),(29338,106,'Augoror Navy Issue Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(29339,106,'Scythe Fleet Issue Blueprint',' ',0,0.01,0,1,NULL,28775000.0000,1,NULL,0),(29340,26,'Osprey Navy Issue','Caldari ships have never been renowned for their speed. With this in mind, Caldari Navy engineers set about designing the Osprey Navy Issue. The fastest Caldari cruiser in existence and a formidable missile boat, this vessel gives Navy personnel and State loyalists alike greater opportunities to conduct true skirmish warfare than ever before.',11780000,107000,460,1,1,11274568.0000,1,1370,0),(29341,106,'Osprey Navy Issue Blueprint',' ',0,0.01,0,1,NULL,28750000.0000,1,NULL,0),(29344,26,'Exequror Navy Issue','The Exequror Navy Issue was commissioned by Federation Navy High Command in response to the proliferation of close-range blaster vessels on the modern stellar battlefield. While it doesn\'t boast the speed of some of its class counterparts, this up-close-and-personal gunboat nonetheless possesses some of the more advanced hybrid plasma-coil compression subsystems available, making it a lethal adversary in any upfront engagement.',11280000,112000,465,1,8,11251106.0000,1,1370,0),(29345,106,'Exequror Navy Issue Blueprint',' ',0,0.01,0,1,NULL,74000000.0000,1,NULL,0),(29346,319,'Starbase Auxiliary Power Array III','These arrays provide considerable added power output, allowing for an increased number of deployable structures in the starbase\'s field of operation.',100,100,0,1,NULL,0.0000,0,NULL,0),(29347,186,'Mission Faction Vessels Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(29348,226,'Apocalypse Bow','This Apocalypse-class battleship has been torn in half; the bow section is largely intact, although there are no obvious signs of life.',0,0,0,1,4,0.0000,0,NULL,0),(29349,226,'Apocalypse Stern','This Apocalypse-class battleship has been torn in half; while the stern appears to be maintaining structural integrity, the obvious signs of reactor breaches make it very unlikely that anyone is left alive inside.',0,0,0,1,4,0.0000,0,NULL,0),(29350,226,'Armageddon Bow','With its spine snapped and large areas of its armor stripped away, this Armageddon must have been subjected to massive amount of damage.',0,0,0,1,4,0.0000,0,NULL,0),(29351,226,'Armageddon Stern','Despite the obvious absence of a front end, this section of wreck appears largely intact at first glance. A more detailed scan though reveals deep fractures throughout the structure, betraying the titanic stresses it has been subjected to.',0,0,0,1,4,0.0000,0,NULL,0),(29352,226,'Raven Hull','While the wings and bow have been sheared off this Raven-class battleship, the central hull structure has lived up to Caldari engineering standards and remained intact. Any remaining crew will likely have evacuated or perished by now.',0,0,0,1,1,0.0000,0,NULL,0),(29353,226,'Raven Wing','This piece of wreckage is the starboard wing of a Raven-class battleship, sheared off at the root. Where the rest of the ship ended up is anyone\'s guess.',0,0,0,1,1,0.0000,0,NULL,0),(29354,226,'Scorpion Lower Hull','This piece of wreckage is part of the lower hull of a Scorpion-class battleship. This area is mainly given over to ship systems, so loss of life resulting from the multiple hull breaches should have been comparatively minimal',0,0,0,1,1,0.0000,0,NULL,0),(29355,226,'Scorpion Masthead','The masthead section of Scorpion-class battleships contains a large amount of sensitive equipment that would be of great interest to rival empires. In this case, though, it\'s clear that the damage inflicted means whatever\'s inside would only be of interest to scrap dealers',0,0,0,1,1,0.0000,0,NULL,0),(29356,226,'Scorpion Upper Hull','Containing a large number of crew battle stations, the damage to this section of Scorpion superstructure must have entailed a huge loss of life',0,0,0,1,1,0.0000,0,NULL,0),(29357,226,'Megathron Bow','This Megathron bow section functioned as designed, tearing cleanly away from the rest of the hull under sustained fire',0,0,0,1,8,0.0000,0,NULL,0),(29358,226,'Megathron Hull','This Megathron hull has weathered significant damage, with most major protrusions ripped away. Distress beacons still function within the wreckage, but it seems unlikely that any pockets of atmosphere remain',0,0,0,1,8,0.0000,0,NULL,0),(29359,226,'Tempest Lower Sail','As is common with Minmatar designs, this Tempest battleship has fragmented into multiple sections under heavy fire. This lower section appears largely inert, with only a few arcing connectors showing any signs of activity',0,0,0,1,2,0.0000,0,NULL,0),(29360,226,'Tempest Upper Sail','As is common with Minmatar designs, this Tempest battleship has fragmented into multiple sections under heavy fire. A few red lights still blink forlornly within the bridge section, but the corpses drifting inside make clear that there are no other signs of life on board',0,0,0,1,2,0.0000,0,NULL,0),(29361,226,'Tempest Midsection','As is common with Minmatar designs, this Tempest battleship has fragmented into multiple sections under heavy fire. This midsection seems to have taken the brunt of the damage in this case',0,0,0,1,2,0.0000,0,NULL,0),(29362,226,'Tempest Stern','As is common with Minmatar designs, this Tempest battleship has fragmented into multiple sections under heavy fire. The sparking power relays at the forward end of this drive section suggest there is still some life in the main reactors, but the radiation readings indicate that this was probably not a good thing for any surviving crew.',0,0,0,1,2,0.0000,0,NULL,0),(29363,226,'Naglfar Wreck','The remains of a destroyed Naglfar',0,0,0,1,2,0.0000,0,NULL,0),(29364,226,'Naglfar Upper Half','The upper half of this mighty Naglfar-class dreadnaught has sustained considerable damage to its starboard batteries. A few intermittent signals which might be signs of life deep inside can still be detected, but there\'s no easy way to cut through the mangled wreckage and find out',0,0,0,1,2,0.0000,0,NULL,0),(29365,186,'Mission Faction Industrials Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(29382,226,'Caldari Prime Station (Under Construction)',' ',0,0,0,1,1,0.0000,0,NULL,0),(29386,226,'CONCORD Battleship Wreck','CONCORD vessels employ advanced hull technology which allows them to maintain external integrity even after the ship has suffered complete systems failure. This is definitely one of those cases - while the hull appears intact, the rest of the ship is very clearly non-functional',0,0,0,1,8,0.0000,0,NULL,0),(29387,15,'Damaged Amarr Station Hub',' ',0,0,0,1,4,0.0000,0,NULL,0),(29388,15,'Damaged Amarr Military Station ',' ',0,0,0,1,4,0.0000,0,NULL,0),(29389,15,'Damaged Amarr Trading Post',' ',0,0,0,1,4,0.0000,0,NULL,0),(29390,15,'Damaged CONCORD Station',' ',0,0,0,1,8,0.0000,0,NULL,0),(29391,319,'Visera Yanala',' ',100000,100000000,10000,1,1,0.0000,0,NULL,0),(29414,922,'10km Caldari Capture Point','This object registers the presence of ships within 10km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29415,922,'10km Gallente Capture Point','This object registers the presence of ships within 10km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29416,922,'10km Minmatar Capture Point','This object registers the presence of ships within 10km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29418,922,'20km Caldari Capture Point','This object registers the presence of ships within 20km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29419,922,'20km Gallente Capture Point','This object registers the presence of ships within 20km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29420,922,'20km Minmatar Capture Point','This object registers the presence of ships within 20km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29421,922,'30km Caldari Capture Point','This object registers the presence of ships within 30km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29422,922,'30km Gallente Capture Point','This object registers the presence of ships within 30km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29423,922,'30km Minmatar Capture Point','This object registers the presence of ships within 30km',1000000,1,0,1,NULL,0.0000,0,NULL,0),(29437,319,'Starbase Auxiliary Power Array I','These arrays provide considerable added power output, allowing for an increased number of deployable structures in the starbase\'s field of operation.',100,100,0,1,NULL,0.0000,0,NULL,0),(29438,306,'Disabled Badger','The engines of this cargo vessel have been disabled so that it cannot move.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29439,283,'Admiral Meledier ','Admiral Meledier apparently wishes to defect to Amarr. Well, so be it: It\'s all a bit suspicious, but it\'s not your decision. ',85,1,0,1,NULL,0.0000,1,NULL,0),(29445,306,'Cargo Container - Physical Samples','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29446,319,'Large Container of Explosives','This large container is full of explosives.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(29447,283,'Gallente Politician','A planetside politician of the Gallente Federation.',90,2,0,1,NULL,0.0000,1,NULL,0),(29452,226,'Fortified Gallente Bunker','A Gallente Bunker',100000,100000000,0,1,4,0.0000,0,NULL,0),(29453,226,'Fortified Gallente Lookout','A lookout. Look out.',0,0,0,1,4,0.0000,0,NULL,0),(29454,226,'Fortified Gallente Barricade','A barricade.',0,0,0,1,4,0.0000,0,NULL,0),(29455,226,'Fortified Gallente Barrier','A barrier.',0,0,0,1,4,0.0000,0,NULL,0),(29456,226,'Fortified Gallente Battery','A battery. Juicy.',0,0,0,1,4,0.0000,0,NULL,0),(29457,226,'Fortified Gallente Fence','A fence.',0,0,0,1,4,0.0000,0,NULL,0),(29458,226,'Fortified Gallente Junction','A junction.',0,0,0,1,4,0.0000,0,NULL,0),(29459,226,'Fortified Gallente Wall','A wall.',0,0,0,1,4,0.0000,0,NULL,0),(29460,226,'Gallente Starbase Control Tower','Gallente Control Towers are more pleasing to the eye than they are strong or powerful. They have above average electronic countermeasures, average CPU output, and decent power output compared to towers from the other races, but are quite lacking in sophisticated defenses.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(29461,319,'Starbase Hangar Tough','A stand-alone deep-space construction designed to allow pilots to dock and refit their ships on the fly.',100000,1150,8850,1,NULL,0.0000,0,NULL,0),(29464,314,'Runaway Daughter','She\'s gone into suspended animation. It\'s probably for the best.',400,25,0,1,NULL,100.0000,1,NULL,0),(29466,927,'The Incredible Hulk','The backbone of any serious industrial operation, Hulks are amongst the most efficient mining vessels in circulation and sometimes re-engineered for survivability.',40000000,200000,8000,1,8,0.0000,0,NULL,0),(29467,319,'Power Generator 250k','This generator provides power to nearby structures. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(29468,319,'Shipyard Tough','Large construction tasks can be undertaken at this shipyard.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(29469,319,'Amarr Starbase Control Tower Tough','The Amarr have always been fond of majestic and intimidating constructions. Their Control Towers do not deviate from that tradition and are truly big and powerful structures, intended more for preservation of territorial interests than commercial benefits.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(29470,281,'Starcakes','The recipe for this highly ornate, traditional Jin-Mei sweet varies from planet to planet, and sometimes from city to city, but its fillings are always dense, sugary, and rich. Each cake\'s jelly center is held in place with a crusty exterior that, as befits tradition, is so highly decorated with symbols that it resembles a volcanic planet: It is possible to read the baker\'s story, lineage, and certifications in the crust\'s maze of lines and ridges, although a reader must be quite dedicated to finish the task before falling to temptation. ',400,2,0,1,NULL,98.0000,1,NULL,0),(29471,314,'Ancient Painblade','This antique weapon is the traditional precursor to the modern day\'s Painblade. <br><br>\r\r\n\r\r\nIn ancient times, Jin-Mei soldiers riding to the field used to plunge their swords into filth, in the well-founded expectation that the wounds they inflicted would cause infection and rot. This nasty tactic was given new life when royal technicians (in those days referred to as <i>Nuyin</i>, something akin to \"wizards\") developed a blade whose surface, when unsheathed, swiftly attracted and encouraged bacterial growth, giving life to all kinds of deadly filth. <br><br>\r\r\n\r\r\nNowadays, these items are mostly used in theatrical plays, and anyone who gets within a hand\'s reach of their swinging blades usually spends half an act wailing about it before finally dropping dead. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29472,526,'Ceremonial Brush','Before the advent of electronics, these writing tools were used throughout the Achuran continent. In times of war, it was not at all uncommon for a victor to use a brush-like pen to draw stylized icons representing the outcome of the battle and the heroics performed by his side. These icons would then be copied and molded onto an ivory or metal stamp, which was dipped into hot wax and used to stamp the victor\'s seal on the final agreement. <br><br>\r\r\n\r\r\nIt should be noted that the brushes and stamps are not the only tools in this box. Cleaning implements are of course included, and so are tiny pliers and some manner of disinfectant, for it was traditional that the victor\'s brush be inset with eyelashes drawn from the screaming conquered.',0.5,0.1,0,1,NULL,0.0000,1,NULL,0),(29473,526,'Medicinal Herbs','Traditional herbal remedies have been used for perhaps tens of thousands of years among the Vheriokor tribes of Minmatar. However, they have become so popular over time, particularly among the Gallente peoples, that various herbal concoctions and infusions can be found in virtually every part of inhabited space. <br><br>\r\r\n\r\r\nBut don\'t eat the roots. <br><br>\r\r\n\r\r\nNo, seriously. No matter what any scary prophet says. <br><br>\r\r\n\r\r\nHerbs are said to cure everything from colds to warp sickness, though they are also popular for mild recreation. If a cargo container of herbs seems the slightest bit lighter after a long ship\'s journey, it is the wise captain who does not question his crew too closely, nor visit their living quarters after hours. ',5,0.2,0,1,NULL,0.0000,1,NULL,0),(29474,314,'Singing Staff','A traditional musical instrument of the Vheriokor peoples, the singing staff is made from a few tightly-wound strings attached to a small staff. It is today played only ceremonially, and those proficient in its use are rare. <br><br>\r\r\n\r\r\nThe instrument is fitted over a pole, strings on one side and staff on the other, and then drawn diagonally across the pole\'s surface, eliciting soft monotones. The staffs themselves are usually made from ivory or some other type of bone. Some of these latter types are preferred, for it is said that they have an extra tone that can be heard only when one plays a song of sadness and loss. <br><br>\r\r\n\r\r\nWhile there exist plenty of poles specifically designed for this instrument, technically just about anything will do: a metal stand, a chair leg, or even, if the strings are wound tightly enough, a human appendage. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29475,314,'Intaki Clackers','A traditional Intaki musical instrument, the clacker consists of two flat pieces of lightweight material, loosely bound at one edge. When that end is held and the other end swung forward, the instrument produces a sharp clashing sound. <br><br>\r\r\n\r\r\nGiven the scarcity of wood in space, the instrument today is often made from plastic or other polymer variants. More complex variants have lights or chemicals inset in the material that can make the clackers do anything from reflecting light to taking on an eerie glow, or even emitting sparks. <br><br>\r\r\n\r\r\nIt\'s not at all uncommon for older siblings to frighten their younger relatives by sneaking up at them in the dark of night, rattling their clackers like some red-eyed beast of myth snapping its jaws. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29476,314,'Folkloric Painting','The Intaki have a long and glorious tradition of three-color paintings that depict scenes from both history and mythology, often melding the two into a highly symbolic rendition of their people\'s presence and purpose in the world of New Eden. <br><br>\r\r\n\r\r\nIn recent decades, the traditional Intaki painting style has been adopted by painters of the abstract \"Reticular school,\" an anti-factionalist, neo-traditional movement made famous by Suri Naatha and the Circle of Nineteen. ',0.5,0.2,0,1,NULL,0.0000,1,NULL,0),(29477,314,'Number Box','This construction, consisting of rows of pellets set onto colorful pins, once allowed Ni-Kunni mathematicians and natural philosophers to perform highly complex calculations. Its use faded into memory, as most things do, only to be rediscovered as a tool with which to teach students the particulars of certain highly abstract three-dimensional calculations required for space flight. <br><br>\r\r\n\r\r\nThe number box\'s pins are placed both horizontally and vertically, so the pellets can be slid along a triple axis; the box is also, to the relief of some teachers, heavy and solid enough to hit a student firmly over the head if he still can\'t grasp the math. ',5,0.2,0,1,NULL,0.0000,1,NULL,0),(29478,314,'Traditional Board Game','An ancient board game said to have been devised by the Ni-Kunni, this game was reputedly used for anything from entertainment on long ship hauls to deciding the fates of battles. Pieces in ancient times were made of wood or bone, but now most often consist of polymer compounds cast into intricate shapes. The game is easy to learn, hard to master, and really stupid to bet on. ',0.5,0.1,0,1,NULL,0.0000,1,NULL,0),(29479,526,'Firecrackers','Small explosive devices with extremely loud retorts   some even relying on cheap, built-in speakers to amplify their effects   these items are used for celebration (and often to prompt heart attacks) throughout the world of New Eden. ',100,1,0,1,NULL,0.0000,1,NULL,0),(29480,314,'Antique Vheriokor Statue','This statue represents a serpentine figure from ancient Vheriokor mythology; whether it bodes good or ill depends on its origin and the mindset of its viewer. Regardless, originals are increasingly rare these days. ',5,0.2,0,1,NULL,0.0000,1,NULL,0),(29481,281,'Ghalen Pastries','Ghalen is an old Achuran dish of ground meat mixed with chopped vegetables, wrapped in large green leaves and cooked in fat and oils. Each Ghalen pastry is usually the size of a man\'s fist, dripping with juice when one bites into it. It is served piping hot and is one of the few dishes of old that has not only retained its appeal, but become known throughout the world of New Eden. ',100,1,0,1,NULL,98.0000,1,NULL,0),(29482,281,'Ghalen Dumplings','Ghalen dumplings are variants of the more common Ghalen pastries. The dumplings have far less filling, if any, and usually consist merely of rice balls rolled in leaves and then deep-fried. On holy days, they are eaten without any condiment or side dish, but in recent times they\'ve gained vast popularity with young consumers, who tend to dip them in all manner of spicy sauces. ',120,1,0,1,NULL,98.0000,1,NULL,0),(29483,526,'Zydrine Wine','This delicate wine is brewed from rice leaves. It often takes on a faint green hue akin to that of raw Zydrine ore, whence it derives its popular name. <br><br>\r\r\n\r\r\nWhile Zydrine wine is in fact quite potent, it is very light on the palate and has an aftertaste of green tea. The resultant tendency for drinkers to assume the wine is non-alcoholic has led to some very amusing situations. ',500,1,0,1,NULL,0.0000,1,NULL,0),(29484,526,'Zydrine Burn','A cousin of the more refined Zydrine wine, Zydrine Burn (or just \"Burn\") is made from rice leaves and several unspecified components, one of which may or may not be liquefied fedo scent glands. The experience of drinking Burn has been compared to standing behind a spaceship\'s subspace engine, while the ship is running, with one\'s mouth open. <br><br>\r\r\n\r\r\nZydrine Burn is enjoyed, or at least ingested, throughout New Eden by masses in search of a new life experience. In this, it generally rewards. ',400,1,0,1,NULL,0.0000,1,NULL,0),(29485,526,'Kuashi','Two moderately ornate sticks ending in sharp points, with two-inch serrated blades along the forward edge, kuashi are used as eating utensils by the Jin-Mei people (and in fact their use has become common throughout the Caldari State). They are versatile implements, used to pick up small morsels or to stab larger items on their points (and even, among less couth folk, to cut portions away from platters of food). When the point is used to stab, the serrated edges help keep the largest mouthfuls attached to the sticks, thus avoiding clumsy faux pas. <br><br>\r\r\n\r\r\nIn some modern kuashi, tiny magnets are inset into the pointed tips to help the wielder keep them together (and thus to keep food properly pinned between), with pressure sensors in the dull ends determining their level of magnetism. ',50,0.5,0,1,NULL,0.0000,1,NULL,0),(29489,283,'Fugitive Slaves','These slaves have escaped from their masters, but have yet to gain legal protection or recognition as free people.',80,1.5,0,1,NULL,0.0000,1,NULL,0),(29495,937,'Rank',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(29496,937,'Medal',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(29497,937,'Ribbon',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(29503,226,'Indestructible Minmatar Starbase','The Matari aren\'t really that high-tech, preferring speed rather then firepower or involved technology. Unfortunately that doesn\'t apply very well to stationary objects, much to the liking of the Amarr Empire. Amarrians call it a scrapheap of epic proportions. But don\'t underestimate these structures. Minmatar commanders usually have the last laugh when it comes to combat.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(29504,284,'OP Insecticide','Organophosphates, similar to nerve gases, have long been used as insecticides, and as bugs evolve, so too must the methods for dealing with them. This particular insecticide is perhaps the most lethal known to humankind, and can kill nearly anything exposed to it. ',250,0.25,0,1,NULL,320.0000,1,NULL,0),(29505,226,'Fortified Amarr Bunker','A bunker. Beware.',0,0,0,1,4,0.0000,0,NULL,0),(29506,226,'Fortified Caldari Bunker','A bunker. Beware.',0,0,0,1,4,0.0000,0,NULL,0),(29507,226,'Caldari Starbase Control Tower','At first the Caldari Control Towers were manufactured by Kaalakiota, but since they focused their efforts mostly on other, more profitable installations, they soon lost the contract and the Ishukone corporation took over the Control Towers\' development and production.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(29508,226,'Fortified Caldari Lookout','A lookout. Look out.',0,0,0,1,4,0.0000,0,NULL,0),(29509,226,'Fortified Caldari Elevator','An elevator.',0,0,0,1,4,0.0000,0,NULL,0),(29511,226,'China Monument',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(29530,937,'Certificate','A certificate is an official document certifying that you have received specific education or have passed a test, to recognize most any minor achievement throughout many levels of your life.',0,0,0,1,NULL,0.0000,0,NULL,0),(29531,314,'Old Map','This is an old map.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29532,306,'Cartographer\'s Quarters','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(29546,226,'Amarr Revelation Dreadnought','A Revelation Dreadnought.',0,0,0,1,4,0.0000,0,NULL,0),(29549,306,'Reconnaissance Ship Wreck','The remains of a destroyed reconnaissance ship.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29551,226,'Fortified Angel Barricade','A barricade.',0,0,0,1,4,0.0000,0,NULL,0),(29552,226,'Fortified Angel Barrier','A barrier.',0,0,0,1,4,0.0000,0,NULL,0),(29553,226,'Fortified Angel Battery','A battery.',0,0,0,1,4,0.0000,0,NULL,0),(29554,226,'Fortified Angel Bunker','Angel Bunker',100000,100000000,0,1,4,0.0000,0,NULL,0),(29555,226,'Fortified Angel Elevator','An elevator.',0,0,0,1,4,0.0000,0,NULL,0),(29556,226,'Fortified Angel Fence','A fence.',0,0,0,1,4,0.0000,0,NULL,0),(29557,226,'Fortified Angel Junction','A junction.',0,0,0,1,4,0.0000,0,NULL,0),(29558,226,'Fortified Angel Lookout','A lookout. Look out.',0,0,0,1,4,0.0000,0,NULL,0),(29559,226,'Fortified Angel Wall','A wall.',0,0,0,1,4,0.0000,0,NULL,0),(29561,226,'Fortified Blood Raider Barricade','A barricade.',0,0,0,1,4,0.0000,0,NULL,0),(29562,226,'Fortified Blood Raider Battery','A battery.',0,0,0,1,4,0.0000,0,NULL,0),(29563,226,'Fortified Blood Raider Elevator','An elevator.',0,0,0,1,4,0.0000,0,NULL,0),(29564,226,'Fortified Blood Raider Lookout','A lookout. Look out.',0,0,0,1,4,0.0000,0,NULL,0),(29565,226,'Fortified Blood Raider Wall','A wall.',0,0,0,1,4,0.0000,0,NULL,0),(29566,226,'Fortified Amarr Barricade','A barricade.',0,0,0,1,4,0.0000,0,NULL,0),(29567,226,'Fortified Amarr Barrier','A barrier.',0,0,0,1,4,0.0000,0,NULL,0),(29568,226,'Fortified Amarr Elevator','An elevator.',0,0,0,1,4,0.0000,0,NULL,0),(29569,226,'Fortified Amarr Fence','A fence.',0,0,0,1,4,0.0000,0,NULL,0),(29570,226,'Fortified Amarr Junction','A junction.',0,0,0,1,4,0.0000,0,NULL,0),(29571,226,'Fortified Caldari Barricade','A barricade.',0,0,0,1,4,0.0000,0,NULL,0),(29572,226,'Fortified Caldari Barrier','A barrier.',0,0,0,1,4,0.0000,0,NULL,0),(29573,226,'Fortified Caldari Battery','A battery.',0,0,0,1,4,0.0000,0,NULL,0),(29574,226,'Fortified Caldari Fence','A fence.',0,0,0,1,4,0.0000,0,NULL,0),(29575,226,'Fortified Caldari Wall','A wall.',0,0,0,1,4,0.0000,0,NULL,0),(29576,226,'Fortified Guristas Barricade','A barricade.',0,0,0,1,4,0.0000,0,NULL,0),(29577,226,'Fortified Guristas Barrier','A barrier.',0,0,0,1,4,0.0000,0,NULL,0),(29578,226,'Fortified Guristas Battery','A battery.',0,0,0,1,4,0.0000,0,NULL,0),(29579,226,'Fortified Guristas Wall','A wall.',0,0,0,1,4,0.0000,0,NULL,0),(29580,226,'Fortified Guristas Lookout ','A lookout. Look out.',0,0,0,1,4,0.0000,0,NULL,0),(29581,226,'Fortified Guristas Junction','A junction.',0,0,0,1,4,0.0000,0,NULL,0),(29582,226,'Fortified Guristas Fence','A fence.',0,0,0,1,4,0.0000,0,NULL,0),(29583,226,'Fortified Guristas Elevator','An elevator.',0,0,0,1,4,0.0000,0,NULL,0),(29584,226,'Fortified Guristas Bunker','A Guristas Bunker',100000,100000000,0,1,4,0.0000,0,NULL,0),(29585,226,'Fortified Drone Barricade','A barricade.',0,0,0,1,4,0.0000,0,NULL,0),(29586,226,'Fortified Drone Barrier','A barrier.',0,0,0,1,4,0.0000,0,NULL,0),(29589,226,'Fortified Drone Battery','A battery.',0,0,0,1,4,0.0000,0,NULL,0),(29590,226,'Fortified Drone Elevator','An elevator.',0,0,0,1,4,0.0000,0,NULL,0),(29591,226,'Fortified Drone Fence','A fence.',0,0,0,1,4,0.0000,0,NULL,0),(29592,226,'Fortified Drone Junction','A junction.',0,0,0,1,4,0.0000,0,NULL,0),(29593,226,'Fortified Drone Lookout','A lookout. Look out.',0,0,0,1,4,0.0000,0,NULL,0),(29594,226,'Fortified Drone Wall','A wall.',0,0,0,1,4,0.0000,0,NULL,0),(29595,226,'Fortified Serpentis Elevator','An elevator.',0,0,0,1,4,0.0000,0,NULL,0),(29596,226,'Fortified Sansha Barricade','A barricade.',0,0,0,1,4,0.0000,0,NULL,0),(29597,226,'Fortified Sansha Barrier','A barrier.',0,0,0,1,4,0.0000,0,NULL,0),(29598,226,'Fortified Sansha Battery','A battery.',0,0,0,1,4,0.0000,0,NULL,0),(29599,226,'Fortified Sansha Bunker','A Sansha Bunker',100000,100000000,0,1,4,0.0000,0,NULL,0),(29600,226,'Fortified Sansha Elevator','An elevator.',0,0,0,1,4,0.0000,0,NULL,0),(29601,226,'Fortified Sansha Fence','A fence.',0,0,0,1,4,0.0000,0,NULL,0),(29602,226,'Fortified Sansha Junction','A junction.',0,0,0,1,4,0.0000,0,NULL,0),(29603,226,'Fortified Sansha Lookout','A lookout. Look out.',0,0,0,1,4,0.0000,0,NULL,0),(29604,226,'Fortified Sansha Wall','A wall.',0,0,0,1,4,0.0000,0,NULL,0),(29606,226,'Leviathan Wreck','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships. What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,1,0.0000,0,NULL,0),(29607,314,'Gallentean Viral Agent','The causative agent of an infectious disease, the viral agent is a parasite with a noncellular structure composed mainly of nucleic acid within a protein coat.',100,0.5,0,1,NULL,850.0000,1,NULL,0),(29608,306,'Radio Telescope - Hacking - Encoded Data Chip','This piece of floating rubble looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29613,397,'Large Ship Assembly Array','A mobile assembly facility where large ships such as Battleships, Freighters and Industrial Command Ships can be manufactured.\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n2% reduction in manufacturing required materials\r\r\n\r\r\nNote: To use a ship from a Ship Assembly Array a Ship Maintenance Array with enough free storage space needs to be in range that the ship can be moved there.',200000000,25000,18500500,1,NULL,90000000.0000,1,932,0),(29614,283,'Brutor Workers','They favor physical prowess over everything else and can be frightening to face in the flesh.',100,3,0,1,NULL,0.0000,1,NULL,0),(29616,476,'Guristas Nova Citadel Torpedo','Citadel Torpedoes are behemoths designed for maximum firepower against capital ships and installations. They are usable only by capital ships and starbase defense batteries.\r\r\n\r\r\nNocxium atoms captured in morphite matrices form this missile\'s devastating payload. A volley of these is able to completely obliterate most everything that floats in space, be it vehicle or structure.',1500,0.3,0,100,NULL,278458.0000,1,1194,0),(29618,476,'Guristas Inferno Citadel Torpedo','Citadel Torpedoes are behemoths designed for maximum firepower against capital ships and installations. They are usable only by capital ships and starbase defense batteries.\r\r\n\r\r\nPlasma suspended in an electromagnetic field gives this torpedo the ability to deliver a flaming inferno of destruction, wreaking almost unimaginable havoc.',1500,0.3,0,100,NULL,360746.0000,1,1194,0),(29620,476,'Guristas Scourge Citadel Torpedo','Citadel Torpedoes are behemoths designed for maximum firepower against capital ships and installations. They are usable only by capital ships and starbase defense batteries.\r\r\n\r\r\nFitted with a graviton pulse generator, this weapon causes massive damage as it overwhelms ships\' internal structures, tearing bulkheads and armor plating apart with frightening ease.',1500,0.3,0,100,NULL,332424.0000,1,1194,0),(29622,476,'Guristas Mjolnir Citadel Torpedo','Citadel Torpedoes are behemoths designed for maximum firepower against capital ships and installations. They are usable only by capital ships and starbase defense batteries.\r\r\n\r\r\nNothing more than a baby nuclear warhead, this guided missile wreaks havoc with the delicate electronic systems aboard a starship. Specifically designed to damage shield systems, it is able to ravage heavily shielded targets in no time.',1500,0.3,0,100,NULL,386168.0000,1,1194,0),(29624,10,'Stargate (Amarr System)',' ',100000000000,10000000,0,1,4,0.0000,0,NULL,0),(29625,10,'Stargate (Amarr Border)',' ',100000000000,1000000000,0,1,4,0.0000,0,NULL,0),(29626,10,'Stargate (Amarr Region)',' ',100000000000,10000000000,0,1,4,0.0000,0,NULL,0),(29627,10,'Stargate (Caldari Constellation)',' ',100000000000,10000000,0,1,1,0.0000,0,NULL,0),(29628,10,'Stargate (Caldari Unused)',' ',100000000000,10000000,0,1,1,0.0000,0,NULL,0),(29629,10,'Stargate (Caldari Region)',' ',100000000000,10000000,0,1,1,0.0000,0,NULL,0),(29630,10,'Stargate (Gallente Unused 2)',' ',100000000000,10000000,0,1,8,0.0000,0,NULL,0),(29631,10,'Stargate (Gallente Unused 1)',' ',100000000000,10000000,0,1,8,0.0000,0,NULL,0),(29632,10,'Stargate (Gallente Region)',' ',100000000000,10000000000,0,1,8,0.0000,0,NULL,0),(29633,10,'Stargate (Minmatar System)',' ',100000000000,10000000,0,1,2,0.0000,0,NULL,0),(29634,10,'Stargate (Minmatar Border)',' ',100000000000,1000000000,0,1,2,0.0000,0,NULL,0),(29635,10,'Stargate (Minmatar Region)',' ',100000000000,10000000000,0,1,2,0.0000,0,NULL,0),(29637,257,'Industrial Command Ships','Skill at operating industrial command ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,8,50000000.0000,1,377,0),(29639,186,'Orca Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(29640,436,'Unrefined Hyperflurite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(29641,436,'Unrefined Ferrofluid Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(29642,436,'Unrefined Prometium Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(29643,436,'Unrefined Neo Mercurite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(29644,436,'Unrefined Dysporite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(29645,436,'Unrefined Fluxed Condensates Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(29659,428,'Unrefined Fluxed Condensates','When combined with other materials and alloys, fluxed condensates help contribute to a unique quantum state highly conducive to efficient reactor operation.',0,1,0,1,NULL,512.0000,1,500,0),(29660,428,'Unrefined Dysporite','Quicksilver mixed with dysprosium forms the soft but extremely resilient dysporite, an amalgamatic alloy which plays a key role in most advanced sensor and reactor technologies.',0,1,0,1,NULL,320.0000,1,500,0),(29661,428,'Unrefined Neo Mercurite','A silvery, shimmering liquid compound, Neo Mercurite is a crucial element in many forms of advanced sensor and processor technology.',0,1,0,1,NULL,320.0000,1,500,0),(29662,428,'Unrefined Prometium','A highly radioactive cadmium-promethium compound, used as a catalytic agent in the manufacturing of thrusters, reactor units and shield emitters, among other things.',0,1,0,1,NULL,320.0000,1,500,0),(29663,428,'Unrefined Ferrofluid','Ferrofluids are superparamagnetic fluids containing tiny particles of magnetic solids suspended in liquid. The primary component in the creation of ferrogels.',0,1,0,1,NULL,512.0000,1,500,0),(29664,428,'Unrefined Hyperflurite','Hyperflurite is one of the most radioactive substances known to man. Composed of a mixture of radioactive metals and raw hydrocarbons, this luminescent goop provides catalysis for a variety of generative and reactive machine processes.',0,1,0,1,NULL,320.0000,1,500,0),(29665,667,'Independent Green-Crewed Armageddon','The mighty Armageddon class is the main warship of the Amarr Empire. Its heavy armaments and strong front are specially designed to crash into any battle like a juggernaut and deliver swift justice in the name of the Emperor.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',20500000,1100000,235,1,4,0.0000,0,NULL,0),(29667,667,'Independent Green-Crewed Apocalypse','In days past, only those in high favor with the Emperor could hope to earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. In latter years, even though now in full market circulation, these golden, metallic monstrosities are still feared and respected as enduring symbols of Amarrian might.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(29668,943,'30 Day Pilot\'s License Extension (PLEX)','<font size=\"14\"><b>PLEX - Pilot License Extension</b></font>\r\r\nPLEX can be used to add game time to your account or to unlock special character and account services.\r\r\n\r\r\n<b>Account time:</b> One PLEX is equal to 30 days of game time which can be added to your account by using the PLEX directly from your in-game inventory.\r\r\n<b>Multiple character training:</b> Activate 30 days of passive skill gain on additional characters on your account with PLEX.\r\r\n<b>Character transfer:</b> Transferring characters between two accounts can be paid for with PLEX.\r\r\n<b>Character re-sculpt:</b> Customize and recreate your character s facial appearance.\r\r\n<b>Convert to AURUM:</b> PLEX can be exchanged for AURUM, the currency used in the New Eden Store where unique fashion accessories and cosmetic ship customizations are sold.\r\r\n\r\r\n<br><font size=\"14\"><b>Buying PLEX</b></font>\r\r\nYou can buy PLEX on the EVE market using ISK or securely on <url=https://secure.eveonline.com/PLEX/>https://secure.eveonline.com/PLEX/</url> using conventional payment methods.',0,0.01,0,1,NULL,0.0000,1,1923,0),(29671,667,'Independent Green-Crewed Abaddon ','The Abaddon class ship is a celestial tool of destruction. It is designed to enter combat from the outset, targeting enemies at range and firing salvo after salvo at them, and to remain intact on the battlefield until every heretic in sight has been torn to shreds.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.\r\r\n',20500000,1100000,235,1,4,0.0000,0,NULL,0),(29673,667,'Independent Armageddon ','The mighty Armageddon class is the main warship of the Amarr Empire. Its heavy armaments and strong front are specially designed to crash into any battle like a juggernaut and deliver swift justice in the name of the Emperor.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.\r\r\n',19500000,1150000,235,1,4,0.0000,0,NULL,0),(29674,667,'Independent Apocalypse ','In days past, only those in high favor with the Emperor could hope to earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. In latter years, even though now in full market circulation, these golden, metallic monstrosities are still feared and respected as enduring symbols of Amarrian might.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(29675,667,'Independent Abaddon','The Abaddon class ship is a celestial tool of destruction. It is designed to enter combat from the outset, targeting enemies at range and firing salvo after salvo at them, and to remain intact on the battlefield until every heretic in sight has been torn to shreds.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',19500000,1150000,235,1,4,0.0000,0,NULL,0),(29676,667,'Independent Veteran Armageddon','The mighty Armageddon class is the main warship of the Amarr Empire. Its heavy armaments and strong front are specially designed to crash into any battle like a juggernaut and deliver swift justice in the name of the Emperor.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',20500000,1100000,525,1,4,0.0000,0,NULL,0),(29677,667,'Independent Veteran Apocalypse','In days past, only those in high favor with the Emperor could hope to earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. In latter years, even though now in full market circulation, these golden, metallic monstrosities are still feared and respected as enduring symbols of Amarrian might.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',20500000,1100000,525,1,4,0.0000,0,NULL,0),(29678,667,'Independent Veteran Abaddon','The Abaddon class ship is a celestial tool of destruction. It is designed to enter combat from the outset, targeting enemies at range and firing salvo after salvo at them, and to remain intact on the battlefield until every heretic in sight has been torn to shreds.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.\r\r\n',20500000,1100000,525,1,4,0.0000,0,NULL,0),(29679,674,'Independent Green-Crewed Raven','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.\r\r\n',22000000,1080000,235,1,1,0.0000,0,NULL,0),(29680,674,'Independent Green-Crewed Rokh','Having long suffered the lack of an adequate hybrid platform, the Caldari State\'s capsule pilots found themselves rejoicing as the Rokh\'s design specs were released. A fleet vessel if ever there was one, this far-reaching and durable beast is expected to see a great deal of service on battlefields near and far.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.\r\r\n',22000000,1080000,235,1,1,0.0000,0,NULL,0),(29681,674,'Independent Green-Crewed Scorpion','The first Scorpion-class battleship was launched only a couple of years ago, and those that have been built are considered to be prototypes. Little is known of its capabilities, but what has been garnered suggests that the Scorpion is crammed to the brink with sophisticated hi-tech equipment that few can match. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.\r\r\n',22000000,1080000,235,1,1,0.0000,0,NULL,0),(29682,674,'Independent Raven','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(29683,674,'Independent Rokh','Having long suffered the lack of an adequate hybrid platform, the Caldari State\'s capsule pilots found themselves rejoicing as the Rokh\'s design specs were released. A fleet vessel if ever there was one, this far-reaching and durable beast is expected to see a great deal of service on battlefields near and far.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(29684,674,'Independent Scorpion','The first Scorpion-class battleship was launched only a couple of years ago, and those that have been built are considered to be prototypes. Little is known of its capabilities, but what has been garnered suggests that the Scorpion is crammed to the brink with sophisticated hi-tech equipment that few can match. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(29685,674,'Independent Veteran Raven','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(29686,674,'Independent Veteran Rokh','Having long suffered the lack of an adequate hybrid platform, the Caldari State\'s capsule pilots found themselves rejoicing as the Rokh\'s design specs were released. A fleet vessel if ever there was one, this far-reaching and durable beast is expected to see a great deal of service on battlefields near and far.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(29687,674,'Independent Veteran Scorpion','The first Scorpion-class battleship was launched only a couple of years ago, and those that have been built are considered to be prototypes. Little is known of its capabilities, but what has been garnered suggests that the Scorpion is crammed to the brink with sophisticated hi-tech equipment that few can match. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.\r\r\n\r\r\n',20500000,22000000,235,1,1,0.0000,0,NULL,0),(29689,680,'Independent Green-Crewed Dominix','The Dominix is one of the old warhorses dating back to the Gallente-Caldari War. While no longer regarded as the king of the hill, it is by no means obsolete. Its formidable hulk and powerful weapons batteries means that anyone not in the largest and latest battleships will regret ever locking horns with it.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(29690,680,'Independent Green-Crewed Hyperion','Recognizing the necessity for a blaster platform to round out their high-end arsenal, the Federation Navy brought in top-level talent to work on the Hyperion. The result: one of the most lethal and versatile gunboats ever to take to the dark skies.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(29691,680,'Independent Green-Crewed Megathron','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(29692,680,'Independent Dominix','The Dominix is one of the old warhorses dating back to the Gallente-Caldari War. While no longer regarded as the king of the hill, it is by no means obsolete. Its formidable hulk and powerful weapons batteries means that anyone not in the largest and latest battleships will regret ever locking horns with it.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(29693,680,'Independent Hyperion','Recognizing the necessity for a blaster platform to round out their high-end arsenal, the Federation Navy brought in top-level talent to work on the Hyperion. The result: one of the most lethal and versatile gunboats ever to take to the dark skies.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(29694,680,'Independent Megathron','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(29695,680,'Independent Veteran Dominix','The Dominix is one of the old warhorses dating back to the Gallente-Caldari War. While no longer regarded as the king of the hill, it is by no means obsolete. Its formidable hulk and powerful weapons batteries means that anyone not in the largest and latest battleships will regret ever locking horns with it.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',19000000,1140000,675,1,8,0.0000,0,NULL,0),(29696,680,'Independent Veteran Hyperion','Recognizing the necessity for a blaster platform to round out their high-end arsenal, the Federation Navy brought in top-level talent to work on the Hyperion. The result: one of the most lethal and versatile gunboats ever to take to the dark skies.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',19000000,1140000,675,1,8,0.0000,0,NULL,0),(29697,680,'Independent Veteran Megathron','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',19000000,1140000,675,1,8,0.0000,0,NULL,0),(29698,706,'Independent Green-Crewed Maelstrom','With the Maelstrom, versatility is the name of the game. Its defensive capabilities make it ideally suited for small raid groups or solo work, while its 8 turret hardpoints present opportunities for untold carnage on the fleet battlefield.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(29700,706,'Independent Green-Crewed Tempest','The Tempest is one of the Republic Fleet\'s key vessels; a versatile gunship proficient at long-range bombardment and capable of dishing out specialized types of damage with great effectiveness.  A well-rounded squadron of Tempests has been proven time and time again to be an invaluable wild card in a fleet battle, one which opponents should ignore at their own peril.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(29701,706,'Independent Green-Crewed Typhoon','Much praised by its proponents and much maligned by its detractors, the Typhoon-class battleship has always been one of the most hotly debated spacefaring vessels around. Its distinguishing aspect - and the source of most of the controversy - is its sheer versatility, variously seen as either a lack of design focus or a deliberate freedom for pilot modification.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(29702,706,'Independent Maelstrom','With the Maelstrom, versatility is the name of the game. Its defensive capabilities make it ideally suited for small raid groups or solo work, while its 8 turret hardpoints present opportunities for untold carnage on the fleet battlefield.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(29703,706,'Independent Tempest','The Tempest is one of the Republic Fleet\'s key vessels; a versatile gunship proficient at long-range bombardment and capable of dishing out specialized types of damage with great effectiveness.  A well-rounded squadron of Tempests has been proven time and time again to be an invaluable wild card in a fleet battle, one which opponents should ignore at their own peril.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(29704,706,'Independent Typhoon','Much praised by its proponents and much maligned by its detractors, the Typhoon-class battleship has always been one of the most hotly debated spacefaring vessels around. Its distinguishing aspect - and the source of most of the controversy - is its sheer versatility, variously seen as either a lack of design focus or a deliberate freedom for pilot modification.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(29705,706,'Independent Veteran Maelstrom','With the Maelstrom, versatility is the name of the game. Its defensive capabilities make it ideally suited for small raid groups or solo work, while its 8 turret hardpoints present opportunities for untold carnage on the fleet battlefield.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',19000000,850000,550,1,2,0.0000,0,NULL,0),(29706,706,'Independent Veteran Tempest','The Tempest is one of the Republic Fleet\'s key vessels; a versatile gunship proficient at long-range bombardment and capable of dishing out specialized types of damage with great effectiveness.  A well-rounded squadron of Tempests has been proven time and time again to be an invaluable wild card in a fleet battle, one which opponents should ignore at their own peril.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',19000000,850000,550,1,2,0.0000,0,NULL,0),(29707,706,'Independent Veteran Typhoon','Much praised by its proponents and much maligned by its detractors, the Typhoon-class battleship has always been one of the most hotly debated spacefaring vessels around. Its distinguishing aspect - and the source of most of the controversy - is its sheer versatility, variously seen as either a lack of design focus or a deliberate freedom for pilot modification.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',19000000,850000,550,1,2,0.0000,0,NULL,0),(29716,306,'Angel Ship Rubble','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29717,306,'Blood Ship Rubble','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29718,306,'Guristas Ship Rubble','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29719,306,'Sansha Ship Rubble','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29720,306,'Serpentis Ship Rubble','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29721,306,'Angel Ship Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29722,306,'Blood Ship Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29723,306,'Guristas Ship Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29724,306,'Sansha Ship Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29725,306,'Serpentis Ship Wreck','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29726,306,'Angel Ship Derelict','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29727,306,'Blood Ship Derelict','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29728,306,'Guristas Ship Derelict','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29729,306,'Sansha Ship Derelict','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29730,306,'Serpentis Ship Derelict','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29731,306,'Angel Ship Remains','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29732,306,'Blood Ship Remains','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29733,306,'Guristas Ship Remains','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29734,306,'Sansha Ship Remains','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29735,306,'Serpentis Ship Remains','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29736,306,'Serpentis Ship Debris','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29737,306,'Sansha Ship Debris','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29738,306,'Guristas Ship Debris','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29739,306,'Blood Ship Debris','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29740,306,'Angel Ship Debris','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29741,306,'Angel Ship Waste','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29742,306,'Blood Ship Waste','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29743,306,'Guristas Ship Waste','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29744,306,'Sansha Ship Waste','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29745,306,'Serpentis Ship Waste','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29746,668,'Independent Green-Crewed Augoror','The Augoror-class cruiser is one of the old warhorses of the Amarr Empire, having seen action in both the Jovian War and the Minmatar Rebellion. It is mainly used by the Amarrians for escort and scouting duties where frigates are deemed too weak. Like most Amarrian vessels, the Augoror depends first and foremost on its resilience and heavy armor to escape unscathed from unfriendly encounters.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',12000000,120000,450,1,4,0.0000,0,NULL,0),(29747,668,'Independent Green-Crewed Arbitrator','The Arbitrator is unusual for Amarr ships in that it\'s primarily a drone carrier. While it is not the best carrier around, it has superior armor that gives it greater durability than most ships in its class.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',12000000,120000,450,1,4,0.0000,0,NULL,0),(29748,668,'Independent Green-Crewed Maller','Quite possibly the toughest cruiser in the galaxy, the Maller is a common sight in Amarrian Imperial Navy operations. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',12000000,120000,450,1,4,0.0000,0,NULL,0),(29749,668,'Independent Green-Crewed Omen','The Omen is a stereotypical example of the Amarrian School of thinking when it comes to ship design: thick armor and hard hitting lasers. Advancements in heat dissipation allow the Omen to fire its lasers faster than other ships without this technology.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',12000000,120000,450,1,4,0.0000,0,NULL,0),(29753,668,'Independent Arbitrator','The Arbitrator is unusual for Amarr ships in that it\'s primarily a drone carrier. While it is not the best carrier around, it has superior armor that gives it greater durability than most ships in its class.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',11800000,118000,235,1,4,0.0000,0,NULL,0),(29754,668,'Independent Augoror','The Augoror-class cruiser is one of the old warhorses of the Amarr Empire, having seen action in both the Jovian War and the Minmatar Rebellion. It is mainly used by the Amarrians for escort and scouting duties where frigates are deemed too weak. Like most Amarrian vessels, the Augoror depends first and foremost on its resilience and heavy armor to escape unscathed from unfriendly encounters.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',11800000,118000,235,1,4,0.0000,0,NULL,0),(29755,668,'Independent Maller','Quite possibly the toughest cruiser in the galaxy, the Maller is a common sight in Amarrian Imperial Navy operations. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',11800000,118000,235,1,4,0.0000,0,NULL,0),(29756,668,'Independent Omen','The Omen is a stereotypical example of the Amarrian School of thinking when it comes to ship design: thick armor and hard hitting lasers. Advancements in heat dissipation allow the Omen to fire its lasers faster than other ships without this technology.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',11800000,118000,235,1,4,0.0000,0,NULL,0),(29757,668,'Independent Veteran Arbitrator','The Arbitrator is unusual for Amarr ships in that it\'s primarily a drone carrier. While it is not the best carrier around, it has superior armor that gives it greater durability than most ships in its class.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',13500000,130000,350,1,4,0.0000,0,NULL,0),(29758,668,'Independent Veteran Augoror','The Augoror-class cruiser is one of the old warhorses of the Amarr Empire, having seen action in both the Jovian War and the Minmatar Rebellion. It is mainly used by the Amarrians for escort and scouting duties where frigates are deemed too weak. Like most Amarrian vessels, the Augoror depends first and foremost on its resilience and heavy armor to escape unscathed from unfriendly encounters.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',13500000,130000,350,1,4,0.0000,0,NULL,0),(29759,668,'Independent Veteran Maller','Quite possibly the toughest cruiser in the galaxy, the Maller is a common sight in Amarrian Imperial Navy operations. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',13500000,130000,350,1,4,0.0000,0,NULL,0),(29760,668,'Independent Veteran Omen','The Omen is a stereotypical example of the Amarrian School of thinking when it comes to ship design: thick armor and hard hitting lasers. Advancements in heat dissipation allow the Omen to fire its lasers faster than other ships without this technology.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',13500000,130000,350,1,4,0.0000,0,NULL,0),(29761,673,'Independent Green-Crewed Blackbird','The Blackbird is a small high-tech cruiser newly employed by the Caldari Navy. Commonly seen in fleet battles or acting as wingman, it is not intended for head-on slugfests, but rather delicate tactical situations. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',9600000,96000,450,1,1,0.0000,0,NULL,0),(29762,673,'Independent Green-Crewed Caracal','The Caracal is a powerful vessel that specializes in missile deployment. It has excellent shield defenses, but poor armor plating. Its missile arsenal, when fully stocked, is capable of making mincemeat of almost anyone. \r\n\r\nThe markings on this ship reveal no obvious connection to the State.',9600000,96000,450,1,1,0.0000,0,NULL,0),(29763,673,'Independent Green-Crewed Moa','The Moa was designed as an all-out combat ship, and its heavy armament allows the Moa to tackle almost anything that floats in space. In contrast to its nemesis the Thorax, the Moa is most effective at long range where its railguns and missile batteries can rain death upon foes.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',9600000,96000,450,1,1,0.0000,0,NULL,0),(29764,673,'Independent Green-Crewed Osprey','The Osprey offers excellent versatility and power for its low price. Designed from the top down as a cheap but complete cruiser, the Osprey utilizes the best the Caldari have to offer in state-of-the-art armor alloys, sensor technology and weaponry - all mass manufactured to ensure low price. In the constant struggle to stay ahead of the Gallente, new technology has been implemented in the field of mining laser calibration. A notable improvement in ore yields has been made, especially in the hands of a well trained pilot.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',9600000,96000,450,1,1,0.0000,0,NULL,0),(29765,673,'Independent Blackbird','The Blackbird is a small high-tech cruiser newly employed by the Caldari Navy. Commonly seen in fleet battles or acting as wingman, it is not intended for head-on slugfests, but rather delicate tactical situations. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',10100000,101000,235,1,1,0.0000,0,NULL,0),(29766,673,'Independent Caracal','The Caracal is a powerful vessel that specializes in missile deployment. It has excellent shield defenses, but poor armor plating. Its missile arsenal, when fully stocked, is capable of making mincemeat of almost anyone. \r\n\r\nThe markings on this ship reveal no obvious connection to the State.',10100000,101000,235,1,1,0.0000,0,NULL,0),(29767,673,'Independent Moa','The Moa was designed as an all-out combat ship, and its heavy armament allows the Moa to tackle almost anything that floats in space. In contrast to its nemesis the Thorax, the Moa is most effective at long range where its railguns and missile batteries can rain death upon foes.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',10100000,101000,235,1,1,0.0000,0,NULL,0),(29768,673,'Independent Osprey','The Osprey offers excellent versatility and power for its low price. Designed from the top down as a cheap but complete cruiser, the Osprey utilizes the best the Caldari have to offer in state-of-the-art armor alloys, sensor technology and weaponry - all mass manufactured to ensure low price. In the constant struggle to stay ahead of the Gallente, new technology has been implemented in the field of mining laser calibration. A notable improvement in ore yields has been made, especially in the hands of a well trained pilot.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',10100000,101000,235,1,1,0.0000,0,NULL,0),(29769,673,'Independent Veteran Blackbird','The Blackbird is a small high-tech cruiser newly employed by the Caldari Navy. Commonly seen in fleet battles or acting as wingman, it is not intended for head-on slugfests, but rather delicate tactical situations. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',14000000,140000,345,1,1,0.0000,0,NULL,0),(29770,673,'Independent Veteran Caracal','The Caracal is a powerful vessel that specializes in missile deployment. It has excellent shield defenses, but poor armor plating. Its missile arsenal, when fully stocked, is capable of making mincemeat of almost anyone. \r\n\r\nThe markings on this ship reveal no obvious connection to the State.',14000000,140000,345,1,1,0.0000,0,NULL,0),(29771,673,'Independent Veteran Moa','The Moa was designed as an all-out combat ship, and its heavy armament allows the Moa to tackle almost anything that floats in space. In contrast to its nemesis the Thorax, the Moa is most effective at long range where its railguns and missile batteries can rain death upon foes.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',14000000,140000,345,1,1,0.0000,0,NULL,0),(29772,673,'Independent Veteran Osprey','The Osprey offers excellent versatility and power for its low price. Designed from the top down as a cheap but complete cruiser, the Osprey utilizes the best the Caldari have to offer in state-of-the-art armor alloys, sensor technology and weaponry - all mass manufactured to ensure low price. In the constant struggle to stay ahead of the Gallente, new technology has been implemented in the field of mining laser calibration. A notable improvement in ore yields has been made, especially in the hands of a well trained pilot.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',14000000,140000,345,1,1,0.0000,0,NULL,0),(29775,678,'Independent Green-Crewed Exequror','The Exequror is a heavy cargo cruiser capable of defending itself against raiding frigates, but lacks prowess in heavier combat situations. It is mainly used in relatively peaceful areas where bulk and strength is needed without too much investment involved. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',11300000,113000,235,1,8,0.0000,0,NULL,0),(29776,678,'Independent Green-Crewed Celestis','The Celestis cruiser is a versatile ship which can be employed in a myriad of roles, making it handy for small corporations with a limited number of ships. True to Gallente style the Celestis is especially deadly in close quarters combat due to its advanced targeting systems.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',11300000,113000,235,1,8,0.0000,0,NULL,0),(29777,678,'Independent Green-Crewed Thorax ','The Thorax-class cruiser is the latest combat ship commissioned by the Federation. While the Thorax is a very effective ship at any range, typical of modern Gallente design philosophy it is most effective when working at extreme close range where its blasters and hordes of combat drones tear through even the toughest of enemies.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',11300000,113000,235,1,8,0.0000,0,NULL,0),(29778,678,'Independent Green-Crewed Vexor','The Vexor is a strong combat ship that is also geared to operate in a variety of other roles. The Vexor is especially useful for surveying in potentially hostile sectors as it can stay on duty for a very long time before having to return to base. Furthermore, it is well capable of defending itself against even concentrated attacks.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',11300000,113000,235,1,8,0.0000,0,NULL,0),(29779,678,'Independent Celestis','The Celestis cruiser is a versatile ship which can be employed in a myriad of roles, making it handy for small corporations with a limited number of ships. True to Gallente style the Celestis is especially deadly in close quarters combat due to its advanced targeting systems.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(29780,678,'Independent Exequror','The Exequror is a heavy cargo cruiser capable of defending itself against raiding frigates, but lacks prowess in heavier combat situations. It is mainly used in relatively peaceful areas where bulk and strength is needed without too much investment involved. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(29781,678,'Independent Thorax','The Thorax-class cruiser is the latest combat ship commissioned by the Federation. While the Thorax is a very effective ship at any range, typical of modern Gallente design philosophy it is most effective when working at extreme close range where its blasters and hordes of combat drones tear through even the toughest of enemies.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(29782,678,'Independent Vexor','The Vexor is a strong combat ship that is also geared to operate in a variety of other roles. The Vexor is especially useful for surveying in potentially hostile sectors as it can stay on duty for a very long time before having to return to base. Furthermore, it is well capable of defending itself against even concentrated attacks.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',11200000,112000,480,1,8,0.0000,0,NULL,0),(29783,678,'Independent Veteran Celestis','The Celestis cruiser is a versatile ship which can be employed in a myriad of roles, making it handy for small corporations with a limited number of ships. True to Gallente style the Celestis is especially deadly in close quarters combat due to its advanced targeting systems.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',13250000,150000,400,1,8,0.0000,0,NULL,0),(29784,678,'Independent Veteran Exequror','The Exequror is a heavy cargo cruiser capable of defending itself against raiding frigates, but lacks prowess in heavier combat situations. It is mainly used in relatively peaceful areas where bulk and strength is needed without too much investment involved. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',13250000,150000,400,1,8,0.0000,0,NULL,0),(29785,678,'Independent Veteran Thorax','The Thorax-class cruiser is the latest combat ship commissioned by the Federation. While the Thorax is a very effective ship at any range, typical of modern Gallente design philosophy it is most effective when working at extreme close range where its blasters and hordes of combat drones tear through even the toughest of enemies.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',13250000,150000,400,1,8,0.0000,0,NULL,0),(29786,678,'Independent Veteran Vexor','The Vexor is a strong combat ship that is also geared to operate in a variety of other roles. The Vexor is especially useful for surveying in potentially hostile sectors as it can stay on duty for a very long time before having to return to base. Furthermore, it is well capable of defending itself against even concentrated attacks.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.\r\r\n',13250000,150000,400,1,8,0.0000,0,NULL,0),(29787,705,'Independent Green-Crewed Bellicose','Being a highly versatile class of Minmatar ships, the Bellicose has been used as a combat juggernaut as well as a support ship for wings of frigates. While not quite in the league of newer navy cruisers, the Bellicose is still a very solid ship for most purposes, especially in terms of long range combat.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',9900000,99000,120,1,2,0.0000,0,NULL,0),(29788,705,'Independent Green-Crewed Rupture','The Rupture is slow for a Minmatar ship, but it more than makes up for it in power. The Rupture has superior firepower and is used by the Minmatar Republic both to defend space stations and other stationary objects and as part of massive attack formations.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',9900000,99000,120,1,2,0.0000,0,NULL,0),(29789,705,'Independent Green-Crewed Scythe','The Scythe-class cruiser is the oldest Minmatar ship still in use. It has seen many battles and is an integrated part in Minmatar tales and heritage. Recent firmware upgrades \"borrowed\" from the Caldari have vastly increased the efficiency of its mining output.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',9900000,99000,120,1,2,0.0000,0,NULL,0),(29790,705,'Independent Green-Crewed Stabber','The Stabber is the mainstay of the Minmatar fleet. It is light and extremely fast, yet surprisingly powerful, with a wide variety of weapons. It is one of few Minmatar vessels that have reached popularity outside Minmatar space.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',9900000,99000,120,1,2,0.0000,0,NULL,0),(29791,705,'Independent Bellicose','Being a highly versatile class of Minmatar ships, the Bellicose has been used as a combat juggernaut as well as a support ship for wings of frigates. While not quite in the league of newer navy cruisers, the Bellicose is still a very solid ship for most purposes, especially in terms of long range combat.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',10900000,109000,120,1,2,0.0000,0,NULL,0),(29792,705,'Independent Rupture','The Rupture is slow for a Minmatar ship, but it more than makes up for it in power. The Rupture has superior firepower and is used by the Minmatar Republic both to defend space stations and other stationary objects and as part of massive attack formations.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',10900000,109000,120,1,2,0.0000,0,NULL,0),(29793,705,'Independent Scythe','The Scythe-class cruiser is the oldest Minmatar ship still in use. It has seen many battles and is an integrated part in Minmatar tales and heritage. Recent firmware upgrades \"borrowed\" from the Caldari have vastly increased the efficiency of its mining output.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',10900000,109000,120,1,2,0.0000,0,NULL,0),(29794,705,'Independent Stabber','The Stabber is the mainstay of the Minmatar fleet. It is light and extremely fast, yet surprisingly powerful, with a wide variety of weapons. It is one of few Minmatar vessels that have reached popularity outside Minmatar space.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',10900000,109000,120,1,2,0.0000,0,NULL,0),(29795,705,'Independent Veteran Bellicose','Being a highly versatile class of Minmatar ships, the Bellicose has been used as a combat juggernaut as well as a support ship for wings of frigates. While not quite in the league of newer navy cruisers, the Bellicose is still a very solid ship for most purposes, especially in terms of long range combat.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',12500000,120000,475,1,2,0.0000,0,NULL,0),(29796,705,'Independent Veteran Rupture','The Rupture is slow for a Minmatar ship, but it more than makes up for it in power. The Rupture has superior firepower and is used by the Minmatar Republic both to defend space stations and other stationary objects and as part of massive attack formations.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',12500000,120000,475,1,2,0.0000,0,NULL,0),(29797,705,'Independent Veteran Scythe','The Scythe-class cruiser is the oldest Minmatar ship still in use. It has seen many battles and is an integrated part in Minmatar tales and heritage. Recent firmware upgrades \"borrowed\" from the Caldari have vastly increased the efficiency of its mining output.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',12500000,120000,475,1,2,0.0000,0,NULL,0);
INSERT INTO `invTypes` VALUES (29798,705,'Independent Veteran Stabber','The Stabber is the mainstay of the Minmatar fleet. It is light and extremely fast, yet surprisingly powerful, with a wide variety of weapons. It is one of few Minmatar vessels that have reached popularity outside Minmatar space.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',12500000,120000,475,1,2,0.0000,0,NULL,0),(29804,665,'Independent Green-Crewed Executioner','The Executioner is another newly commissioned ship of the Amarr Imperial Navy. The Executioner was designed specially to counter the small, fast raider frigates of the Minmatar Republic; thus it is different from most Amarr ships in favoring speed over defenses. With the Executioner, the Amarrians have expanded their tactical capabilities on the battlefield.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2820000,24398,235,1,4,0.0000,0,NULL,0),(29805,665,'Independent Green-Crewed Inquisitor','The Inquisitor is another example of how the Amarr Imperial Navy has modeled their design to counter specific tactics employed by the other empires. The Inquisitor is a fairly standard Amarr ship in most respects, having good defenses and lacking mobility. It is more Caldari-like than most Amarr ships, however, since its arsenal mostly consists of missile bays.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2820000,24398,235,1,4,0.0000,0,NULL,0),(29806,665,'Independent Green-Crewed Punisher','The Amarr Imperial Navy has been upgrading many of its ships in recent years and adding new ones. The Punisher is one of the most recent ones and considered by many to be the best Amarr frigate in existence. As witnessed by its heavy armaments, the Punisher is mainly intended for large-scale military operations, acting in coordination with larger military vessels, but it is more than powerful enough for solo operations.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2820000,24398,235,1,4,0.0000,0,NULL,0),(29807,665,'Independent Green-Crewed Crucifier','The Crucifier was first designed as an explorer/scout, but the current version employs the electronic equipment originally intended for scientific studies for more offensive purposes. The Crucifier\'s electronic and computer systems take up a large portion of the internal space leaving limited room for cargo or traditional weaponry.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2820000,24398,235,1,4,0.0000,0,NULL,0),(29808,665,'Independent Crucifier','The Crucifier was first designed as an explorer/scout, but the current version employs the electronic equipment originally intended for scientific studies for more offensive purposes. The Crucifier\'s electronic and computer systems take up a large portion of the internal space leaving limited room for cargo or traditional weaponry.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(29809,665,'Independent Executioner','The Executioner is another newly commissioned ship of the Amarr Imperial Navy. The Executioner was designed specially to counter the small, fast raider frigates of the Minmatar Republic; thus it is different from most Amarr ships in favoring speed over defenses. With the Executioner, the Amarrians have expanded their tactical capabilities on the battlefield.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(29810,665,'Independent Inquisitor','The Inquisitor is another example of how the Amarr Imperial Navy has modeled their design to counter specific tactics employed by the other empires. The Inquisitor is a fairly standard Amarr ship in most respects, having good defenses and lacking mobility. It is more Caldari-like than most Amarr ships, however, since its arsenal mostly consists of missile bays.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(29811,665,'Independent Punisher','The Amarr Imperial Navy has been upgrading many of its ships in recent years and adding new ones. The Punisher is one of the most recent ones and considered by many to be the best Amarr frigate in existence. As witnessed by its heavy armaments, the Punisher is mainly intended for large-scale military operations, acting in coordination with larger military vessels, but it is more than powerful enough for solo operations.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(29812,665,'Independent Veteran Crucifier','The Crucifier was first designed as an explorer/scout, but the current version employs the electronic equipment originally intended for scientific studies for more offensive purposes. The Crucifier\'s electronic and computer systems take up a large portion of the internal space leaving limited room for cargo or traditional weaponry.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(29813,665,'Independent Veteran Executioner','The Executioner is another newly commissioned ship of the Amarr Imperial Navy. The Executioner was designed specially to counter the small, fast raider frigates of the Minmatar Republic; thus it is different from most Amarr ships in favoring speed over defenses. With the Executioner, the Amarrians have expanded their tactical capabilities on the battlefield.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(29814,665,'Independent Veteran Inquisitor','The Inquisitor is another example of how the Amarr Imperial Navy has modeled their design to counter specific tactics employed by the other empires. The Inquisitor is a fairly standard Amarr ship in most respects, having good defenses and lacking mobility. It is more Caldari-like than most Amarr ships, however, since its arsenal mostly consists of missile bays.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(29815,665,'Independent Veteran Punisher','The Amarr Imperial Navy has been upgrading many of its ships in recent years and adding new ones. The Punisher is one of the most recent ones and considered by many to be the best Amarr frigate in existence. As witnessed by its heavy armaments, the Punisher is mainly intended for large-scale military operations, acting in coordination with larger military vessels, but it is more than powerful enough for solo operations.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(29816,671,'Independent Green-Crewed Griffin','The Griffin is much used by the Caldari Navy as a support vessel in combat squadrons, using its impressive array of electronic gadgetry to disrupt the operation of target ships, making them easy prey for traditional combat vessels.\r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1612000,16120,80,1,1,0.0000,0,NULL,0),(29817,671,'Independent Green-Crewed Heron','The Heron has good computer and electronic systems, giving it the option of participating in electronic warfare. But it has relatively poor defenses and limited weaponry, so it\'s more commonly used for scouting and exploration.\r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1612000,16120,80,1,1,0.0000,0,NULL,0),(29818,671,'Independent Green-Crewed Kestrel','The Kestrel is a heavy missile boat with a fairly large cargo space and one of the most sophisticated sensor arrays around. Interestingly enough, it has been used by both the Caldari Navy and several wealthy trade corporations as a cargo-hauling vessel. It is one of few trading vessels with good punching power, making it ideal for solo trade-runs in dangerous areas. \r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1612000,16120,80,1,1,0.0000,0,NULL,0),(29819,671,'Independent Green-Crewed Merlin','The Merlin is the most powerful all-out combat frigate of the Caldari. It is highly valued for its versatility in using both missiles and turrets, while its defenses are exceptionally strong for a Caldari vessel.\r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1612000,16120,80,1,1,0.0000,0,NULL,0),(29820,671,'Independent Griffin','The Griffin is much used by the Caldari Navy as a support vessel in combat squadrons, using its impressive array of electronic gadgetry to disrupt the operation of target ships, making them easy prey for traditional combat vessels.\r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29821,671,'Independent Heron','The Heron has good computer and electronic systems, giving it the option of participating in electronic warfare. But it has relatively poor defenses and limited weaponry, so it\'s more commonly used for scouting and exploration.\r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29822,671,'Independent Kestrel','The Kestrel is a heavy missile boat with a fairly large cargo space and one of the most sophisticated sensor arrays around. Interestingly enough, it has been used by both the Caldari Navy and several wealthy trade corporations as a cargo-hauling vessel. It is one of few trading vessels with good punching power, making it ideal for solo trade-runs in dangerous areas. \r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29823,671,'Independent Merlin','The Merlin is the most powerful all-out combat frigate of the Caldari. It is highly valued for its versatility in using both missiles and turrets, while its defenses are exceptionally strong for a Caldari vessel.\r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29824,671,'Independent Veteran Griffin','The Griffin is much used by the Caldari Navy as a support vessel in combat squadrons, using its impressive array of electronic gadgetry to disrupt the operation of target ships, making them easy prey for traditional combat vessels.\r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29825,671,'Independent Veteran Heron','The Heron has good computer and electronic systems, giving it the option of participating in electronic warfare. But it has relatively poor defenses and limited weaponry, so it\'s more commonly used for scouting and exploration.\r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29826,671,'Independent Veteran Kestrel','The Kestrel is a heavy missile boat with a fairly large cargo space and one of the most sophisticated sensor arrays around. Interestingly enough, it has been used by both the Caldari Navy and several wealthy trade corporations as a cargo-hauling vessel. It is one of few trading vessels with good punching power, making it ideal for solo trade-runs in dangerous areas. \r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29827,671,'Independent Veteran Merlin','The Merlin is the most powerful all-out combat frigate of the Caldari. It is highly valued for its versatility in using both missiles and turrets, while its defenses are exceptionally strong for a Caldari vessel.\r\r\n\r\r\nThe markings on this vessel reveal no obvious connection to the State.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29828,671,'Independent Green-Crewed Condor','The Condor is fast and agile. It has limited cargo space so it\'s not very suitable for trading or mining. It is best used as an assault vessel in a hit-and-run type of operations.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',1612000,16120,80,1,1,0.0000,0,NULL,0),(29829,671,'Independent Condor','The Condor is fast and agile. It has limited cargo space so it\'s not very suitable for trading or mining. It is best used as an assault vessel in a hit-and-run type of operations.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29830,671,'Independent Veteran Condor','The Condor is fast and agile. It has limited cargo space so it\'s not very suitable for trading or mining. It is best used as an assault vessel in a hit-and-run type of operations.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the State.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29831,677,'Independent Green-Crewed Atron','The Atron is a hard nugget with an advanced power conduit system, but little space for cargo. Although it is a good harvester when it comes to mining, its main ability is as a combat vessel.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2250000,22500,125,1,8,0.0000,0,NULL,0),(29859,677,'Independent Green-Crewed Imicus','The Imicus is a slow but hard-shelled frigate, ideal for any type of scouting activity. Used by merchant, miner and combat groups, the Imicus is usually relied upon as the operation\'s eyes and ears when traversing low security sectors.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2250000,22500,125,1,8,0.0000,0,NULL,0),(29863,677,'Independent Green-Crewed Incursus','The Incursus is commonly found spearheading Gallentean military operations. Its speed and surprising strength make it excellent for skirmishing duties. Incursus-class ships move together in groups and can quickly and effectively gang up on ships many times their size and overwhelm them. In recent years the Incursus has increasingly found its way into the hands of pirates, who love its aggressive appearance.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2250000,22500,125,1,8,0.0000,0,NULL,0),(29864,677,'Independent Green-Crewed Maulus','The Maulus is a high-tech vessel, specialized for electronic warfare. It is particularly valued in fleet warfare due to its optimization for sensor dampening technology.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2250000,22500,125,1,8,0.0000,0,NULL,0),(29865,677,'Independent Green-Crewed Tristan','Often nicknamed The Fat Man, this nimble little frigate is mainly used by the Federation in escort duties or on short-range patrols. The Tristan has been very popular throughout Gallente space for years because of its versatility. It is rather expensive, but buyers will definitely get their money\'s worth, as the Tristan is one of the more powerful frigates available on the market.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2250000,22500,125,1,8,0.0000,0,NULL,0),(29866,677,'Independent Atron','The Atron is a hard nugget with an advanced power conduit system, but little space for cargo. Although it is a good harvester when it comes to mining, its main ability is as a combat vessel.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29867,677,'Independent Imicus','The Imicus is a slow but hard-shelled frigate, ideal for any type of scouting activity. Used by merchant, miner and combat groups, the Imicus is usually relied upon as the operation\'s eyes and ears when traversing low security sectors.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29868,677,'Independent Incursus','The Incursus is commonly found spearheading Gallentean military operations. Its speed and surprising strength make it excellent for skirmishing duties. Incursus-class ships move together in groups and can quickly and effectively gang up on ships many times their size and overwhelm them. In recent years the Incursus has increasingly found its way into the hands of pirates, who love its aggressive appearance.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29869,677,'Independent Maulus','The Maulus is a high-tech vessel, specialized for electronic warfare. It is particularly valued in fleet warfare due to its optimization for sensor dampening technology.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29870,677,'Independent Tristan','Often nicknamed The Fat Man, this nimble little frigate is mainly used by the Federation in escort duties or on short-range patrols. The Tristan has been very popular throughout Gallente space for years because of its versatility. It is rather expensive, but buyers will definitely get their money\'s worth, as the Tristan is one of the more powerful frigates available on the market.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29871,677,'Independent Veteran Atron','The Atron is a hard nugget with an advanced power conduit system, but little space for cargo. Although it is a good harvester when it comes to mining, its main ability is as a combat vessel.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29872,677,'Independent Veteran Imicus','The Imicus is a slow but hard-shelled frigate, ideal for any type of scouting activity. Used by merchant, miner and combat groups, the Imicus is usually relied upon as the operation\'s eyes and ears when traversing low security sectors.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29873,677,'Independent Veteran Incursus','The Incursus is commonly found spearheading Gallentean military operations. Its speed and surprising strength make it excellent for skirmishing duties. Incursus-class ships move together in groups and can quickly and effectively gang up on ships many times their size and overwhelm them. In recent years the Incursus has increasingly found its way into the hands of pirates, who love its aggressive appearance.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29874,677,'Independent Veteran Maulus','The Maulus is a high-tech vessel, specialized for electronic warfare. It is particularly valued in fleet warfare due to its optimization for sensor dampening technology.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29875,677,'Independent Veteran Tristan','Often nicknamed The Fat Man, this nimble little frigate is mainly used by the Federation in escort duties or on short-range patrols. The Tristan has been very popular throughout Gallente space for years because of its versatility. It is rather expensive, but buyers will definitely get their money\'s worth, as the Tristan is one of the more powerful frigates available on the market.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29876,683,'Independent Green-Crewed Breacher','The Breacher\'s structure is little more than a fragile scrapheap, but the ship\'s missile launcher hardpoints and superior sensors have placed it among the most valued Minmatar frigates when it comes to long range combat.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',2250000,22500,75,1,2,0.0000,0,NULL,0),(29878,683,'Independent Green-Crewed Probe','The Probe is large compared to most Minmatar frigates and is considered a good scout and cargo-runner.  Uncharacteristically for a Minmatar ship, its hard outer coating makes it difficult to destroy, while the limited weapon hardpoints force it to rely on fighter assistance if engaged in combat.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',2250000,22500,75,1,2,0.0000,0,NULL,0),(29879,683,'Independent Green-Crewed Rifter','The Rifter is a very powerful combat frigate and can easily \r\r\ntackle the best frigates out there. It has gone through \r\r\nmany radical design phases since its inauguration during \r\r\nthe Minmatar Rebellion. The Rifter has a wide variety of \r\r\noffensive capabilities, making it an unpredictable and deadly adversary. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',2250000,22500,75,1,2,0.0000,0,NULL,0),(29881,683,'Independent Green-Crewed Vigil','The Vigil is an unusual Minmatar ship, serving both as a long range scout as well as an electronic warfare platform. It is fast and agile, allowing it to keep the distance needed to avoid enemy fire while making use of jammers or other electronic gadgets.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',2250000,22500,75,1,2,0.0000,0,NULL,0),(29882,683,'Independent Breacher','The Breacher\'s structure is little more than a fragile scrapheap, but the ship\'s missile launcher hardpoints and superior sensors have placed it among the most valued Minmatar frigates when it comes to long range combat.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29883,683,'Independent Probe','The Probe is large compared to most Minmatar frigates and is considered a good scout and cargo-runner.  Uncharacteristically for a Minmatar ship, its hard outer coating makes it difficult to destroy, while the limited weapon hardpoints force it to rely on fighter assistance if engaged in combat.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29884,683,'Independent Rifter','The Rifter is a very powerful combat frigate and can easily \r\r\ntackle the best frigates out there. It has gone through \r\r\nmany radical design phases since its inauguration during \r\r\nthe Minmatar Rebellion. The Rifter has a wide variety of \r\r\noffensive capabilities, making it an unpredictable and deadly adversary. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29885,683,'Independent Slasher','The Slasher is cheap, but versatile. It\'s been manufactured en masse, making it one of the most common vessels in Minmatar space. The Slasher is extremely fast, with decent armaments, and is popular amongst budding pirates and smugglers.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29886,683,'Independent Vigil','The Vigil is an unusual Minmatar ship, serving both as a long range scout as well as an electronic warfare platform. It is fast and agile, allowing it to keep the distance needed to avoid enemy fire while making use of jammers or other electronic gadgets.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29887,683,'Independent Veteran Breacher','The Breacher\'s structure is little more than a fragile scrapheap, but the ship\'s missile launcher hardpoints and superior sensors have placed it among the most valued Minmatar frigates when it comes to long range combat.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29888,683,'Independent Veteran Probe','The Probe is large compared to most Minmatar frigates and is considered a good scout and cargo-runner.  Uncharacteristically for a Minmatar ship, its hard outer coating makes it difficult to destroy, while the limited weapon hardpoints force it to rely on fighter assistance if engaged in combat.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29889,683,'Independent Veteran Rifter','The Rifter is a very powerful combat frigate and can easily \r\r\ntackle the best frigates out there. It has gone through \r\r\nmany radical design phases since its inauguration during \r\r\nthe Minmatar Rebellion. The Rifter has a wide variety of \r\r\noffensive capabilities, making it an unpredictable and deadly adversary. \r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29891,683,'Independent Green-Crewed Slasher','The Slasher is cheap, but versatile. It\'s been manufactured en masse, making it one of the most common vessels in Minmatar space. The Slasher is extremely fast, with decent armaments, and is popular amongst budding pirates and smugglers.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',2250000,22500,75,1,2,0.0000,0,NULL,0),(29892,683,'Independent Veteran Slasher','The Slasher is cheap, but versatile. It\'s been manufactured en masse, making it one of the most common vessels in Minmatar space. The Slasher is extremely fast, with decent armaments, and is popular amongst budding pirates and smugglers.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29893,683,'Independent Veteran Vigil','The Vigil is an unusual Minmatar ship, serving both as a long range scout as well as an electronic warfare platform. It is fast and agile, allowing it to keep the distance needed to avoid enemy fire while making use of jammers or other electronic gadgets.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Republic.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29894,306,'Angel Ship Ruins','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29895,306,'Blood Ship Ruins','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29896,306,'Guristas Ship Ruins','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29897,306,'Sansha Ship Ruins','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29898,306,'Serpentis Ship Ruins','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29899,306,'Angel Ship Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29900,306,'Blood Ship Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29901,306,'Guristas Ship Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29902,306,'Sansha Ship Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29903,306,'Serpentis Ship Hulk','You surmise that with some salvaging equipment there is still something of value to be had from this wreck.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(29904,818,'Lieutenant Orien Hakk','Raised on the Archangels station in Hemin, Orien Hakk spent most of his adult life fighting to survive amid a sea of crime and poverty. His lucky break came a few years ago, where he managed to sneak aboard an outbound industrial. Quickly realizing that he had unwittingly inserted himself into a slave transport bound for the Amarr home worlds, he commandeered the vessel and its captured crew. For months he roamed the spacelanes of Curse before an Angel raiding party pinned him down. Impressed with his merciless determination and cruel ingenuity, he was offered a place inside the Cartel; a lasting home for people of his caliber, and a place where he has gone from strength to strength.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29905,817,'Lieutenant Thora Faband','Though she was once an honorary member of their tribe, Thora Faband\'s name is one the Thukkers would nowadays rather forget. For almost a decade, she earned their trust under the guise of a failed trader seeking new beginnings. Over time she built up a foundation of goodwill and support, eventually earning a position as a production overseer in a covert facility said to be hidden deep inside the B-ROFP system. <p>\r\r\n\r\r\nFor almost a full year, she secretly turned the Thukkers\' production capabilities toward her own ends, manufacturing massive amounts of the illegal X-Instinct booster. When her plans were eventually uncovered, she convinced the Thukkers that she had been producing them for use in their own roaming caravan fleets. Before the matter could be resolved by the tribal elders, however, she had destroyed the facility, stolen all the stock and vanished south toward the Heaven constellation.',10900000,109000,120,1,2,0.0000,0,NULL,0),(29906,816,'Captain Artey Vinck','Angel Captain Artey Vinck used to be one of the most successful civilian traders in the entire Nadire constellation of Sinq Laison, a place known for ruthlessly competitive trading practices. As with many booming Gallentean traders, his success eventually put him in the crosshairs of the criminal underworld. Recognizing an opportunity to shift their goods deep inside Federation space, Serpentis thugs threatened him with financial ruin if he didn\'t begin smuggling boosters for them. <p>\r\r\n\r\r\nTheir extortion attempt ended poorly, however, when Vinck decided to go over their heads and cut a far more lucrative and efficient deal with their superiors. Days later they were all dead and Vinck vanished down the path of piracy and narcotics peddling. Since that time he has never been directly linked to any criminal activity, although in recent times he is rumored to have begun leading countless operations involving X-Instinct sales, both inside Federation space and beyond.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(29907,816,'Captain Appakir Tarvia','Although few ever know the true histories of the Domination Angels\' members, rumors abound that Tarvia was once a humble and harmless archaeologist working on the Eve gate alongside his colleagues in the Servant Sisters of Eve. The Angel Cartel has an immense and well-funded interest in uncovering the valuable secrets locked away inside the ancient Jovian stations they now inhabit. If the rumors are indeed true, then Tarvia would undoubtedly have been tempted away from his work, often viewed as a secondary aim by the Sisters, who set the provision of humanitarian aid as their top priority. Few men of science would have been able to resist the opportunity to conduct research that could change the face of New Eden overnight.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(29908,817,'Lieutenant Kaura Triat','Formerly a Thukker Tribe member, Triat was enticed into work for the Salvation Angels when it became clear that a life of wandering would not get her any closer to the goals she had set for herself and her people. A firm believer in the potential of booster technology to uplift all of humanity, she has turned away from aimless and simple-minded drug peddling and begun working for the Cartel, who, like their partners in Serpentis, appreciate the deeper benefits of their trade. In Triat\'s eyes, the final manifestation of booster technology represents nothing less than the end of slavery.',10900000,109000,120,1,2,0.0000,0,NULL,0),(29909,818,'Lieutenant Tolen Akochi','Caldari by birth, Tolen Akochi was the youngest of seven siblings in a highly successful family that built its fortunes on the back of risk-averse applied research. Even had he ever become heir to anything of substance, his daring methods would have never been tolerated by his family. Accepting these harsh realities, Akochi took what few assets were in his possession and set out for Curse. Serpentis agents soon realized that like their own leader, he had inherited the most important thing of all -- his father\'s talents. After a particularly ruthless SARO raid which almost cost him his life, Akochi saw first-hand how science on the frontier was an industry under constant threat. From that moment on, he changed paths and turned his brilliant mind toward combat training.',1645000,16450,120,1,2,0.0000,0,NULL,0),(29910,816,'Captain Saira Katori','Katori has years of combat experience, having worked her way up from a lowly grunt to a respected commander. Prior to her days of piracy she served as a rookie inside the Caldari Navy but when they ruled her unfit to be a starship captain she sought other means to take to the stars. She is allegedly a close personal friend of Vepas Minimala who, as the rumor goes, was the one that recognized her raw talent and paid for everything she needed to grow into the fearsome pilot she is today.',19000000,22000000,235,1,1,0.0000,0,NULL,0),(29911,816,'Captain Isoryn Ardorele','Formerly a Federation Navy commander, Isoryn Ardorele joined the Guristas Pirates for the simplest of reasons. While deployed inside Caldari borders on a reconnaissance operation for the Federation, Ardorele was targeted back home by State black ops soldiers who kidnapped her family and threatened to kill them if she didn\'t withdraw her forces. Against the orders of her superiors, Ardorele complied with the Caldari and was consequently labeled a traitor to the nation she had served for years. Although devastated by the decision, she was able to understand how it came to be. What she could not understand, however, was the death of her family at the hands of Caldari soldiers who, without any apparent thought or compassion, reneged on their end of the bargain. <p>\r\r\n\r\r\nSince that day, her mental wellbeing has come into question time and time again, since she engages in nothing short of genocide on the spacelanes. Keen to harness both her military knowledge and raw hatred for the Caldari people, Guristas leadership offered her a position overseeing their new narcotics operations near State borders. Ardorele is said to be completely uninterested in the booster side of things, but nobody can argue with the results of her security patrols. Her tendency to indiscriminately slaughter every Caldari that she comes across has meant that the curious stay well away. ',19000000,22000000,235,1,1,0.0000,0,NULL,0),(29912,817,'Lieutenant Asitei Ohkunen','There is a great deal said about Asitei Ohkunen but separating the fact from the fiction is no easy task. Reclusive and secretive, he has made himself scarce to everyone but his Gurista cohorts since abandoning his post in the Caldari Navy. Although the Caldari State initially denied he ever worked for them, a leaked CONCORD file later revealed that Ohkunen was indeed registered with them as an electronics expert. The political backlash from the State following the leak was in fact the only time people ever heard the name Asitei Ohkunen. Whatever crimes he may have committed, if any, his name certainly hasn\'t been linked to them.',10100000,101000,235,1,1,0.0000,0,NULL,0),(29913,817,'Lieutenant Sukkenen Fusura','A computer expert like few others, Sukkenen Fusura was once destined for a promising career in the Caldari State. As an inquisitive young man with few moral qualms, he would often roam the greater network looking for challenging databases to hack into. It was this dubious hobby of his that saw him fall from grace inside the State, after he was caught digging around classified corporate databases. It didn\'t take long for the Guristas Pirates to notice just how easily he bypassed many of the State\'s classified systems, and soon enough he was spotted slipping out of Lonetrek towards Venal in the north. Fusura recently caused quite a stir when he boasted on a public network that the Caldari State\'s biotech corporations had all contributed heavily toward improving the design and production of the Guristas Crash boosters.',10100000,101000,235,1,1,0.0000,0,NULL,0),(29914,818,'Lieutenant Rodani Mihra','As a lower-class Khanid exiled from the Amarr Empire, Rodani Mihra had to quickly adapt to a challenging and foreign environment. Pledging that he would never submit himself to manual labor, Mihra fine-tuned his talents at trading and market analysis. His service to the Guristas began almost a decade ago, just as he was about to enter into legitimate work as an advertising consultant. After a chance meeting with a Gurista booster manufacturer made him realize just how much money he could make with his skills, he left for Venal and never returned. Mihra is said to be absurdly protective of the financial kingdom he has built up around Blue Pill boosters these past years.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29915,818,'Lieutenant Onoki Ekala','Like so many ranking Guristas commanders, Onoki Ekala once had strong ties to the Caldari Navy. A  knowledge nomad  similar to the famed Tyma Raitaru, he spent many years as a freelance scientist selling his patents to the highest bidder, which in his case were most commonly Navy subsidiaries. Considered a brilliant innovator across a number of disciplines, Ekala made a small fortune optimizing anything from missile manufacturing processes to bio-weapon delivery mechanisms. <p>\r\r\n\r\r\nRealizing that it was a simple matter of ISK and greed, the Guristas offered him access to research funding and cloning technology in exchange for his lasting loyalty. Ekala has stayed with them for almost a decade since then, much to the disappointment of his former clients in the Caldari Navy.',1650000,16500,235,1,1,0.0000,0,NULL,0),(29916,816,'Captain Scane Essyn','Scane Essyn worked alongside Serpentis Officer Brynn Jerdola at the Federal Intelligence Office for many years. As one of the few close enough to her to be aware of her mission to infiltrate the Serpentis hierarchy, he was often rumored to be her lover. Not long after it became widely acknowledged that Jerdola had defected, Essyn quietly slipped outside Federation borders and was next seen in the Wyvern Constellation, flanked by a fleet of Serpentis Vindicators. Whether he followed her lead in defecting -- or, indeed, was the reason for it happening -- remains unknown. Most likely this very issue is still an ongoing investigation inside the shadowy corridors of the FIO.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(29917,816,'Captain Amiette Barcier','Originally a high-ranking fleet commander for the Angel Cartel\'s Archangel Division, Barcier first came in to contact with Serpentis on a joint operation with the Guardian Angels, where her squadron was tasked with the defense of Serpentis Inquest HQ. Seeing what they thought was a weak link in Fountain\'s defensive line, CONCORD raiding parties repeatedly tried to hamper Inquest research operations. Rumor has it that Barcier eventually came to the attention of Salvador Sarpati himself when   after four long months of nothing but failed attempts   CONCORD\'s elite SARO Division called for an end to the assaults. Since that day, Barcier has continued to deliver results and impress her new employer.',17500000,1140000,480,1,8,0.0000,0,NULL,0),(29918,817,'Lieutenant Elois Ottin','Once destined to be a holovid star, Elois Ottin\'s promising career as an actress was crushed under the weight of a severe Drop addiction. Her drug dependence became a huge public scandal when a jaded lover ran to the press with the story. Unfortunately for Ottin, the revelation came on the heels of a highly successful anti-drug campaign. Federation politicians and their lackeys in the media wasted little time in alienating her completely. Seizing the opportunity to counter the Federation\'s propaganda machine, Serpentis Corporation saw to it that from then on, she would have access to training, cloning technology and anything else needed to become a flag-bearer for their ideals.',11200000,112000,480,1,8,0.0000,0,NULL,0),(29919,817,'Lieutenant Rayle Melania','Born and bred on the Serpentis headquarters station in Serpentis Prime, Rayle Melania lived a daily life of crime, poverty and booster addiction. He struggled for many years as a lowly pimp and failed drug dealer before his far more impressive capabilities as a capsuleer pilot were uncovered. Taking the hard lessons from the station ghettos with him straight into the spacelanes, Melania quickly earned a name for himself as one of the most rough and ruthless narco-thugs Serpentis had employed in recent years.',11200000,112000,480,1,8,0.0000,0,NULL,0),(29920,818,'Lieutenant Raute Viriette','A relic from the early years following the booster ban, Raute Viriette spent the last few decades locked away inside Poteque Pharmaceuticals biolabs, supposedly working on a top-secret research project for the Federal government. It was one of the worst kept secrets inside Poteque that her entry into science had come at a time when booster research was still seen in some fringe communities as the next great scientific breakthrough. Over the years however, people had forgotten about these associations. It was only recently, when she vanished from her post in the Federation, that people began to remember.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29921,818,'Lieutenant Irrie Carlan','Formerly a Federation Customs officer, few understand the ways of customs and anti-narcotic squads like Irrie Carlan. Tempted away from her duty to the Federation by the promise of vast riches and access to Serpentis Inquest\'s cloning technology, she wasted little time in defecting. Although she gambled the promise of a successful career away, the decision has been one she could hardly regret, having rocketed up the Serpentis chain of command on the back of her rare and precious knowledge.',2650000,26500,235,1,8,0.0000,0,NULL,0),(29922,816,'Captain Tori Aanai','A graduate from the School of Applied Knowledge, Tori Aanai stands as one of many lessons about the dangerous freedom that capsuleer technology bestows. Shortly after her graduation, Aanai found herself deployed deep inside Stain. She was guarding what was to become a failed attempt by the Poksu Mineral Group to uncover mineral riches in a system they wrongly assumed was unexploited. When the industrial convoy fled in the face of an unexpected Sansha presence, for reasons known only to her, Aanai decided to stay. From that point on, she has been linked to countless illegal activities. <p>\r\r\n\r\r\nDED reports state that she has been killed over a thousand times on the fringes of empire space, recklessly exposing herself to near-harmless physical death as she coordinates large-scale Frentix production and distribution on the front lines. Despite their success at reining her operations in, the DED has never brought them to a complete standstill. Indeed, many say that each death has only hardened her resolve.',10010000,100100,235,1,4,0.0000,0,NULL,0),(29923,817,'Lieutenant Onuoto TS-08A','The pilot inside this Phantasm-class cruiser seems to be locked into a series of highly complex tactical maneuvers designed to hit hard and leave little room for their opponent to survive the opening assault. Although this battle strategy would spell instant death for a rookie or even an intermediate pilot, to a capsuleer these maneuvers are severely limited and, after some observation, easily predicted. Every few seconds the pilot attempts to open a comms link. When accepted, all that is transmitted is a deafening static.',10010000,100100,235,1,4,0.0000,0,NULL,0),(29924,818,'Lieutenant Onuoto TS-08B','The pilot inside this Succubus-class frigate seems to be locked into a series of highly-complex tactical maneuvers designed to pin down an enemy in anticipation for a larger onslaught. Although this battle strategy would spell instant death for a rookie or even an intermediate pilot, to a capsuleer these maneuvers are severely limited and, after some observation, easily predicted. Every few seconds the pilot attempts to open a comms link. When accepted, it does nothing other than fill the audio receivers with the same looping audio fragment of some long-forgotten speech by Sansha Kuvakei.',2112000,21120,235,1,4,0.0000,0,NULL,0),(29925,816,'Captain Aneika Sareko','Known across Delve for her ruthless rise to Captain of the Crimson Hand fleet, Sareko has built a reputation for no-nonsense dealings and zero tolerance for insubordination. Of Caldari descent, she is primarily interested in business and getting the job done, but when clients\' arrangements start to look suspect, her Sani Sabik side comes out in force. One particular story bears out the truth of this, although it has never been substantiated by CONCORD. <p>\r\r\n\r\r\nApparently, during a particularly successful SARO raid deep into Delve, officers came across what appeared to be a cloning facility. Inside, however, the infrastructure had been converted into a prison of sorts. Rebellious Crimson Hand personnel had been cloned and subjected to a daily regime of capital punishment. Unofficial sources claimed they had been locked up inside their capsule prisons for as long as nine months, dying a new death each day only to be reborn to suffer it all over again. ',19500000,1150000,235,1,4,0.0000,0,NULL,0),(29926,817,'Lieutenant Kannen Sumas','A former Priest based out of Penirgman, Sumas was once a famed theologian back in his home system. He served almost two decades in the Imperial Navy before the lure of immortality brought him into the Crimson Hand\'s service. His finely honed expertise in Amarrian warfare, now augmented with the limitless potential of capsule technology has shaped him into a fearsome personal bodyguard for high-ranking military officers.',11800000,118000,235,1,4,0.0000,0,NULL,0),(29927,818,'Lieutenant Anton Rideux','To most customers, Rideux is the public face for the outfit and the only person in the Hand they\'re likely to ever see. As a relatively calm and amicable Intaki he is perfectly suited to handle the front end of business with clients both large and small. Very rarely will he get his hands dirty but if his own personal honor or credibility comes under attack then he is quick to have an example made out of his detractors.',2860000,28600,235,1,4,0.0000,0,NULL,0),(29932,314,'Sareko\'s Capsule','The self-destruct unit on this capsule has had the safety timer removed, a unique Crimson Hand modification that ensures military officers are rarely captured alive. The corpse also appears to have been liquefied in some way during the process, adding a dark ruby hue to the capsule fluid within.',32000,1000,0,1,NULL,0.0000,1,NULL,0),(29933,314,'Victor Emblem','This is an expensive replica of an old Imperial Navy medal once given to soldiers on their 20th year of service. Crimson Hand lieutenant Kannen Sumas has embedded a data file underneath the resilient metal alloy exterior. The file\'s sole contents are a few selected verses of the Amarrian Scriptures, all of them celebrating the virtues of humility in the face of a superior foe. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29934,314,'Splinter Bodyguard','Although the explosion of Anton Rideux\'s ship has scrambled the electronics, the intentions behind this Rogue Drone redesign remain clear. In typical Crimson Hand style, the violent and unpredictable Splinter variant has been captured and reprogrammed to protect its host ship. The fact that Rideux didn\'t launch it suggests perhaps the job hadn\'t quite been finished yet. ',34000,25,0,1,NULL,0.0000,1,NULL,0),(29935,314,'Cartel Holovids','Encapsulated in a surprisingly sturdy metal casing, this holovid collection appears to have survived the explosion of Serpentis drug lord Amiette Barcier\'s vessel. It seems that each of the numerous holovids involve a different depiction of the Angel Cartel from amateur documentaries theorizing about secretive research projects to underground films glorifying the Cartel\'s highly violent raids. ',1,1,0,1,NULL,250.0000,1,NULL,0),(29936,314,'Accounting Records','It appears as if the only thing designed to survive the explosion of Rayle Melania\'s vessel was his accounting log, perhaps so it could later be recovered by his Serpentis colleagues. Although heavily encrypted, fragments of data are decipherable. Even from what little is readable, it is clear that Melania handles the shifting of his narcotic goods personally.  According to one transaction log, he made almost 300 individual deliveries across seven regions of New Eden, all in the space of a single day.',1,1,0,1,NULL,10000.0000,1,NULL,0),(29937,314,'Inquest Drone','Hundreds of these tiny devices were released momentarily before the explosion of Irrie Carlan\'s vessel. Motionless upon launch, they began to spring to life shortly afterwards, flitting around the ruins of the ship as they assessed the damage. Most curiously, they appeared to perform some kind of in-space surgical procedure on Carlan\'s corpse once it had been located amongst the wreckage. Now removed from the rest of its swarm, this particular drone has powered down entirely and seemingly erased its own subroutines. Any chance at reverse-engineering it in this state would be slim.',1,1,0,1,NULL,0.0000,1,NULL,0),(29938,314,'Cipher Router','This heavily damaged fluid router appears to offer a low-profile backdoor into classified FIO networks. In a more functional state this unit could have shed some light on whether or not Serpentis Captain Scane Essyn truly defected. Without a way to bypass the various built-in encryption systems, however, it will be impossible to make sense of any recoverable data. This could be proof of Essyn using old knowledge to his advantage in a new career, or simply his link back to one he never abandoned in the first place.',10,2,0,1,NULL,0.0000,1,NULL,0),(29939,314,'Ottin Holoreels Case','Kept safe from the explosion of her vessel, this Holoreel collection is a meticulous document of Serpentis Lieutenant Elois Ottin\'s entire acting career. A large Impetus logo is emblazoned on the outside of the container, suggesting that perhaps the case was a gift from the corporation. Although Ottin rarely managed to snare contracts with Impetus to produce her works, they did manage and fund her two most successful acting ventures. At one point she had a third lined up, but when her drug dependency became public knowledge Impetus dropped the contract amid the scandal. ',1,1,0,1,NULL,0.0000,1,NULL,0),(29940,314,'Advisory Notes',' Found among the wreckage of Serpentis Lieutenant Rautte Viriette\'s vessel, these notes offer a glimpse into her recent scientific pursuits. From what little is decipherable, Viriette seems to be advising Serpentis Inquest scientists on various methods of production efficiency, all of which appear to be applied to the manufacture of Drop boosters. Although there is no evidence directly linking any of her previous Poteque research to her current work with the Serpentis, it is clear that the methods she has learned in the last few decades are being put to good use.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29941,314,'Dysfunctional Fluid Router','The backbones of communication across New Eden, fluid routers play a crucial role in all faster than light (FTL) transmissions. The locator and identification subsystems on this particular model appear to have been removed entirely, most likely as part of an attempt to avoid CONCORD interference. Although the unit is heavily damaged from the explosion of Saira Katori\'s ship, fragments of data have survived in its cache. Most interesting among them is an unsent mail to Vepas Minimala which reveals a certain degree of familiarity between them.',1,1,0,1,NULL,0.0000,1,NULL,0),(29942,314,'Research Data Fragment','Barely intact as it lies among the wreckage of his ship, this data terminal offers a rare insight into the likely research interests of the enigmatic and reclusive pirate Asitei Ohkunen. Huge amounts of data have been compiled on the neurological states of test subjects, all of them under the effects of various boosters. The reasoning behind these tests remains uncertain, although the narrow focus on electrical impulses inside the brain might suggest an attempt at some kind of digitally-produced emulation.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29943,314,'Demographic Analyses','Moments before the destruction of his ship Rodani Mihra attempted to destroy these files. The formatting procedure didn\'t fully complete before his ship was downed, however, and fragments of data remain, including one important-looking document. Highly convoluted and riddled with economic terminology, it appears to be a comprehensive report on various regions. Each and every system has been broken down into demographic sub-groups that clearly outline where the demand for illegal boosters is currently greatest and where it is mostly likely to grow in the coming weeks and months.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29944,314,'Ardorele Heirloom','Found drifting in a container amongst the wreckage of her ship, Guristas Captain Isoryn Ardorele\'s personal possessions tell a tale of devastating loss. Federation Navy medals rewarding long years of service, hand paintings made by her late daughter, a wedding ring   all mementos of a past destroyed by Caldari thugs. With such a constant and effective reminder of her painful history, it is little wonder that Ardorele manages to sustain her murderous rage towards the Caldari. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29945,314,'Network Decryption Analyzer','This strange-looking piece of equipment was discovered unharmed amid the shattered hull of Guristas Lieutenant Sukkenen Fusura\'s vessel. Although baffling in its complexity, it is clearly used as a tool to breach secure networks. All the software appears to be proprietary, however. Without some way to understand even the basic functionality or system design there is little chance of using the device, let alone reverse-engineering it.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29946,314,'Ekala\'s Design Documents','Heavily damaged from the explosion of his vessel, Guristas Captain Onoki Ekala\'s private designs fail to offer any significant insights into what his brilliant mind is currently working toward. Careful analysis of the reconstructed diagrams reveals various bio-chemical refining array designs, but many crucial details are missing. Presumably this facility has something to do with the processing of cytoserocin, the material harvested from gas clouds as part of booster production. Without access to more information, the designs alone offer no real clue as to what Ekala is up to save for the obvious; producing Crash boosters.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29947,314,'Enigmatic Reports','Completely unharmed from the destruction of Angel Captain Appakir Tarvia\'s vessel, this data storage unit appears to contain a wealth of information, although every last byte is encrypted in an unknown cipher that looks leagues above current data protection technology. Every attempt made to crack the code returns nothing more than a list of strange errors, none of which are typical for decryption fault analysis. More ominously still, each attempt at decryption seems to activate an internal uplink to a remote system in the Heaven constellation, with no apparent way to stop what must be outbound transmissions. <p>\r\r\n\r\r\nDespite the impenetrability of the data, one small image juts out among the garbled text, offering an explanation as menacing as the fact that it was clearly excluded from the encryption as some kind of warning.  ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29948,314,'Insorum Booster Prototype','The only known cure for the infamous Vitoc method that Amarrians use to control their massive slave contingents, Insorum is the answer to every loyal Minmatar\'s desire to see their people freed from its insidious grip. How Angel Lieutenant Kaura Triat even came into possession of such a rare and highly-valued Insorum sample is anyone\'s guess. More intriguing, however, is the fact that it seems to have been heavily modified by scientists, perhaps those working for Serpentis Inquest. Encased in a resilient tamper-proof case that will destroy the contents within if opened by anyone but its owner, this sample seems to have been integrated with the Sooth Sayer booster. What purpose this process might have served remains entirely unclear. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29949,314,'SARO Emblem','Bizarrely enough, it seems that Angel Cartel Lieutenant Tolan Akochi has been carrying around a CONCORD dog tag, even going to the trouble of protecting it against the rigors of exposure in space. A database query on the ID number offers a grim explanation as to why, revealing that it belongs to an ex-SARO Commander. Although nothing about him is listed on the CONCORD public network, third party news articles related to his name detail how he once lead an offensive on Serpentis Inquest Headquarters. Initially thought to be a success, later pieces tell the story of what eventually amounted to a large-scale operational failure in the face of unexpected resistance. The final article available outlines a particularly gruesome death suffered by him, his entire family and a swathe of known associates.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29950,314,'Customs Patrol Schedule','Found among the wreckage of Angel Captain Artey Vinck\'s vessel, this innocuous looking data core actually holds a wealth of information about previous Federation Customs patrol routes, now probably a little outdated. The level of detail is staggering: including locations of almost every single Customs vessel in operation across the entire Sinq Laison region. With information like this, a smuggler could pass undetected anywhere they pleased with complete impunity. Attached to the information is a brief note bearing the logo of Serpentis Corporation that reads  Fly safe Artey, times change. As ever, I.C. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29951,314,'DisX Stash','Encapsulated in a resilient Mexallon alloy container, this drug stash was clearly intended to survive the explosion of Angel Lieutenant Thora Faband\'s vessel, most likely so it could be recovered by her Cartel associates. A cursory analysis of the contents reveals them to be a modified version of an X-Instinct variant known as  DisX  which possesses greatly increased dissociative elements that serve to heighten sensory deprivation. Strangely enough, these drugs are most popular among the Matari tribes that she cheated to make them. They value DisX as a catalyst for self-exploration and spiritual insight.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29952,314,'Rebellion Cache','Locked away inside a secure container, this mass stockpile of small arms has somehow managed not to detonate following the explosion of Angel Lieutenant Orien Hakk\'s vessel. There must be tens of thousands of rifles and pistols here, all of them fully loaded and ready for immediate use. The weapons are supplemented by a deadly assortment of explosives and blunt weapons. Emblazoned on the cover of the container is what appears to be a parachute mechanism and the words  Rebel Cache. ',1000,50,0,1,NULL,0.0000,1,NULL,0),(29953,314,'PDW-09FX Data Shell','This data storage unit must have contained invaluable insights into ongoing Sansha\'s Nation operations. However, it is encased within a neodymium trigger mechanism which caused it to auto-delete every single file in its database the moment it was exposed to the cold vacuum of space. A design utilizing the atmospheric reactivity of neodymium lies at the cutting edge of technology, requiring a level of ingenuity and craftsmanship well outside a True Slave\'s capabilities and indeed even beyond that of its former owner, Sansha\'s Nation Captain Toriiko Aanai. Stranger still, however, is the fact that this shell was also clearly designed to survive the explosion of her ship.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29954,314,'PDW-09FX Tactical Subroutines','This appears to be the logical nexus of the Phantasm-class cruiser once piloted by what was most probably a True Slave. Although heavily damaged following the explosion that freed it from the vessel, there are several semi-functional tactical subroutines still in operation now, seemingly unaware of their disconnection. The circuitry appears to have at one point been integrated into the pilot in some way, forming a frighteningly efficient harmony of mind and machine. Most disconcerting however, is the fact that various aspects of the software technology could only be a few years old. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29955,314,'Address #298 Audio Fragment','Unmistakably the voice of Sansha Kuvakei, this audio fragment captures a brief glimpse of a low-key speech he made over a century ago. Dating from the height of his fame, Kuvakei\'s speech is riddled with self-indulgent rhetoric and delusions of grandeur. As the speech\'s intensity reaches its peak, his final line  I am the answer  loops repeatedly for a few minutes before the process begins all over again. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(29964,954,'Legion Defensive - Adaptive Augmenter','Capitalizing on the exceptional defensive capabilities of fullerene-based components, this subsystem allows a pilot to augment their Legion\'s armor resistance, dramatically enhancing its survivability in combat. Tiny molecular-level conduits play a crucial role in orchestrating the flow of nano-assemblers beneath the armor\'s surface, guarding the flow of vital repairs against disruptive impact. \r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n4% bonus to all armor resistances per level \r\r\n10% bonus to remote armor repair system effectiveness per level',1400000,40,300,1,4,4800000.0000,1,1126,0),(29965,954,'Legion Defensive - Nanobot Injector','The advanced Sleeper-based technology in this subsystem is focused on increasing the effectiveness of a vessel\'s armor nanobots. When integrated into the hull of a Legion, it offers a substantial increase in the armor output of any repair modules fitted, whether local or remote. Although the subsystem offers the same end result as other built-in armor repair augmentations, the technology driving it operates in a vastly different way, allowing for easy removal from its host vessel. \r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to armor repairer effectiveness per level',1400000,40,300,1,4,4800000.0000,1,1126,0),(29966,954,'Legion Defensive - Augmented Plating','Although this subsystem uses the same armor nano-assemblers as standard empire technology, various optimizations have been made. Taking full advantage of recently discovered Sleeper designs, the use of fullerene-based technology has allowed for the combination of far smaller and more resilient components.  \r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n7.5% bonus to armor hitpoints per level.\r\r\n',1400000,40,340,1,4,4800000.0000,1,1126,0),(29967,954,'Legion Defensive - Warfare Processor','After countless failed projects over the years, the dream of linking fleets with sub-Battlecruiser hulls was eventually shelved and relegated to the realm of engineering theory. It remained this way for some time, tempting few starship manufacturers to revisit the challenge, even after the discovery of ancient Sleeper designs and the influx of fullerene-based technology. It was not until the first Strategic Cruiser hulls began appearing in small numbers across the empires that they began to truly appreciate the potential Tech III vessels had for modifications.  \r\r\n\r\r\nNot long after, the first warfare processor housing became a reality. Although what it delivered as a standalone unit was undoubtedly impressive, what would count more in time was the way it served as a catalyst. The unit demonstrated to the wider spacefaring industry that the possibilities for Tech III ships were broader than first imagined, and in doing so, it heralded the beginning of even more radical and innovative designs.\r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n2% bonus to effectiveness of Armored Warfare, Information Warfare, and Skirmish Warfare Links per subsystem skill level\r\r\n\r\r\nRole Bonus:\r\r\nCan fit Warfare Links',1400000,40,300,1,4,4800000.0000,1,1126,0),(29969,954,'Tengu Defensive - Adaptive Shielding','Based on the same advanced technology employed by Sleeper drones to harden their armor plating, these tiny nano-assemblers have been reconfigured to improve a shield\'s resistance to damage. The influx of superior construction materials and the modularity of Sleeper components have made even this drastic redesign into a fairly simple process.   \r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n4% bonus to all shield resistances per level\r\r\n10% bonus to shield transporter effectiveness per level\r\r\n',1400000,40,420,1,1,4800000.0000,1,1127,0),(29970,954,'Tengu Defensive - Amplification Node','When confronted with the challenge of adapting Sleeper designs to produce shield boost amplification systems, Caldari engineers turned to the defense systems used by certain Talocan structures that had also been found in a few ancient ruins. In some rare cases, the shielding systems on Talocan facilities were constructed using a harmony of Sleeper and Talocan designs. The first successful production of a shield boost amplification node drew heavily upon early study of this particular combination. \r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to shield booster effectiveness per level\r\n',1400000,40,440,1,1,4800000.0000,1,1127,0),(29971,954,'Tengu Defensive - Supplemental Screening','Making full use of recent scientific advances afforded by the discovery of ancient technologies, Caldari starship designers have reverse engineered the equipment behind the Sleeper\'s metallofullerene armor plating. Through a complex substitution method, skilled engineers and physicists have been able to supplement a Tengu\'s shields, offering increased survivability for a pilot under heavy fire. \r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n5% bonus to shield hitpoints per level.\r\r\n3% bonus to passive shield recharge rate per level.\r\r\n',1400000,40,410,1,1,4800000.0000,1,1127,0),(29972,954,'Tengu Defensive - Warfare Processor','After countless failed projects over the years, the dream of linking fleets with sub-Battlecruiser hulls was eventually shelved and relegated to the realm of engineering theory. It remained this way for some time, tempting few starship manufacturers to revisit the challenge, even after the discovery of ancient Sleeper designs and the influx of fullerene-based technology. It was not until the first Strategic Cruiser hulls began appearing in small numbers across the empires that they began to truly appreciate the potential Tech III vessels had for modifications.  \r\r\n\r\r\nNot long after, the first warfare processor housing became a reality. Although what it delivered as a standalone unit was undoubtedly impressive, what would count more in time was the way it served as a catalyst. The unit demonstrated to the wider spacefaring industry that the possibilities for Tech III ships were broader than first imagined, and in doing so, it heralded the beginning of even more radical and innovative designs. \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n2% bonus to effectiveness of Siege Warfare, Information Warfare, and Skirmish Warfare Links per subsystem skill level\r\r\n\r\r\nRole Bonus:\r\r\nCan fit Warfare Links',1400000,40,290,1,1,4800000.0000,1,1127,0),(29974,954,'Loki Defensive - Adaptive Shielding','Based on the same advanced technology employed by Sleeper drones to harden their armor plating, these tiny nano-assemblers have been reconfigured to improve a shield\'s resistance to damage. The influx of superior construction materials and the modularity of Sleeper components have made even this drastic redesign into a fairly simple process.   \r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n4% bonus to all shield resistances per level\r\r\n10% bonus to shield transporter effectiveness per level\r\r\n',1400000,40,280,1,2,4800000.0000,1,1128,0),(29975,954,'Loki Defensive - Adaptive Augmenter','Capitalizing on the exceptional defensive capabilities of fullerene-based components, this subsystem allows a pilot to augment their Loki\' armor resistance, dramatically enhancing its survivability in combat. Tiny molecular-level conduits play a crucial role in orchestrating the flow of nano-assemblers beneath the armor\'s surface, guarding the flow of vital repairs against disruptive impact.\r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n4% bonus to all armor resistances per level.',1400000,40,270,1,2,4800000.0000,1,1128,0),(29976,954,'Loki Defensive - Amplification Node','When confronted with the challenge of adapting Sleeper designs to produce signature reduction systems, Sebiestor engineers turned to the defense systems used by certain Talocan structures that had also been found amongst a few ancient ruins. An unexpected harmony of Sleeper and Talocan design was discovered after extensive reverse engineering attempts and this new method was born soon after. \r\n\r\nBased around the amplification of noise in surrounding local space, the subsystem allows a pilot to passively emit such significant electromagnetic interference that hostile sensors, tracking subroutines and missile detonation triggers will all treat the ship as if it is significantly smaller than it actually is.  \r\n\r\nSubsystem Skill Bonus: \r\n5% reduction in signature radius per level.\r\n',1400000,40,300,1,2,4800000.0000,1,1128,0),(29977,954,'Loki Defensive - Warfare Processor','After countless failed projects over the years, the dream of linking fleets with sub-Battlecruiser hulls was eventually shelved and relegated to the realm of engineering theory. It remained this way for some time, tempting few starship manufacturers to revisit the challenge, even after the discovery of ancient Sleeper designs and the influx of fullerene-based technology. It was not until the first Strategic Cruiser hulls began appearing in small numbers across the empires that they began to truly appreciate the potential Tech III vessels had for modifications.  \r\r\n\r\r\nNot long after, the first warfare processor housing became a reality. Although what it delivered as a standalone unit was undoubtedly impressive, what would count more in time was the way it served as a catalyst. The unit demonstrated to the wider spacefaring industry that the possibilities for Tech III ships were broader than first imagined, and in doing so, it heralded the beginning of even more radical and innovative designs. \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n2% bonus to effectiveness of Skirmish Warfare, Siege Warfare, and Armored Warfare Links per subsystem skill level\r\r\n\r\r\nRole Bonus:\r\r\nCan fit Warfare Links',1400000,40,200,1,2,4800000.0000,1,1128,0),(29979,954,'Proteus Defensive - Adaptive Augmenter','Capitalizing on the exceptional defensive capabilities of fullerene-based components, this subsystem allows a pilot to augment their Proteus\' armor resistance, dramatically enhancing its survivability in combat. Tiny molecular-level conduits play a crucial role in orchestrating the flow of nano-assemblers beneath the armor\'s surface, guarding the flow of vital repairs against disruptive impact.\r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n4% bonus to all armor resistances per level.\r\r\n10% bonus to remote armor repair system effectiveness per level\r\r\n',1400000,40,320,1,8,4800000.0000,1,1129,0),(29980,954,'Proteus Defensive - Nanobot Injector','The advanced Sleeper-based technology in this subsystem is focused on increasing the effectiveness of a vessel\'s armor nanobots. When integrated into the hull of a Proteus, it offers a substantial increase in the armor output of any repair modules fitted, whether local or remote. Although the subsystem offers the same end result as other built-in armor repair augmentations, the technology driving it operates in a vastly different way, allowing for easy removal from its host vessel.  \r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to armor repairer effectiveness per level',1400000,40,300,1,8,4800000.0000,1,1129,0),(29981,954,'Proteus Defensive - Augmented Plating','Although this subsystem uses the same armor nano-assemblers as standard empire technology, various optimizations have been made. Taking full advantage of recently discovered Sleeper designs, the use of fullerene-based technology has allowed for the combination of far smaller and more resilient components.  \r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n7.5% bonus to armor hitpoints per level.',1400000,40,280,1,8,4800000.0000,1,1129,0),(29982,954,'Proteus Defensive - Warfare Processor','After countless failed projects over the years, the dream of linking fleets with sub-Battlecruiser hulls was eventually shelved and relegated to the realm of engineering theory. It remained this way for some time, tempting few starship manufacturers to revisit the challenge, even after the discovery of ancient Sleeper designs and the influx of fullerene-based technology. It was not until the first Strategic Cruiser hulls began appearing in small numbers across the empires that they began to truly appreciate the potential Tech III vessels had for modifications.  \r\r\n\r\r\nNot long after, the first warfare processor housing became a reality. Although what it delivered as a standalone unit was undoubtedly impressive, what would count more in time was the way it served as a catalyst. The unit demonstrated to the wider spacefaring industry that the possibilities for Tech III ships were broader than first imagined, and in doing so, it heralded the beginning of even more radical and innovative designs. \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n2% bonus to effectiveness of Armored Warfare, Skirmish Warfare, and Information Warfare Links per subsystem skill level\r\r\n\r\r\nRole Bonus:\r\r\nCan fit Warfare Links',1400000,40,220,1,8,4800000.0000,1,1129,0),(29984,963,'Tengu','When we first saw the flock, we were surrounded, caught in a spectacle of stimuli. Brilliant colors, dancing lights, beautiful cacophonies, wafting ambrosia. Those birds surrounded us, each one a different shape, an altered species, a new wonder. I tried to follow a single bird, but my efforts were futile: Transformation is natural to their existence. Imagine it: an undulating mass, a changing mob, all those beasts partaking in wonderful transmogrification.  \r\r\n\r\r\nThese were our augurs, our deliverers, our saviors. Standing amidst the flock, we should have feared their glory; instead, we drew hope. This moment is the first time I understood what it meant to be Caldari: Divinity in the flock, delivery in flux, one being, many changes.\r\r\n\r\r\n   - Janto Sitarbe, <i>The Legendary Flock</i>\r\r\n',8201000,92000,0,1,1,18800000.0000,1,1140,0),(29985,996,'Tengu Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(29986,963,'Legion','Revelation burrows through the material world, devours creation\'s soil, digests the thoughtless void, and produces significance with God\'s grace. From emptiness comes meaning, essence from existence, soul from matter.\r\r\n\r\r\nIs God through the wormhole? Did God grant us this boon, this new technology, a revelation from on high? These weapons are God\'s new prophecy, domain, and blessing. Let us use God\'s grace and prepare New Eden. We are God\'s soldiers, weapons, glory. Our people are God\'s army. Together, we are the legion.\r\r\n\r\r\n    -<i>The Heresies of Hinketsu</i>\r\r\n',6815000,118000,0,1,4,18800000.0000,1,1139,0),(29987,996,'Legion Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(29988,963,'Proteus','Freedom is liquid, supple, mellifluous. It surrounds us, engulfs our bodies, drowns our fear. We plumb freedom\'s depths and consume the nourishment within. From these waters, we are born; when we die, we shall return to those waters. \r\r\n\r\r\nOut there, among the stars, are the waters, freedom incarnate. That dark, endless void is our destiny, our path, our goal. We must not fear it, nor should we control it. Rather, we should embrace it, trust it, love it. Its ever-changing face, its protean existence, is our very essence. We are those stars, the void, the awesome waters of space: ancient, forever, free.\r\r\n\r\r\n    - Jinsente Parmen, <i>The Gallente in New Eden</i>\r\r\n\r\r\n',5341000,115000,0,1,8,18800000.0000,1,1141,0),(29989,996,'Proteus Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(29990,963,'Loki','For many Minmatar, the high mountains of Matar hold wonders unknown to the rest of New Eden: hidden glens, beautiful creatures, buried customs. Not surprisingly, the Krusual tribe lay claim to these mountains, their home for generations and base to their machinations.\r\r\n\r\r\nKrusual elders whisper ancient tales among their huddled tribes, describing the glory of heroes past and enigmatic prophecies of old. On the darkest day, at the most hopeless moments, an elder may speak of <i>loki</i>, in reverent tones and excited hushes. In the ancient tongue, the <i>loki</i> are the crux of Krusual thought. There is no direct translation for this word; in fact, <i>loki</i> translates differently among the elders. It can mean  hidden wonder  or  secret passage ,  changing mask  or  unseen dagger . Regardless of its context, <i>loki</i> has one meaning common to all its tales across all the elders:  hope .\r\r\n',6540000,80000,0,1,2,18800000.0000,1,1142,0),(29991,996,'Loki Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(29992,964,'Optimized Nano-engines','Forming the beating heart of the Sleeper\'s automated drones, these tiny engines count in the billions. When fully intact, they deliver levels of power efficiency unrivalled by current technology. Unfortunately, whenever a Sleeper drone is destroyed, these engines are the first to go with them, making it difficult to emulate their functionality without the addition of other materials. \r\r\n\r\r\nTo recreate a functional nanoengine housing, PPD fullerene fibers are combined with metallofullerenes and fullerene fiber conduits to rebuild the basic structures that once housed them. After that, the fused nanomechanical engines are connected to one another, forming a composite whole. \r\r\n\r\r\nAlthough mechanical engineers have theorized about this construction method for many decades, the process was always held back by a lack of fullerene material. It is said that only hours after the discovery of fullerite clouds in wormhole space, the empires used significant amounts of their fullerene stockpiles to produce these engines. The reasoning behind this is simply the staggering breadth of potential applications these engines have. When it comes to engineering, there isn\'t much they can\'t do.',1,10,0,1,NULL,400000.0000,1,1147,0),(29993,965,'Optimized Nano-Engines Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(29994,964,'Warfare Computation Core','Warfare computation cores begin as basic microprocessors that handle the flow of data between various combat analyzers, prioritizing vital information and calculations. The cores are first built around salvaged Sleeper warfare processors which are then further enhanced by the integration of fullerene polymers and other Sleeper technology. The addition of emergent combat analyzers expands the functionality to include more abstract combat calculations, such as comparative analyses of fleets and predictive IFF identifications. \r\r\n\r\r\nWhen encased in thermophased metallofullerene plating, the cores can be embedded directly into the ship\'s hull. This allows for a far more efficient production method of Tech III vessels, enabling any subsystem variation to integrate into a hull without the need for further redesign in the combat electronics systems. ',1,10,0,1,NULL,400000.0000,1,1147,0),(29995,965,'Warfare Computation Core Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(29996,964,'Emergent Neurovisual Interface','As a capsuleer, few things are more important in space flight than the ability to instantly gauge one\'s surroundings and make decisions accordingly. For this reason, capsules inside starships make frequent use of neurovisual reproductions; emulations that recreate external stimuli using the most low-latency processor available   the human brain. This process relies on digital relays from camera drones and monitoring systems embedded into the hull. After capturing the data, they then feed it directly into the brain, at which point the external surrounds are recreated almost instantaneously. Functions familiar to any capsuleer such as the overview, tactical overlay and hostile threat indicators are just a few examples of the device\'s capabilities. \r\r\n\r\r\nAlthough NVI technology has been around since the inception of the capsule, the addition of salvaged Sleeper drone components and the now widely available fullerene polymers has carried the functionality forward into the new Tech III paradigm. Even before the first Strategic Cruiser was built, engineers hypothesized about potential issues with an NVI trying to communicate with an almost limitless combination of subsystems. Fortunately, the solution to the problem came wrapped up in the same technology that moved Tech III vessels from the world of scientific theory into reality.',1,20,0,1,NULL,400000.0000,1,1147,0),(29997,965,'Emergent Neurovisual Interface Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(29998,967,'Neuroprotectant Injector Array','Tech III Component used in the manufacture of advanced hulls and subsystems. ',1,5,0,1,NULL,0.0000,0,NULL,0),(30000,967,'defunct item 8','Tech III Component used in the manufacture of advanced hulls and subsystems. ',1,5,0,1,NULL,0.0000,0,NULL,0),(30002,964,'Fullerene Intercalated Sheets','The manufacture of this component requires the rarest and most valuable technology salvageable from Sleeper drones. These sheets represent some of the most advanced composite materials known to New Eden. When other, more valuable devices are embedded into the structure at the molecular level, the sheets\' performance enhances tremendously. The end result is a component with an almost endless number of applications in starship design. \r\r\n\r\r\nUltra-resilient armor plating, defensive nanoassemblers, electronics housing, and even the molecular-level circuitry itself are only a few of the near-countless roles that fullerene intercalated sheets can perform. Although unrivalled in their modularity, the cost of construction remains a barrier on supply; consequently, they remain a component to be used only when absolutely necessary. \r\r\n\r\r\nScientists and engineers alike claim that a steadier supply of these rare Sleeper pieces would instantly advance starship design ten years. Other experts have made even more interesting claims, stating that the staggering utility of the components suggests a level of technological advancement sufficient for capsule production.',1,5,0,1,NULL,400000.0000,1,1147,0),(30003,965,'Fullerene Intercalated Sheets Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(30008,964,'Reinforced Metallofullerene Alloys','These ultra-hard alloys are initially created from lanthanum metallofullerenes and heuristic selfassemblers; a combination that makes for an incredibly resilient base material. From there, fulleroferrocene and graphene nanoribbons are integrated into the metals, forming alloys that have unprecedented levels of structural strength. Although they have many uses in the manufacture of armor plating, the distinguishing feature of the alloys is the level of modularity they allow in starship design. A hull section comprised of metallofullerene alloys is able to accommodate a virtually endless array of subsystems around it, no matter how different their shape is.',1,10,0,1,NULL,400000.0000,1,1147,0),(30009,965,'Reinforced Metallofullerene Alloys Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(30013,479,'Core Scanner Probe I','A scanner probe used for scanning down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a> in space.\r\r\n\r\r\nCan be launched from <a href=showinfo:17938>Core Probe Launchers</a> and <a href=showinfo:18639>Expanded Probe Launchers</a>.',1,0.1,0,1,NULL,4470.0000,1,1199,0),(30014,486,'Core Scanner Probe I Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,320,0),(30016,967,'Nozzle Reinforcements','A strange piece of equipment recovered from a Sleeper drone. ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30017,967,'Thruster Mounts','A strange piece of equipment recovered from a Sleeper drone. ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30018,966,'Fused Nanomechanical Engines','The beating heart of the Sleeper\'s automated drones, these tiny engines count in the billions. When fully intact, they deliver levels of power efficiency unrivaled by current technology. Unfortunately, whenever a Sleeper drone goes down, these engines are the first to go with them, making it difficult to emulate their functionality without the addition of other components.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30019,966,'Powdered C-540 Graphite','This white, dusty substance was extracted from the center of high impact craters in the Sleeper drone\'s armor. When mixed with other materials it forms a stiff resin that can either be used to hold various pieces of hull sheets together or to coat them for additional protection against radiation and heat.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30020,967,'Thermoelectric Power Core','Since it has no moving parts, this solid-state power core can operate for extremely long amounts of time without the need for maintenance, offering an unlimited amount of energy regeneration in the process. Although the resilience of the Sleeper design is drastically different from other technology, the same fundamental principles have been used in capacitor production for centuries.  ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30021,966,'Modified Fluid Router','The backbones of communication across New Eden, fluid routers play a crucial role in all faster-than-light (FTL) transmissions. The Sleeper drones have been equipped with much the same communications equipment as contemporary starships. The only major difference observable with the Sleeper Fluid Routers is in the way transmissions are translated. The drones must be talking in their own proprietary language.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30022,966,'Heuristic Selfassemblers','These advanced nanoassemblers appear to be able to change their molecular structure on the fly, adapting to incoming damage. Without any understanding of how to properly operate them however, they only offer their default formations. Even in such a state, they add a significant amount of resilience to armor plating.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30023,967,'generic item 40','Most of these tiny circuits have fused together from the heat and force of the Sleeper drone\'s explosion. The detonation of the drone\'s power core must have been immense to have had such an effect on these resilient nanostructures. ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30024,966,'Cartesian Temporal Coordinator','At first glance this coordinator appears to be a common enough piece of equipment, albeit an odd one to be found inside a drone. Designed to plot various points in time across a potentially infinite period, these devices are often used for scientific calculations. \r\r\n\r\r\nFor some unknown reason, this particular coordinator is configured to synchronize its processing speed in time with the distance travelled between two points. What purpose this serves remains a mystery, but the object\'s basic functionality can be reconfigured. With the addition of a few other components, it would allow electronics systems to more easily withstand the interference from subspace distortion. ',0,0.01,0,1,NULL,0.0000,1,1862,0),(30025,967,'Thermophased Metallofullerenes','A strange piece of equipment recovered from a Sleeper drone. ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30027,967,'Isogen V','Morphite is a highly unorthodox mineral that can only be found in the hard-to-get Mercoxit ore. It is hard to use Morphite as a basic building material, but when it is joined with existing structures it can enhance the performance and durability manifold. This astounding quality makes this the material responsible for ushering in a new age in technology breakthroughs. ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30028,479,'Combat Scanner Probe I','A scanner probe used for scanning down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a>, starships, structures and drones.\r\r\n\r\r\nCan be launched from <a href=showinfo:18639>Expanded Probe Launchers</a>.',1,1,0,1,NULL,24550.0000,1,1199,0),(30029,486,'Combat Scanner Probe I Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,320,0),(30036,955,'Legion Electronics - Energy Parasitic Complex','During some of the first conflicts with them, Amarr engineers noticed a remarkable feature in Sleeper drone technology: the ability of drones to transfer power between one another without the need for specialized equipment. This technology seemed to be innate to every drone in some capacity, and while the engineers could not reproduce this system in modern space vessels, they were able to adapt the technology into modular Tech III designs. The energy parasitic complex turns the Sleeper tech on its head, changing the energy transfer from a symbiotic function to a vampiric one by providing a boost to energy neutralizer and energy vampire equipment.\r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to energy vampire and energy neutralizer transfer amount per level\r\n',1200000,40,0,1,4,4800000.0000,1,1611,0),(30037,973,'Legion Electronics - Energy Parasitic Complex Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30038,955,'Legion Electronics - Tactical Targeting Network','Many engineers have attempted to reproduce the precision of the Sleeper drones\' weapon systems, but with very few results. The closest reproduction achieved thus far is this targeting network, a complex system of neurovisual interlays, automated trigger response units, and microscanning resolution ordinances. The combination of these processes produces a bonus to scan resolution, easing the targeting of enemies in space.\r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n15% bonus to scan resolution per level\r\r\n',1200000,40,0,1,4,4800000.0000,1,1611,0),(30039,973,'Legion Electronics - Tactical Targeting Network Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30040,955,'Legion Electronics - Dissolution Sequencer','This subsystems employs a nano-electromechanical dispersion field to strengthen a vessel\'s sensor systems. Made from billions of advanced molecular-level circuits, the subsystem offers improved protection against hostile ECM. \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n15% bonus to ship sensor strength, 5% bonus to max targeting range per level.\r\r\n',1200000,40,0,1,4,4800000.0000,1,1611,0),(30041,973,'Legion Electronics - Dissolution Sequencer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30042,955,'Legion Electronics - Emergent Locus Analyzer','Emboldened by the development of other, more specialized subsystems, engineers and astrophysicists alike began to investigate modifications to a Strategic Cruiser that could aid their fellow scientists and explorers. The first reverse-engineering projects were predominantly focused on ways to improve a vessel\'s astrometrics capabilities. The two-pronged solution of boosting both the strength of the launchers and the probes they deployed proved to be the most popular design in the end. It was not long after the first designs were sold that others took notice and began to reverse-engineer their own. Soon enough, the subsystem was catapulted into mainstream Tech III subsystem manufacture, although perhaps for more than just that one reason.  \r\r\n\r\r\nThe first designers of the emergent locus analyzer noted an additional   and entirely unintended   effect in tractor beams. Not only did they reach further, but they would also pull in their cargo more quickly than normal tractor beams. It was an unexpected by-product of the processes that increased scan probe strength, but far from an undesirable one. Although it is not fully clear what part of the construction process enables this additional benefit, so long as the subsystem is built in that exact fashion, it will continue to provide it.  \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n10% increase to scan strength of probes per level.\r\r\n20% bonus to range and velocity of tractor beams per level.\r\r\n\r\r\nRole Bonus:\r\r\n-99% reduced CPU need for Scan Probe Launchers.\r\r\n+10 Virus Strength to Relic and Data Analyzers.',1200000,40,0,1,4,4800000.0000,1,1611,0),(30043,973,'Legion Electronics - Emergent Locus Analyzer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30046,955,'Tengu Electronics - Obfuscation Manifold','This subsystem operates using the same fundamental mechanics as the signal distortion amplifier. When installed into a Tech III vessel, the fullerene-based components resonate with any ECM modules fitted, bolstering their disruptive strength.\r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n12.5% bonus to ECM target jammer optimal range per level.\r\r\n',1200000,40,0,1,1,4800000.0000,1,1630,0),(30047,973,'Tengu Electronics - Obfuscation Manifold Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30048,955,'Tengu Electronics - CPU Efficiency Gate','New technologies have resulted in a noticeable increase in CPU efficiency, as better nanotech enables further miniaturization of circuits, the result of which is a marked decrease in system bottlenecking. This CPU efficiency gate capitalizes on that technology, offering a pilot greater CPU output.\r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to CPU per level.\r\n',1200000,40,0,1,1,4800000.0000,1,1630,0),(30049,973,'Tengu Electronics - CPU Efficiency Gate Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30050,955,'Tengu Electronics - Dissolution Sequencer','This subsystems employs a nano-electromechanical dispersion field to strengthen a vessel\'s sensor systems. Made from billions of advanced molecular-level circuits, the subsystem offers improved protection against hostile ECM. \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n15% bonus to ship sensor strength, 5% bonus to targeting range per level.\r\r\n',1200000,40,0,1,1,4800000.0000,1,1630,0),(30051,973,'Tengu Electronics - Dissolution Sequencer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30052,955,'Tengu Electronics - Emergent Locus Analyzer','Emboldened by the development of other, more specialized subsystems, engineers and astrophysicists alike began to investigate modifications to a Strategic Cruiser that could aid their fellow scientists and explorers. The first reverse-engineering projects were predominantly focused on ways to improve a vessel\'s astrometrics capabilities. The two-pronged solution of boosting both the strength of the launchers and the probes they deployed proved to be the most popular design in the end. It was not long after the first designs were sold that others took notice and began to reverse-engineer their own. Soon enough, the subsystem was catapulted into mainstream Tech III subsystem manufacture, although perhaps for more than just that one reason.  \r\r\n\r\r\nThe first designers of the emergent locus analyzer noted an additional   and entirely unintended   effect in tractor beams. Not only did they reach further, but they would also pull in their cargo more quickly than normal tractor beams. It was an unexpected by-product of the processes that increased scan probe strength, but far from an undesirable one. Although it is not fully clear what part of the construction process enables this additional benefit, so long as the subsystem is built in that exact fashion, it will continue to provide it.  \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n10% increase to scan strength of probes per level.\r\r\n20% bonus to range and velocity of tractor beams per level.\r\r\n\r\r\nRole Bonus:\r\r\n-99% reduced CPU need for Scan Probe Launchers.\r\r\n+10 Virus Strength to Relic and Data Analyzers.',1200000,40,0,1,1,4800000.0000,1,1630,0),(30053,973,'Tengu Electronics - Emergent Locus Analyzer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30056,955,'Proteus Electronics - Friction Extension Processor','The friction extension processor capitalizes on recent advances made in fullerene-based component development. The system works on a similar design to interdiction spheres by expanding a ship\'s warp interdiction range. The technology behind it has existed in theory for some years, dating back to when engineers first began development of Heavy Interdiction Cruisers. They noticed an increased efficiency in the electronic disruption of fullerene molecules when combined with the static disruption energies of the spheres. When more fullerene-based materials suddenly became available, it was only a matter of further testing before theory became reality. \r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to warp disruptor and warp scrambler range per level.\r\n',1200000,40,0,1,8,4800000.0000,1,1628,0),(30057,973,'Proteus Electronics - Friction Extension Processor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30058,955,'Proteus Electronics - CPU Efficiency Gate','New technologies have resulted in a noticeable increase in CPU efficiency, as better nanotech enables further miniaturization of circuits, the result of which is a marked decrease in system bottlenecking. This CPU efficiency gate capitalizes on that technology, offering a pilot greater CPU output.\r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to CPU per level',1200000,40,0,1,8,4800000.0000,1,1628,0),(30059,973,'Proteus Electronics - CPU Efficiency Gate Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30060,955,'Proteus Electronics - Dissolution Sequencer','This subsystems employs a nano-electromechanical dispersion field to strengthen a vessel\'s sensor systems. Made from billions of advanced molecular-level circuits, the subsystem offers improved protection against hostile ECM. \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n15% bonus to ship sensor strength, 5% bonus to max targeting range per level.\r\r\n',1200000,40,0,1,8,4800000.0000,1,1628,0),(30061,973,'Proteus Electronics - Dissolution Sequencer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30062,955,'Proteus Electronics - Emergent Locus Analyzer','Emboldened by the development of other, more specialized subsystems, engineers and astrophysicists alike began to investigate modifications to a Strategic Cruiser that could aid their fellow scientists and explorers. The first reverse-engineering projects were predominantly focused on ways to improve a vessel\'s astrometrics capabilities. The two-pronged solution of boosting both the strength of the launchers and the probes they deployed proved to be the most popular design in the end. It was not long after the first designs were sold that others took notice and began to reverse-engineer their own. Soon enough, the subsystem was catapulted into mainstream Tech III subsystem manufacture, although perhaps for more than just that one reason.  \r\r\n\r\r\nThe first designers of the emergent locus analyzer noted an additional   and entirely unintended   effect in tractor beams. Not only did they reach further, but they would also pull in their cargo more quickly than normal tractor beams. It was an unexpected by-product of the processes that increased scan probe strength, but far from an undesirable one. Although it is not fully clear what part of the construction process enables this additional benefit, so long as the subsystem is built in that exact fashion, it will continue to provide it.  \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n10% increase to scan strength of probes per level.\r\r\n20% bonus to range and velocity of tractor beams per level.\r\r\n\r\r\nRole Bonus:\r\r\n-99% reduced CPU need for Scan Probe Launchers.\r\r\n+10 Virus Strength to Relic and Data Analyzers.',1200000,40,0,1,8,4800000.0000,1,1628,0),(30063,973,'Proteus Electronics - Emergent Locus Analyzer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30066,955,'Loki Electronics - Immobility Drivers','Even millennia old, the technology employed by Sleeper drones is far from lacking. This is particularly true in the field of interdiction technology, where their capabilities often exceed contemporary systems. Consequently, this aspect of their fearsome arsenal has been the focus of much study and in some rare cases, the starting point for scientific breakthroughs. Minmatar researchers studied the long-range webification systems of the Sleeper drones from the moment they were discovered, quickly reverse engineering a subsystem for their Loki that could replicate the Sleeper\'s own offensive modules. The end result is a noticeable amplification of a stasis webifier\'s effective range.\r\n\r\nSubsystem Skill Bonus: \r\n30% bonus to stasis webifier range per level\r\n',1200000,40,0,1,2,4800000.0000,1,1629,0),(30067,973,'Loki Electronics - Immobility Drivers Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30068,955,'Loki Electronics - Tactical Targeting Network','Many engineers have attempted to reproduce the precision of the Sleeper drones\' weapon systems, but with very few results. The closest reproduction achieved thus far is this targeting network, a complex system of neurovisual interlays, automated trigger response units, and microscanning resolution ordinances. The combination of these processes produces a bonus to scan resolution, easing the targeting of enemies in space.\r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n15% bonus to scan resolution per level\r\r\n',1200000,40,0,1,2,4800000.0000,1,1629,0),(30069,973,'Loki Electronics - Tactical Targeting Network Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30070,955,'Loki Electronics - Dissolution Sequencer','This subsystems employs a nano-electromechanical dispersion field to strengthen a vessel\'s sensor systems. Made from billions of advanced molecular-level circuits, the subsystem offers improved protection against hostile ECM. \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n15% bonus to ship sensor strength, 5% bonus to max targeting range per level.\r\r\n',1200000,40,0,1,2,4800000.0000,1,1629,0),(30071,973,'Loki Electronics - Dissolution Sequencer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30072,955,'Loki Electronics - Emergent Locus Analyzer','Emboldened by the development of other, more specialized subsystems, engineers and astrophysicists alike began to investigate modifications to a Strategic Cruiser that could aid their fellow scientists and explorers. The first reverse-engineering projects were predominantly focused on ways to improve a vessel\'s astrometrics capabilities. The two-pronged solution of boosting both the strength of the launchers and the probes they deployed proved to be the most popular design in the end. It was not long after the first designs were sold that others took notice and began to reverse-engineer their own. Soon enough, the subsystem was catapulted into mainstream Tech III subsystem manufacture, although perhaps for more than just that one reason.  \r\r\n\r\r\nThe first designers of the emergent locus analyzer noted an additional   and entirely unintended   effect in tractor beams. Not only did they reach further, but they would also pull in their cargo more quickly than normal tractor beams. It was an unexpected by-product of the processes that increased scan probe strength, but far from an undesirable one. Although it is not fully clear what part of the construction process enables this additional benefit, so long as the subsystem is built in that exact fashion, it will continue to provide it.  \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n10% increase to scan strength of probes per level.\r\r\n20% bonus to range and velocity of tractor beams per level.\r\r\n\r\r\nRole Bonus:\r\r\n-99% reduced CPU need for Scan Probe Launchers.\r\r\n+10 Virus Strength to Relic and Data Analyzers.',1200000,40,0,1,2,4800000.0000,1,1629,0),(30073,973,'Loki Electronics - Emergent Locus Analyzer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30076,957,'Legion Propulsion - Chassis Optimization','This subsystem exploits the latest technological advances afforded by discovery of the ancient Sleeper race\'s own designs. Optimizations made to the chassis allow for vast improvements to be made to a Legion\'s base velocity. Although the various layout optimizations sacrifice other options for propulsion customization, the flow-on effects from an increase in base velocity make it an attractive upgrade for those whose Tech III vessels are in need of an overall speed increase.\r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to max velocity per level.',1400000,40,0,1,4,4800000.0000,1,1134,0),(30077,973,'Legion Propulsion - Chassis Optimization Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30078,957,'Legion Propulsion - Fuel Catalyst','The ancient Sleeper race was known to have mastered various sustainable energy technologies including thermoelectric systems, which they usually built directly into a vessel\'s hull. Capsuleer reverse-engineers took little time to adapt salvaged versions of these Sleeper energy systems into their own modular Tech III vessel pieces. \r\n\r\nThanks to widespread demand in the Amarrian transport industry, fuel catalyst systems were one of the first to be developed for the Empire. Making full use of locally generated thermoelectric power, they are able to supplement the fuel needs of an afterburner. This process makes it possible to inject fuel in larger amounts for the same capacitor cost, offering pilots a significant boost to the velocity increase from afterburners. \r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to afterburner speed per level.',1400000,40,0,1,4,4800000.0000,1,1134,0),(30079,973,'Legion Propulsion - Fuel Catalyst Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30080,957,'Legion Propulsion - Wake Limiter','This subsystem limits the wake left behind by a starship\'s microwarpdrive, allowing a pilot to maintain a lowered signature radius while still moving at high speed. The underlying design is based on the same technology used by smaller Sleeper drones and empire-produced Interceptors. Although the engineering processes behind wake limiters have existed for quite some time in the empires, their application in modular subsystems has only become a possibility after fullerene polymers became more widely available. \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n5% reduction in microwarpdrive signature radius penalty per level.\r\r\n',1400000,40,0,1,4,4800000.0000,1,1134,0),(30081,973,'Legion Propulsion - Wake Limiter Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30082,957,'Legion Propulsion - Interdiction Nullifier','Dubbed the  interdiction nullifier  by the Guristas, who suffered its first introduction on the battlefield, this subsystem grants a startling and unprecedented capability; an immunity to non-targeted interdiction such as mobile warp disruptors and interdiction spheres. \r\n\r\nThe origins of the first  nullifier  designs are shrouded in mystery, but the subsystem\'s initial production of is thought to have taken place soon after the wormhole openings, and well before the technology became widespread knowledge. Not long after the first Tengu were designed, the Caldari Navy intercepted emergency transmissions from Guristas fleets across Venal, Tenal and Vale of the Silent. All of the reports made mention of Loki-class vessels slipping past defensive deployments and into core Guristas territory despite all efforts to stop the ships or slow them down.  \r\n\r\nFollowing these reports, rumors spread that other groups began to discover and implement this extraordinary new technology, and yet of all the factions that leapt upon the opportunity, none were so eager or ruthless in their own race to capitalize as the independent capsuleer and pirate organizations that make the nullsec frontiers their home.  \r\n\r\nSubsystem Skill Bonus:\r\n5% increased agility per level\r\n\r\nRole Bonus:\r\nImmunity to non-targeted interdiction',1400000,40,0,1,4,4800000.0000,1,1134,0),(30083,973,'Legion Propulsion - Interdiction Nullifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30086,957,'Tengu Propulsion - Intercalated Nanofibers','Constructed from hard yet lightweight fullerene polymers, these intercalated fibers boost the agility of a starship without compromising its structural resilience. Even though basic nanofibers have existed for hundreds of years, the integration of various Sleeper-based salvage and other polymers takes the technology to a completely new level of modularity. This has allowed the same centuries-old technology to be ported over to the new Tech III paradigm. \r\n\r\nSubsystem Skill Bonus: \r\n5% increased agility per level.\r\n',1400000,40,0,1,1,4800000.0000,1,1135,0),(30087,973,'Tengu Propulsion - Intercalated Nanofibers Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30088,957,'Tengu Propulsion - Gravitational Capacitor','This subsystem lowers the capacitor cost of warping and increases actual warp speed. With the influx of fullerene-based polymers and the discovery of Sleeper drone technology, the same fundamental principles once only sparingly employed in advance scout vessels such as Covert Ops and Interceptors could be re-applied to modular Tech III vessels. The Caldari are said to have been the first empire to benefit from reverse-engineering attempts aimed at producing these subsystems, something which the Gallente Federation\'s own scientists flatly deny.\r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n12.5% bonus to warp speed per level\r\r\n15% reduction in capacitor need when initiating warp per level\r\r\n',1400000,40,0,1,1,4800000.0000,1,1135,0),(30089,973,'Tengu Propulsion - Gravitational Capacitor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30090,957,'Tengu Propulsion - Fuel Catalyst','The ancient Sleeper race was known to have mastered various sustainable energy technologies including thermoelectric systems, which they usually built directly into a vessel\'s hull. Capsuleer reverse-engineers took little time to adapt salvaged versions of these Sleeper energy systems into their own modular Tech III vessel pieces. \r\n\r\nThanks to widespread demand in the Caldari transport industry, fuel catalyst systems were one of the first to be developed. Making full use of locally generated thermoelectric power, they are able to supplement the fuel needs of an afterburner. This process makes it possible to inject fuel in larger amounts for the same capacitor cost, offering pilots a significant boost to the velocity increase from afterburners.\r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to afterburner speed per level.\r\n',1400000,40,0,1,1,4800000.0000,1,1135,0),(30091,973,'Tengu Propulsion - Fuel Catalyst Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30092,957,'Tengu Propulsion - Interdiction Nullifier','Dubbed the  interdiction nullifier  by the Guristas, who suffered its first introduction on the battlefield, this subsystem grants a startling and unprecedented capability; an immunity to non-targeted interdiction such as mobile warp disruptors and interdiction spheres. \r\n\r\nThe origins of the first  nullifier  designs are shrouded in mystery, but the subsystem\'s initial production of is thought to have taken place soon after the wormhole openings, and well before the technology became widespread knowledge. Not long after the first Tengu were designed, the Caldari Navy intercepted emergency transmissions from Guristas fleets across Venal, Tenal and Vale of the Silent. All of the reports made mention of Loki-class vessels slipping past defensive deployments and into core Guristas territory despite all efforts to stop the ships or slow them down.  \r\n\r\nFollowing these reports, rumors spread that other groups began to discover and implement this extraordinary new technology, and yet of all the factions that leapt upon the opportunity, none were so eager or ruthless in their own race to capitalize as the independent capsuleer and pirate organizations that make the nullsec frontiers their home.  \r\n\r\nSubsystem Skill Bonus:\r\n5% increased agility per level\r\n\r\nRole Bonus:\r\nImmunity to non-targeted interdiction',1400000,40,0,1,1,4800000.0000,1,1135,0),(30093,973,'Tengu Propulsion - Interdiction Nullifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30096,957,'Proteus Propulsion - Wake Limiter','This subsystem limits the wake left behind by a starship\'s microwarpdrive, allowing a pilot to maintain a lowered signature radius while still moving at high speed. The underlying design is based on the same technology used by smaller Sleeper drones and empire-produced Interceptors. Although the engineering processes behind wake limiters have existed for quite some time in the empires, their application in modular subsystems has only become a possibility after fullerene polymers became more widely available.\r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n5% reduction in microwarpdrive signature radius penalty per level.',1400000,40,0,1,8,4800000.0000,1,1136,0),(30097,973,'Proteus Propulsion - Wake Limiter Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30098,957,'Proteus Propulsion - Localized Injectors','This subsystem uses molecular-level nanotubes to increase the combustive efficiency of afterburners. Fuel is injected locally in a far more effective and controllable manner, thereby reducing the draw on the capacitor system. Although the decrease in capacitor use is relatively modest, even minute enhancements at this level can mean the difference between victory and defeat.\r\n\r\nSubsystem Skill Bonus: \r\n15% reduction in afterburner and microwarpdrive capacitor consumption per level\r\n',1400000,40,0,1,8,4800000.0000,1,1136,0),(30099,973,'Proteus Propulsion - Localized Injectors Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30100,957,'Proteus Propulsion - Gravitational Capacitor','This subsystem lowers the capacitor cost of warping and increases actual warp speed. With the influx of fullerene-based polymers and the discovery of Sleeper drone technology, the same fundamental principles once only sparingly employed in advance scout vessels such as Covert Ops and Interceptors could be re-applied to modular Tech III vessels. Although the Caldari claim to have been the first to successfully reverse-engineer these subsystems, the Federation argues that they were the first to deliver the breakthrough. Despite the contention, neither party seems keen to publicize the research data necessary to back their respective claims.\r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n12.5% bonus to warp speed per level\r\r\n15% reduction in capacitor need when initiating warp per level\r\r\n',1400000,40,0,1,8,4800000.0000,1,1136,0),(30101,973,'Proteus Propulsion - Gravitational Capacitor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30102,957,'Proteus Propulsion - Interdiction Nullifier','Dubbed the  interdiction nullifier  by the Guristas, who suffered its first introduction on the battlefield, this subsystem grants a startling and unprecedented capability; an immunity to non-targeted interdiction such as mobile warp disruptors and interdiction spheres. \r\n\r\nThe origins of the first  nullifier  designs are shrouded in mystery, but the subsystem\'s initial production of is thought to have taken place soon after the wormhole openings, and well before the technology became widespread knowledge. Not long after the first Tengu were designed, the Caldari Navy intercepted emergency transmissions from Guristas fleets across Venal, Tenal and Vale of the Silent. All of the reports made mention of Loki-class vessels slipping past defensive deployments and into core Guristas territory despite all efforts to stop the ships or slow them down.  \r\n\r\nFollowing these reports, rumors spread that other groups began to discover and implement this extraordinary new technology, and yet of all the factions that leapt upon the opportunity, none were so eager or ruthless in their own race to capitalize as the independent capsuleer and pirate organizations that make the nullsec frontiers their home.  \r\n\r\nSubsystem Skill Bonus:\r\n5% increased agility per level\r\n\r\nRole Bonus:\r\nImmunity to non-targeted interdiction',1400000,40,0,1,8,4800000.0000,1,1136,0),(30103,973,'Proteus Propulsion - Interdiction Nullifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30106,957,'Loki Propulsion - Chassis Optimization','This subsystem exploits the latest technological advances afforded by discovery of the ancient Sleeper race\'s own designs. Optimizations made to the chassis allow for vast improvements to be made to a Loki\'s base velocity. Although the various layout optimizations sacrifice other options for propulsion customization, the flow-on effects from an increase in base velocity make it an attractive upgrade for those whose Tech III vessels are in need of an overall speed increase.\r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to max velocity per level.\r\n',1400000,40,0,1,2,4800000.0000,1,1137,0),(30107,973,'Loki Propulsion - Chassis Optimization Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30108,957,'Loki Propulsion - Intercalated Nanofibers','Constructed from hard yet lightweight fullerene polymers, these intercalated fibers boost the agility of a starship without compromising its structural resilience. Even though basic nanofibers have existed for hundreds of years, the integration of various Sleeper-based salvage and other polymers takes the technology to a completely new level of modularity. This has allowed the same centuries-old technology to be ported over to the new Tech III paradigm. \r\n\r\nSubsystem Skill Bonus: \r\n5% increased agility per level.\r\n',1400000,40,0,1,2,4800000.0000,1,1137,0),(30109,973,'Loki Propulsion - Intercalated Nanofibers Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30110,957,'Loki Propulsion - Fuel Catalyst','The ancient Sleeper race was known to have mastered various sustainable energy technologies including thermoelectric systems, which they usually built directly into a vessel\'s hull. Capsuleer reverse-engineers took little time to adapt salvaged versions of these Sleeper energy systems into their own modular Tech III vessel pieces. \r\n\r\nThanks to widespread demand in many Minmatar industries, fuel catalyst systems were one of the first to be developed. Making full use of locally generated thermoelectric power, they are able to partially meet the fuel needs of an afterburner. This process makes it possible to inject fuel in larger amounts for the same capacitor cost, offering pilots a significant boost to the velocity increase from afterburners. \r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to afterburner speed per level.\r\n',1400000,40,0,1,2,4800000.0000,1,1137,0),(30111,973,'Loki Propulsion - Fuel Catalyst Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30112,957,'Loki Propulsion - Interdiction Nullifier','Dubbed the  interdiction nullifier  by the Guristas, who suffered its first introduction on the battlefield, this subsystem grants a startling and unprecedented capability; an immunity to non-targeted interdiction such as mobile warp disruptors and interdiction spheres. \r\n\r\nThe origins of the first  nullifier  designs are shrouded in mystery, but the subsystem\'s initial production of is thought to have taken place soon after the wormhole openings, and well before the technology became widespread knowledge. Not long after the first Tengu were designed, the Caldari Navy intercepted emergency transmissions from Guristas fleets across Venal, Tenal and Vale of the Silent. All of the reports made mention of Loki-class vessels slipping past defensive deployments and into core Guristas territory despite all efforts to stop the ships or slow them down.  \r\n\r\nFollowing these reports, rumors spread that other groups began to discover and implement this extraordinary new technology, and yet of all the factions that leapt upon the opportunity, none were so eager or ruthless in their own race to capitalize as the independent capsuleer and pirate organizations that make the nullsec frontiers their home.  \r\n\r\nSubsystem Skill Bonus:\r\n5% increased agility per level\r\n\r\nRole Bonus:\r\nImmunity to non-targeted interdiction',1400000,40,0,1,2,4800000.0000,1,1137,0),(30113,973,'Loki Propulsion - Interdiction Nullifier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30117,956,'Legion Offensive - Drone Synthesis Projector','Sleeper drones, while completely devoid of modern shielding technology, are nonetheless sturdy, mainly due to their metallofullerene armor plating and hull composition. When drones are docked into this system, the projection system enhances their damage capabilities, both in absorbing and delivering damage, through the creation of a fullerene-based field around the drones.  \r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to medium energy turret capacitor use per level\r\n10% bonus to drone damage per level\r\n7.5% bonus to drone hitpoints per level',800000,40,0,1,4,4800000.0000,1,1130,0),(30118,956,'Legion Offensive - Assault Optimization','Originally a laser-based weapons system, Amarrian starship engineers were forced to seek alternative construction methods when several fatal flaws were discovered in their design. Khanid Innovations was quick to offer a missile-based solution that benefitted greatly from their years of experience working on Sacrilege cruisers. The reapplication of their previously successful technology was so fast and effective that the more traditional Amarrian engineers could do little but watch as the knowledge and consequent implementation of these new engineering methodologies proliferated across the cluster. \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n5% bonus to Heavy Assault missile damage per level\r\r\n5% bonus to Heavy, Heavy Assault and Rapid Light Missile Launcher rate of fire per level',800000,40,0,1,4,4800000.0000,1,1130,0),(30119,956,'Legion Offensive - Liquid Crystal Magnifiers','One of the many gems discovered amidst Sleeper technology was the creation of more efficient liquid crystal lenses. Amarr researchers have engineered these lenses to increase a laser\'s focus for longer stretches, both in distance and in timing, allowing a laser to reach farther targets with more efficiency of energy output. Additionally, the fullerene-infused lenses can generate higher temperatures and stronger, more damaging beams and pulses. \r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to medium energy turret capacitor use per level \r\n10% bonus to medium energy turret damage per level\r\n10% bonus to medium energy turret optimal range per level\r\n',800000,40,0,1,4,4800000.0000,1,1130,0),(30120,956,'Legion Offensive - Covert Reconfiguration','From the moment Strategic Cruisers became a reality, there were whispers amongst the scientific community about the potential for advances in cloaking technology. They remained that alone for the longest time, with few involved in the reverse-engineering process willing to share any news of their discoveries. Everyone knew that, should the technology ever become a reality, the capabilities of the new Strategic Cruisers would change overnight.\r\n\r\nThe Amarrians are suspected to have developed cloaking technology for the Legion around the same time as the first capsuleer designs began to surface. For almost a full week, Minmatar rebel camps deep inside Heimatar and Metropolis were subjected to ruthless guerilla attacks, almost unprecedented in their ferocity and viciousness.  Although initially confused by such a marked changed in their opponent\'s warfare philosophy, the Matari knew that each target had been a high profile objective for the Imperial Navy, and noted with deep suspicion how all of the squads had been spearheaded by Legions that could hit and fade with alarming ease. Few doubted who was behind the bloodshed. The Amarrians remained silent for the most part, the only official statement; that God\'s will had manifested itself in the heart of evil. \r\n\r\nSubsystem Skill Bonus:\r\n10% bonus to medium energy turret capacitor use per level\r\n\r\nRole Bonus:\r\n100% reduction in Cloaking Device CPU use\r\n\r\nNotes: Can fit covert ops cloaks and covert cynosural field generators. Cloak reactivation delay reduced to 5 seconds.',800000,40,0,1,4,4800000.0000,1,1130,0),(30122,956,'Tengu Offensive - Accelerated Ejection Bay','This missile launcher system was formed not from the missile bays of Sleeper drones, but from the direct-fire turrets and hardpoints salvaged from them instead. Adapting the underlying technology behind the drones\' rapid-firing turrets for their own missile systems, Caldari engineers have managed to revolutionize modular launching mechanisms, improving launch speed and kinetic warhead payloads. \r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n5% bonus to Kinetic Missile Damage per level\r\r\n7.5% bonus to Heavy, Heavy Assault and Rapid Light missile launcher rate of fire per level\r\r\n10% bonus to Heavy Missile and Heavy Assault missile velocity per level\r\r\n\r\r\n',800000,40,0,1,1,4800000.0000,1,1131,0),(30123,956,'Tengu Offensive - Rifling Launcher Pattern','An odd bit of technology garnered from the Sleepers is missile rifling, a method adapted from more primitive projectile technology. The launcher bays in this missile pattern contain long, microscopic grooves that spiral through the launcher and can fit any known missile shape. Once the missile is launched, these grooves give additional velocity and accuracy to the missile. Additionally, the shallow cuts contain wiring that enhances the missile\'s guidance system, creating another conduit for communication between ship, missile, and target.\r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n10% bonus to ECM target jammer strength per level\r\r\n5% bonus to Heavy Assault Launcher, Heavy Missile Launcher and Rapid Light Missile Launcher Rate of Fire per level\r\r\n',800000,40,0,1,1,4800000.0000,1,1131,0),(30124,956,'Tengu Offensive - Magnetic Infusion Basin','This subsystem serves as a specialized storage bin for a ship\'s hybrid ammo. The basin, however, also serves as a cyclotron, infusing the ammo with magnetic energy immediately before it is injected into the turret. The amplified ammo has an increased range and damage potential. \r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to medium hybrid turret damage per level\r\n20% bonus to medium hybrid turret optimal range per level',800000,40,0,1,1,4800000.0000,1,1131,0),(30125,956,'Tengu Offensive - Covert Reconfiguration','From the moment Strategic Cruisers became a reality, there were whispers amongst the scientific community about the potential for advances in cloaking technology. They remained that alone for the longest time, with few involved in the reverse engineering process willing to share any news of their discoveries. Everyone knew that, should the technology ever become a reality, the capabilities of the new Strategic Cruisers would change overnight.\r\r\n\r\r\nWhen some of the State\'s first cloaking subsystems were unveiled at a secure Caldari military complex, those select few spectators did not understand for a moment, the reason behind the comparatively underwhelming offense. When the first Tengu broke from its attack and vanished in front of hundreds of onlookers   not only from the field of battle, but from the system itself   the reasons behind a conservative weapons design suddenly became clear. \r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n5% bonus to missile launcher rate of fire per level\r\r\n\r\r\nRole Bonus:\r\r\n100% reduction in Cloaking Device CPU use\r\r\n\r\r\nNotes: Can fit covert ops cloaks and covert cynosural field generators. Cloak reactivation delay reduced to 5 seconds.',800000,40,0,1,1,4800000.0000,1,1131,0),(30127,956,'Proteus Offensive - Dissonic Encoding Platform','A unique application of fullerene material can be found in this platform, where vibrations from the metallic plating  transfer from turret to hybrid charge. Discharged ammo immersed in this dissonic frequency maintains its shape and velocity pattern once launched towards a target. However, upon impact, the ammo undulates in an unstable fashion, transfering the frequency to its target and thereby causing more damage.\r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to medium hybrid turret damage per level\r\n10% bonus to medium hybrid turret falloff per level\r\n7.5% bonus to medium hybrid turret tracking per level',800000,40,0,1,8,4800000.0000,1,1132,0),(30128,956,'Proteus Offensive - Hybrid Propulsion Armature','This complex armature is composed of fullerene composites and based upon the understood weapons mechanics of salvaged Sleeper drones. Gallente researchers have fused this technology with the emerging theories on magnetic resonance and microwarp capabilities to power the kinetic energy systems of hybrid turrets. With these mechanics in place, the propulsion armature creates an effective distribution module for hybrid charges, bolstering their damage output and their falloff range.\r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to medium hybrid turret damage per level \r\n10% bonus to medium hybrid turret falloff per level\r\n',800000,40,0,1,8,4800000.0000,1,1132,0),(30129,956,'Proteus Offensive - Drone Synthesis Projector','Sleeper drones, while completely devoid of modern shielding technology, are nonetheless sturdy, mainly due to their metallofullerene armor plating and hull composition. Most of these technological applications are for capsuleer vessels, but a few rogue Gallente firms have quietly created this bay for use with contemporary drones. When drones are docked into this system, the projection system enhances their damage capabilities, both in absorbing and delivering damage, through the creation of a fullerene-based field around the drones.  \r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to medium hybrid turret damage per level \r\n10% bonus to drone damage per level\r\n7.5% bonus to drone hitpoints per level\r\n',800000,40,0,1,8,4800000.0000,1,1132,0),(30130,956,'Proteus Offensive - Covert Reconfiguration','From the moment Strategic Cruisers became a reality, there were whispers amongst the scientific community about the potential for advances in cloaking technology. They remained that alone for the longest time, with few involved in the reverse engineering process willing to share any news of their discoveries. Everyone knew that, should the technology ever become a reality, the capabilities of the new Strategic Cruisers would change overnight.\r\r\n\r\r\nTo many Gallente and Caldari, the development of the Proteus covert reconfiguration signaled a repeat of the technological arms race that arose from the ashes of Crielere. Once again seeking a balance of power, and entirely convinced that the Caldari were attempting to reverse-engineer their own cloak-capable Strategic Cruisers, the Federation diverted immense resources to their research. Private firms and the largest of conglomerates all played a role in development, offering up prototype designs and speculative theories that collectively resulted in some of the first Covert-Capable Proteus produced. It is not known who, or what organization led the project. Nor is known when, or where, the first Covert Reconfigurations were deployed. If it had not been for capsuleers developing the same designs, most people would have remained oblivious to their existence, just the way the Federation would have preferred.\r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n5% bonus to medium hybrid turret damage per level\r\r\n\r\r\nRole Bonus:\r\r\n100% reduction in Cloaking Device CPU use\r\r\n\r\r\nNotes: Can fit covert ops cloaks and covert cynosural field generators. Cloak reactivation delay reduced to 5 seconds.',800000,40,0,1,8,4800000.0000,1,1132,0),(30132,956,'Loki Offensive - Turret Concurrence Registry','Increasing the tracking capabilities of projectile weaponry has never been an easy task, yet the introduction of Sleeper technology has made this job more achievable. This registry is based on the idea of concurrence, where firing mechanisms can recycle energy among multiple turret emissions. This recycled energy is not only sustainable, but more powerful as well, a marvel considering its normal power output relative to other turret systems. Projectile turrets can be modified to use this surplus power to not only augment projectile damage output, but also to make minute adjustments on the fly, offering increasing tracking speed and optimal range.\r\n\r\nSubsystem Skill Bonus: \r\n10% bonus to medium projectile turret damage per level \r\n10% bonus to medium projectile turret optimal range per level\r\n7.5% bonus to medium projectile turret tracking per level\r\n',800000,40,0,1,2,4800000.0000,1,1133,0),(30133,956,'Loki Offensive - Projectile Scoping Array','Scoping arrays were mostly out of fashion in recent ship design, but Sleeper technology has brought them somewhat back into vogue. Based upon the remarkable flexibility fullerene-based technology, Sleeper-based scoping arrays allowed projectile weaponry to produce longer-ranged accuracy without reducing the weapon\'s rate-of-fire. While a resurgence of scoping arrays is not expected, this subsystem certainly shows its uses in modern warfare.\r\n\r\nSubsystem Skill Bonus: \r\n7.5% bonus to medium projectile turret rate of fire per level\r\n10% bonus to medium projectile falloff per level.\r\n',800000,40,0,1,2,4800000.0000,1,1133,0),(30134,956,'Loki Offensive - Hardpoint Efficiency Configuration','Adaptation and innovation go hand-in-hand, and this subsystem is a prime example of both ideas. While researching Sleeper drone weapon systems, a group of Minmatar engineers discovered special similarities to the technology behind all Sleeper weapon types. Distilling the underlying mechanic to its essence produced this hardpoint configuration, which enabled projectile weapons and missile launchers to share power sources and energy supplies (most of which were advanced beyond modern standards). This offers a vast increase to the rate of fire of both weapon types. Attempts to merge this technology to other weapon groups have, as yet, proven unsuccessful.\r\r\n\r\r\nSubsystem Skill Bonus: \r\r\n7.5% bonus to medium projectile turret rate of fire per level\r\r\n7.5% bonus to Heavy, Heavy Assault and Rapid Light Missile Launcher rate of fire per level\r\r\n',800000,40,0,1,2,4800000.0000,1,1133,0),(30135,956,'Loki Offensive - Covert Reconfiguration','From the moment Strategic Cruisers became a reality, there were whispers amongst the scientific community about the potential for advances in cloaking technology. They remained that alone for the longest time, with few involved in the reverse engineering process willing to share any news of their discoveries. Everyone knew that, should the technology ever become a reality, the capabilities of the new Strategic Cruisers would change overnight.    \r\r\n\r\r\nThe Loki\'s Covert Reconfiguration designs arose out of a collective will to respond to what was thought to be Amarrian aggression deep inside their home regions. Unlike many scientific and technological breakthroughs, it was not the Sebiestor tribe alone who ushered in the paradigm shift to covert-capable Strategic Cruisers. It was only through consultation and collaboration with many other tribes and sub-factions that something substantial began to take shape. \r\r\n\r\r\nThe Krusual and Thukker are said to have played the most important roles, however, in realizing the final design; the Thukker by providing the cloaking technology, and the Krusual by convincing them to do so. How they achieved this, or what they may have promised remains a secret; the two tribes are notorious for having many, and keeping them all.\r\r\n\r\r\nSubsystem Skill Bonus:\r\r\n5% bonus to medium projectile turret rate of fire per level\r\r\n\r\r\nRole Bonus:\r\r\n100% reduction in Cloaking Device CPU use\r\r\n\r\r\nNotes: Can fit covert ops cloaks and covert cynosural field generators. Cloak reactivation delay reduced to 5 seconds.',800000,40,0,1,2,4800000.0000,1,1133,0),(30139,958,'Tengu Engineering - Power Core Multiplier','Comprised of countless nanomachines that enhance the energy flow from a ship\'s reactor core, this engineering subsystem offers a pilot the option of increasing the power grid of their vessel. Although the empires mastered energy grid upgrades many centuries ago, the adaptation of old designs to the new Tech III paradigm has been a more recent breakthrough. \r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to power output per level.\r\n',1200000,40,0,1,1,4800000.0000,1,1123,0),(30140,973,'Tengu Engineering - Power Core Multiplier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30141,958,'Tengu Engineering - Augmented Capacitor Reservoir','Another example of an old technology re-worked to fit the new Tech III paradigm, augmented capacitor subsystems improve upon the size of a vessel\'s capacitor. Designers of Tech III vessels were initially hampered by the problem of how to design a modular ship that could swap out basic engineering upgrades on a per-need basis. This proved particularly true when it came to increasing a vessel\'s capacitor size without the use of batteries. In the end, the provision of fullerene-based polymers allowed for solutions that had only existed in theory up until that point. \r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to capacitor capacity per level.\r\n',1200000,40,0,1,1,4800000.0000,1,1123,0),(30142,973,'Tengu Engineering - Augmented Capacitor Reservoir Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30143,958,'Tengu Engineering - Capacitor Regeneration Matrix','Using the same technology that can be found inside the ancient Sleeper race\'s guardian drones, this regeneration matrix greatly improves the recharge rate of a Tech III vessel\'s capacitor. Even though empire-based designs have achieved this effect for centuries, the way in which this system works is markedly different.  \r\n\r\nRather than the usual tweaking of capacitor fluid formulas, this design simply triples the number of nanotubes inside   something not possible until the recent influx of fullerene polymers from which this subsystem is made. This results in a drastic increase in the speed and efficiency of energy flow throughout a ship. The quicker that the surplus power can be redirected back to the core, the more that it can contribute to the overall recharge rate of the capacitor.\r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to capacitor recharge time per level.\r\n',1200000,40,0,1,1,4800000.0000,1,1123,0),(30144,973,'Tengu Engineering - Capacitor Regeneration Matrix Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30145,958,'Tengu Engineering - Supplemental Coolant Injector','When it came to overheating modules on Tech III vessels, the spaceship engineering industry always knew, or at the very least suspected, that a larger breakthrough was on its way. Those first small advances made by reverse-engineering ancient Sleeper hulls were seen by many as simply the beginning of something greater. For these and other reasons, few were surprised by the introduction of a subsystem focused purely on pushing the  heat  envelope. \r\n\r\nVarious designs surfaced in the weeks and months following the opening of the new wormholes, each offering increasingly smaller improvements on the last. Research seemed to stagnate for a while and it was not until the idea of additional, localized coolant injectors became widespread that heat-focused subsystems truly began to perform in a class of their own. The current iterations offer pilots truly unprecedented abilities when it comes to overheating and pushing modules to their limits. Military experts and even capsuleers alike have been left wondering just how drastically this new design, along with so many other radical new entries to the subsystems field, will reshape interstellar warfare.   \r\n\r\nSubsystem Skill Bonus:\r\n5% Reduction in the amount of heat damage absorbed by modules per level. ',1200000,40,0,1,1,4800000.0000,1,1123,0),(30146,973,'Tengu Engineering - Supplemental Coolant Injector Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30149,958,'Proteus Engineering - Power Core Multiplier','Comprised of countless nanomachines that enhance the energy flow from a ship\'s reactor core, this engineering subsystem offers a pilot the option of increasing the power grid of their vessel. Although the empires mastered energy grid upgrades many centuries ago, the adaptation of old designs to the new Tech III paradigm has been a more recent breakthrough. \r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to power output per level.\r\n',1200000,40,0,1,8,4800000.0000,1,1124,0),(30150,973,'Proteus Engineering - Power Core Multiplier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30151,958,'Proteus Engineering - Augmented Capacitor Reservoir','Another example of an old technology re-worked to fit the new Tech III paradigm, augmented capacitor subsystems redirect large segments of the capacitor to power other modules. In this case, reverse engineers have redesigned the ship\'s power flow to augment the systems responsible for microwarpdrive capacitor injection and drone control. Collectively, they combine to allow for a greater overall MWD speed, and increased resilience of a pilot\'s drones.\r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to drone MWD speed per level \r\n7.5% bonus to drone hitpoints per level\r\n',1200000,40,0,1,8,4800000.0000,1,1124,0),(30152,973,'Proteus Engineering - Augmented Capacitor Reservoir Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30153,958,'Proteus Engineering - Capacitor Regeneration Matrix','Using the same technology that can be found inside the ancient Sleeper race\'s guardian drones, this regeneration matrix greatly improves the recharge rate and size of a Tech III vessel\'s capacitor. Even though empire-based designs have achieved this effect for centuries, the way in which this system works is markedly different. \r\n\r\nRather than the usual tweaking of capacitor fluid formulas, this design simply triples the number of nanotubes inside   something not possible until the recent influx of fullerene polymers from which this subsystem is made. The end result is a drastic increase in the speed and efficiency of energy flow throughout a ship, as well as a much larger surface area, which allows for above average capacitor size. The faster that the surplus power can be redirected back to the core, the more that it can contribute to the overall recharge rate of the capacitor. \r\n\r\nSubsystem Skill Bonus:\r\n5% Reduction to capacitor recharge time per level.',1200000,40,0,1,8,4800000.0000,1,1124,0),(30154,973,'Proteus Engineering - Capacitor Regeneration Matrix Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30155,958,'Proteus Engineering - Supplemental Coolant Injector','When it came to overheating modules on Tech III vessels, the spaceship engineering industry always knew, or at the very least suspected, that a larger breakthrough was on its way. Those first small advances made by reverse-engineering ancient Sleeper hulls were seen by many as simply the beginning of something greater. For these and other reasons, few were surprised by the introduction of a subsystem focused purely on pushing the  heat  envelope. \r\n\r\nVarious designs surfaced in the weeks and months following the opening of the new wormholes, each offering increasingly smaller improvements on the last. Research seemed to stagnate for a while and it was not until the idea of additional, localized coolant injectors became widespread that heat-focused subsystems truly began to perform in a class of their own. The current iterations offer pilots truly unprecedented abilities when it comes to overheating and pushing modules to their limits. Military experts and even capsuleers alike have been left wondering just how drastically this new design, along with so many other radical new entries to the subsystems field, will reshape interstellar warfare.   \r\n\r\nSubsystem Skill Bonus:\r\n5% Reduction in the amount of heat damage absorbed by modules per level. ',1200000,40,0,1,8,4800000.0000,1,1124,0),(30156,973,'Proteus Engineering - Supplemental Coolant Injector Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30159,958,'Loki Engineering - Power Core Multiplier','Comprised of countless nanomachines that enhance the energy flow from a ship\'s reactor core, this engineering subsystem offers a pilot the option of increasing the power grid of their vessel. Although the empires mastered energy grid upgrades many centuries ago, the adaptation of old designs to the new Tech III paradigm has been a more recent breakthrough. \r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to power output per level.\r\n',1200000,40,0,1,2,4800000.0000,1,1125,0),(30160,973,'Loki Engineering - Power Core Multiplier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30161,958,'Loki Engineering - Augmented Capacitor Reservoir','Another example of an old technology re-worked to fit the new Tech III paradigm, augmented capacitor subsystems improve upon the size of a vessel\'s capacitor. Designers of Tech III vessels were initially hampered by the problem of how to design a modular ship that could swap out basic engineering upgrades on a per-need basis. This proved particularly true when it came to increasing a vessel\'s capacitor size without the use of batteries. In the end, the provision of fullerene-based polymers allowed for solutions that had only existed in theory up until that point. \r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to capacitor capacity per level.\r\n',1200000,40,0,1,2,4800000.0000,1,1125,0),(30162,973,'Loki Engineering - Augmented Capacitor Reservoir Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30163,958,'Loki Engineering - Capacitor Regeneration Matrix','Using the same technology that can be found inside the ancient Sleeper race\'s guardian drones, this regeneration matrix greatly improves the recharge rate of a Tech III vessel\'s capacitor. Even though empire-based designs have achieved this effect for centuries, the way in which this system works is markedly different. \r\n\r\nRather than the usual tweaking of capacitor fluid formulas, this design simply triples the number of nanotubes inside   something not possible until the recent influx of fullerene polymers from which this subsystem is made. This results in a drastic increase in the speed and efficiency of energy flow throughout a ship. The quicker that the surplus power can be redirected back to the core, the more that it can contribute to the overall recharge rate of the capacitor.\r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to capacitor recharge time per level.\r\n',1200000,40,0,1,2,4800000.0000,1,1125,0),(30164,973,'Loki Engineering - Capacitor Regeneration Matrix Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30165,958,'Loki Engineering - Supplemental Coolant Injector','When it came to overheating modules on Tech III vessels, the spaceship engineering industry always knew, or at the very least suspected, that a larger breakthrough was on its way. Those first small advances made by reverse-engineering ancient Sleeper hulls were seen by many as simply the beginning of something greater. For these and other reasons, few were surprised by the introduction of a subsystem focused purely on pushing the  heat  envelope. \r\n\r\nVarious designs surfaced in the weeks and months following the opening of the new wormholes, each offering increasingly smaller improvements on the last. Research seemed to stagnate for a while and it was not until the idea of additional, localized coolant injectors became widespread that heat-focused subsystems truly began to perform in a class of their own. The current iterations offer pilots truly unprecedented abilities when it comes to overheating and pushing modules to their limits. Military experts and even capsuleers alike have been left wondering just how drastically this new design, along with so many other radical new entries to the subsystems field, will reshape interstellar warfare.   \r\n\r\nSubsystem Skill Bonus:\r\n5% Reduction in the amount of heat damage absorbed by modules per level. ',1200000,40,0,1,2,4800000.0000,1,1125,0),(30166,973,'Loki Engineering - Supplemental Coolant Injector Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30169,958,'Legion Engineering - Power Core Multiplier','Comprised of countless nanomachines that enhance the energy flow from a ship\'s reactor core, this engineering subsystem offers a pilot the option of increasing the power grid of their vessel. Although the empires mastered energy grid upgrades many centuries ago, the adaptation of old designs to the new Tech III paradigm has been a more recent breakthrough.\r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to power output per level.\r\n',1200000,40,0,1,4,4800000.0000,1,1122,0),(30170,973,'Legion Engineering - Power Core Multiplier Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30171,958,'Legion Engineering - Augmented Capacitor Reservoir','Another example of an old technology re-worked to fit the new Tech III paradigm, augmented capacitor subsystems improve upon the size of a vessel\'s capacitor. Designers of Tech III vessels were initially hampered by the problem of how to design a modular ship that could swap out basic engineering upgrades on a per-need basis. This proved particularly true when it came to increasing a vessel\'s capacitor size without the use of batteries. In the end, the provision of fullerene-based polymers allowed for solutions that had only existed in theory up until that point.\r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to capacitor capacity per level.\r\n',1200000,40,0,1,4,4800000.0000,1,1122,0),(30172,973,'Legion Engineering - Augmented Capacitor Reservoir Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30173,958,'Legion Engineering - Capacitor Regeneration Matrix','Using the same technology that can be found inside the ancient Sleeper race\'s guardian drones, this regeneration matrix greatly improves the recharge rate of a Tech III vessel\'s capacitor. Even though empire-based designs have achieved this effect for centuries, the way in which this system works is markedly different. \r\n\r\nRather than the usual tweaking of capacitor fluid formulas, this design simply triples the number of nanotubes inside   something not possible until the recent influx of fullerene polymers from which this subsystem is made. This results in a drastic increase in the speed and efficiency of energy flow throughout a ship. The quicker that the surplus power can be redirected back to the core, the more that it can contribute to the overall recharge rate of the capacitor.\r\n\r\nSubsystem Skill Bonus: \r\n5% bonus to capacitor recharge time per level.\r\n',1200000,40,0,1,4,4800000.0000,1,1122,0),(30174,973,'Legion Engineering - Capacitor Regeneration Matrix Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30175,958,'Legion Engineering - Supplemental Coolant Injector','When it came to overheating modules on Tech III vessels, the spaceship engineering industry always knew, or at the very least suspected, that a larger breakthrough was on its way. Those first small advances made by reverse-engineering ancient Sleeper hulls were seen by many as simply the beginning of something greater. For these and other reasons, few were surprised by the introduction of a subsystem focused purely on pushing the  heat  envelope. \r\n\r\nVarious designs surfaced in the weeks and months following the opening of the new wormholes, each offering increasingly smaller improvements on the last. Research seemed to stagnate for a while and it was not until the idea of additional, localized coolant injectors became widespread that heat-focused subsystems truly began to perform in a class of their own. The current iterations offer pilots truly unprecedented abilities when it comes to overheating and pushing modules to their limits. Military experts and even capsuleers alike have been left wondering just how drastically this new design, along with so many other radical new entries to the subsystems field, will reshape interstellar warfare.   \r\n\r\nSubsystem Skill Bonus:\r\n5% Reduction in the amount of heat damage absorbed by modules per level. ',1200000,40,0,1,4,4800000.0000,1,1122,0),(30176,973,'Legion Engineering - Supplemental Coolant Injector Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30182,283,'Serpentis Informant','This is a Serpentis officer. Well, ex-officer. He has agreed to turn himself in to authorities and give them information on the Serpentis in exchange for their protection. Maybe he grew a conscience and decided to give up the life of crime. <p>\r\r\n\r\r\nHowever, it\'s more likely he made someone bigger than him angry, and the only way to save his own skin was to give himself up. Who says there\'s honor among thieves?',80,1,0,1,NULL,0.0000,1,NULL,0),(30187,971,'Intact Thruster Sections','Even after millennia of exposure to space, these thruster sections show barely any signs of mechanical wear and appear to be completely functional. The modular design of Sleeper propulsion systems is similar to that of the empires, but deviates in a few interesting areas. \r\r\n\r\r\nPristine, working examples of Sleeper technology such as this are extremely rare and even more valuable. With the right skills and equipment, they can offer great insights into the scientific pursuits of the ancient race that designed them. ',0,10,0,1,NULL,0.0000,1,1909,0),(30188,983,'Sleepless Patroller','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30189,983,'Sleepless Watchman','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30190,983,'Sleepless Escort','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30191,983,'Sleepless Outguard','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30192,982,'Sleepless Defender','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30193,982,'Sleepless Upholder','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30194,982,'Sleepless Preserver','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30195,982,'Sleepless Safeguard','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30196,959,'Sleepless Sentinel','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30197,959,'Sleepless Keeper','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30198,959,'Sleepless Warden','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30199,959,'Sleepless Guardian','An abundance of repair seams in this Sleeper drone\'s armor tell the story of millennia spent on duty, protecting the same unchanging area. The drone moves about with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',19000000,19000000,120,1,64,0.0000,0,NULL,0),(30200,985,'Awakened Patroller','The design of this Sleeper drone echoes what is believed to be the very earliest Sleeper Starships, suggesting it was perhaps constructed during that period too. Contrasting with its possible age is the unspoiled condition of its armor, suggesting that if it is indeed as ancient as its designers, it has only very recently been put into service. ',10900000,109000,120,1,64,0.0000,0,NULL,0),(30201,985,'Awakened Watchman','The design of this Sleeper drone echoes what is believed to be the very earliest Sleeper Starships, suggesting it was perhaps constructed during that period too. Contrasting with its possible age is the unspoiled condition of its armor, suggesting that if it is indeed as ancient as its designers, it has only very recently been put into service. ',10900000,109000,120,1,64,0.0000,0,NULL,0),(30202,985,'Awakened Escort','The design of this Sleeper drone echoes what is believed to be the very earliest Sleeper Starships, suggesting it was perhaps constructed during that period too. Contrasting with its possible age is the unspoiled condition of its armor, suggesting that if it is indeed as ancient as its designers, it has only very recently been put into service. ',10900000,109000,120,1,64,0.0000,0,NULL,0),(30203,984,'Awakened Defender','The design of this Sleeper drone echoes what is believed to be the very earliest Sleeper Starships, suggesting it was perhaps constructed during that period too. Contrasting with its possible age is the unspoiled condition of its armor, suggesting that if it is indeed as ancient as its designers, it has only very recently been put into service. ',10900000,109000,120,1,64,0.0000,0,NULL,0),(30204,984,'Awakened Upholder','The design of this Sleeper drone echoes what is believed to be the very earliest Sleeper Starships, suggesting it was perhaps constructed during that period too. Contrasting with its possible age is the unspoiled condition of its armor, suggesting that if it is indeed as ancient as its designers, it has only very recently been put into service. ',10900000,109000,120,1,64,0.0000,0,NULL,0),(30205,984,'Awakened Preserver','The design of this Sleeper drone echoes what is believed to be the very earliest Sleeper Starships, suggesting it was perhaps constructed during that period too. Contrasting with its possible age is the unspoiled condition of its armor, suggesting that if it is indeed as ancient as its designers, it has only very recently been put into service. ',10900000,109000,120,1,64,0.0000,0,NULL,0),(30206,960,'Awakened Sentinel','The design of this Sleeper drone echoes what is believed to be the very earliest Sleeper Starships, suggesting it was perhaps constructed during that period too. Contrasting with its possible age is the unspoiled condition of its armor, suggesting that if it is indeed as ancient as its designers, it has only very recently been put into service. ',10900000,109000,120,1,64,0.0000,0,NULL,0),(30207,960,'Awakened Keeper','The design of this Sleeper drone echoes what is believed to be the very earliest Sleeper Starships, suggesting it was perhaps constructed during that period too. Contrasting with its possible age is the unspoiled condition of its armor, suggesting that if it is indeed as ancient as its designers, it has only very recently been put into service. ',10900000,109000,120,1,64,0.0000,0,NULL,0),(30208,960,'Awakened Warden','The design of this Sleeper drone echoes what is believed to be the very earliest Sleeper Starships, suggesting it was perhaps constructed during that period too. Contrasting with its possible age is the unspoiled condition of its armor, suggesting that if it is indeed as ancient as its designers, it has only very recently been put into service. ',10900000,109000,120,1,64,0.0000,0,NULL,0),(30209,987,'Emergent Patroller','The pristine condition of this Sleeper drone\'s armor suggests it has only recently been activated, perhaps even newly-manufactured . Even though it appears to be a relative newcomer to the swarm, there is little questioning that it bears the same deadly technology as its more elderly and experienced kin.',1910000,19100,120,1,64,0.0000,0,NULL,0),(30210,987,'Emergent Watchman','The pristine condition of this Sleeper drone\'s armor suggests it has only recently been activated, perhaps even newly-manufactured . Even though it appears to be a relative newcomer to the swarm, there is little questioning that it bears the same deadly technology as its more elderly and experienced kin.',1910000,19100,120,1,64,0.0000,0,NULL,0),(30211,987,'Emergent Escort','The pristine condition of this Sleeper drone\'s armor suggests it has only recently been activated, perhaps even newly-manufactured . Even though it appears to be a relative newcomer to the swarm, there is little questioning that it bears the same deadly technology as its more elderly and experienced kin.',1910000,19100,120,1,64,0.0000,0,NULL,0),(30212,986,'Emergent Defender','The pristine condition of this Sleeper drone\'s armor suggests it has only recently been activated, perhaps even newly-manufactured . Even though it appears to be a relative newcomer to the swarm, there is little questioning that it bears the same deadly technology as its more elderly and experienced kin.',1910000,19100,120,1,64,0.0000,0,NULL,0),(30213,986,'Emergent Upholder','The pristine condition of this Sleeper drone\'s armor suggests it has only recently been activated, perhaps even newly-manufactured . Even though it appears to be a relative newcomer to the swarm, there is little questioning that it bears the same deadly technology as its more elderly and experienced kin.',1910000,19100,120,1,64,0.0000,0,NULL,0),(30214,986,'Emergent Preserver','The pristine condition of this Sleeper drone\'s armor suggests it has only recently been activated, perhaps even newly-manufactured . Even though it appears to be a relative newcomer to the swarm, there is little questioning that it bears the same deadly technology as its more elderly and experienced kin.',1910000,19100,120,1,64,0.0000,0,NULL,0),(30215,961,'Emergent Sentinel','The pristine condition of this Sleeper drone\'s armor suggests it has only recently been activated, perhaps even newly-manufactured . Even though it appears to be a relative newcomer to the swarm, there is little questioning that it bears the same deadly technology as its more elderly and experienced kin.',1910000,19100,120,1,64,0.0000,0,NULL,0),(30216,961,'Emergent Keeper','The pristine condition of this Sleeper drone\'s armor suggests it has only recently been activated, perhaps even newly-manufactured . Even though it appears to be a relative newcomer to the swarm, there is little questioning that it bears the same deadly technology as its more elderly and experienced kin.',1910000,19100,120,1,64,0.0000,0,NULL,0),(30217,961,'Emergent Warden','The pristine condition of this Sleeper drone\'s armor suggests it has only recently been activated, perhaps even newly-manufactured . Even though it appears to be a relative newcomer to the swarm, there is little questioning that it bears the same deadly technology as its more elderly and experienced kin.',1910000,19100,120,1,64,0.0000,0,NULL,0),(30221,500,'Snowball CXIV',' ',100,0.1,0,100,NULL,0.0000,1,1663,0),(30222,976,'Melted Snowball CX','This snowball used to be bigger than your head. Now it is just a puddle of water. Onoes.',100,1,0,100,NULL,0.0000,1,1663,0),(30223,353,'QA Mega Module','This module does not exist.',1,1,0,1,NULL,100000.0000,0,NULL,0),(30227,973,'Legion Defensive - Adaptive Augmenter Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30228,973,'Legion Defensive - Nanobot Injector Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30229,973,'Legion Defensive - Augmented Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30230,973,'Legion Defensive - Warfare Processor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30232,973,'Tengu Defensive - Adaptive Shielding Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30233,973,'Tengu Defensive - Amplification Node Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30234,973,'Tengu Defensive - Supplemental Screening Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30235,973,'Tengu Defensive - Warfare Processor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30237,973,'Proteus Defensive - Adaptive Augmenter Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30238,973,'Proteus Defensive - Nanobot Injector Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30239,973,'Proteus Defensive - Augmented Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30240,973,'Proteus Defensive - Warfare Processor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30242,973,'Loki Defensive - Adaptive Shielding Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30243,973,'Loki Defensive - Adaptive Augmenter Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30244,973,'Loki Defensive - Amplification Node Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30245,973,'Loki Defensive - Warfare Processor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30247,967,'Standalone Warfare Processor','A strange piece of equipment recovered from a Sleeper drone. ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30248,966,'Emergent Combat Analyzer','This combat analyzer appears to use the same fundamental programming as standard Empire-issue technology, although it operates at a much higher level of efficiency. These devices are typically employed in fleets where they provide predictive analyses of complex battle scenarios and supplement other combat electronics that handle smaller elements. \r\r\n\r\r\nCombat analyzers are best employed in tasks such as calculating a fleet\'s success rate, running comparative analyses between fleets and other similarly abstract problem-solving tasks requiring higher levels of heuristic programming. Even though the equipment has been badly damaged, the core functionality remains intact. With a skilled programmer and a talented mechanic, it could be re-integrated into a starship.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30249,967,'Nanoassembler Ligaments','Designed in eerily organic ligament-like formations, these nanoassemblers are still fully operational. With the addition of a few other components and some reprogramming, they could be repurposed for use in defensive systems. ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30250,967,'Nanoelectromechanical Sheets','Only a few millimeters thick, these sheets of fullerene alloys are able to store and generate power in small amounts, supplementing the capacitor of a ship and offering local power to nanoassemblers. They work best when integrated into armor plating around power core and repair systems. ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30251,966,'Neurovisual Input Matrix','Used in conjunction with other equipment inside the capsule, neurovisual input matrices serve the vital function of translating external stimuli into visual data. Ship identifier tags, hostile threat indicators and tactical overlay interfaces are all typical examples of N.I.M at work. The Sleeper variants of these matrices are not substantively different from contemporary devices, needing only a few supplemental components and some minor reprogramming before they can operate in much the same way. The only major deviation is in the energy efficiency. The Sleeper device is almost a thousand times less demanding on a ship\'s power core.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30252,966,'Thermoelectric Catalysts','These tiny nanomachines have been injected into the thermoelectric power core at the heart of the Sleeper drone. Inside each one is a small array of chemicals and components, all of which play a role in producing the often violent chemical reactions that provide power to the drones. Only the most advanced Sleeper drones are known to have had their power cores enhanced in this way. \r\r\n\r\r\nEven though they all share the same fundamental role, thousands of minor variations in the machines that have emerged after millennia of use, as they adapted to the minute changes in chemical composition and electrical flux. How exactly they came to do this remains a mystery, but it is clear that the current product is the result of countless iterations. \r\r\n\r\r\nAlthough salvaged easily enough, they have been built from the ground up to be integrated into other Sleeper technology. Trying to enhance any engineering systems outside of the Sleeper\'s own thermoelectric power cores with the current level of technology would represent an impossible reverse-engineering task.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30253,967,'generic item 5','This white, dusty substance was extracted from the centre of high impact craters in the Sleeper drone\'s armor. When mixed with other materials it forms a stiff resin that can either be used to hold various pieces of hull sheets together or to coat them for additional protection against radiation and heat. ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30254,966,'Electromechanical Hull Sheeting','These ultra-thin nanoplastic sheets are resilient enough to survive the explosion of the Sleeper drones that carry them. The molecular-level circuitry inside them can be encased in layers of protective fullerene alloys that are billions of times their size, allowing electronics systems to be safely embedded just beneath the armor surface.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30255,967,'Thermal Diffusion Film','Normally synthesized at great cost, small amounts of this film are also able to be removed from the outer layers of a Sleeper drone\'s armor. When combined with other materials it has the capability to spread thermal damage out across the hull, cooling it quickly, thus minimize the incoming damage from heat-based weaponry. \r\r\n',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30256,967,'Generic Hull Salvage 4','Interface Circuits are common building blocks of starship subsystems.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30257,967,'Generic Hull Salvage 5','An \"Aphid\" logic circuit. The nickname is derived from the unfortunate acronym of autonomous field programmable holographic signal processor with embedded holographic data storage.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30258,966,'Resonance Calibration Matrix','RCM play an important role in stabilizing a ship\'s alignment prior to, and in the first moments of, interstellar warp. The Sleeper drone RCM system works in an entirely different manner to contemporary Empire-based technology and yet the angles of alignment produced by their final calculations are always identical. Even though their inner workings remain a mystery, the matrices operate in a predictable and reliable enough fashion to form the basis of a new, slightly more efficient jump drive.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30259,966,'Melted Nanoribbons','Most of these tiny circuits have fused together from the heat and force of the Sleeper drone\'s explosion. The detonation of the drone\'s power core must have been immense to have had such an effect on these resilient nanostructures.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30260,967,'Ruined Scraps 3','A slightly damaged but still seemingly usable capacitor console. Capacitor consoles are a necessary component of starship capacitor units.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30261,967,'Ruined Scraps 4','The Micro Circuit is one of the most common electronics components seen in use.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30262,967,'Intact Coolant Regulator','A soup of nanite assemblers typically used in armor manufacturing processes.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30263,967,'Intact Particle Emitter','Your average run-of-the-mill closed loop electrical network with redundant autonomous switchgear.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30264,967,'Intact Field Harmonic Regulator','Power Conduit runs through ships delivering energy like arteries deliver blood through a body. Large ships can have hundreds of miles of conduit.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30265,967,'Intact Sleeper AI Control Core','An expert system used in the construction of missile launchers. This one has been damaged by fire or an explosion.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30266,967,'Intact Secondary Power Couples','This Thermonuclear Trigger Unit while smashed still seems to have it\'s nuclei containment field intact and the plasma seems to be near thermal equilibrium. It would be a shame to waste this unit just because of its cosmetic damage.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30267,967,'Intact Plasma Conduit','Power Conduit runs through ships delivering energy like arteries deliver blood through a body. Large ships can have hundreds of miles of conduit. This conduit is tangled and knotted as it seems to have gone through some sort of catastrophe.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30268,966,'Jump Drive Control Nexus','Barely salvageable from the wreck of a Sleeper drone, this device could have been something much more impressive when it was fully functional. In its current state it is almost unrecognizable, having been scratched, burned and even chemically melted. It looks like it was housed next to the drone\'s power core, which would explain the extreme heat damage it suffered when the drone exploded. \r\r\n\r\r\nStranger yet, it almost seems as if it was lined with some kind of triggered-release corrosive. The self-destruct mechanism   if that\'s even what it was   only caused so much damage, and the acid didn\'t burn cleanly through the center of the drive. \r\r\n\r\r\nEven as a shadow of its former self, it can be combined with other components to form a fully functional warp drive. Being capable of this, even in such a bad state, strongly suggests that the device was capable of other types of more advanced interstellar travel. Why a Sleeper drone was equipped with this level of technology remains a mystery.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30269,966,'Defensive Control Node','A rudimentary analysis of this device reveals an amazingly broad potential for the manipulation of nanomachines, allowing the user to reprogram them for numerous roles. The Sleeper defensive systems were so modular that, even though this particular node was designed to coordinate armor-repairing nanoassemblers, it could just as easily be reconfigured for shield defense.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30270,966,'Central System Controller','Still fully intact and operational, this device stands as a testament to the ancient Sleeper\'s impressive scientific achievements. Although thousands of years old, the technology inside it is not only comparable to modern electronic designs, but in some cases even exceeds it. \r\r\n\r\r\nCentral system controllers lie at the heart of a starship\'s electronics systems. They are responsible for coordinating the flow of information between various analyzers and control nodes, monitoring subsystems, and ensuring they receive the appropriate supply of electrical power. Tackling such complex tasks simultaneously (and with near-zero latency) demands immense processing power and faultless, error-free programming. Traditionally, a CSC would comprise a significant portion of the cost in a starship\'s electronics systems, but the fullerene-based Sleeper designs have provided breakthroughs in the efficiency of circuitry and presented new and improved methods for increasing computational accuracy. The end result is a drastically reduced cost for top-of-the-line performance. \r\r\n',0,0.01,0,1,NULL,0.0000,1,1862,0),(30271,966,'Emergent Combat Intelligence','Although emergent systems are not fully-fledged Artificial Intelligences, they are often so advanced that they can border on sentience. The means by which they are created is also a common source for claims that they are in fact, full-blown AIs. Emergent system development is said to have been an early focal point in Jovian software design, where they hoped to create an atmosphere in which an advanced system could self-assemble its own consciousness and thus  emerge  as a sentient being. What became of these projects remains unknown, although the Jovians appear to have abandoned these pursuits many millennia ago in favor of something more tangible and containable.  \r\r\n\r\r\nDesigned from the ground up to perform complex, real-time combat calculations such as weapon tracking and heat optimization, this device shows the signatures of an emergent intelligence. Despite this, various hard limitations have been encoded into the device at the most fundamental level, greatly limiting its potential to evolve any further. Even in its current state though, it represents some of the most advanced combat electronics ever built. Although nothing about the software is in itself revolutionary, it is able to tackle highly complex tasks with a frightening level of speed and efficiency.',0,0.01,0,1,NULL,0.0000,1,1862,0),(30272,967,'Sleeper Ward Console','The control unit for a starships shield systems.',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30273,319,'Abandoned Sleeper Enclave','Imposing in its majesty, this giant dome stands as a testament to the technological might of the ancient Sleeper race. Even millennia old, the innumerable electronics systems within are still comparable to contemporary technology, in some cases even exceeding it. The distinctive hub-like design of this particular structure suggests that it operated as some kind of central data nexus, a shining capital amongst a digital metropolis. \r\r\n\r\r\nThis Enclave is heavily damaged from thousands of years in the unforgiving solitude of space. The only signs of life within are weak electronic signals.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30274,319,'Eroded Sleeper Thermoelectric Converter','After countless years in space, this structure is showing some signs of age. A brief analysis of the semi-functional technology inside reveals that it operates as some kind of auxiliary power source for other structures. Erosion in one of the armor panels exposes a small internal hangar bay, perhaps used as a docking port to power the Sleeper\'s automated drones.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30275,319,'Exposed Sleeper Interlink Hub','Distinctively Sleeper in design, this structure served as an information hub, linking various data sources with one another. Although countless years in the harsh environments of space have rendered its defenses all but non-existent, the structure continues to relay information back and forth, oblivious to its own vulnerability.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30276,319,'Crippled Sleeper Preservation Conduit','Tiny windows looking out into space offer a glimpse past this structure\'s once-impressive armor plating and through to the strange sights within. Barely visible in the dim light are rows upon rows of small chambers, stretching out endlessly inside the darkened hallways of this mammoth conduit. A myriad of connective wires interlace with giant pipelines, all of them broken or badly damaged. A strange electronic interference emanates from deep inside the facility, suggesting that perhaps not everything inside has fallen into disrepair.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30277,319,'Malfunctioning Sleeper Multiplex Forwarder','The Sleeper Multiplex Forwarder may have been responsible for transferring data between various Sleeper facilities. Hundreds of years in space have taken their toll, however, and brief scans of the structure show only miniscule amounts of electronic activity.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30278,319,'Decrepit Talocan Outpost Core','Centuries of emptiness have left this Talocan outpost\'s central hub in disarray, but the chambers and corridors inside portray a busy (if very spartan) existence. Advanced technology mingles with rustic repairs and patchwork assemblages. Some of the technology is ancient and very rudimentary in design, harkening back to cultures long gone, yet with hints of familiarity. Much of the interior is in shambles, and the outer hull is breached in several areas, leaving the outpost core teetering on the edge of total destruction. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30279,319,'Collapsed Talocan Observation Dome','Large windows and telescoping turrets peer out into the surrounding darkness. The windows of this dome are cracked and the roof partially collapsed, but the empty eyes of the Talocan observation dome always appears to be staring, despite the absence of its original occupants. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30280,319,'Offline Talocan Reactor Spire','The Spire\'s mechanical infrastructure suggests that it was once used for generating power and harvesting electricity. However, the design resembles a combination of different styles, many of them reminiscent of modern power stations. Despite many attempts, the internal generators won\'t start working, and the spire is now utterly offline, just another mass of debris in space. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30293,226,'Sleeper Preservation Conduit','Tiny windows looking out into space offer a glimpse past this structure\'s impressive armor plating and through to the strange sights within. Barely visible in the dim light are rows upon rows of small chambers, stretching out endlessly inside the darkened hallways of this mammoth conduit. A myriad of connective wires interlace with giant pipelines, feeding into every area of the facility. Although they can be seen coiling up through the foundations, the compounds they are ferrying remain a mystery.\r\r\n\r\r\nA strange electronic interference emanates from deep within, pulsing randomly every few seconds.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30294,226,'Talocan Observation Dome','Large windows and telescoping turrets peer out into the surrounding darkness. The Talocan observation dome always appears to be staring, despite the absence of its original occupants.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30295,226,'Talocan Outpost Core','Centuries of emptiness have left this Talocan outpost\'s central hub in disarray, but the chambers and corridors inside portray a busy (if very spartan) existence. Advanced technology mingles with rustic repairs and patchwork assemblages. Some of the technology is ancient and very rudimentary in design, harkening back to cultures long gone, yet with hints of familiarity.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30298,226,'Talocan Reactor Spire','Centuries of emptiness have left this Talocan outpost\'s central hub in disarray, but the chambers and corridors inside portray a busy (if very spartan) existence. Advanced technology mingles with rustic repairs and patchwork assemblages. Some of the technology is ancient and very rudimentary in design, harkening back to cultures long gone, yet with hints of familiarity.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30299,226,'Sleeper Enclave','Imposing in its majesty, this giant dome stands as a testament to the technological might of the ancient Sleeper race. Even millennia old, the innumerable electronics systems within are still comparable to contemporary technology, in some cases even exceeding it. The distinctive hub-like design of this particular structure suggests that it operated as some kind of central data nexus, a shining capital amongst a digital metropolis.\r\r\n\r\r\nAlthough entirely functional and intact, the only signs of life within are electrical currents and the eerily constant transfers of data.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30300,226,'Sleeper Thermoelectric Converter','Despite countless years in space, this structure appears to be entirely functional. A brief analysis of the technology inside reveals that it operates as some kind of central power source for other Sleeper facilities. Faint seams in the rigid armor suggest it may even house a docking port to power the Sleeper\'s automated drones.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30301,226,'Sleeper Multiplex Forwarder','The Sleeper Multiplex Forwarder was built as a massive router for transferring electronic data between various Sleeper facilities. Although enclosed in super-resilient metal alloys, the size of the data cables suggests that it is capable of transmitting extraordinary amounts of information.  ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30302,226,'Sleeper Interlink Hub','Distinctively Sleeper in design, this structure operates as an information hub, linking up various data sources with one another. An extraordinarily resilient superstructure guards the flow of information inside from any disruption.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30303,974,'Fulleroferrocene','Fulleroferrocene is a rare organometallic compound used to strengthen and supplement other materials. Most commonly, it is used to improve the structural integrity of metal alloys, but research is continuing on its potential applications in nanomechanical devices.',0,0.1,0,1,NULL,0.0000,1,1860,0),(30304,974,'PPD Fullerene Fibers','The discovery of these microscopic, tubular structures has helped pave new paths in the construction of advanced starships. Known for their unrivaled strength-to-weight ratio, composite metals made of unique PPD fullerene fibers have become the standard for defensive plating. Atomic-scale, nanomechanical systems used inside repair modules often employ fullerene fibers as well.',0,0.5,0,1,NULL,0.0000,1,1860,0),(30305,974,'Fullerene Intercalated Graphite','Originally this material was only used in the construction of advanced semiconductors, a role in which it still performs admirably. In recent years, however, structural engineers have proven that it has even better applications in nano-electromechanical systems. The unique  superlubricity    a state of zero or near-zero friction   between mechanical components made of F.I.G significantly limits wear, allowing the tiny devices to operate for exceptionally long periods without the need for maintenance.',0,0.8,0,1,4,0.0000,1,1860,0),(30306,974,'Methanofullerene','One of the most useful organic semiconductors discovered in recent years, methanofullerene can be blended with other polymers to create incredibly efficient solar cells, offering a near-endless source of power in places that would otherwise be difficult to supply.',0,0.75,0,1,NULL,0.0000,1,1860,0),(30307,974,'Lanthanum Metallofullerene','This fullerene-lanthanum compound is made by encasing a single lanthanum atom in a cage of carbon atoms. The incredibly high melting point of lanthanum compounds make them ideal for the construction of offensive hardpoints, where heat dissipation is critical to keeping weapons systems operating effectively.',0,1,0,1,NULL,0.0000,1,1860,0),(30308,974,'Scandium Metallofullerene','A fullerene-scandium compound made by encasing a single scandium atom in a cage of carbon atoms. Scandium is a grey-white element that has historically been incredibly hard to find. Scandium-tipped missiles were once valued for their armor-piercing qualities, which allowed them to wreck havoc deep inside starship hulls. The only thing holding the weapons industry back from these and other similar applications has been the low supply of the material.',0,0.65,0,1,NULL,0.0000,1,1860,0),(30309,974,'Graphene Nanoribbons','Single-walled nanotubes such as these have been at the forefront of advanced electronics production for centuries. The nanoribbons make for some of the best, and smallest, conductors in the world, offering scientists new ways forward in the miniaturization of electronics systems.',0,1.5,0,1,NULL,0.0000,1,1860,0),(30310,974,'Carbon-86 Epoxy Resin','C-86 epoxy resin is most commonly applied as a thin film to the structures housing propulsion systems. The tremendous flame-retardant properties of materials covered in the resin help prevent heat buildup and minimize onboard fires.',0,0.4,0,1,NULL,0.0000,1,1860,0),(30311,974,'C3-FTM Acid','Difficult to procure and expensive to create, this rare chemical compound plays an important role as a neuroprotective agent for capsule pilots. It is integrated into the life-support systems on board a capsuleer\'s vessel, where it helps limit brain cell death and neurodegeneration.',0,0.2,0,1,NULL,0.0000,1,1860,0),(30312,967,'Nanotori Polymers','Nanotori are carbon nanotubes bent into rings. The final product and its application vary drastically depending on the angle at which the tubes were rolled and the radius of the circle they created. For this reason, nanotori can be found in anything from metal alloys to insulators and semiconductors.',0,5,0,1,NULL,0.0000,0,NULL,0),(30313,967,'Nanobud Polymers','A combination of carbon nanotubes and other fullerenes, nanobuds have the unique properties of both materials, making them useful in the construction of advanced electronics as well as ultra-hard metal alloys.',0,5,0,1,NULL,0.0000,0,NULL,0),(30314,967,'Fullero-Ferrocene','Fulleroferrocene is a rare organometallic compound used to strengthen and supplement other materials. Most commonly, it is used to improve the structural integrity of metal alloys, but research is continuing on its potential applications in nanomechanical devices.',0,5,0,1,NULL,0.0000,0,NULL,0),(30315,967,'generic item 6','C-86 Epoxy Resin is most commonly applied as a thin film to the structures housing propulsion systems. The tremendous flame-retardant properties of materials covered in the resin help prevent heat buildup and improve internal combustive efficiency.',0,5,0,1,NULL,0.0000,0,NULL,0),(30316,967,'Polyfullerene Condensate','This mixture of fullerene condensates is most commonly used to line gas storage tanks on starships. The unique qualities of the liquid provide increased thermal efficiency and reduced the risk of combustive malfunctions.',0,5,0,1,NULL,0.0000,0,NULL,0),(30317,967,'generic item 4','The discovery of these microscopic tubular structures has helped pave new paths in the construction of advanced starships. Known for their unrivalled strength-to-weight ratio, composite metals made of unique PPD fullerene fibers have become the standard for defensive plating. Atomic-scale nanomechanical systems used inside repair modules often employ fullerene fibers as well.',0,5,0,1,NULL,0.0000,0,NULL,0),(30318,967,'Plutonium Metallofullerene','A fullerene-plutonium compound made by encasing a single plutonium atom in a cage of carbon atoms. Scientists originally envisaged this compound as a useful substance for non-applied research, but when the huge explosive potential of loosely-packed plutonium atoms inside a rigid fullerene cage was discovered, what little material there was quickly disappeared into the research labs of weapons manufacturers.',0,5,0,1,NULL,0.0000,0,NULL,0),(30319,967,'Polymer 17',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(30320,967,'Polymer 18',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(30321,967,'Polymer 19',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(30322,967,'Polymer 20',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(30324,270,'Defensive Subsystem Technology','Understanding of the technology used to create advanced defensive subsystems.',0,0.01,0,1,NULL,10000000.0000,1,375,0),(30325,270,'Engineering Subsystem Technology','Understanding of the technology used to create advanced engineering subsystems.',0,0.01,0,1,NULL,10000000.0000,1,375,0),(30326,270,'Electronic Subsystem Technology','Understanding of the technology used to create advanced electronic subsystems.',0,0.01,0,1,NULL,10000000.0000,1,375,0),(30327,270,'Offensive Subsystem Technology','Understanding of the technology used to create advanced offensive subsystems.',0,0.01,0,1,NULL,10000000.0000,1,375,0),(30328,65,'Civilian Stasis Webifier','Reduces the maximum speed of a ship by employing micro energy streams which effectively entangle the target temporarily, thereby slowing it down.',0,5,0,1,NULL,468.0000,1,683,0),(30329,145,'Civilian Stasis Webifier Blueprint',' ',0,0.01,0,1,4,224880.0000,1,1570,0),(30342,77,'Civilian Thermic Dissipation Field','Boosts shield resistance against thermal damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,20,0,1,NULL,802.0000,1,1692,0),(30343,157,'Civilian Thermic Dissipation Field Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1548,0),(30344,977,'Fulleroferrocene Reaction',' ',0,1,0,1,NULL,15000000.0000,1,1854,0),(30345,977,'PPD Fullerene Fibers Reaction',' ',0,1,0,1,NULL,15000000.0000,1,1854,0),(30346,977,'Fullerene Intercalated Graphite Reaction',' ',0,1,0,1,NULL,15000000.0000,1,1854,0),(30347,882,'defunct reaction 4',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(30348,977,'Lanthanum Metallofullerene Reaction',' ',0,1,0,1,NULL,15000000.0000,1,1854,0),(30349,977,'Scandium Metallofullerene Reaction',' ',0,1,0,1,NULL,15000000.0000,1,1854,0),(30350,977,'Graphene Nanoribbons Reaction',' ',0,1,0,1,NULL,15000000.0000,1,1854,0),(30351,977,'Carbon-86 Epoxy Resin Reaction',' ',0,1,0,1,NULL,15000000.0000,1,1854,0),(30352,977,'C3-FTM Acid Reaction',' ',0,1,0,1,NULL,15000000.0000,1,1854,0),(30353,882,'defunct reaction 3',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(30354,882,'defunct reaction 2',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(30355,882,'defunct reaction 1',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(30356,882,'defunct reaction 6',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(30357,882,'defunct reaction 7',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(30358,882,'defunct reaction 5',' ',0,1,0,1,NULL,0.0000,0,NULL,0),(30365,286,'Webber Drone','These webifier drones were developed by the Gallentean research and development firm CreoDron, who are renowned across the cluster for high quality drone manufacture. The patent was sold to all of the other empires early after the rise of the capsuleer. Since that time, these and other similar drones have seen use in various training programs, most usually focused on familiarizing a pilot with advanced combat techniques such as, in this case, dealing with Stasis Webification on the battlefield. ',3500,250,235,1,NULL,0.0000,0,NULL,0),(30366,286,'Runner Drone','These Runner drones were first engineered by Serpentis scientists, who originally used them as forward scouts in systems bordering Gallentean space. Over time, Federation Navy scouts discovered their presence and soon enough, reverse-engineered their own variants. Since then, these and other similar drones have seen use in various training programs, most usually focused on familiarizing a pilot with advanced combat techniques on the battlefield. ',3500,250,235,1,NULL,0.0000,0,NULL,0),(30368,977,'Methanofullerene Reaction',' ',0,1,0,1,NULL,15000000.0000,1,1854,0),(30369,286,'Angel Rookie','This is a fighter for the Angel Cartel. It is protecting the assets of the Angel Cartel and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2112000,21120,100,1,2,0.0000,0,NULL,0),(30370,711,'Fullerite-C50','Fullerite is the solid-state manifestation of fullerene molecules and can be found naturally occurring within interstellar gas clouds. Fullerites are coveted for the unique structural properties that make them some of the most useful materials known to humankind. Fullerene-based technology has applications in electronics, propulsion and engineering as well as the construction of ultra-hard metal alloys and heat-resistant weapons systems.\r\r\n\r\r\nAlthough all of the empires have developed a rudimentary understanding of how to manipulate fullerene, only the Jovians are known to have mastered the science. This has allowed them to maintain a significant technological advantage over other races in many crucial areas. ',0,1,0,1,NULL,0.0000,1,1859,0),(30371,711,'Fullerite-C60','Fullerite is the solid-state manifestation of fullerene molecules and can be found naturally occurring within interstellar gas clouds. Fullerites are coveted for the unique structural properties that make them some of the most useful materials known to humankind. Fullerene-based technology has applications in electronics, propulsion and engineering as well as the construction of ultra-hard metal alloys and heat-resistant weapons systems.\r\r\n\r\r\nAlthough all of the empires have developed a rudimentary understanding of how to manipulate fullerene, only the Jovians are known to have mastered the science. This has allowed them to maintain a significant technological advantage over other races in many crucial areas. ',0,1,0,1,NULL,0.0000,1,1859,0),(30372,711,'Fullerite-C70','Fullerite is the solid-state manifestation of fullerene molecules and can be found naturally occurring within interstellar gas clouds. Fullerites are coveted for the unique structural properties that make them some of the most useful materials known to humankind. Fullerene-based technology has applications in electronics, propulsion and engineering as well as the construction of ultra-hard metal alloys and heat-resistant weapons systems.\r\r\n\r\r\nAlthough all of the empires have developed a rudimentary understanding of how to manipulate fullerene, only the Jovians are known to have mastered the science. This has allowed them to maintain a significant technological advantage over other races in many crucial areas. ',0,1,0,1,NULL,0.0000,1,1859,0),(30373,711,'Fullerite-C72','Fullerite is the solid-state manifestation of fullerene molecules and can be found naturally occurring within interstellar gas clouds. Fullerites are coveted for the unique structural properties that make them some of the most useful materials known to humankind. Fullerene-based technology has applications in electronics, propulsion and engineering as well as the construction of ultra-hard metal alloys and heat-resistant weapons systems. \r\r\n\r\r\nAlthough all of the empires have developed a rudimentary understanding of how to manipulate fullerene, only the Jovians are known to have mastered the science. This has allowed them to maintain a significant technological advantage over other races in many crucial areas. ',0,2,0,1,NULL,0.0000,1,1859,0),(30374,711,'Fullerite-C84','Fullerite is the solid-state manifestation of fullerene molecules and can be found naturally occurring within interstellar gas clouds. Fullerites are coveted for the unique structural properties that make them some of the most useful materials known to humankind. Fullerene-based technology has applications in electronics, propulsion and engineering as well as the construction of ultra-hard metal alloys and heat-resistant weapons systems. \r\r\n\r\r\nAlthough all of the empires have developed a rudimentary understanding of how to manipulate fullerene, only the Jovians are known to have mastered the science. This has allowed them to maintain a significant technological advantage over other races in many crucial areas. ',0,2,0,1,NULL,0.0000,1,1859,0),(30375,711,'Fullerite-C28','Fullerite is the solid-state manifestation of fullerene molecules and can be found naturally occurring within interstellar gas clouds. Fullerites are coveted for the unique structural properties that make them some of the most useful materials known to humankind. Fullerene-based technology has applications in electronics, propulsion and engineering as well as the construction of ultra-hard metal alloys and heat-resistant weapons systems.\r\r\n\r\r\nAlthough all of the empires have developed a rudimentary understanding of how to manipulate fullerene, only the Jovians are known to have mastered the science. This has allowed them to maintain a significant technological advantage over other races in many crucial areas.',0,2,0,1,NULL,0.0000,1,1859,0),(30376,711,'Fullerite-C32','Fullerite is the solid-state manifestation of fullerene molecules and can be found naturally occurring within interstellar gas clouds. Fullerites are coveted for the unique structural properties that make them some of the most useful materials known to humankind. Fullerene-based technology has applications in electronics, propulsion and engineering as well as the construction of ultra-hard metal alloys and heat-resistant weapons systems.\r\r\n\r\r\nAlthough all of the empires have developed a rudimentary understanding of how to manipulate fullerene, only the Jovians are known to have mastered the science. This has allowed them to maintain a significant technological advantage over other races in many crucial areas. ',0,5,0,1,NULL,0.0000,1,1859,0),(30377,711,'Fullerite-C320','Fullerite is the solid-state manifestation of fullerene molecules and can be found naturally occurring within interstellar gas clouds. Fullerites are coveted for the unique structural properties that make them some of the most useful materials known to humankind. Fullerene-based technology has applications in electronics, propulsion and engineering as well as the construction of ultra-hard metal alloys and heat-resistant weapons systems.\r\r\n\r\r\nAlthough all of the empires have developed a rudimentary understanding of how to manipulate fullerene, only the Jovians are known to have mastered the science. This has allowed them to maintain a significant technological advantage over other races in many crucial areas. ',0,5,0,1,NULL,0.0000,1,1859,0),(30378,711,'Fullerite-C540','Fullerite is the solid-state manifestation of fullerene molecules and can be found naturally occurring within interstellar gas clouds. Fullerites are coveted for the unique structural properties that make them some of the most useful materials known to humankind. Fullerene-based technology has applications in electronics, propulsion and engineering as well as the construction of ultra-hard metal alloys and heat-resistant weapons systems. \r\r\n\r\r\nAlthough all of the empires have developed a rudimentary understanding of how to manipulate fullerene, only the Jovians are known to have mastered the science. This has allowed them to maintain a significant technological advantage over other races in many crucial areas. ',0,10,0,1,NULL,0.0000,1,1859,0),(30379,286,'Blood Raider Rookie','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2810000,28100,120,1,4,0.0000,0,NULL,0),(30380,286,'Guristas Rookie','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',1500100,15001,45,1,1,0.0000,0,NULL,0),(30381,286,'Serpentis Rookie','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Very low',2450000,24500,60,1,8,0.0000,0,NULL,0),(30382,979,'Amarr Subsystems Data Interface','This data interface allows the integration of ancient technology with Amarr systems.\r\r\n\r\r\nUsed for Reverse Engineering jobs.',1,1,0,1,4,0.0000,1,NULL,0),(30383,979,'Caldari Subsystems Data Interface','This data interface allows the integration of ancient technology with Caldari systems.\r\r\n\r\r\nUsed for Reverse Engineering jobs.',1,1,0,1,1,0.0000,1,NULL,0),(30384,979,'Minmatar Subsystems Data Interface','This data interface allows the integration of ancient technology with Minmatar systems.\r\r\n\r\r\nUsed for Reverse Engineering jobs.',1,1,0,1,2,0.0000,1,NULL,0),(30385,979,'Gallente Subsystems Data Interface','This data interface allows the integration of ancient technology with Gallente systems.\r\r\n\r\r\nUsed for Reverse Engineering jobs.',1,1,0,1,8,0.0000,1,NULL,0),(30386,716,'R.Db.- Hybrid Technology','The Hybrid Technology database is a special item designed to integrate ancient technology with the technological specifications of the four empires.',0,1,0,1,NULL,0.0000,1,NULL,0),(30387,356,'R.Db.- Hybrid Technology Blueprint',' ',0,0.01,0,1,NULL,0.0000,0,NULL,0),(30388,226,'Arena_GA_MainStructure01',' ',2000,2000,0,1,8,0.0000,0,NULL,0),(30389,397,'Subsystem Assembly Array','A mobile assembly facility where advanced subsystems and hulls of strategic cruisers can be manufactured. This structure has no specific time or material requirement bonuses to subsystem manufacturing.\r\r\n\r\r\nNote: Tech III hulls cannot be assembled at starbase structures.  The hulls and subsystems can only be assembled whilst docked in a station.',200000000,17000,2000000,1,NULL,100000000.0000,1,932,0),(30391,920,'Omni Effect Beacon','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30392,973,'Legion Offensive - Drone Synthesis Projector Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30393,973,'Legion Offensive - Assault Optimization Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30394,973,'Legion Offensive - Liquid Crystal Magnifiers Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30395,973,'Legion Offensive - Covert Reconfiguration Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30397,973,'Tengu Offensive - Accelerated Ejection Bay Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30398,973,'Tengu Offensive - Rifling Launcher Pattern Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30399,973,'Tengu Offensive - Magnetic Infusion Basin Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30400,973,'Tengu Offensive - Covert Reconfiguration Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30402,973,'Proteus Offensive - Dissonic Encoding Platform Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30403,973,'Proteus Offensive - Hybrid Propulsion Armature Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30404,973,'Proteus Offensive - Drone Synthesis Projector Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30405,973,'Proteus Offensive - Covert Reconfiguration Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30407,973,'Loki Offensive - Turret Concurrence Registry Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30408,973,'Loki Offensive - Projectile Scoping Array Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30409,973,'Loki Offensive - Hardpoint Efficiency Configuration Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30410,973,'Loki Offensive - Covert Reconfiguration Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(30412,226,'Caldari Arena MainStructure','A main structure for CA combat simulator',0,0,0,1,1,0.0000,0,NULL,0),(30413,226,'Arena_GA_SmallStructure01',' ',2000,2000,0,1,8,0.0000,0,NULL,0),(30414,226,'Caldari Arena SmallStructure',' ',0,0,0,1,1,0.0000,0,NULL,0),(30416,226,'Arena_GA_CenterFX01',' ',0,0,0,1,8,0.0000,0,NULL,0),(30419,226,'Caldari Arena CenterPiece',' ',0,0,0,1,1,0.0000,0,NULL,0),(30420,77,'Civilian EM Ward Field','Boosts shield resistance against EM damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,20,0,1,NULL,802.0000,1,1695,0),(30421,157,'Civilian EM Ward Field Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1548,0),(30422,77,'Civilian Explosive Deflection Field','Boosts shield resistance against explosive damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance.',10000,20,0,1,NULL,802.0000,1,1694,0),(30423,157,'Civilian Explosive Deflection Field Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1548,0),(30424,77,'Civilian Kinetic Deflection Field','Boosts shield resistance against kinetic damage.<br><br>Penalty: Using more than one type of this module, or similar modules that affect the same resistance type, will result in a penalty to the boost you get on that type of resistance',10000,20,0,1,NULL,802.0000,1,1693,0),(30425,157,'Civilian Kinetic Deflection Field Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1548,0),(30426,386,'Phantasmata Missile','Cruise missile used by Sleeper battleships.',1250,0.05,0,100,NULL,7500.0000,0,NULL,0),(30428,385,'Praedormitan Missile','Heavy missile used by Sleeper cruisers.',1000,0.03,0,100,NULL,2000.0000,0,NULL,0),(30430,384,'Oneiric Missile','Heavy missile used by Sleeper frigates.',700,0.015,0,100,NULL,370.0000,0,NULL,0),(30434,226,'Arena_MM_CenterPiece01',' ',0,0,0,1,2,0.0000,0,NULL,0),(30435,226,'Arena_GA_CenterPiece01',' ',0,0,0,1,8,0.0000,0,NULL,0),(30436,226,'Infested Lookout Ruins',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(30439,226,'mobilestorage',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(30440,226,'RedCloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(30444,226,'Comet - Fire Comet Copy','Comet',1e35,20,0,250,NULL,3068504.0000,0,NULL,0),(30446,226,'Comet - Dark Comet Copy','Comet',1e35,20,0,250,NULL,3068504.0000,0,NULL,0),(30447,226,'Comet - Gold Comet Copy','Comet',1e35,20,0,250,NULL,3068504.0000,0,NULL,0),(30448,226,'Comet - Toxic Comet Copy','Comet',1e35,20,0,250,NULL,3068504.0000,0,NULL,0),(30449,226,'Gas Cloud 1 Copy',' ',10,100,0,200,NULL,0.0000,0,NULL,0),(30451,226,'Arena_AM_CenterPiece01',' ',0,0,0,1,4,0.0000,0,NULL,0),(30452,226,'Arena_AM_MainStructure01',' ',0,0,0,1,4,0.0000,0,NULL,0),(30453,226,'Arena_MM_MainStructure01',' ',0,0,0,1,2,0.0000,0,NULL,0),(30454,226,'Arena_AM_CenterFX01',' ',0,0,0,1,4,0.0000,0,NULL,0),(30455,226,'Arena_AM_SmallStructure01',' ',0,0,0,1,4,0.0000,0,NULL,0),(30456,226,'Arena_MM_SmallStructure01',' ',0,0,0,1,2,0.0000,0,NULL,0),(30457,186,'Sleeper Small Advanced Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30458,186,'Sleeper Medium Advanced Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30459,186,'Sleeper Large Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30460,383,'Vigilant Sentry Tower','These fearsome sentry towers have remained the faithful and dangerous guardians of their sleeping masters, even after countless years of constant duty. As unpredictable as they are powerful, the towers have been expertly designed to provide lasting vigilance with an unquestioning, mechanical loyalty. The weapons systems on board are frighteningly precise and devastating upon impact.',1000,1000,1000,1,64,0.0000,0,NULL,0),(30461,383,'Wakeful Sentry Tower','These fearsome sentry towers have remained the faithful and dangerous guardians of their sleeping masters, even after countless years of constant duty. As unpredictable as they are powerful, the towers have been expertly designed to provide lasting vigilance with an unquestioning, mechanical loyalty. The weapons systems on board are frighteningly precise and devastating upon impact.',1000,1000,1000,1,64,0.0000,0,NULL,0),(30462,383,'Restless Sentry Tower','These fearsome sentry towers have remained the faithful and dangerous guardians of their sleeping masters, even after countless years of constant duty. As unpredictable as they are powerful, the towers have been expertly designed to provide lasting vigilance with an unquestioning, mechanical loyalty. The weapons systems on board are frighteningly precise and devastating upon impact.',1000,1000,1000,1,64,0.0000,0,NULL,0),(30464,964,'Metallofullerene Plating','Metallofullerene plating is used to protect the connective joins in hull and subsystem structures so that Tech III vessels can be taken apart and put back together endlessly, all without the risk of wear. Mechanical engineers first attempted to create the plating using plutonium metallofullerenes, but it was quickly discovered that even miniscule amounts of them had a sizeable impact on ship mass. When integrated into armor plating in larger amounts, they also risked turning the vessel into a giant warhead, something even less desirable. \r\r\n\r\r\nA solution was finally found. Tiny amounts of metallofullerenes would be integrated in conjunction with far larger quantities of graphene nanoribbons and then coated in powdered C-540 graphite. This process allowed the material to maintain structural durability whilst keeping mass down. The last and most ingenious addition was to incorporate fulleroferrocene into the metal beneath layers of electromechanical hull sheeting. This had the effect of turning the normally dangerous explosive reactions into kinetic energy, which could then be used to supplement the power supply to local nanoassemblers.',1,5,0,1,NULL,400000.0000,1,1147,0),(30465,965,'Metallofullerene Plating Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(30466,964,'Electromechanical Interface Nexus','When integrated into a starship with other components, an EMI Nexus is used to facilitate manual control over numerous electromechanical systems which, by default, run in an automated manner according to their programmed roles. Typically, the EMI Nexus acts as a conduit between a capsuleer and their ship, serving as an interface through which they can operate normally automated electromechanical systems, such as a Central System Controller. Other more simple tasks, such as the activation of a ship\'s modules, also frequently rely on these components.',1,10,0,1,NULL,400000.0000,1,1147,0),(30467,965,'Electromechanical Interface Nexus Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(30470,964,'Neurovisual Output Analyzer','As a capsuleer, few things are more important in space-flight than the ability to instantly gauge one\'s surroundings and make decisions accordingly. For this reason, capsules inside starships make frequent use of neurovisual reproductions; emulations that recreate external stimuli using the most low-latency processor available: the human brain. This process relies on digital relays from camera drones and monitoring systems embedded into the hull. After the data is captured, it is then relayed directly into the brain, at which point the external surrounds are recreated almost instantaneously.\r\r\n\r\r\nThe synthetic translation of external stimuli into neurovisual imagery is incredibly risky, even relative to the standard hazards of pod piloting. Even though capsuleers have an innate resistance to neurobiological damage from these sorts of processes, the near- constant exposure to them has been linked to increased risk of aggressive neurodegenerative diseases. In recent years, engineers have begun to integrate neurovisual output analyzers into a starship\'s electronics systems. These devices monitor the pilot\'s status and, if necessary, take measures to protect against anything from mild headaches to catastrophic neural failure.',1,5,0,1,NULL,400000.0000,1,1147,0),(30471,965,'Neurovisual Output Analyzer Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(30474,964,'Nanowire Composites','Nanowire composites function as connective links between subsystems. Graphene nanoribbons form the base of the components, carrying electrical power between other devices integrated into electromechanical hull sheets. A final coating of thermal diffusion film ensures efficient heat dispersion, allowing a starship captain to overload modules connected to subsystems without risking the entire vessel.',1,5,0,1,NULL,400000.0000,1,1147,0),(30475,965,'Nanowire Composites Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(30476,964,'Fulleroferrocene Power Conduits','These conduits supply power to minute, molecular-level devices. Extremely strong and yet surprising flexible, they have traditionally been used in rare situations where the normal methods of power supply were rendered impossible. The advent of Tech III starship technology and the influx of fullerene-based materials have seen the conduits take on new and more widespread roles. \r\r\n\r\r\nThe addition or removal of a single subsystem in a Tech III vessel can drastically change the ship\'s structure, and with it the internal wiring and available power supply routes.  Fulleroferrocene power conduits have become an essential component in the construction of these new vessels for this very reason. The conduits can be remapped through a ship with relative ease, allowing for the near-endless variations of subsystems to be completely interchangeable without posing any problems of how to power them.',1,5,0,1,NULL,400000.0000,1,1147,0),(30477,965,'Fulleroferrocene Power Conduits Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(30478,964,'Reconfigured Subspace Calibrator','Subspace calibrators perform the crucial role of tuning in on subspace frequencies. Being able to accurately pinpoint a destination on the other side of a wormhole is vital to interstellar travel, as it allows pilots to traverse wormholes safe in the knowledge that they won\'t accidentally arrive out the other side at the centre of a sun. \r\r\n\r\r\nThis particular calibrator was produced from a combination of fullerene polymers and salvaged Sleeper technology. The unique grouping enables some drastic reconfigurations to the basic design. The end result is a vastly increased efficiency in calculation time. Due to the modular design of Tech III vessels, tuning into subspace frequencies must be done individually for each subsystem. The development of this particular component has been an important time-saver in an area where mere seconds can mean life or death.',1,10,0,1,NULL,400000.0000,1,1147,0),(30479,965,'Reconfigured Subspace Calibrator Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1191,0),(30484,186,'Sleeper Small Basic Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30485,186,'Sleeper Small Intermediate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30486,479,'Sisters Combat Scanner Probe','A scanner probe used for scanning down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a>, starships, structures and drones.\r\r\n\r\r\nCan be launched from <a href=showinfo:18639>Expanded Probe Launchers</a>.',1,1,0,1,NULL,16358.0000,1,1199,0),(30488,479,'Sisters Core Scanner Probe','A scanner probe used for scanning down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a> in space.\r\r\n\r\r\nCan be launched from <a href=showinfo:17938>Core Probe Launchers</a> and <a href=showinfo:18639>Expanded Probe Launchers</a>.',1,0.1,0,1,NULL,4470.0000,1,1199,0),(30492,186,'Sleeper Medium Basic Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30493,186,'Sleeper Medium Intermediate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30494,186,'Sleeper Large Basic Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30495,186,'Sleeper Large Intermediate Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30496,186,'Sleeper Large Advanced Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30497,526,'Reinforced Metal Scraps','This mechanical hardware has obviously outlived its use, and is now ready to be recycled.  Many station maintenance departments use the material gained from recycling these scraps to manufacture steel plates which replace worn out existing plates in the station hull.  Most station managers consider this a cost-effective approach, rather than to send out a costly mining expedition for the ore, although these scraps rarely are enough to satisfy demand.\r\r\n\r\r\nThis commodity is not affected by the scrap metal processing skill any more than any other recyclable item.',10000,0.01,0,1,NULL,5000.0000,1,NULL,0),(30502,226,'Talocan Polestar','The central piece of this Talocan station is the Polestar, the nerve center of the complex and the heart of Talocan survival. Though dilapidated and unusable, the Polestar\'s outer hull holds many propulsion jets and mini-generators, implying its use as a self-sufficient structure with independent capabilities. From the burn marks around the propulsion thrusters, this Polestar has been jettisoned many times as a necessary structure for a migrant culture.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30503,226,'Talocan Coupling Array','The long capsules in the coupling array offer no hints as to their purpose. Archaeologists conjecture that the Array contained escape vessels, food bins, fuel resources or equipment for punishment. Some theories purport that all of the above are true.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30504,226,'Talocan Static Gate','This standing structure shares many similar aspects with modern acceleration gates. Whispers among Talocan lore-keepers tell of the Talocan\'s firm grasp of astronautical engineering, and this gate may offer some insight into this ancient race\'s knowledge.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30505,226,'Talocan Exchange Depot','Amidst the ruins of this Talocan outpost, the exchange depot looms, its presence foreboding. Judging from the wreckage inside, the depot was either used for imprisonment or cultural exchange; eerily, there seems to be very little difference between the two. Whatever its purpose, this structure is rather prevalent among the outposts, displaying its importance in Talocan society.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30506,226,'Talocan Extraction Silo','This towering structure contains all the basic elements of a regular silo: cavernous storage areas, thick walls, extensive ventilation, etc. Based on the scans of this silo, however, the silo\'s previous contents are unknown. The residue from inside reveals nothing known in modern times, or even odd genetic combinations. Whatever its contents, the silo emits an unfamiliar   and uneasy   presence.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30507,319,'Worn Talocan Static Gate','This standing structure shares many similar aspects with modern acceleration gates. Whispers among Talocan lore-keepers tell of the Talocan\'s firm grasp of astronautical engineering. This gate may offer some insight into this ancient race\'s knowledge, if only it could be fully repaired. Eons in space have worn the static gate completely down.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30508,319,'Inverted Talocan Exchange Depot','Amidst the ruins of this Talocan outpost, the exchange depot looms, its presence foreboding. Judging from the wreckage inside, the depot was either used for imprisonment or cultural exchange; eerily, there seems to be very little difference between the two. Whatever its purpose, this structure is rather prevalent among the outposts, displaying its importance in Talocan society.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30509,319,'Disrupted Talocan Polestar','The central piece of this Talocan station is the Polestar, the nerve center of the complex and the heart of Talocan survival. Though dilapidated and unusable, the Polestar\'s outer hull is breached in many parts. Its propulsion jets and mini-generators are destroyed and decaying. From the burn marks around the propulsion thrusters, this Polestar has been jettisoned many times as a necessary structure for a migrant culture, but in this condition the Polestar\'s current location will remain its last. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30510,319,'Broken Talocan Coupling Array','The long capsules in the coupling array offer no hints as to their purpose. Archaeologists conjecture that the Array contained escape vessels, food bins, fuel resources or equipment for punishment. Some theories purport that all of the above are true. Cracked and worn, the coupling array won\'t function as any of these, as its fragile frame is completely broken inside and out. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30511,319,'Hollow Talocan Extraction Silo','This towering structure contains all the basic elements of a regular silo: cavernous storage areas, thick walls, extensive ventilation, etc. Based on the scans of this silo, however, the silo\'s previous contents are unknown. The residue from inside reveals nothing known in modern times, or even odd genetic combinations. Whatever its contents, the silo emits an unfamiliar   and uneasy   presence.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30512,319,'Weakened Sleeper Drone Hangar','Clearly built to serve the needs of the Sleeper\'s automated defense drones, this ominous structure functions as one of their central docking points. The hangar\'s defensive capabilities have degraded over the millennia, leaving a thin outer shell that offers only token resistance to attack.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30513,226,'Sleeper Drone Hangar','Clearly built to serve the needs of the Sleeper\'s automated defense drones, this ominous structure functions as one of their central docking points. Despite its age, the facility shows few signs of decay, suggesting that it is perhaps maintained by its residents.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30514,226,'Talocan Wreckage','This appears to be the much-mangled remains of a Talocan vessel. It\'s too damaged to recover anything useful from',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30515,226,'Unidentified Wreckage','There\'s no telling what this used to be; now though it\'s definitely scrap',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30516,1207,'Malfunctioning Sleeper Databank','This databank has clearly been the site of a serious impact, but it remains online. You may be able to extract something with your Data Analyzer.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30517,1207,'Ejected Sleeper Databank','Ejected Sleeper Databank: This modular structure was long ago subjected to some sort of emergency ejection procedure, but you can detect an intact databank concealed under its heavy plating. You may be able to extract something with your Data Analyzer.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30518,1207,'Deformed Sleeper Databank','Deformed Sleeper Databank: This section of hull plating once shielded an auxiliary databank on its obverse. The databank has been exposed to space for some time now, but you may still be able to extract something with your Data Analyzer.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30519,1207,'Obsolete Sleeper Databank','Obsolete Sleeper Databank: This could once have been an airlock. Or an essential component of a ventilation system. Or some kind of stasis pod. Whatever it was, the only thing of value that remains is the databank you can detect concealed within.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30520,1207,'Broken Sleeper Databank','This object was severed from some larger structure in the distant past, perhaps as the result of an asteroid strike. Fortunately, a once-redundant power source has provided just enough energy to keep its databank operable. You may be able to extract something with your Data Analyzer.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30521,1207,'Spavined Sleeper Databank','This hull plate still has an unobstructed access point for the databank it holds. You may be able to extract something with your Data Analyzer.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30522,1207,'Forgotten Sleeper Artifact','Your analyzer is picking up something of interest in this piece of twisted wreckage, though you can\'t for the life of you see what it is.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30523,1207,'Lost Sleeper Artifact','You suspect this battered hunk of metal may conceal some kind of relic.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30524,1207,'Abandoned Sleeper Artifact','This might once have been an important piece of an engine, but now you\'re not getting anything out of it without the help of an analyzer.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30525,1207,'Sleeper Artifact','You think there might be something concealed here that an analyzer could discover.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30526,1207,'Decrepit Sleeper Artifact','This mangled sheet of hull plating contains something of interest to your analyzer.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30527,1207,'Forlorn Sleeper Artifact','Analysis could yield something valuable.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30528,1207,'Abandoned Talocan Battleship','It looks like this ship was gutted, then left to drift.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30529,1207,'Deserted Talocan Cruiser','It looks like this ship was gutted, then left to drift.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30530,1207,'Derelict Talocan Frigate','It looks like this ship was gutted, then left to drift.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30532,1240,'Amarr Defensive Systems','Skill in the operation of Amarr Defensive Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,5000000.0000,1,1824,0),(30536,1240,'Amarr Electronic Systems','Skill in the operation of Amarr Electronic Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,5000000.0000,1,1824,0),(30537,1240,'Amarr Offensive Systems','Skill in the operation of Amarr Offensive Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,5000000.0000,1,1824,0),(30538,1240,'Amarr Propulsion Systems','Skill in the operation of Amarr Propulsion Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,5000000.0000,1,1824,0),(30539,1240,'Amarr Engineering Systems','Skill in the operation of Amarr Engineering Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,5000000.0000,1,1824,0),(30540,1240,'Gallente Defensive Systems','Skill in the operation of Gallente Defensive Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30541,1240,'Gallente Electronic Systems','Skill in the operation of Gallente Electronic Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30542,1240,'Caldari Electronic Systems','Skill in the operation of Caldari Electronic Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30543,1240,'Minmatar Electronic Systems','Skill in the operation of Minmatar Electronic Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30544,1240,'Caldari Defensive Systems','Skill in the operation of Caldari Defensive Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30545,1240,'Minmatar Defensive Systems','Skill in the operation of Minmatar Defensive Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30546,1240,'Gallente Engineering Systems','Skill in the operation of Gallente Engineering Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30547,1240,'Minmatar Engineering Systems','Skill in the operation of Minmatar Engineering Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30548,1240,'Caldari Engineering Systems','Skill in the operation of Caldari Engineering Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30549,1240,'Caldari Offensive Systems','Skill in the operation of Caldari Offensive Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30550,1240,'Gallente Offensive Systems','Skill in the operation of Gallente Offensive Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30551,1240,'Minmatar Offensive Systems','Skill in the operation of Minmatar Offensive Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30552,1240,'Caldari Propulsion Systems','Skill in the operation of Caldari Propulsion Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30553,1240,'Gallente Propulsion Systems','Skill in the operation of Gallente Propulsion Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30554,1240,'Minmatar Propulsion Systems','Skill in the operation of Minmatar Propulsion Subsystems used on Tech III ships. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,5000000.0000,1,1824,0),(30558,971,'Malfunctioning Thruster Sections','After millennia of exposure to space, these thruster sections have begun to wear significantly, offering only a limited example of their full functionality. The modular design of Sleeper propulsion systems is still observable however, and is notably similar to that of the empires, only deviating in a few interesting areas.\r\r\n\r\r\nA determined and lucky researcher could still successfully reverse engineer something useful from this, but they would certainly stand a better chance with a more functional design. ',0,10,0,1,NULL,0.0000,1,1909,0),(30562,971,'Wrecked Thruster Sections','Originally misidentified by the analyzers as nothing more than scrap, these ancient thruster sections are only marginally more than that. Whether it was centuries of radiation or some violent explosion countless years ago, these thrusters have been damaged long ago and are now in a state of advanced erosion as a result. \r\r\n\r\r\nThe modular design of the Sleeper propulsion systems appears to be similar to empire technology, with only slight deviations observable. Perhaps there are secrets to the Sleeper propulsion designs locked away inside these broken relics, but it would take a significant amount of luck for even a skilled researcher to successfully reverse engineer them and find out. ',0,10,0,1,NULL,0.0000,1,1909,0),(30574,995,'Magnetar',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(30575,995,'Black Hole',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(30576,995,'Red Giant',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(30577,995,'Pulsar',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(30579,988,'Wormhole Z971','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30582,992,'Intact Power Cores','Rescued from a crumbling Sleeper structure, these ancient power cores stand as an excellent example of Sleeper engineering. Unlike everything else that surrounded them, these cores appeared to be almost newly-manufactured.\r\r\n\r\r\nPristine, working examples of Sleeper technology such as this are extremely rare and even more valuable. With the right skills and equipment, they can offer great insights into the scientific pursuits of the ancient race that designed them. ',0,10,0,1,NULL,0.0000,1,1909,0),(30583,988,'Wormhole R943','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30584,988,'Wormhole X702','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30586,992,'Malfunctioning Power Cores','Taken from amongst countless other ruined devices that cluttered the Sleeper facility once housing them, these ancient Sleeper power cores are still intact, yet extremely defective. Unlocking the technological secrets behind them would be a difficult task in their current state. Only those researchers who are skilled in reverse engineering would have a chance, and even then, not a great one. ',0,10,0,1,NULL,0.0000,1,1909,0),(30588,992,'Wrecked Power Cores','These ancient power cores have all but succumbed to millennia of neglect and disuse. A few elements of their basic design remain intact, offering a skilled researcher some small hope that the secrets locked away inside may still be reverse engineered into something more functional.',0,10,0,1,NULL,0.0000,1,1909,0),(30599,990,'Intact Electromechanical Component','This ancient piece of electronics equipment is in near-perfect condition, untarnished by centuries of disuse. The design of the circuitry appears to be highly modular, offering a wide-ranging insight into Sleeper electronics systems.\r\r\n\r\r\nPristine, working examples of Sleeper technology such as this are extremely rare and even more valuable. With the right skills and equipment, they can offer great insights into the scientific pursuits of the ancient race that designed them. ',0,10,0,1,NULL,0.0000,1,1909,0),(30600,990,'Malfunctioning Electromechanical Component','This ancient piece of electronics equipment has long since begun to malfunction. Despite centuries of disuse having taken a heavy toll on the device, the design of the circuitry remains clear enough to form the basis of scientific study. A skilled researcher could have a decent chance at unlocking the secrets of Sleeper electronics design within. ',0,10,0,1,NULL,0.0000,1,1909,0),(30605,990,'Wrecked Electromechanical Component','This ancient piece of electronics equipment has all but disintegrated after centuries of disuse. Much of the circuitry has been claimed by decay, leaving only the most fundamental information available for reverse engineering attempts. Even despite the low chance of success, in the hands of a skilled researcher these components could still help unlock the secrets of Sleeper electronics design.',0,10,0,1,NULL,0.0000,1,1909,0),(30614,993,'Intact Armor Nanobot','Recovered from amongst the debris of a Sleeper facility, this ancient device is somehow still entirely functional. Just one of these items holds countless nanoassemblers inside, offering a comprehensive view of the finer details in the Sleeper\'s defensive systems.\r\r\n\r\r\nPristine, working examples of Sleeper technology such as this are extremely rare and even more valuable. With the right skills and equipment, they can offer great insights into the scientific pursuits of the ancient race that designed them. ',0,10,0,1,NULL,0.0000,1,1909,0),(30615,993,'Malfunctioning Armor Nanobot','Recovered from amongst the debris of a Sleeper facility, this ancient device is locked into a slow decline. Just one of these items holds countless nanoassemblers inside, offering a comprehensive view of the finer details in the Sleeper\'s defensive systems. Unfortunately, a great deal of the assemblers inside this one have fused together, causing a terminal chain reaction inside the device.\r\r\n\r\r\nEven though it is badly damaged, a skilled scientist could still possibly extract enough information to try and reverse engineer it. ',0,10,0,1,NULL,0.0000,1,1909,0),(30618,993,'Wrecked Armor Nanobot','Recovered from amongst the debris of a Sleeper facility, this ancient device is almost entirely shut down. Just one of these items would normally hold countless nanoassemblers inside, offering a comprehensive view of the finer details in the Sleeper\'s defensive systems. Unfortunately, all of the assemblers inside this one have fused together, causing a terminal chain reaction inside the device.\r\r\n\r\r\nEven though it is only a shell of what it once used to be, with a bit of guesswork and luck, a skilled scientist might still be able to extract enough information to try and reverse engineer it. ',0,10,0,1,NULL,0.0000,1,1909,0),(30628,991,'Intact Weapon Subroutines','This collection of electronic devices represents the core of the computerized functionality behind the Sleeper weapons systems. An amalgam of advanced calibration and tracking devices, they are the driving force behind the frightening accuracy and efficiency of Sleeper armaments. \r\r\n\r\r\nThe subroutines have been coded into various devices which were then secreted away inside an ultra-hard metallofullerene alloy container. They show barely any sign of age, serving as an almost perfect example of Sleeper weapons design. \r\r\n\r\r\nPristine, working examples of Sleeper technology such as this are extremely rare and even more valuable. With the right skills and equipment, they can offer great insights into the scientific pursuits of the ancient race that designed them. ',0,10,0,1,NULL,0.0000,1,1909,0),(30632,991,'Malfunctioning Weapon Subroutines','This collection of electronic devices represents the core of the computerized functionality behind the Sleeper weapons systems. An amalgam of advanced calibration and tracking devices, they are the driving force behind the frightening accuracy and efficiency of Sleeper armaments. \r\r\n\r\r\nThe subroutines have been coded into various devices which were then secreted away inside an ultra-hard metallofullerene alloy container. A small tear in the container\'s seal has exposed them to centuries of radiation however, leaving them barely functional.\r\r\n\r\r\nEven despite this, a skilled scientist could still possibly extract enough information to reverse engineer one. ',0,10,0,1,NULL,0.0000,1,1909,0),(30633,991,'Wrecked Weapon Subroutines','This collection of electronic devices represents the core of the computerized functionality behind the Sleeper weapons systems. An amalgam of advanced calibration and tracking devices, they are the driving force behind the frightening accuracy and efficiency of Sleeper armaments. \r\r\n\r\r\nThe subroutines have been coded into various devices which were then stored inside the facility from which they came. Exposed to countless centuries of radiation after its walls began to erode, the subroutines are barely recognizable, offering only the most rudimentary glimpses into Sleeper weapons design. It would take a skilled researcher and a good amount of luck to successfully reverse engineer anything functional from such a broken mess. ',0,10,0,1,NULL,0.0000,1,1909,0),(30642,988,'Wormhole O128','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30643,988,'Wormhole N432','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30644,988,'Wormhole M555','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30645,988,'Wormhole B041','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30646,988,'Wormhole U319','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30647,988,'Wormhole B449','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30648,988,'Wormhole N944','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30649,988,'Wormhole S199','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30650,257,'Amarr Strategic Cruiser','Skill at operating Amarr Strategic Cruisers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,1500000.0000,1,377,0),(30651,257,'Caldari Strategic Cruiser','Skill at operating Caldari Strategic Cruisers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,1,1500000.0000,1,377,0),(30652,257,'Gallente Strategic Cruiser','Skill at operating Gallente Strategic Cruisers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,8,1500000.0000,1,377,0),(30653,257,'Minmatar Strategic Cruiser','Skill at operating Minmatar Strategic Cruisers. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,2,1500000.0000,1,377,0),(30654,952,'Luxury Spaceliner','The large majority of luxury vessels are produced inside the Federation, which has an unrivaled reputation for opulence in boutique and luxury yacht design. Ships of this class are typically flown by the elite of interstellar society, but pilots and passengers can also include high-ranking corporate and governmental officials.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30655,404,'Hybrid Polymer Silo','Specialized container designed to store and handle polymers used in the production of hybrid components',100000000,4000,40000,1,NULL,7500000.0000,1,483,0),(30656,438,'Polymer Reactor Array','The polymer reactor array is used to mix fullerenes with minerals and other materials to form hybrid polymers.\r\r\n\r\r\nOnly Hybrid Reactions will work in this array.',100000000,4000,1,1,NULL,12500000.0000,1,490,0),(30657,988,'Wormhole A641','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30658,988,'Wormhole R051','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30659,988,'Wormhole V283','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30660,988,'Wormhole H121','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30661,988,'Wormhole C125','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30662,988,'Wormhole O883','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30663,988,'Wormhole M609','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30664,988,'Wormhole L614','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30665,988,'Wormhole S804','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30666,988,'Wormhole N110','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30667,988,'Wormhole J244','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30668,988,'Wormhole Z060','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30669,995,'Wolf-Rayet Star',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(30670,995,'Cataclysmic Variable',' ',1e35,1,0,1,NULL,0.0000,0,NULL,0),(30671,988,'Wormhole Z647','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30672,988,'Wormhole D382','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30673,988,'Wormhole O477','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30674,988,'Wormhole Y683','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30675,988,'Wormhole N062','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30676,988,'Wormhole R474','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30677,988,'Wormhole B274','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30678,988,'Wormhole A239','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30679,988,'Wormhole E545','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30680,988,'Wormhole V301','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30681,988,'Wormhole I182','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30682,988,'Wormhole N968','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30683,988,'Wormhole T405','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30684,988,'Wormhole N770','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30685,988,'Wormhole A982','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30686,988,'Wormhole S047','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30687,988,'Wormhole U210','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30688,988,'Wormhole K346','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30689,988,'Wormhole P060','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30690,988,'Wormhole N766','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30691,988,'Wormhole C247','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30692,988,'Wormhole X877','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30693,988,'Wormhole H900','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30694,988,'Wormhole U574','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30695,988,'Wormhole D845','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30696,988,'Wormhole N290','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30697,988,'Wormhole K329','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30698,988,'Wormhole Y790','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30699,988,'Wormhole D364','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30700,988,'Wormhole M267','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30701,988,'Wormhole E175','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30702,988,'Wormhole H296','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30703,988,'Wormhole V753','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30704,988,'Wormhole D792','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30705,988,'Wormhole C140','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30706,988,'Wormhole Z142','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30707,988,'Wormhole Q317','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30708,988,'Wormhole G024','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30709,988,'Wormhole L477','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30710,988,'Wormhole Z457','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30711,988,'Wormhole V911','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30712,988,'Wormhole W237','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30713,988,'Wormhole B520','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30714,988,'Wormhole C391','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30715,988,'Wormhole C248','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30716,283,'Tahaki Karin','Her face is close enough, if you\'ve only seen a photo or a holo. Right height, right weight. Her voice is close enough, too. Accent, vocabulary, everything suggests this is Tahaki Karin.\r\r\n\r\r\nShe isn\'t, of course, but you\'ve been forewarned. Anyone who knew the original would find themselves hard-put to detect the mimic. There are little things, though. The scar on her neck is newer. Her nails are filed smooth rather than roughly clipped. And she listens. To everything. She doesn\'t make a point of it, of course. But she\'s taking in everything. The whine of the electrical system, the buzz coming off the gravity plating.\r\r\n\r\r\nWho is she, really? You don\'t know. But she\'s closer to being Karin than she is anyone else. Close enough.\r\r\n',80,3,0,1,NULL,1000.0000,1,NULL,0),(30719,283,'Kritsan Parthus','Parthus is an Amarr pirate. Quiet in person, he\'s known both as a wild gambler and a man who can cover his bets. His success in outfitting and executing illegal missions is similar: he takes a lot of risks, but thinks practically and can generally repay his debts.',90,1,0,1,NULL,0.0000,1,NULL,0),(30720,306,'Parthus\' Malfunctioning Capsule','This capsule contains the Amarrian pirate Kritsan Parthus. The internal warp drive of the pod appear to be heavily damaged from the explosion of his ship, leaving him stranded.',10000,1200,1400,1,NULL,0.0000,0,NULL,0),(30725,678,'Civilian Gallente Cruiser Celestis','The Celestis cruiser is a versatile ship which can be employed in a myriad of roles, making it handy for small corporations with a limited number of ships. True to Gallente style the Celestis is especially deadly in close quarters combat due to its advanced targeting systems.\r\r\n\r\r\nThis ship poses no immediate threat.\r\r\n',11300000,113000,235,1,8,0.0000,0,NULL,0),(30726,678,'Civilian Gallente Cruiser Exequror','The Exequror is a heavy cargo cruiser capable of defending itself against raiding frigates, but lacks prowess in heavier combat situations. It is mainly used in relatively peaceful areas where bulk and strength is needed without too much investment involved. \r\r\n\r\r\nThis ship poses no immediate threat.',11300000,113000,235,1,8,0.0000,0,NULL,0),(30727,678,'Civilian Gallente Cruiser Thorax','The Thorax-class cruiser is the latest combat ship commissioned by the Federation. While the Thorax is a very effective ship at any range, typical of modern Gallente design philosophy it is most effective when working at extreme close range where its blasters and hordes of combat drones tear through even the toughest of enemies.\r\r\n\r\r\nThis ship poses no immediate threat.\r\r\n',11300000,113000,235,1,8,0.0000,0,NULL,0),(30728,678,'Civilian Gallente Cruiser Vexor','The Vexor is a strong combat ship that is also geared to operate in a variety of other roles. The Vexor is especially useful for surveying in potentially hostile sectors as it can stay on duty for a very long time before having to return to base. Furthermore, it is well capable of defending itself against even concentrated attacks.\r\r\n\r\r\nThis ship poses no immediate threat.\r\r\n',11300000,113000,235,1,8,0.0000,0,NULL,0),(30729,673,'Civilian Caldari Cruiser Blackbird','The Blackbird is a small high-tech cruiser newly employed by the Caldari Navy. Commonly seen in fleet battles or acting as wingman, it is not intended for head-on slugfests, but rather delicate tactical situations. \r\r\n\r\r\nThis ship poses no immediate threat.',9600000,96000,450,1,1,0.0000,0,NULL,0),(30730,673,'Civilian Caldari Cruiser Caracal','The Caracal is a powerful vessel that specializes in missile deployment. It has excellent shield defenses, but poor armor plating. Its missile arsenal, when fully stocked, is capable of making mincemeat of almost anyone. \r\n\r\nThis ship poses no immediate threat.',9600000,96000,450,1,1,0.0000,0,NULL,0),(30731,673,'Civilian Caldari Cruiser Moa','The Moa was designed as an all-out combat ship, and its heavy armament allows the Moa to tackle almost anything that floats in space. In contrast to its nemesis the Thorax, the Moa is most effective at long range where its railguns and missile batteries can rain death upon foes.\r\r\n\r\r\nThis ship poses no immediate threat.',9600000,96000,450,1,1,0.0000,0,NULL,0),(30732,673,'Civilian Caldari Cruiser Osprey','The Osprey offers excellent versatility and power for its low price. Designed from the top down as a cheap but complete cruiser, the Osprey utilizes the best the Caldari have to offer in state-of-the-art armor alloys, sensor technology and weaponry - all mass manufactured to ensure low price. In the constant struggle to stay ahead of the Gallente, new technology has been implemented in the field of mining laser calibration. A notable improvement in ore yields has been made, especially in the hands of a well trained pilot.\r\r\n\r\r\nThis ship poses no immediate threat.',9600000,96000,450,1,1,0.0000,0,NULL,0),(30733,668,'Civilian Amarr Cruiser Arbitrator','The Arbitrator is unusual for Amarr ships in that it\'s primarily a drone carrier. While it is not the best carrier around, it has superior armor that gives it greater durability than most ships in its class.\r\r\n\r\r\nThis ship poses no immediate threat.',12000000,120000,450,1,4,0.0000,0,NULL,0),(30734,668,'Civilian Amarr Cruiser Augoror','The Augoror-class cruiser is one of the old warhorses of the Amarr Empire, having seen action in both the Jovian War and the Minmatar Rebellion. It is mainly used by the Amarrians for escort and scouting duties where frigates are deemed too weak. Like most Amarrian vessels, the Augoror depends first and foremost on its resilience and heavy armor to escape unscathed from unfriendly encounters.\r\r\n\r\r\nThis ship poses no immediate threat.',12000000,120000,450,1,4,0.0000,0,NULL,0),(30735,668,'Civilian Amarr Cruiser Maller','Quite possibly the toughest cruiser in the galaxy, the Maller is a common sight in Amarrian Imperial Navy operations. It is mainly used for military duty, although a few can be found in the private sector acting as escort ships for very important dispatches. \r\r\n\r\r\nThis ship poses no immediate threat.',12000000,120000,450,1,4,0.0000,0,NULL,0),(30736,668,'Civilian Amarr Cruiser Omen','The Omen is a stereotypical example of the Amarrian School of thinking when it comes to ship design: thick armor and hard hitting lasers. Advancements in heat dissipation allow the Omen to fire its lasers faster than other ships without this technology.\r\r\n\r\r\nThis ship poses no immediate threat.',12000000,120000,450,1,4,0.0000,0,NULL,0),(30737,666,'Independent Harbinger','Right from its very appearance on a battlefield, the Harbinger proclaims its status as a massive weapon, a laser burning through the heart of the ungodly. Everything about it exhibits this focused intent, from the lights on its nose and wings that root out the infidels, to the large number of turreted high slots that serve to destroy them. Should any heathens be left alive after the Harbinger\'s initial assault, its drones will take care of them.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',13500000,130000,350,1,4,0.0000,0,NULL,0),(30738,666,'Independent Prophecy','The Prophecy is built on an ancient Amarrian warship design dating back to the earliest days of starship combat.  Originally intended as a full-fledged battleship, it was determined after mixed fleet engagements with early prototypes that the Prophecy would be more effective as a slightly smaller, more mobile form of artillery support.\r\r\n\r\r\nThe markings on this ship reveal no obvious connection to the Empire.',13500000,130000,350,1,4,0.0000,0,NULL,0),(30739,705,'Civilian Minmatar Cruiser Bellicose','Being a highly versatile class of Minmatar ships, the Bellicose has been used as a combat juggernaut as well as a support ship for wings of frigates. While not quite in the league of newer navy cruisers, the Bellicose is still a very solid ship for most purposes, especially in terms of long range combat.\r\r\n\r\r\nThis ship poses no immediate threat.',9900000,99000,120,1,2,0.0000,0,NULL,0),(30740,705,'Civilian Minmatar Cruiser Rupture','The Rupture is slow for a Minmatar ship, but it more than makes up for it in power. The Rupture has superior firepower and is used by the Minmatar Republic both to defend space stations and other stationary objects and as part of massive attack formations.\r\r\n\r\r\nThis ship poses no immediate threat.',9900000,99000,120,1,2,0.0000,0,NULL,0),(30741,705,'Civilian Minmatar Cruiser Scythe','The Scythe-class cruiser is the oldest Minmatar ship still in use. It has seen many battles and is an integrated part in Minmatar tales and heritage. Recent firmware upgrades \"borrowed\" from the Caldari have vastly increased the efficiency of its mining output.\r\r\n\r\r\nThis ship poses no immediate threat.',9900000,99000,120,1,2,0.0000,0,NULL,0),(30742,705,'Civilian Minmatar Cruiser Stabber','The Stabber is the mainstay of the Minmatar fleet. It is light and extremely fast, yet surprisingly powerful, with a wide variety of weapons. It is one of few Minmatar vessels that have reached popularity outside Minmatar space.\r\r\n\r\r\nThis ship poses no immediate threat.',9900000,99000,120,1,2,0.0000,0,NULL,0),(30743,595,'Society of Conscious Thought Cruiser','The Society of Conscious Thought applies its cruiser when anticipating hostilities or when carrying precious cargo. Despite their objections to violence, they rather be deadly than dead.',10900000,109000,120,1,2,0.0000,0,NULL,0),(30744,880,'Neural Network Analyzer','Even millennium old, this bulky piece of equipment shows barely any sign of age. The explosion of the Sleeper drone ferrying it around doesn\'t seem to have affected it in any way, either. This device was clearly built to last.\r\r\n\r\r\nA cursory analysis of the software systems within reveals that it operates as some kind of monitoring device. The specialized design suggests it was used to process vast amounts of basic data and identify anomalies.\r\r\n\r\r\nGiven its age and unique design, there would likely be very few who could make sense of the programming. Those who do recognize the value of such a component, however, would likely be willing to part with a significant sum of ISK to own it. ',1,0.1,0,1,4,200000.0000,1,1109,0),(30745,880,'Sleeper Data Library','Found amongst the debris of an incapacitated Sleeper drone, this large device appears to be a data archive of some sort. Although the information within remains a complete mystery, it is immediately apparent that it stretches far back into time.\r\r\n\r\r\nSmall data fragments preceding each file appear to function as time-stamps. If this is indeed what they are, then this Data Library could offer a snapshot of the universe stretching back millennia.\r\r\n\r\r\nAlthough it is obviously of great value in and of itself, those who have some basic understanding of interpreting the data would undoubtedly pay the most for it, should an opportunistic salvager wish to part with such a rare piece of technology. ',1,0.1,0,1,4,500000.0000,1,1109,0),(30746,880,'Ancient Coordinates Database','Recovered from the wrecked hull of a Sleeper drone, this database stands as a testament to the lasting power of their ancient technology. Not only has it managed to survive for millennia completely intact, but it has come through the violence of its bearer\'s destruction without even a scratch. \r\r\n\r\r\nA brief analysis of the technology inside reveals that the database may in fact still be fully functional. The format and layout of the information within suggests it is a list of three-dimensional coordinates, charting a path to some distant place. \r\r\n\r\r\nAlthough this device could hold incredibly valuable information, there would only be a handful of people in the entire cluster that could make any sense of it. Finding a buyer may not be that easy. ',1,0.1,0,1,NULL,1500000.0000,1,1109,0),(30747,880,'Sleeper Drone AI Nexus','Rescued from the ruined hull of a Sleeper drone, this AI Nexus represents the digital soul of these strange creations. Although the technology behind the Sleeper AI is for the most part recognizable, this device offers some insight into the few mysterious aspects that are not.\r\r\n\r\r\nAs coveted as this component must be, only the foremost drone technicians in all of New Eden would be able to possibly find some use in it. There is little doubt however that the promise such a thing holds would ensure they paid a tidy sum. ',1,0.1,0,1,NULL,5000000.0000,1,1109,0),(30752,997,'Intact Hull Section','Found drifting amongst the ruins of a Sleeper compound, these large sections of a Sleeper vessel represent a significant archaeological discovery. Not only is the hull itself an incredibly rare find, but the excellent condition it is in makes this a particularly useful case study for the Sleeper\'s ship construction methods.\r\r\n\r\r\nPristine, working examples of Sleeper technology such as this are extremely rare and even more valuable. With the right skills and equipment, they can offer great insights into the scientific pursuits of the ancient race that designed them. ',0,100,0,1,NULL,0.0000,1,1909,0),(30753,997,'Malfunctioning Hull Section','Found drifting amongst the ruins of a Sleeper compound, these large sections of a Sleeper vessel represent a significant archaeological discovery. The hull itself is an incredibly rare find, tainted only by the condition it is in. Although it was clearly built to survive the stress of space, the countless years of environmental exposure have still taken a heavy toll, stripping from it a great deal of the original functionality. \r\r\n\r\r\nEven despite the damage, it would still make a respectable case study for the Sleeper\'s vessel construction methods. A skilled scientist could still possibly extract enough information to try and reverse engineer it. ',0,100,0,1,NULL,0.0000,1,1909,0),(30754,997,'Wrecked Hull Section','Mistakenly identified by the analyzers as a derelict structure, these ancient Sleeper hull fragments are almost entirely destroyed. Whether slow erosion or some more rapid and violent event devastated the technology remains unclear. It is simply too badly damaged to make an educated guess. \r\r\n\r\r\nThere isn\'t much of a chance that anything useful could be reverse engineered from such badly ruined fragments, but there is little doubt that those few lucky researchers who successfully managed it would uncover the secrets to Sleeper hull designs. For many, that opportunity alone would be worth the gamble. ',0,100,0,1,NULL,0.0000,1,1909,0),(30755,314,'Strange Datacore','This item, clearly salvaged from one of the wrecked ships, is recognizable as a datacore, but has a foreign interface that doesn\'t quite look like it came from any empire you\'re familiar with.',0.75,0.1,0,1,NULL,0.0000,1,NULL,0),(30756,314,'Red','This is the corpse of a man wearing a red shirt. It looks like he was a pretty tough guy just a few hours ago.',80,1,0,1,NULL,0.0000,1,NULL,0),(30757,283,'Nebben Centrien, Janitor','Nebben Centrien is in top physical condition, with sharp eyes and a shrewd expression.',100,3,0,1,NULL,0.0000,1,NULL,0),(30758,306,'Centrien\'s Shuttle','This vessel is just enough to keep its occupant alive. Looks like the station crew didn\'t want Nebben Centrien fighting back.',1450000,16120,145,1,NULL,0.0000,0,NULL,0),(30759,283,'Chef Aubrei Azil','Aubrei Azil is a talented space-faring chef and ship\'s cook.',100,3,0,1,NULL,0.0000,1,NULL,0),(30760,306,'Azil\'s Transport','This tiny craft is badly damaged. All propulsion units have been completely disabled.',1450000,16120,145,1,1,0.0000,0,NULL,0),(30761,283,'Doctor Luija Elban','Dr. Elban is an extremely competent ship\'s doctor who has recently been having a run of rather bad luck.',70,1,0,1,NULL,0.0000,1,NULL,0),(30762,952,'Dead Drop','Dr. Elban\'s kidnappers are expecting you to put a lot of money into this can.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30763,665,'Civilian Amarr Frigate Crucifier','The Crucifier was first designed as an explorer/scout, but the current version employs the electronic equipment originally intended for scientific studies for more offensive purposes. The Crucifier\'s electronic and computer systems take up a large portion of the internal space leaving limited room for cargo or traditional weaponry.\r\r\n\r\r\nThis ship poses no immediate threat.',2820000,24398,235,1,4,0.0000,0,NULL,0),(30764,665,'Civilian Amarr Frigate Executioner','The Executioner is another newly commissioned ship of the Amarr Imperial Navy. The Executioner was designed specially to counter the small, fast raider frigates of the Minmatar Republic; thus it is different from most Amarr ships in favoring speed over defenses. With the Executioner, the Amarrians have expanded their tactical capabilities on the battlefield.\r\r\n\r\r\nThis ship poses no immediate threat.',2820000,24398,235,1,4,0.0000,0,NULL,0),(30765,665,'Civilian Amarr Frigate Inquisitor','The Inquisitor is another example of how the Amarr Imperial Navy has modeled their design to counter specific tactics employed by the other empires. The Inquisitor is a fairly standard Amarr ship in most respects, having good defenses and lacking mobility. It is more Caldari-like than most Amarr ships, however, since its arsenal mostly consists of missile bays.\r\r\n\r\r\nThis ship poses no immediate threat.',2820000,24398,235,1,4,0.0000,0,NULL,0),(30766,665,'Civilian Amarr Frigate Punisher','The Amarr Imperial Navy has been upgrading many of its ships in recent years and adding new ones. The Punisher is one of the most recent ones and considered by many to be the best Amarr frigate in existence. As witnessed by its heavy armaments, the Punisher is mainly intended for large-scale military operations, acting in coordination with larger military vessels, but it is more than powerful enough for solo operations.\r\r\n\r\r\nThis ship poses no immediate threat.',2820000,24398,235,1,4,0.0000,0,NULL,0),(30768,314,'A Lot of Money','This is a lot of money.',10,3,0,1,NULL,0.0000,1,NULL,0),(30769,671,'Civilian Caldari Frigate Condor','The Condor is fast and agile. It has limited cargo space so it\'s not very suitable for trading or mining. It is best used as an assault vessel in a hit-and-run type of operations.\r\r\n\r\r\nThis ship poses no immediate threat.',1612000,16120,80,1,1,0.0000,0,NULL,0),(30770,671,'Civilian Caldari Frigate Griffin','The Griffin is much used by the Caldari Navy as a support vessel in combat squadrons, using its impressive array of electronic gadgetry to disrupt the operation of target ships, making them easy prey for traditional combat vessels.\r\r\n\r\r\nThis ship poses no immediate threat.',1612000,16120,80,1,1,0.0000,0,NULL,0),(30771,671,'Civilian Caldari Frigate Heron','The Heron has good computer and electronic systems, giving it the option of participating in electronic warfare. But it has relatively poor defenses and limited weaponry, so it\'s more commonly used for scouting and exploration.\r\r\n\r\r\nThis ship poses no immediate threat.',1612000,16120,80,1,1,0.0000,0,NULL,0),(30772,671,'Civilian Caldari Frigate Kestrel','The Kestrel is a heavy missile boat with a fairly large cargo space and one of the most sophisticated sensor arrays around. Interestingly enough, it has been used by both the Caldari Navy and several wealthy trade corporations as a cargo-hauling vessel. It is one of few trading vessels with good punching power, making it ideal for solo trade-runs in dangerous areas. \r\r\n\r\r\nThis ship poses no immediate threat.',1612000,16120,80,1,1,0.0000,0,NULL,0),(30773,671,'Civilian Caldari Frigate Merlin','The Merlin is the most powerful all-out combat frigate of the Caldari. It is highly valued for its versatility in using both missiles and turrets, while its defenses are exceptionally strong for a Caldari vessel.\r\r\n\r\r\nThis ship poses no immediate threat.',1612000,16120,80,1,1,0.0000,0,NULL,0),(30774,283,'Engineer Tahaki Karin','Tahaki Karin is a youngish woman of middling height and build, dressed practically in a mechanic\'s coveralls. Her hands are rough and heavily callused, and she carries some scars that look like they were caused by shrapnel. Her voice is brisk, carrying a clear expectation that her orders will be followed. She looks like she\'s seen a lot recently, and none of it\'s been pleasant.',70,1,0,1,NULL,0.0000,1,NULL,0),(30775,306,'The Heartbreak','Engineer Tahaki Karin signed on with this ship not long ago, and now it\'s destroyed. She\'s been having a tough time lately.',1450000,16120,145,1,NULL,0.0000,0,NULL,0),(30776,314,'Mizara\'s Doll','This doll is old and well-worn. It still smells faintly of brown sugar.',2,1,0,1,NULL,0.0000,1,NULL,0),(30777,952,'Mizara Family Hovel','Even among the remnants of this rundown mining colony, the Mizara family\'s hovel looks particularly impoverished.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30778,314,'Mysterious Statuette','This ancient, faintly engraved statuette looks like just the kind of thing Canius was after.',2,1,0,1,NULL,0.0000,1,NULL,0),(30779,306,'Ancient Tomb Dig Site','Both conservative Amarr and the fanatical Blood Raiders have left this tomb alone out of respect for the honored dead. You think you could get a good pot out of it.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30780,314,'Strange Coded Document','This document would look like gibberish if it weren\'t for Dagan\'s signature at the bottom. Perhaps Canius can decipher it.',0.75,0.1,0,1,NULL,0.0000,1,NULL,0),(30781,306,'Corrupted Drone','This corrupted drone looks safe to approach.',1450000,16120,145,1,NULL,0.0000,0,NULL,0),(30782,314,'Corrupted Drone Components','These components were gathered from obviously malfunctioning drones.',2,1,0,1,NULL,0.0000,1,NULL,0),(30783,952,'Colonial Supply Depot','The \"Medical Supply Hold\" is down to a few bandages and cobwebs.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30784,314,'Dr. Castille\'s Data Core (Property of CreoDron)','This data core contains Dr. Aspasia Castille\'s notes on the corrupted drone problem, but it\'s heavily encrypted.',0.75,0.1,0,1,NULL,0.0000,1,NULL,0),(30785,306,'Destroyed Ship','It doesn\'t really matter whose ship this was, now. What matters is that Dr. Castille\'s data may be still be inside.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30786,226,'Storage Warehouse','These huge spacebound facilities are used to stock anything from ammunitions to agricultural supplies.',0,0,0,1,NULL,0.0000,0,NULL,0),(30788,270,'Propulsion Subsystem Technology','Understanding of the technology used to create advanced propulsion subsystems.',0,0.01,0,1,NULL,10000000.0000,1,375,0),(30789,226,'Fortified Starbase Auxiliary Power Array','These arrays provide considerable added power output, allowing for an increased number of deployable structures in the starbase\'s field of operation.',0,0,0,1,4,0.0000,0,NULL,0),(30790,674,'Civilian Caldari Battleship Scorpion','The first Scorpion-class battleship was launched only a couple of years ago, and those that have been built are considered to be prototypes. Little is known of its capabilities, but what has been garnered suggests that the Scorpion is crammed to the brink with sophisticated hi-tech equipment that few can match. \r\r\n\r\r\nThis ship poses no immediate threat.',22000000,1080000,235,1,1,0.0000,0,NULL,0),(30791,674,'Civilian Caldari Battleship Rokh','Having long suffered the lack of an adequate hybrid platform, the Caldari State\'s capsule pilots found themselves rejoicing as the Rokh\'s design specs were released. A fleet vessel if ever there was one, this far-reaching and durable beast is expected to see a great deal of service on battlefields near and far.\r\r\n\r\r\nThis ship poses no immediate threat.',22000000,1080000,235,1,1,0.0000,0,NULL,0),(30792,674,'Civilian Caldari Battleship Raven','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.\r\r\n\r\r\nThis ship poses no immediate threat.',22000000,1080000,235,1,1,0.0000,0,NULL,0),(30793,952,'Storage Warehouse Container','These huge spacebound facilities are used to stock anything from ammunitions to agricultural supplies.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30794,314,'Farming Supplies','This huge freight container is loaded with all sorts of agricultural equipment. Almost anything a farm could need has been packed away inside, from seeds and plant samples to tractors and ploughs.',50000,150,0,1,NULL,0.0000,1,NULL,0),(30797,226,'Talocan Outpost Hub','Though large in design, this structure is sparsely adorned, with only a few antechambers and docking platforms inside. Speculation among historians suggests that this outpost hub was capable of immediate and easy disconnection from the Talocan outpost in case of attack, but there hasn\'t been a scholarly consensus about this.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30798,226,'Talocan Outpost Conduit','Narrow tubes and electrical wiring fill the outpost conduit. Equal parts electrical artery and linking structure, the interior of this connecting structure is in disrepair, but it\'s polyferrous hull keeps the ravages of space and time at bay.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30799,226,'Debris - Broken Drive Unit Part 1','This massive hulk of debris seems to have once been a part of the outer hull of a battleship or station.',0,0,0,1,NULL,0.0000,0,NULL,0),(30800,226,'Debris - Broken Drive Unit Part 2','This damaged hunk of machinery could once have been a part of a powerplant or relay station.',0,0,0,1,NULL,0.0000,0,NULL,0),(30801,226,'Debris - Power Feed','This space debris appears to have served as an external power conduit system on a gigantic vessel.',0,0,0,1,NULL,0.0000,0,NULL,0),(30802,226,'Debris - Crumpled Metal','This floating debris appears to have once been a part of an outer hull or armor, ripped apart by an explosion or asteroid impact.',0,0,0,1,NULL,0.0000,0,NULL,0),(30804,283,'Lieutenant Kirus','Irai Kirus is a lowly smuggler known to operate in both Amarr and Minmatar space. Interrogating him will likely reveal the name and location of his superior.',100,1,0,1,NULL,0.0000,1,NULL,0),(30805,952,'Wolf Burgan\'s Hideout','According to Serpentis intelligence, this outpost is the hiding spot for Wolf Burgan. According to your intelligence, this is where Wolf Burgan loaded an unhealthy amount of explosives.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30806,319,'Disjointed Talocan Outpost Hub','Though large in design, this structure is sparsely adorned, with only a few antechambers and docking platforms inside. Speculation among historians suggests that this outpost hub was capable of immediate and easy disconnection from the Talocan outpost in case of attack, but there hasn\'t been a scholarly consensus about this. Most of the docking bays have eroded away, and a few walls are on the verge of collapse, leaving the hub in complete disrepair. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30807,319,'Disjointed Talocan Outpost Conduit','Narrow tubes and electrical wiring fill the outpost conduit. Equal parts electrical artery and linking structure, the interior of this connecting structure is in disrepair and on the verge of complete wreckage. ',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30809,314,'Wolf Burgan\'s Body Double','This slab of biomass was once a blank slate waiting to be turned into a functioning clone for some capsuleer. With the help of an engineered virus and the sample you provided, the slab is now a DNA-perfect replication of Wolf Burgan. Sure, it only looks like him if you squint really hard, but that is what explosions are for.',80,1,0,1,NULL,0.0000,1,NULL,0),(30810,314,'Wolf Burgan\'s DNA','The genetic material of Wolf Burgan, taken from a local law enforcement agency. Mercenary life has one major drawback: For every client, there\'s a victim another mercenary available to make you their target.',80,1,0,1,NULL,0.0000,1,NULL,0),(30811,314,'Drone Tracking Data','An analysis of this data may help to uncover the mysteries of that evasive rogue drone.',80,1,0,1,NULL,0.0000,1,NULL,0),(30812,283,'Corin Risia','Corin Risia is a Scope reporter held captive by Mordu\'s Legion. He has information for you   at a price, of course.',70,1,0,1,NULL,0.0000,1,NULL,0),(30813,306,'Wrecked Ship','The remains of a once mighty exploration vessel, now reduced to scarred metal and blackened fragments.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30814,283,'FR Personnel','Peaceful emissaries of comfort and salvation, the Food Relief personnel are not a threat to anybody. But try telling that to a swarm of rogue drones.',70,1,0,1,NULL,0.0000,1,NULL,0),(30815,306,'Habitation Module w/FR Personnel','A defenseless storage facility housing Food Relief workers. Inside the station are loads of supplies and food, as well as personnel workers and a few volunteers.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30816,314,'Medical Supplies','Does what it says on the tin.',10,3,0,1,NULL,0.0000,1,NULL,0),(30818,665,'Izia Tabar','Izia Tabar has been wanted by CONCORD for many years, having been charged with countless kidnappings and assaults. He has always managed to evade their raiding parties by maintaining a large security detachment wherever he goes.',2860000,28600,235,1,4,0.0000,0,NULL,0),(30819,817,'Mysterious Drone','The mysterious drone that began this whole affair. Sensors show that the drone is comprised of an carbonaceous alloy not used by any of the empires. It continuously gives off a signal that on audio sounds like a mournful whale song with the chattering of insects.',10900000,109000,120,1,NULL,0.0000,0,NULL,0),(30820,952,'Generic Cargo Container',' ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30821,517,'Adani Yusev\'s Raven','A Raven piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(30822,186,'Amarr Advanced Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30823,186,'Caldari Advanced Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30824,186,'Gallente Advanced Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30825,186,'Minmatar Advanced Cruiser Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(30826,526,'Altered Identity Records','These identity records will overwrite the original data in the system.',50,1,0,1,NULL,0.0000,1,NULL,0),(30827,283,'Dagan','Dagan lies imprisoned within his pod. Distorted through the glass, you can see impressive, chiseled features contorted in impotent rage. He knows he is at your mercy, and has every reason to fear the \"mercy\" of a capsule pilot.',100,1,0,1,NULL,0.0000,1,NULL,0),(30830,517,'Brus Colterne\'s Megathron','A Megathron piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(30831,988,'Wormhole K162','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(30832,538,'Relic Analyzer II','An archaeology system used to analyze and search ancient ruins. ',0,5,0,1,NULL,149870.0000,1,1718,0),(30833,917,'Relic Analyzer II Blueprint',' ',0,0.01,0,1,NULL,332640.0000,1,NULL,0),(30834,538,'Data Analyzer II','A Hacking system used to override electronic security systems. ',0,5,0,1,NULL,149870.0000,1,1718,0),(30835,917,'Data Analyzer II Blueprint',' ',0,0.01,0,1,NULL,332640.0000,1,NULL,0),(30836,1122,'Salvager II','A specialized scanner used to detect salvageable items in ship wrecks.',0,5,0,1,NULL,149870.0000,1,1715,0),(30837,1123,'Salvager II Blueprint',' ',0,0.01,0,1,NULL,332640.0000,1,NULL,0),(30838,517,'Kitar Ang\'s Tempest','A Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(30839,60,'Civilian Damage Control','Utilizes a combination of containment field emitters and redundancy systems to prevent critical system damage. \r\r\n\r\r\nGrants a bonus to resistance for shield, armor and hull.\r\r\n\r\r\nOnly one Damage Control can be activated at a given time.',5000,5,0,1,NULL,464.0000,1,615,0),(30840,140,'Civilian Damage Control Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,1542,0),(30841,517,'Lear Evanus\' Apocalypse','An Apocalypse piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(30842,31,'InterBus Shuttle','InterBus commissioned Duvolle Laboratories to design them an upgraded shuttlecraft in YC 106. The result was this vessel, which combines compact size with a surprisingly large cargo hold - ideal for the multipurpose transportation that InterBus specializes in.\r\r\n\r\r\nThe ship remained a closely-guarded Interbus asset for many years, but in YC111 it was made available to select capsuleer pilots as part of an outreach programme intended to raise awareness of the InterBus brand among the growing capsuleer population. It remains, however, a very rare sight among the spacelanes and is considered by many to be a valuable collector\'s item.',1600000,5000,20,1,8,5556.0000,1,1618,0),(30843,111,'InterBus Shuttle Blueprint',' ',0,0.01,0,1,4,50000.0000,1,NULL,0),(30844,920,'Pulsar Effect Beacon Class 1','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30845,920,'Black Hole Effect Beacon Class 1','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30846,920,'Cataclysmic Variable Effect Beacon Class 1','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30847,920,'Magnetar Effect Beacon Class 1','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30848,920,'Red Giant Beacon Class 1','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30849,920,'Wolf Rayet Effect Beacon Class 1','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30850,920,'Black Hole Effect Beacon Class 2','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30851,920,'Black Hole Effect Beacon Class 3','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30852,920,'Black Hole Effect Beacon Class 4','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30853,920,'Black Hole Effect Beacon Class 5','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30854,920,'Black Hole Effect Beacon Class 6','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30860,920,'Magnetar Effect Beacon Class 2','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30861,920,'Magnetar Effect Beacon Class 3','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30862,920,'Magnetar Effect Beacon Class 4','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30863,920,'Magnetar Effect Beacon Class 5','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30864,920,'Magnetar Effect Beacon Class 6','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30865,920,'Pulsar Effect Beacon Class 2','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30866,920,'Pulsar Effect Beacon Class 3','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30867,920,'Pulsar Effect Beacon Class 4','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30868,920,'Pulsar Effect Beacon Class 5','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30869,920,'Pulsar Effect Beacon Class 6','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30870,920,'Red Giant Beacon Class 2','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30871,920,'Red Giant Beacon Class 3','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30872,920,'Red Giant Beacon Class 4','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30873,920,'Red Giant Beacon Class 5','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30874,920,'Red Giant Beacon Class 6','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30875,920,'Wolf Rayet Effect Beacon Class 2','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30876,920,'Wolf Rayet Effect Beacon Class 3','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30877,920,'Wolf Rayet Effect Beacon Class 4','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30878,920,'Wolf Rayet Effect Beacon Class 5','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30879,920,'Wolf Rayet Effect Beacon Class 6','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30880,920,'Cataclysmic Variable Effect Beacon Class 2','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30881,920,'Cataclysmic Variable Effect Beacon Class 3','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30882,920,'Cataclysmic Variable Effect Beacon Class 6','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30883,920,'Cataclysmic Variable Effect Beacon Class 5','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30884,920,'Cataclysmic Variable Effect Beacon Class 4','Local spatial phenomena may cause strange effects on your ship systems.',1,20,0,250,NULL,3068504.0000,1,NULL,0),(30887,517,'Tevis Jak\'s Epithal','An Epithal piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(30889,7,'Planet (Shattered)','Shattered worlds were once terrestrial planets, torn asunder by some immense cataclysm. All such worlds in the New Eden cluster are products of the disastrous stellar events that occurred during the \"Seyllin Incident\". However, reports continue to circulate of similar planets discovered in the unmapped systems reached exclusively through unstable wormholes. How these met their fate, if indeed they exist at all, is unknown.',1e35,1,0,1,NULL,0.0000,0,NULL,0),(30894,226,'Amarr Armageddon Battleship','The mighty Armageddon class is one of the enduring warhorses of the Amarr Empire. Once a juggernaut that steamrolled its way into battle, it has now taken on a more stately and calculated approach, sending out a web of drones in its place while it drains the enemy from a distance.',0,0,0,1,4,0.0000,0,NULL,0),(30895,226,'Caldari Raven Battleship','A Raven-class battleship.',0,0,0,1,1,0.0000,0,NULL,0),(30896,226,'Minmatar Tempest Battleship','A Tempest-class battleship.',0,0,0,1,2,0.0000,0,NULL,0),(30897,226,'Gallente Dominix Battleship','A Dominix-class battleship.',105000000,1010000,600,1,8,0.0000,0,NULL,0),(30898,226,'Minmatar Wreathe industrial','A Wreathe-class industrial.',0,0,0,1,2,0.0000,0,NULL,0),(30899,952,'Cargo Wreathe','A Wreathe-class industrial awaiting cargo.',0,0,500,1,2,0.0000,0,NULL,0),(30900,226,'Fortified Drone Structure I','This gigantic superstructure was built by the effort of thousands of rogue drones. While the structure appears to be incomplete, its intended shape remains a mystery to the clueless carbon-based lifeforms.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(30901,226,'Sleeper Engineering Station','This enigmatic structure appears to house numerous engineering subsystems. An outer defense system is still online, shielding the installation from any hostile actions. Inside the facility there is a maze of data networks tangled amongst the cables and conduits that sustain them.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30902,226,'Talocan Embarkment Destroyer','This Talocan ship wreckage drifts in space with surprising grace and efficiency. Even completely offline and abandoned, the embarkment destroyer appears to have been created for just this function, or at least for survival across vast stretches of unknown space for extended periods of time. Despite its incapacitated status, the wreckage looks sturdy enough to be rebuilt; perhaps its appearance is merely a ruse, a trap set long ago by a dead civilization. Regardless, caution is recommended.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30903,226,'Talocan Disruption Tower','The Talocan disruption tower is the most mysterious of the Talocan structures. Although certainly a part of the Talocan station, its hinges and propulsion systems imply ready removal from stations, but the peaks and points are unlike any current weapon grouping or turret structure. The tower appears as more of a mechanical syringe than a defense turret, but that may be just speculation. Regardless of the theories, the disruption tower is an unsettling relic of the Talocans.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30904,226,'Talocan Engineering Station','This is a Talocan engineering station',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30905,226,'Sleeper linkage structure','This is a Sleeper linkage structure',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30906,526,'Letter of Recommendation','<i>For the eyes of Militia recruitment officers:\r\r\n\r\r\n<p>Sir,\r\r\n<br>I do hereby certify and vouchsafe that the bearer of this document is a newly-certified capsuleer of good character and firm disposition, whom I do rightly judge is a fine and worthy candidate for enrolment into our most esteemed and successful Militia organization.\r\r\n\r\r\n<p>Furthermore, I have verified that, at time of issuance, the bearer does meet the criteria for Fast Track recruitment, namely that:\r\r\n<ul>\r\r\n<li>The pilot\'s sign-in account is less than thirty (30) days old\r\r\n<li>The pilot\'s standings with our faction are not lower than zero (0)\r\r\n<li>The pilot\'s standings with our faction are below the standard zero-point-five (0.5) threshold for recruitment\r\r\n</ul>\r\r\n\r\r\nPlease verify that these details are correct at time of your receipt of this document. If everything is in order then I formally request that you enroll the bearer into the Militia without hesitation or delay, that they might further serve the just and righteous cause of our people.</i>',0.5,0.1,0,1,NULL,0.0000,1,NULL,0),(30907,314,'Smuggler\'s Warning About Sister Alitura','Good news from Kirus. Remember that Sisters of EVE agent, Alitura, who nearly caught our trail? The boss called in some favors and got her reassigned to Arnon IX in Essence. The good Sister Alitura may be resourceful, but she\'d need a capsuleer with clearance to all four empires to be any threat, and we know how much the Sisters love capsuleers. ',1,1,0,1,NULL,0.0000,1,NULL,0),(30908,715,'Gue Mouey\'s Vindicator','This station is being used as a Syndicate trade hub.  It was recently erected as the Syndicates answer to the growing demand for drugs and weapons in this constellation.  It also acts as a neutral bargaining ground between Caldari vendors from Kois City and the pirate elements.',0,0,0,1,8,0.0000,0,NULL,0),(30927,319,'Sleeper Archive Terminal','This structure appears to be a modified engineering station, although it contains more instruments for information-gathering than commonly seen in stations of its ilk. Currently inactive, the terminal sports a great number of antechambers and libraries both digital and physical, as well as innumerable laboratories of all shapes and sizes.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(30948,927,'State Transport','Industrials are a common sight in the universe of EVE, connecting supply points to each other.',13500000,270000,5250,1,1,0.0000,0,NULL,0),(30949,952,'Josameto Verification Center','To more rapidly assist capsuleers in their employ, Nugoeihuvi has recently established verification centers such as this one, which operate as a one-stop destination where pilots can receive future orders, sensitive cargo and secure information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30950,673,'Corporate Liaison','These corporate agents act as intermediaries between spacefaring pilots and their station-bound counterparts. Anything from the assignment of work to intelligence provision can be handled by authorized liaisons. ',9600000,96000,450,1,1,0.0000,0,NULL,0),(30951,314,'Verification Key','These keys are used by many corporations in the Caldari State to more easily and efficiently identify the bearer as a trusted employee, often granting them access to exclusive or classified information.',10,3,0,1,NULL,0.0000,1,NULL,0),(30952,314,'Dossier   Author Unknown','This dossier appears to be an excerpt of  internal employee profiling done by Nugoeihuvi Corporation.<br><br> Isha is something of an enigma, even to the few of us who know him. Apparently he\'s spent over 30 years here at NOH. Nobody has many details since he doesn\'t seem to keep any staff. I\'ve heard he makes use of pod pilots whenever he needs anything done but I\'ve no idea where the funds for that come from, perhaps the NOH directorate. <br><br> My House of Records contacts tell me he started work here in the Internal Security division of NOH. He now works in another department, unofficially titled as  Advisory . It\'s anyone\'s guess when he moved across or what his work entails. In situations like these nobody asks questions. \r\r\n',10,0.1,0,1,NULL,0.0000,1,NULL,0),(30953,952,'Cargo Facility 7A-21','This industrial structure serves as a platform for warehouses and the sorting of cargo containers.',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(30954,314,'Hyasyoda Captain','Recovered from a battered security compound, this Hyasyoda captain met an untimely end. His demise suggests that perhaps Hyasyoda wasn\'t in total agreement with Serpentis about the arrangements made in Onirvura.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(30955,314,'S.I Formula Sheet','Nothing in this file is decipherable, only the name. Serpentis could be using any one of a million different decryption methods. The good news is that a brute force attack could take as little as a few days, the bad news is that it could also take as long as a few decades. It all depends on how esoteric the cipher is, or if it\'s even a known, documented one. If it\'s a hybrid cipher, then it depends on how unique or distinctive both - assuming it\'s only two, of course - original parent ciphers were. A hybrid decryption analysis alone can take weeks, assuming that an original identifier for one single method is found.<br><br>It\'s probably best to just take this back to Isha.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(30956,306,'Hyasyoda Security Compound','This minor defense facility reveals that heavy fighting took place here not long ago. Giant holes in the outer armor have still not been properly repaired, and heat signatures coming from inside the compound show that some fires within have not even been extinguished; only contained, as they slowly burn themselves out of oxygen.',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(30957,517,'Aursa Kunivuri\'s Tayra','A Tayra piloted by an agent.',0,0,0,1,1,0.0000,0,NULL,0),(30964,314,'CPF.HYA LogInt Facility POI-26: Data Cache','Found amongst the rubble of the Hyasyoda Logistics Center, this heavily encrypted data cache reveals very little. There is however, one dysfunctional and damaged data partition that can be easily read. Although much of the information is banal and uninteresting administrative jargon, there is one small report included that touches upon the Serpentis facility. Strangely enough, according to the official documentation here, the last time any Hyasyoda personnel visited the area was almost a year ago.',10,3,0,1,NULL,0.0000,1,NULL,0),(30965,952,'Communications Array','Communications Array',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(30966,526,'NOH Signal Operators','Trusted with secrets that at times, are shared only with the uppermost echelons of Nugoeihuvi, these signal operators are the very definition of  insiders . For these men and women, there will be no other career in their life. The classified information they transmit on a daily basis ensures that much.<br><br>Although Caldari in positions like this tend to lead lives as happy as any other citizen, those lives can also quite easily come to an end if they ever decide the grass is greener elsewhere, or cave to an offer of ISK for information. Those who are identified as potential risks are frequently targeted by Nugoeihuvi\'s own Internal Security department, if not immediately  removed . Nugoeihuvi\'s defense force is called  Internal Security  for a reason; they practically invented the concept, refining it to the level of ruthless self-scrutiny inherent in every corporate infrastructure today.',1,1,0,1,NULL,0.0000,1,NULL,0),(30967,314,'Questionable Cargo','This small container has been welded shut and then covered in a thin red film of hardened fullerene alloys. Gaining access would require a plethora of specialized scientific equipment. Why an entertainment company like Nugoeihuvi would be interested in such an item is anyone\'s guess.   ',10,3,0,1,NULL,0.0000,1,NULL,0),(30968,283,'CPF Security Personnel','Corporate Police Force personnel pride themselves on the reputation they have for remaining calm in even the most pressing times. This crew hardly looks shaken, despite having been pulled from a facility that just moments after their departure, became a ball of flame and debris. For them, such things are likely a frequent occurrence.',85,3,0,1,NULL,0.0000,1,NULL,0),(30969,306,'CPF Habitation Module','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30970,875,'State Transport Freighter','The large navy forces of the Empires regularly use freighters to transport a wide variety of military items and personnel en masse.',1200000000,16250000,785000,1,1,0.0000,0,NULL,0),(30974,670,'Civilian Amarr Bestower','The Bestower has for decades been used by the Empire as a slave transport, shipping human labor between cultivated planets in Imperial space. As a proof to how reliable this class has been through the years, the Emperor himself has used an upgraded version of this very same class as transports for the Imperial Treasury. The Bestower has very thick armor and large cargo space.\r\r\n\r\r\nThis ship poses no immediate threat.',13500000,260000,5100,1,4,0.0000,0,NULL,0),(30975,474,'FedNav F.O.F Identifier Tag AC-106V:FNSBR','This device is granted to Federation Navy pilots in the Black Rise theatre of operations, where it helps avoid friendly-fire incidents against undercover Gallente pilots flying Caldari and Amarr ships. Once placed inside the cargo bay, it integrates itself through short-range wireless transponders into the host vessel\'s electronics systems, marking it as a  friendly  to Federation Navy ships.<br><br>Given the obvious exploitability of such a system, these ID tags represent just one part of the Federation Navy\'s sophisticated F.O.F tracking methods, and any hostile pilots attempting to rely on this alone to infiltrate Federation borders will find that the ruse only lasts so long. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(30976,306,'Federation Navy Shipyard','Large construction tasks can be undertaken at this shipyard.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(30980,283,'Caldari Prisoners of War','All of these Caldari P.O.Ws show the signs of appalling treatment over an extended period of time. Even the most well-off are still suffering from starvation and serious malnourishment. The worst of them are barely alive after enduring sleep deprivation, physical abuse and other more excessive forms of torture. The women in particular, have not fared well under their Gallente jail masters, who have remorselessly taken whatever they desired from their captured prey.',100,0.5,0,1,NULL,0.0000,1,NULL,0),(30981,306,'Federation Detention Facility FNSBR-106V.1','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30982,306,'Encrypted Communications Array','Dull, tedious treasure lies within.',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(30987,773,'Small Trimark Armor Pump I','This ship modification is designed to increase a ship\'s total armor hit points at the expense of max velocity.',200,5,0,1,NULL,0.0000,1,1206,0),(30988,787,'Small Trimark Armor Pump I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1203,0),(30991,226,'Pandemic Legion - Winners of Alliance Tournament VI','Constructed in honor of the capsuleers of Pandemic Legion who fought and defeated their opponents, in a series of gruelling and murderous fights, to claim their place as winners of the sixth round of the great Alliance Tournament. Pandemic Legion can truly claim to be among the true elite, the best of the best.',0,0,0,1,NULL,0.0000,0,NULL,0),(30992,517,'Sinas Egassuo\'s Chimera','The Chimera\'s design is based upon the Kairiola, a vessel holding tremendous historical significance for the Caldari. Initially a water freighter, the Kairiola was refitted in the days of the Gallente-Caldari war to act as a fighter carrier during the orbital bombardment of Caldari Prime. It was most famously flown by the legendary Admiral Yakia Tovil-Toba directly into Gallente Prime\'s atmosphere, where it fragmented and struck several key locations on the planet. This event, where the good Admiral gave his life, marked the culmination of a week\'s concentrated campaign of distraction which enabled the Caldari to evacuate their people from their besieged home planet. Where the Chimera roams, the Caldari remember.',0,0,0,1,1,0.0000,0,NULL,0),(30993,773,'Capital Trimark Armor Pump I','This ship modification is designed to increase a ship\'s total armor hit points at the expense of max velocity.',200,40,0,1,NULL,0.0000,1,1730,0),(30994,787,'Capital Trimark Armor Pump I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1719,0),(30995,861,'Gallente Federation Civilians','A Gallente Federation shuttle.',1600000,5000,10,1,8,0.0000,0,NULL,0),(30996,306,'Shuttle Wreck','This small ball of debris looks like it might once have been a shuttle. Or possibly some jettisoned garbage. There is definitely some Gallente technology mixed in here somewhere though.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(30997,773,'Small Anti-EM Pump I','This ship modification is designed to increase a ship\'s armor EM resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(30998,787,'Small Anti-EM Pump I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1203,0),(30999,773,'Medium Anti-EM Pump I','This ship modification is designed to increase a ship\'s armor EM resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31000,787,'Medium Anti-EM Pump I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1204,0),(31001,773,'Capital Anti-EM Pump I','This ship modification is designed to increase a ship\'s armor EM resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(31002,787,'Capital Anti-EM Pump I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1719,0),(31003,773,'Small Anti-EM Pump II','This ship modification is designed to increase a ship\'s armor EM resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31004,787,'Small Anti-EM Pump II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31005,773,'Medium Anti-EM Pump II','This ship modification is designed to increase a ship\'s armor EM resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31006,787,'Medium Anti-EM Pump II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31007,773,'Capital Anti-EM Pump II','This ship modification is designed to increase a ship\'s armor EM resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(31008,787,'Capital Anti-EM Pump II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31009,773,'Small Anti-Explosive Pump I','This ship modification is designed to increase a ship\'s armor explosive resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31010,787,'Small Anti-Explosive Pump I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1203,0),(31011,773,'Medium Anti-Explosive Pump I','This ship modification is designed to increase a ship\'s armor explosive resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31012,787,'Medium Anti-Explosive Pump I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1204,0),(31013,773,'Capital Anti-Explosive Pump I','This ship modification is designed to increase a ship\'s armor explosive resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(31014,787,'Capital Anti-Explosive Pump I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1719,0),(31015,773,'Small Anti-Explosive Pump II','This ship modification is designed to increase a ship\'s armor explosive resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31016,787,'Small Anti-Explosive Pump II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31017,773,'Medium Anti-Explosive Pump II','This ship modification is designed to increase a ship\'s armor explosive resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31018,787,'Medium Anti-Explosive Pump II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31019,773,'Capital Anti-Explosive Pump II','This ship modification is designed to increase a ship\'s armor explosive resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(31020,787,'Capital Anti-Explosive Pump II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31021,773,'Small Anti-Kinetic Pump I','This ship modification is designed to increase a ship\'s armor kinetic resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31022,787,'Small Anti-Kinetic Pump I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1203,0),(31023,773,'Medium Anti-Kinetic Pump I','This ship modification is designed to increase a ship\'s armor kinetic resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31024,787,'Medium Anti-Kinetic Pump I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1204,0),(31025,773,'Capital Anti-Kinetic Pump I','This ship modification is designed to increase a ship\'s armor kinetic resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(31026,787,'Capital Anti-Kinetic Pump I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1719,0),(31027,773,'Small Anti-Kinetic Pump II','This ship modification is designed to increase a ship\'s armor kinetic resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31028,787,'Small Anti-Kinetic Pump II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31029,773,'Medium Anti-Kinetic Pump II','This ship modification is designed to increase a ship\'s armor kinetic resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31030,787,'Medium Anti-Kinetic Pump II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31031,773,'Capital Anti-Kinetic Pump II','This ship modification is designed to increase a ship\'s armor kinetic resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(31032,787,'Capital Anti-Kinetic Pump II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31033,773,'Small Anti-Thermic Pump I','This ship modification is designed to increase a ship\'s armor thermal resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31034,787,'Small Anti-Thermic Pump I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1203,0),(31035,773,'Medium Anti-Thermic Pump I','This ship modification is designed to increase a ship\'s armor thermal resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31036,787,'Medium Anti-Thermic Pump I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1204,0),(31037,773,'Capital Anti-Thermic Pump I','This ship modification is designed to increase a ship\'s armor thermal resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(31038,787,'Capital Anti-Thermic Pump I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1719,0),(31039,773,'Small Anti-Thermic Pump II','This ship modification is designed to increase a ship\'s armor thermal resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31040,787,'Small Anti-Thermic Pump II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31041,773,'Medium Anti-Thermic Pump II','This ship modification is designed to increase a ship\'s armor thermal resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31042,787,'Medium Anti-Thermic Pump II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31043,773,'Capital Anti-Thermic Pump II','This ship modification is designed to increase a ship\'s armor thermal resistance at the expense of max velocity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(31044,787,'Capital Anti-Thermic Pump II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31045,773,'Small Auxiliary Nano Pump I','This ship modification is designed to increase a ship\'s armor repairer repair amount at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31046,787,'Small Auxiliary Nano Pump I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1203,0),(31047,773,'Medium Auxiliary Nano Pump I','This ship modification is designed to increase a ship\'s armor repairer repair amount at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31048,787,'Medium Auxiliary Nano Pump I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1204,0),(31049,773,'Capital Auxiliary Nano Pump II','This ship modification is designed to increase a ship\'s armor repairer repair amount at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(31050,787,'Capital Auxiliary Nano Pump II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31051,773,'Small Auxiliary Nano Pump II','This ship modification is designed to increase a ship\'s armor repairer repair amount at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31052,787,'Small Auxiliary Nano Pump II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31053,773,'Medium Auxiliary Nano Pump II','XThis ship modification is designed to increase a ship\'s armor repairer repair amount at the expense of increased power grid need for them.\r\r\n\r\r\n{[messageid]299915}',200,10,0,1,NULL,0.0000,1,1207,0),(31054,787,'Medium Auxiliary Nano Pump II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31055,773,'Medium Trimark Armor Pump I','This ship modification is designed to increase a ship\'s total armor hit points at the expense of max velocity.',200,10,0,1,NULL,0.0000,1,1207,0),(31056,787,'Medium Trimark Armor Pump I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1204,0),(31057,773,'Small Trimark Armor Pump II','This ship modification is designed to increase a ship\'s total armor hit points at the expense of max velocity.',200,5,0,1,NULL,0.0000,1,1206,0),(31058,787,'Small Trimark Armor Pump II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31059,773,'Medium Trimark Armor Pump II','This ship modification is designed to increase a ship\'s total armor hit points at the expense of max velocity.',200,10,0,1,NULL,0.0000,1,1207,0),(31060,787,'Medium Trimark Armor Pump II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31061,773,'Capital Trimark Armor Pump II','This ship modification is designed to increase a ship\'s total armor hit points at the expense of max velocity.',200,40,0,1,NULL,0.0000,1,1730,0),(31062,787,'Capital Trimark Armor Pump II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31063,773,'Small Nanobot Accelerator I','This ship modification is designed to reduce a ship\'s armor repair cycle duration at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31064,787,'Small Nanobot Accelerator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1203,0),(31065,773,'Medium Nanobot Accelerator I','This ship modification is designed to reduce a ship\'s armor repair cycle duration at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31066,787,'Medium Nanobot Accelerator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1204,0),(31067,773,'Capital Nanobot Accelerator I','This ship modification is designed to reduce a ship\'s armor repair cycle duration at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1730,0),(31068,787,'Capital Nanobot Accelerator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1719,0),(31069,773,'Small Nanobot Accelerator II','This ship modification is designed to reduce a ship\'s armor repair cycle duration at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1206,0),(31070,787,'Small Nanobot Accelerator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31071,773,'Medium Nanobot Accelerator II','This ship modification is designed to reduce a ship\'s armor repair cycle duration at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1207,0),(31072,787,'Medium Nanobot Accelerator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31073,773,'Medium Remote Repair Augmentor I','This ship modification is designed to reduce the capacitor need for a ship\'s remote armor repair modules at the expense of max velocity.\r\r\n',200,10,0,1,NULL,0.0000,1,1207,0),(31074,787,'Medium Remote Repair Augmentor I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1204,0),(31075,773,'Capital Remote Repair Augmentor I','This ship modification is designed to reduce the capacitor need for a ship\'s remote armor repair modules at the expense of max velocity.',200,40,0,1,NULL,0.0000,1,1730,0),(31076,787,'Capital Remote Repair Augmentor I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1719,0),(31077,773,'Small Remote Repair Augmentor II','This ship modification is designed to reduce the capacitor need for a ship\'s remote armor repair modules at the expense of max velocity.',200,5,0,1,NULL,0.0000,1,1206,0),(31078,787,'Small Remote Repair Augmentor II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31079,773,'Medium Remote Repair Augmentor II','This ship modification is designed to reduce the capacitor need for a ship\'s remote armor repair modules at the expense of max velocity.',200,10,0,1,NULL,0.0000,1,1207,0),(31080,787,'Medium Remote Repair Augmentor II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31081,773,'Capital Remote Repair Augmentor II','This ship modification is designed to reduce the capacitor need for a ship\'s remote armor repair modules at the expense of max velocity.',200,40,0,1,NULL,0.0000,1,1730,0),(31082,787,'Capital Remote Repair Augmentor II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31083,1232,'Small Salvage Tackle I','This ship modification is designed to increase a ship\'s chance of salvage retrieval at the expense of max velocity.',200,5,0,1,NULL,0.0000,1,1782,0),(31084,787,'Small Salvage Tackle I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1800,0),(31085,1232,'Medium Salvage Tackle I','This ship modification is designed to increase a ship\'s chance of salvage retrieval at the expense of max velocity.',200,10,0,1,NULL,0.0000,1,1783,0),(31086,787,'Medium Salvage Tackle I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1799,0),(31087,1232,'Capital Salvage Tackle I','This ship modification is designed to increase a ship\'s chance of salvage retrieval at the expense of max velocity.',200,40,0,1,NULL,0.0000,1,1785,0),(31088,787,'Capital Salvage Tackle I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1797,0),(31089,1232,'Small Salvage Tackle II','This ship modification is designed to increase a ship\'s chance of salvage retrieval at the expense of max velocity.',200,5,0,1,NULL,0.0000,1,1782,0),(31090,787,'Small Salvage Tackle II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31091,1232,'Medium Salvage Tackle II','This ship modification is designed to increase a ship\'s chance of salvage retrieval at the expense of max velocity.',200,10,0,1,NULL,0.0000,1,1783,0),(31092,787,'Medium Salvage Tackle II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31093,1232,'Capital Salvage Tackle II','This ship modification is designed to increase a ship\'s chance of salvage retrieval at the expense of max velocity.',200,40,0,1,NULL,0.0000,1,1785,0),(31094,787,'Capital Salvage Tackle II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31103,517,'Gian Parele\'s Pleasure Cruiser','Gian Parele\'s Pleasure Cruiser',13075000,115000,1750,1,8,0.0000,0,NULL,0),(31105,782,'Small Auxiliary Thrusters I','This ship modification is designed to increase a ship\'s max velocity at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1210,0),(31106,787,'Small Auxiliary Thrusters I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1240,0),(31107,782,'Medium Auxiliary Thrusters I','This ship modification is designed to increase a ship\'s max velocity at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1211,0),(31108,787,'Medium Auxiliary Thrusters I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1241,0),(31109,782,'Capital Auxiliary Thrusters I','This ship modification is designed to increase a ship\'s max velocity at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1740,0),(31110,787,'Capital Auxiliary Thrusters I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1720,0),(31111,782,'Small Auxiliary Thrusters II','This ship modification is designed to increase a ship\'s max velocity at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1210,0),(31112,787,'Small Auxiliary Thrusters II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31113,782,'Medium Auxiliary Thrusters II','This ship modification is designed to increase a ship\'s max velocity at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1211,0),(31114,787,'Medium Auxiliary Thrusters II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31115,782,'Capital Auxiliary Thrusters II','This ship modification is designed to increase a ship\'s max velocity at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1740,0),(31116,787,'Capital Auxiliary Thrusters II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31117,782,'Small Cargohold Optimization I','This ship modification is designed to increase a ship\'s cargo capacity at the expense of armor amount.',200,5,0,1,NULL,0.0000,1,1210,0),(31118,787,'Small Cargohold Optimization I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1240,0),(31119,782,'Medium Cargohold Optimization I','This ship modification is designed to increase a ship\'s cargo capacity at the expense of armor amount.',200,10,0,1,NULL,0.0000,1,1211,0),(31120,787,'Medium Cargohold Optimization I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1241,0),(31121,782,'Capital Cargohold Optimization I','This ship modification is designed to increase a ship\'s cargo capacity at the expense of armor amount.',200,40,0,1,NULL,0.0000,1,1740,0),(31122,787,'Capital Cargohold Optimization I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1720,0),(31123,782,'Small Cargohold Optimization II','This ship modification is designed to increase a ship\'s cargo capacity at the expense of armor amount.',200,5,0,1,NULL,0.0000,1,1210,0),(31124,787,'Small Cargohold Optimization II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31125,782,'Medium Cargohold Optimization II','This ship modification is designed to increase a ship\'s cargo capacity at the expense of armor amount.',200,10,0,1,NULL,0.0000,1,1211,0),(31126,787,'Medium Cargohold Optimization II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31127,782,'Capital Cargohold Optimization II','This ship modification is designed to increase a ship\'s cargo capacity at the expense of armor amount.',200,40,0,1,NULL,0.0000,1,1740,0),(31128,787,'Capital Cargohold Optimization II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31129,782,'Small Dynamic Fuel Valve I','This ship modification is designed to reduce the capacitor need of a ship\'s afterburner and microwarpdrive modules at the expense of armor amount.\r\r\n',200,5,0,1,NULL,0.0000,1,1210,0),(31130,787,'Small Dynamic Fuel Valve I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1240,0),(31131,782,'Medium Dynamic Fuel Valve I','This ship modification is designed to reduce the capacitor need of a ship\'s afterburner and microwarpdrive modules at the expense of armor amount.\r\r\n',200,10,0,1,NULL,0.0000,1,1211,0),(31132,787,'Medium Dynamic Fuel Valve I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1241,0),(31133,782,'Capital Dynamic Fuel Valve I','This ship modification is designed to reduce the capacitor need of a ship\'s afterburner and microwarpdrive modules at the expense of armor amount.\r\r\n',200,40,0,1,NULL,0.0000,1,1740,0),(31134,787,'Capital Dynamic Fuel Valve I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1720,0),(31135,782,'Small Dynamic Fuel Valve II','This ship modification is designed to reduce the capacitor need of a ship\'s afterburner and microwarpdrive modules at the expense of armor amount.\r\r\n',200,5,0,1,NULL,0.0000,1,1210,0),(31136,787,'Small Dynamic Fuel Valve II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31137,782,'Medium Dynamic Fuel Valve II','This ship modification is designed to reduce the capacitor need of a ship\'s afterburner and microwarpdrive modules at the expense of armor amount.\r\r\n',200,10,0,1,NULL,0.0000,1,1211,0),(31138,787,'Medium Dynamic Fuel Valve II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31139,782,'Capital Dynamic Fuel Valve II','This ship modification is designed to reduce the capacitor need of a ship\'s afterburner and microwarpdrive modules at the expense of armor amount.\r\r\n',200,40,0,1,NULL,0.0000,1,1740,0),(31140,787,'Capital Dynamic Fuel Valve II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31141,782,'Small Engine Thermal Shielding I','This ship modification is designed to increase the duration of a ship\'s afterburner or microwarpdrive modules at the expense of armor amount.',200,5,0,1,NULL,0.0000,1,1210,0),(31142,787,'Small Engine Thermal Shielding I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1240,0),(31143,782,'Medium Engine Thermal Shielding I','This ship modification is designed to increase the duration of a ship\'s afterburner or microwarpdrive modules at the expense of armor amount.',200,10,0,1,NULL,0.0000,1,1211,0),(31144,787,'Medium Engine Thermal Shielding I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1241,0),(31145,782,'Capital Engine Thermal Shielding I','This ship modification is designed to increase the duration of a ship\'s afterburner or microwarpdrive modules at the expense of armor amount.',200,40,0,1,NULL,0.0000,1,1740,0),(31146,787,'Capital Engine Thermal Shielding I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1720,0),(31147,782,'Small Engine Thermal Shielding II','This ship modification is designed to increase the duration of a ship\'s afterburner or microwarpdrive modules at the expense of armor amount.',200,5,0,1,NULL,0.0000,1,1210,0),(31148,787,'Small Engine Thermal Shielding II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31149,782,'Medium Engine Thermal Shielding II','This ship modification is designed to increase the duration of a ship\'s afterburner or microwarpdrive modules at the expense of armor amount.',200,10,0,1,NULL,0.0000,1,1211,0),(31150,787,'Medium Engine Thermal Shielding II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31151,782,'Capital Engine Thermal Shielding II','This ship modification is designed to increase the duration of a ship\'s afterburner or microwarpdrive modules at the expense of armor amount.',200,40,0,1,NULL,0.0000,1,1740,0),(31152,787,'Capital Engine Thermal Shielding II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31153,782,'Small Low Friction Nozzle Joints I','This ship modification is designed to increase a ship\'s agility at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1210,0),(31154,787,'Small Low Friction Nozzle Joints I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1240,0),(31155,782,'Medium Low Friction Nozzle Joints I','This ship modification is designed to increase a ship\'s agility at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1211,0),(31156,787,'Medium Low Friction Nozzle Joints I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1241,0),(31157,782,'Capital Low Friction Nozzle Joints I','This ship modification is designed to increase a ship\'s agility at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1740,0),(31158,787,'Capital Low Friction Nozzle Joints I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1720,0),(31159,782,'Small Hyperspatial Velocity Optimizer I','This ship modification is designed to increase a ship\'s warp speed at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,4,0.0000,1,1210,0),(31160,787,'Small Hyperspatial Velocity Optimizer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1240,0),(31161,782,'Medium Hyperspatial Velocity Optimizer I','This ship modification is designed to increase a ship\'s warp speed at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,4,0.0000,1,1211,0),(31162,787,'Medium Hyperspatial Velocity Optimizer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1241,0),(31163,782,'Capital Hyperspatial Velocity Optimizer I','This ship modification is designed to increase a ship\'s warp speed at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,4,0.0000,1,1740,0),(31164,787,'Capital Hyperspatial Velocity Optimizer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1720,0),(31165,782,'Small Hyperspatial Velocity Optimizer II','This ship modification is designed to increase a ship\'s warp speed at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,4,0.0000,1,1210,0),(31166,787,'Small Hyperspatial Velocity Optimizer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31167,782,'Medium Hyperspatial Velocity Optimizer II','This ship modification is designed to increase a ship\'s warp speed at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,4,0.0000,1,1211,0),(31168,787,'Medium Hyperspatial Velocity Optimizer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31169,782,'Capital Hyperspatial Velocity Optimizer II','This ship modification is designed to increase a ship\'s warp speed at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,4,0.0000,1,1740,0),(31170,787,'Capital Hyperspatial Velocity Optimizer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31171,782,'Small Low Friction Nozzle Joints II','This ship modification is designed to increase a ship\'s agility at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1210,0),(31172,787,'Small Low Friction Nozzle Joints II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31173,782,'Medium Low Friction Nozzle Joints II','This ship modification is designed to increase a ship\'s agility at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1211,0),(31174,787,'Medium Low Friction Nozzle Joints II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31175,782,'Capital Low Friction Nozzle Joints II','This ship modification is designed to increase a ship\'s agility at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1740,0),(31176,787,'Capital Low Friction Nozzle Joints II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31177,782,'Small Polycarbon Engine Housing I','This ship modification is designed to increase ship\'s velocity and maneuverability at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1210,0),(31178,787,'Small Polycarbon Engine Housing I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1240,0),(31179,782,'Medium Polycarbon Engine Housing I','This ship modification is designed to increase ship\'s velocity and maneuverability at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1211,0),(31180,787,'Medium Polycarbon Engine Housing I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1241,0),(31181,782,'Capital Polycarbon Engine Housing I','This ship modification is designed to increase ship\'s velocity and maneuverability at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1740,0),(31182,787,'Capital Polycarbon Engine Housing I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1720,0),(31183,782,'Small Polycarbon Engine Housing II','This ship modification is designed to increase ship\'s velocity and maneuverability at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1210,0),(31184,787,'Small Polycarbon Engine Housing II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31185,782,'Medium Polycarbon Engine Housing II','This ship modification is designed to increase ship\'s velocity and maneuverability at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1211,0),(31186,787,'Medium Polycarbon Engine Housing II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31187,782,'Capital Polycarbon Engine Housing II','This ship modification is designed to increase ship\'s velocity and maneuverability at the expense of armor amount.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1740,0),(31188,787,'Capital Polycarbon Engine Housing II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31189,782,'Small Warp Core Optimizer I','This ship modification is designed to reduce a ship\'s capacitor need for initiating warp at the expense of increased signature radius.',200,5,0,1,4,0.0000,1,1210,0),(31190,787,'Small Warp Core Optimizer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1240,0),(31191,782,'Medium Warp Core Optimizer I','This ship modification is designed to reduce a ship\'s capacitor need for initiating warp at the expense of increased signature radius.',200,10,0,1,4,0.0000,1,1211,0),(31192,787,'Medium Warp Core Optimizer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1241,0),(31193,782,'Capital Warp Core Optimizer I','This ship modification is designed to reduce a ship\'s capacitor need for initiating warp at the expense of increased signature radius.',200,40,0,1,4,0.0000,1,1740,0),(31194,787,'Capital Warp Core Optimizer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1720,0),(31195,782,'Small Warp Core Optimizer II','This ship modification is designed to reduce a ship\'s capacitor need for initiating warp at the expense of increased signature radius.',200,5,0,1,4,0.0000,1,1210,0),(31196,787,'Small Warp Core Optimizer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31197,782,'Medium Warp Core Optimizer II','This ship modification is designed to reduce a ship\'s capacitor need for initiating warp at the expense of increased signature radius.',200,10,0,1,4,0.0000,1,1211,0),(31198,787,'Medium Warp Core Optimizer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31199,782,'Capital Warp Core Optimizer II','This ship modification is designed to reduce a ship\'s capacitor need for initiating warp at the expense of increased signature radius.',200,40,0,1,4,0.0000,1,1740,0),(31200,787,'Capital Warp Core Optimizer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31201,1233,'Small Emission Scope Sharpener I','This ship modification is designed to increase the efficiency of a ship\'s relic modules.',200,5,0,1,NULL,0.0000,1,1786,0),(31202,787,'Small Emission Scope Sharpener I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1801,0),(31203,1233,'Medium Emission Scope Sharpener I','This ship modification is designed to increase the efficiency of a ship\'s relic modules.',200,10,0,1,NULL,0.0000,1,1787,0),(31204,787,'Medium Emission Scope Sharpener I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1802,0),(31205,1233,'Capital Emission Scope Sharpener I','This ship modification is designed to increase the efficiency of a ship\'s relic modules.',200,40,0,1,NULL,0.0000,1,1789,0),(31206,787,'Capital Emission Scope Sharpener I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1804,0),(31207,1233,'Small Emission Scope Sharpener II','This ship modification is designed to increase the efficiency of a ship\'s relic modules.',200,5,0,1,NULL,0.0000,1,1786,0),(31208,787,'Small Emission Scope Sharpener II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31209,1233,'Medium Emission Scope Sharpener II','This ship modification is designed to increase the efficiency of a ship\'s relic modules.',200,10,0,1,NULL,0.0000,1,1787,0),(31210,787,'Medium Emission Scope Sharpener II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31211,1233,'Capital Emission Scope Sharpener II','This ship modification is designed to increase the efficiency of a ship\'s relic modules.',200,40,0,1,NULL,0.0000,1,1789,0),(31212,787,'Capital Emission Scope Sharpener II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31213,1233,'Small Gravity Capacitor Upgrade I','This ship modification is designed to increase a ship\'s scan probe strength.',200,5,0,1,NULL,0.0000,1,1786,0),(31214,787,'Small Gravity Capacitor Upgrade I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1801,0),(31215,1233,'Medium Gravity Capacitor Upgrade I','This ship modification is designed to increase a ship\'s scan probe strength.',200,10,0,1,NULL,0.0000,1,1787,0),(31216,787,'Medium Gravity Capacitor Upgrade I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1802,0),(31217,1233,'Capital Gravity Capacitor Upgrade I','This ship modification is designed to increase a ship\'s scan probe strength.',200,40,0,1,NULL,0.0000,1,1789,0),(31218,787,'Capital Gravity Capacitor Upgrade I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1804,0),(31220,1233,'Small Gravity Capacitor Upgrade II','This ship modification is designed to increase a ship\'s scan probe strength.',200,5,0,1,NULL,0.0000,1,1786,0),(31221,787,'Small Gravity Capacitor Upgrade II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31222,1233,'Medium Gravity Capacitor Upgrade II','This ship modification is designed to increase a ship\'s scan probe strength.',200,10,0,1,NULL,0.0000,1,1787,0),(31223,787,'Medium Gravity Capacitor Upgrade II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31224,1233,'Capital Gravity Capacitor Upgrade II','This ship modification is designed to increase a ship\'s scan probe strength.',200,40,0,1,NULL,0.0000,1,1789,0),(31225,787,'Capital Gravity Capacitor Upgrade II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31226,781,'Small Liquid Cooled Electronics I','This ship modification is designed to reduce the CPU need of modules which require the electronics upgrades skill.\r\r\n',200,5,0,1,NULL,0.0000,1,1222,0),(31227,787,'Small Liquid Cooled Electronics I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1252,0),(31228,781,'Medium Liquid Cooled Electronics I','This ship modification is designed to reduce the CPU need of modules which require the electronics upgrades skill.\r\r\n',200,10,0,1,NULL,0.0000,1,1223,0),(31229,787,'Medium Liquid Cooled Electronics I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1253,0),(31230,781,'Capital Liquid Cooled Electronics I','This ship modification is designed to reduce the CPU need of modules which require the electronics upgrades skill.\r\r\n',200,40,0,1,NULL,0.0000,1,1736,0),(31231,787,'Capital Liquid Cooled Electronics I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1724,0),(31232,781,'Small Liquid Cooled Electronics II','This ship modification is designed to reduce the CPU need of modules which require the electronics upgrades skill.\r\r\n',200,5,0,1,NULL,0.0000,1,1222,0),(31233,787,'Small Liquid Cooled Electronics II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31234,781,'Medium Liquid Cooled Electronics II','This ship modification is designed to reduce the CPU need of modules which require the electronics upgrades skill.\r\r\n',200,10,0,1,NULL,0.0000,1,1223,0),(31235,787,'Medium Liquid Cooled Electronics II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31236,781,'Capital Liquid Cooled Electronics II','This ship modification is designed to reduce the CPU need of modules which require the electronics upgrades skill.\r\r\n',200,40,0,1,NULL,0.0000,1,1736,0),(31237,787,'Capital Liquid Cooled Electronics II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31238,1233,'Small Memetic Algorithm Bank I','This ship modification is designed to increase the efficiency of a ship\'s data modules.\r\r\n',200,5,0,1,NULL,0.0000,1,1786,0),(31239,787,'Small Memetic Algorithm Bank I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1801,0),(31240,1233,'Medium Memetic Algorithm Bank I','This ship modification is designed to increase the efficiency of a ship\'s data modules.\r\r\n',200,10,0,1,NULL,0.0000,1,1787,0),(31241,787,'Medium Memetic Algorithm Bank I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1802,0),(31242,1233,'Capital Memetic Algorithm Bank I','This ship modification is designed to increase the efficiency of a ship\'s data modules.',200,40,0,1,NULL,0.0000,1,1789,0),(31243,787,'Capital Memetic Algorithm Bank I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1804,0),(31244,1233,'Small Memetic Algorithm Bank II','This ship modification is designed to increase the efficiency of a ship\'s data modules.\r\r\n',200,5,0,1,NULL,0.0000,1,1786,0),(31245,787,'Small Memetic Algorithm Bank II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31246,1233,'Medium Memetic Algorithm Bank II','This ship modification is designed to increase the efficiency of a ship\'s data modules.\r\r\n',200,10,0,1,NULL,0.0000,1,1787,0),(31247,787,'Medium Memetic Algorithm Bank II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31248,1233,'Capital Memetic Algorithm Bank II','This ship modification is designed to increase the efficiency of a ship\'s data modules.\r\r\n',200,40,0,1,NULL,0.0000,1,1789,0),(31249,787,'Capital Memetic Algorithm Bank II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31250,786,'Small Signal Disruption Amplifier I','This ship modification is designed to reduce a ship\'s capacitor need for ECM and ECM Burst modules.\r\r\n',200,5,0,1,NULL,0.0000,1,1219,0),(31251,787,'Small Signal Disruption Amplifier I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1249,0),(31252,786,'Medium Signal Disruption Amplifier I','This ship modification is designed to reduce a ship\'s capacitor need for ECM and ECM Burst modules.\r\r\n',200,10,0,1,NULL,0.0000,1,1220,0),(31253,787,'Medium Signal Disruption Amplifier I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1250,0),(31254,786,'Capital Signal Disruption Amplifier I','This ship modification is designed to reduce a ship\'s capacitor need for ECM and ECM Burst modules.\r\r\n',200,40,0,1,NULL,0.0000,1,1737,0),(31255,787,'Capital Signal Disruption Amplifier I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1723,0),(31256,786,'Small Signal Disruption Amplifier II','This ship modification is designed to reduce a ship\'s capacitor need for ECM and ECM Burst modules.\r\r\n',200,5,0,1,NULL,0.0000,1,1219,0),(31257,787,'Small Signal Disruption Amplifier II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31258,786,'Medium Signal Disruption Amplifier II','This ship modification is designed to reduce a ship\'s capacitor need for ECM and ECM Burst modules.\r\r\n',200,10,0,1,NULL,0.0000,1,1220,0),(31259,787,'Medium Signal Disruption Amplifier II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31260,786,'Capital Signal Disruption Amplifier II','This ship modification is designed to reduce a ship\'s capacitor need for ECM and ECM Burst modules.\r\r\n',200,40,0,1,NULL,0.0000,1,1737,0),(31261,787,'Capital Signal Disruption Amplifier II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31262,786,'Small Inverted Signal Field Projector I','This ship modification is designed to increase the effectiveness of fitted remote sensor dampeners at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1219,0),(31263,787,'Small Inverted Signal Field Projector I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1249,0),(31264,786,'Medium Inverted Signal Field Projector I','This ship modification is designed to increase the effectiveness of fitted remote sensor dampeners at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1220,0),(31265,787,'Medium Inverted Signal Field Projector I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1250,0),(31266,786,'Capital Inverted Signal Field Projector I','This ship modification is designed to increase the effectiveness of fitted remote sensor dampeners at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1737,0),(31267,787,'Capital Inverted Signal Field Projector I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1723,0),(31268,786,'Small Inverted Signal Field Projector II','This ship modification is designed to increase the effectiveness of fitted remote sensor dampeners at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,2400.0000,1,1219,0),(31269,787,'Small Inverted Signal Field Projector II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31270,786,'Medium Inverted Signal Field Projector II','This ship modification is designed to increase the effectiveness of fitted remote sensor dampeners at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,4800.0000,1,1220,0),(31271,787,'Medium Inverted Signal Field Projector II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31272,786,'Capital Inverted Signal Field Projector II','This ship modification is designed to increase the effectiveness of fitted remote sensor dampeners at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,19200.0000,1,1737,0),(31273,787,'Capital Inverted Signal Field Projector II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31274,1234,'Small Ionic Field Projector I','This ship modification is designed to increase a ship\'s targeting range at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1790,0),(31275,787,'Small Ionic Field Projector I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1805,0),(31276,1234,'Medium Ionic Field Projector I','This ship modification is designed to increase a ship\'s targeting range at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1791,0),(31277,787,'Medium Ionic Field Projector I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1806,0),(31278,1234,'Capital Ionic Field Projector I','This ship modification is designed to increase a ship\'s targeting range at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1793,0),(31279,787,'Capital Ionic Field Projector I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1808,0),(31280,1234,'Small Ionic Field Projector II','This ship modification is designed to increase a ship\'s targeting range at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,2400.0000,1,1790,0),(31281,787,'Small Ionic Field Projector II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31282,1234,'Medium Ionic Field Projector II','This ship modification is designed to increase a ship\'s targeting range at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,4800.0000,1,1791,0),(31283,787,'Medium Ionic Field Projector II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31284,1234,'Capital Ionic Field Projector II','This ship modification is designed to increase a ship\'s targeting range at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,19200.0000,1,1793,0),(31285,787,'Capital Ionic Field Projector II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31286,786,'Small Particle Dispersion Augmentor I','This ship modification is designed to increase the strength of a ship\'s ECM jammers at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1219,0),(31287,787,'Small Particle Dispersion Augmentor I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1249,0),(31288,786,'Medium Particle Dispersion Augmentor I','This ship modification is designed to increase the strength of a ship\'s ECM jammers at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1220,0),(31289,787,'Medium Particle Dispersion Augmentor I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1250,0),(31290,786,'Capital Particle Dispersion Augmentor I','This ship modification is designed to increase the strength of a ship\'s ECM jammers at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1737,0),(31291,787,'Capital Particle Dispersion Augmentor I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1723,0),(31292,786,'Small Particle Dispersion Augmentor II','This ship modification is designed to increase the strength of a ship\'s ECM jammers at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,2400.0000,1,1219,0),(31293,787,'Small Particle Dispersion Augmentor II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31294,786,'Medium Particle Dispersion Augmentor II','This ship modification is designed to increase the strength of a ship\'s ECM jammers at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,4800.0000,1,1220,0),(31295,787,'Medium Particle Dispersion Augmentor II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31296,786,'Capital Particle Dispersion Augmentor II','This ship modification is designed to increase the strength of a ship\'s ECM jammers at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,19200.0000,1,1737,0),(31297,787,'Capital Particle Dispersion Augmentor II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31298,786,'Small Particle Dispersion Projector I','This ship modification is designed to increase the optimal range of a ship\'s ECM, remote sensor dampeners, tracking disruptors and target painters at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1219,0),(31299,787,'Small Particle Dispersion Projector I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1249,0),(31300,786,'Medium Particle Dispersion Projector I','This ship modification is designed to increase the optimal range of a ship\'s ECM, remote sensor dampeners, tracking disruptors and target painters at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1220,0),(31301,787,'Medium Particle Dispersion Projector I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1250,0),(31302,786,'Capital Particle Dispersion Projector I','This ship modification is designed to increase the optimal range of a ship\'s ECM, remote sensor dampeners, tracking disruptors and target painters at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1737,0),(31303,787,'Capital Particle Dispersion Projector I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1723,0),(31304,786,'Small Particle Dispersion Projector II','This ship modification is designed to increase the optimal range of a ship\'s ECM, remote sensor dampeners, tracking disruptors and target painters at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,2400.0000,1,1219,0),(31305,787,'Small Particle Dispersion Projector II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31306,786,'Medium Particle Dispersion Projector II','This ship modification is designed to increase the optimal range of a ship\'s ECM, remote sensor dampeners, tracking disruptors and target painters at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,4800.0000,1,1220,0),(31307,787,'Medium Particle Dispersion Projector II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31308,786,'Capital Particle Dispersion Projector II','This ship modification is designed to increase the optimal range of a ship\'s ECM, remote sensor dampeners, tracking disruptors and target painters at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,19200.0000,1,1737,0),(31309,787,'Capital Particle Dispersion Projector II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31310,1233,'Small Signal Focusing Kit I','This ship modification is designed to increase the scan speed of modules which require the electronics skill (cargo scanner, ship scanner and survey scanner), at the expense of shields.',200,5,0,1,NULL,0.0000,1,1786,0),(31311,787,'Small Signal Focusing Kit I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1801,0),(31312,1233,'Medium Signal Focusing Kit I','This ship modification is designed to increase the scan speed of modules which require the electronics skill (cargo scanner, ship scanner and survey scanner), at the expense of shields.',200,10,0,1,NULL,0.0000,1,1787,0),(31313,787,'Medium Signal Focusing Kit I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1802,0),(31314,1233,'Capital Signal Focusing Kit I','This ship modification is designed to increase the scan speed of modules which require the electronics skill (cargo scanner, ship scanner and survey scanner), at the expense of shields.',200,40,0,1,NULL,0.0000,1,1789,0),(31315,787,'Capital Signal Focusing Kit I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1804,0),(31316,1233,'Small Signal Focusing Kit II','This ship modification is designed to increase the scan speed of modules which require the electronics skill (cargo scanner, ship scanner and survey scanner), at the expense of shields.',200,5,0,1,NULL,2400.0000,1,1786,0),(31317,787,'Small Signal Focusing Kit II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31318,1233,'Medium Signal Focusing Kit II','This ship modification is designed to increase the scan speed of modules which require the electronics skill (cargo scanner, ship scanner and survey scanner), at the expense of shields.',200,10,0,1,NULL,4800.0000,1,1787,0),(31319,787,'Medium Signal Focusing Kit II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31320,1233,'Capital Signal Focusing Kit II','This ship modification is designed to increase the scan speed of modules which require the electronics skill (cargo scanner, ship scanner and survey scanner), at the expense of shields.',200,40,0,1,NULL,19200.0000,1,1789,0),(31321,787,'Capital Signal Focusing Kit II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31322,1234,'Small Targeting System Subcontroller I','This ship modification is designed to increase a ship\'s targeting speed at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1790,0),(31323,787,'Small Targeting System Subcontroller I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1805,0),(31324,1234,'Medium Targeting System Subcontroller I','This ship modification is designed to increase a ship\'s targeting speed at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1791,0),(31325,787,'Medium Targeting System Subcontroller I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1806,0),(31326,1234,'Capital Targeting System Subcontroller I','This ship modification is designed to increase a ship\'s targeting speed at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1793,0),(31327,787,'Capital Targeting System Subcontroller I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1808,0),(31328,1234,'Small Targeting System Subcontroller II','This ship modification is designed to increase a ship\'s targeting speed at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,2400.0000,1,1790,0),(31329,787,'Small Targeting System Subcontroller II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31330,1234,'Medium Targeting System Subcontroller II','This ship modification is designed to increase a ship\'s targeting speed at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,4800.0000,1,1791,0),(31331,787,'Medium Targeting System Subcontroller II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31332,1234,'Capital Targeting System Subcontroller II','This ship modification is designed to increase a ship\'s targeting speed at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,19200.0000,1,1793,0),(31333,787,'Capital Targeting System Subcontroller II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31334,786,'Small Targeting Systems Stabilizer I','This ship modification is designed to reduce a ship\'s targeting delay after de-cloaking at the expense of shields.',200,5,0,1,NULL,0.0000,1,1219,0),(31335,787,'Small Targeting Systems Stabilizer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1249,0),(31336,786,'Medium Targeting Systems Stabilizer I','This ship modification is designed to reduce a ship\'s targeting delay after de-cloaking at the expense of shields.',200,10,0,1,NULL,0.0000,1,1220,0),(31337,787,'Medium Targeting Systems Stabilizer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1250,0),(31338,786,'Capital Targeting Systems Stabilizer I','This ship modification is designed to reduce a ship\'s targeting delay after de-cloaking at the expense of shields.',200,40,0,1,NULL,0.0000,1,1737,0),(31339,787,'Capital Targeting Systems Stabilizer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1723,0),(31340,786,'Small Targeting Systems Stabilizer II','This ship modification is designed to reduce a ship\'s targeting delay after de-cloaking at the expense of shields.',200,5,0,1,NULL,2400.0000,1,1219,0),(31341,787,'Small Targeting Systems Stabilizer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31342,786,'Medium Targeting Systems Stabilizer II','This ship modification is designed to reduce a ship\'s targeting delay after de-cloaking at the expense of shields.',200,10,0,1,NULL,4800.0000,1,1220,0),(31343,787,'Medium Targeting Systems Stabilizer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31344,786,'Capital Targeting Systems Stabilizer II','This ship modification is designed to reduce a ship\'s targeting delay after de-cloaking at the expense of shields.',200,40,0,1,NULL,19200.0000,1,1737,0),(31345,787,'Capital Targeting Systems Stabilizer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31346,786,'Small Tracking Diagnostic Subroutines I','This ship modification is designed to increase the effectiveness of fitted tracking disruptors at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1219,0),(31347,787,'Small Tracking Diagnostic Subroutines I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1249,0),(31348,786,'Medium Tracking Diagnostic Subroutines I','This ship modification is designed to increase the effectiveness of fitted tracking disruptors at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1220,0),(31349,787,'Medium Tracking Diagnostic Subroutines I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1250,0),(31350,786,'Capital Tracking Diagnostic Subroutines I','This ship modification is designed to increase the effectiveness of fitted tracking disruptors at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1737,0),(31351,787,'Capital Tracking Diagnostic Subroutines I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1723,0),(31352,786,'Small Tracking Diagnostic Subroutines II','This ship modification is designed to increase the effectiveness of fitted tracking disruptors at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,2400.0000,1,1219,0),(31353,787,'Small Tracking Diagnostic Subroutines II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31354,786,'Medium Tracking Diagnostic Subroutines II','This ship modification is designed to increase the effectiveness of fitted tracking disruptors at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,4800.0000,1,1220,0),(31355,787,'Medium Tracking Diagnostic Subroutines II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31356,786,'Capital Tracking Diagnostic Subroutines II','This ship modification is designed to increase the effectiveness of fitted tracking disruptors at the expense of shields.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,19200.0000,1,1737,0),(31357,787,'Capital Tracking Diagnostic Subroutines II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31358,781,'Small Ancillary Current Router I','This ship modification is designed to increase a ship\'s powergrid capacity.',200,5,0,1,NULL,0.0000,1,1222,0),(31359,787,'Small Ancillary Current Router I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1252,0),(31360,781,'Medium Ancillary Current Router I','This ship modification is designed to increase a ship\'s powergrid capacity.',200,10,0,1,NULL,0.0000,1,1223,0),(31361,787,'Medium Ancillary Current Router I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1253,0),(31362,781,'Capital Ancillary Current Router I','This ship modification is designed to increase a ship\'s powergrid capacity.',200,40,0,1,NULL,0.0000,1,1736,0),(31363,787,'Capital Ancillary Current Router I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1724,0),(31364,781,'Small Ancillary Current Router II','This ship modification is designed to increase a ship\'s powergrid capacity.',200,5,0,1,NULL,0.0000,1,1222,0),(31365,787,'Small Ancillary Current Router II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31366,781,'Medium Ancillary Current Router II','This ship modification is designed to increase a ship\'s powergrid capacity.',200,10,0,1,NULL,0.0000,1,1223,0),(31367,787,'Medium Ancillary Current Router II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31368,781,'Capital Ancillary Current Router II','This ship modification is designed to increase a ship\'s powergrid capacity.',200,40,0,1,NULL,0.0000,1,1736,0),(31369,787,'Capital Ancillary Current Router II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31370,781,'Small Capacitor Control Circuit I','This ship modification is designed to increase a ship\'s capacitor recharge rate.\r\r\n',200,5,0,1,NULL,0.0000,1,1222,0),(31371,787,'Small Capacitor Control Circuit I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1252,0),(31372,781,'Medium Capacitor Control Circuit I','This ship modification is designed to increase a ship\'s capacitor recharge rate.\r\r\n',200,10,0,1,NULL,0.0000,1,1223,0),(31373,787,'Medium Capacitor Control Circuit I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1253,0),(31374,781,'Capital Capacitor Control Circuit I','This ship modification is designed to increase a ship\'s capacitor recharge rate.\r\r\n',200,40,0,1,NULL,0.0000,1,1736,0),(31375,787,'Capital Capacitor Control Circuit I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1724,0),(31376,781,'Small Capacitor Control Circuit II','This ship modification is designed to increase a ship\'s capacitor recharge rate.\r\r\n',200,5,0,1,NULL,0.0000,1,1222,0),(31377,787,'Small Capacitor Control Circuit II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31378,781,'Medium Capacitor Control Circuit II','This ship modification is designed to increase a ship\'s capacitor recharge rate.\r\r\n',200,10,0,1,NULL,0.0000,1,1223,0),(31379,787,'Medium Capacitor Control Circuit II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31380,781,'Capital Capacitor Control Circuit II','This ship modification is designed to increase a ship\'s capacitor recharge rate.\r\r\n',200,40,0,1,NULL,0.0000,1,1736,0),(31381,787,'Capital Capacitor Control Circuit II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31382,781,'Small Egress Port Maximizer I','This ship modification is designed to reduce a ship\'s capacitor need for all energy emission modules.',200,5,0,1,NULL,0.0000,1,1222,0),(31383,787,'Small Egress Port Maximizer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1252,0),(31384,781,'Medium Egress Port Maximizer I','This ship modification is designed to reduce a ship\'s capacitor need for all energy emission modules.',200,10,0,1,NULL,0.0000,1,1223,0),(31385,787,'Medium Egress Port Maximizer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1253,0),(31386,781,'Capital Egress Port Maximizer I','This ship modification is designed to reduce a ship\'s capacitor need for all energy emission modules.',200,40,0,1,NULL,0.0000,1,1736,0),(31387,787,'Capital Egress Port Maximizer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1724,0),(31388,781,'Small Egress Port Maximizer II','This ship modification is designed to reduce a ship\'s capacitor need for all energy emission modules.',200,5,0,1,NULL,0.0000,1,1222,0),(31389,787,'Small Egress Port Maximizer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31390,781,'Medium Egress Port Maximizer II','This ship modification is designed to reduce a ship\'s capacitor need for all energy emission modules.',200,10,0,1,NULL,0.0000,1,1223,0),(31391,787,'Medium Egress Port Maximizer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31392,781,'Capital Egress Port Maximizer II','This ship modification is designed to reduce a ship\'s capacitor need for all energy emission modules.',200,40,0,1,NULL,0.0000,1,1736,0),(31393,787,'Capital Egress Port Maximizer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31394,781,'Small Powergrid Subroutine Maximizer I','This ship modification is designed to reduce a ship\'s CPU need for all power upgrade modules.',200,5,0,1,NULL,0.0000,1,1222,0),(31395,787,'Small Powergrid Subroutine Maximizer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1252,0),(31396,781,'Medium Powergrid Subroutine Maximizer I','This ship modification is designed to reduce a ship\'s CPU need for all power upgrade modules.',200,10,0,1,NULL,0.0000,1,1223,0),(31397,787,'Medium Powergrid Subroutine Maximizer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1253,0),(31398,781,'Capital Powergrid Subroutine Maximizer I','This ship modification is designed to reduce a ship\'s CPU need for all power upgrade modules.',200,40,0,1,NULL,0.0000,1,1736,0),(31399,787,'Capital Powergrid Subroutine Maximizer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1724,0),(31400,781,'Small Powergrid Subroutine Maximizer II','This ship modification is designed to reduce a ship\'s CPU need for all power upgrade modules.\r\r\n',200,5,0,1,NULL,0.0000,1,1222,0),(31401,787,'Small Powergrid Subroutine Maximizer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31402,781,'Medium Powergrid Subroutine Maximizer II','This ship modification is designed to reduce a ship\'s CPU need for all power upgrade modules.\r\r\n',200,10,0,1,NULL,0.0000,1,1223,0),(31403,787,'Medium Powergrid Subroutine Maximizer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31404,781,'Capital Powergrid Subroutine Maximizer II','This ship modification is designed to reduce a ship\'s CPU need for all power upgrade modules.\r\r\n',200,40,0,1,NULL,0.0000,1,1736,0),(31405,787,'Capital Powergrid Subroutine Maximizer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31406,781,'Small Semiconductor Memory Cell I','This ship modification is designed to increase a ship\'s capacitor capacity.\r\r\n',200,5,0,1,NULL,0.0000,1,1222,0),(31407,787,'Small Semiconductor Memory Cell I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1252,0),(31408,781,'Medium Semiconductor Memory Cell I','This ship modification is designed to increase a ship\'s capacitor capacity.\r\r\n',200,10,0,1,NULL,0.0000,1,1223,0),(31409,787,'Medium Semiconductor Memory Cell I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1253,0),(31410,781,'Capital Semiconductor Memory Cell I','This ship modification is designed to increase a ship\'s capacitor capacity.\r\r\n',200,40,0,1,NULL,0.0000,1,1736,0),(31411,787,'Capital Semiconductor Memory Cell I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1724,0),(31412,781,'Small Semiconductor Memory Cell II','This ship modification is designed to increase a ship\'s capacitor capacity.',200,5,0,1,NULL,0.0000,1,1222,0),(31413,787,'Small Semiconductor Memory Cell II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31414,781,'Medium Semiconductor Memory Cell II','This ship modification is designed to increase a ship\'s capacitor capacity.',200,10,0,1,NULL,0.0000,1,1223,0),(31415,787,'Medium Semiconductor Memory Cell II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31416,781,'Capital Semiconductor Memory Cell II','This ship modification is designed to increase a ship\'s capacitor capacity.',200,40,0,1,NULL,0.0000,1,1736,0),(31417,787,'Capital Semiconductor Memory Cell II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31418,775,'Small Algid Energy Administrations Unit I','This ship modification is designed to decrease the CPU need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,5,0,1,NULL,0.0000,1,1225,0),(31419,787,'Small Algid Energy Administrations Unit I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1255,0),(31420,775,'Medium Algid Energy Administrations Unit I','This ship modification is designed to decrease the CPU need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,10,0,1,NULL,0.0000,1,1226,0),(31421,787,'Medium Algid Energy Administrations Unit I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1256,0),(31422,775,'Capital Algid Energy Administrations Unit I','This ship modification is designed to decrease the CPU need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,40,0,1,NULL,0.0000,1,1735,0),(31423,787,'Capital Algid Energy Administrations Unit I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1725,0),(31424,775,'Small Algid Energy Administrations Unit II','This ship modification is designed to decrease the CPU need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,5,0,1,NULL,0.0000,1,1225,0),(31425,787,'Small Algid Energy Administrations Unit II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31426,775,'Medium Algid Energy Administrations Unit II','This ship modification is designed to decrease the CPU need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,10,0,1,NULL,0.0000,1,1226,0),(31427,787,'Medium Algid Energy Administrations Unit II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31428,775,'Capital Algid Energy Administrations Unit II','This ship modification is designed to decrease the CPU need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,40,0,1,NULL,0.0000,1,1735,0),(31429,787,'Capital Algid Energy Administrations Unit II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31430,775,'Small Energy Ambit Extension I','This ship modification is designed to increase the accuracy falloff range of a ship\'s energy turrets at the expense of increased power grid need for them.',200,5,0,1,NULL,0.0000,1,1225,0),(31431,787,'Small Energy Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1255,0),(31432,775,'Medium Energy Ambit Extension I','This ship modification is designed to increase the accuracy falloff range of a ship\'s energy turrets at the expense of increased power grid need for them.',200,10,0,1,NULL,0.0000,1,1226,0),(31433,787,'Medium Energy Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1256,0),(31434,775,'Capital Energy Ambit Extension I','This ship modification is designed to increase the accuracy falloff range of a ship\'s energy turrets at the expense of increased power grid need for them.',200,40,0,1,NULL,0.0000,1,1735,0),(31435,787,'Capital Energy Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1725,0),(31436,775,'Small Energy Ambit Extension II','This ship modification is designed to increase the accuracy falloff range of a ship\'s energy turrets at the expense of increased power grid need for them.',200,5,0,1,NULL,0.0000,1,1225,0),(31437,787,'Small Energy Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31438,775,'Medium Energy Ambit Extension II','This ship modification is designed to increase the accuracy falloff range of a ship\'s energy turrets at the expense of increased power grid need for them.',200,10,0,1,NULL,0.0000,1,1226,0),(31439,787,'Medium Energy Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31440,775,'Capital Energy Ambit Extension II','This ship modification is designed to increase the accuracy falloff range of a ship\'s energy turrets at the expense of increased power grid need for them.',200,40,0,1,NULL,0.0000,1,1735,0),(31441,787,'Capital Energy Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31442,775,'Small Energy Burst Aerator I','This ship modification is designed to increase a ship\'s energy turrets\' rate of fire at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1225,0),(31443,787,'Small Energy Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1255,0),(31444,775,'Medium Energy Burst Aerator I','This ship modification is designed to increase a ship\'s energy turrets\' rate of fire at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1226,0),(31445,787,'Medium Energy Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1256,0),(31446,775,'Capital Energy Burst Aerator I','This ship modification is designed to increase a ship\'s energy turrets\' rate of fire at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1735,0),(31447,787,'Capital Energy Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1725,0),(31448,775,'Small Energy Burst Aerator II','This ship modification is designed to increase a ship\'s energy turrets\' rate of fire at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1225,0),(31449,787,'Small Energy Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31450,775,'Medium Energy Burst Aerator II','This ship modification is designed to increase a ship\'s energy turrets\' rate of fire at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1226,0),(31451,787,'Medium Energy Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31452,775,'Capital Energy Burst Aerator II','This ship modification is designed to increase a ship\'s energy turrets\' rate of fire at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1735,0),(31453,787,'Capital Energy Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31454,775,'Small Energy Collision Accelerator I','This ship modification is designed to increase the damage output of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1225,0),(31455,787,'Small Energy Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1255,0),(31456,775,'Medium Energy Collision Accelerator I','This ship modification is designed to increase the damage output of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1226,0),(31457,787,'Medium Energy Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1256,0),(31458,775,'Capital Energy Collision Accelerator I','This ship modification is designed to increase the damage output of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1735,0),(31459,787,'Capital Energy Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1725,0),(31460,775,'Small Energy Collision Accelerator II','This ship modification is designed to increase the damage output of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1225,0),(31461,787,'Small Energy Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31462,775,'Medium Energy Collision Accelerator II','This ship modification is designed to increase the damage output of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1226,0),(31463,787,'Medium Energy Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31464,775,'Capital Energy Collision Accelerator II','This ship modification is designed to increase the damage output of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1735,0),(31465,787,'Capital Energy Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31466,775,'Small Energy Discharge Elutriation I','This ship modification is designed to decrease the capacitor need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,5,0,1,NULL,0.0000,1,1225,0),(31467,787,'Small Energy Discharge Elutriation I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1255,0),(31468,775,'Medium Energy Discharge Elutriation I','This ship modification is designed to decrease the capacitor need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,10,0,1,NULL,0.0000,1,1226,0),(31469,787,'Medium Energy Discharge Elutriation I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1256,0),(31470,775,'Capital Energy Discharge Elutriation I','This ship modification is designed to decrease the capacitor need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,40,0,1,NULL,0.0000,1,1735,0),(31471,787,'Capital Energy Discharge Elutriation I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1725,0),(31472,775,'Small Energy Discharge Elutriation II','This ship modification is designed to decrease the capacitor need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,5,0,1,NULL,0.0000,1,1225,0),(31473,787,'Small Energy Discharge Elutriation II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31474,775,'Medium Energy Discharge Elutriation II','This ship modification is designed to decrease the capacitor need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,10,0,1,NULL,0.0000,1,1226,0),(31475,787,'Medium Energy Discharge Elutriation II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31476,775,'Capital Energy Discharge Elutriation II','This ship modification is designed to decrease the capacitor need of a ship\'s energy turrets at the expense of increased power grid need for them.',200,40,0,1,NULL,0.0000,1,1735,0),(31477,787,'Capital Energy Discharge Elutriation II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31478,775,'Small Energy Locus Coordinator I','This ship modification is designed to increase the optimal range of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1225,0),(31479,787,'Small Energy Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1255,0),(31480,775,'Medium Energy Locus Coordinator I','This ship modification is designed to increase the optimal range of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1226,0),(31481,787,'Medium Energy Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1256,0),(31482,775,'Capital Energy Locus Coordinator I','This ship modification is designed to increase the optimal range of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1735,0),(31483,787,'Capital Energy Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1725,0),(31484,775,'Small Energy Locus Coordinator II','This ship modification is designed to increase the optimal range of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1225,0),(31485,787,'Small Energy Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31486,775,'Medium Energy Locus Coordinator II','This ship modification is designed to increase the optimal range of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1226,0),(31487,787,'Medium Energy Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31488,775,'Capital Energy Locus Coordinator II','This ship modification is designed to increase the optimal range of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1735,0),(31489,787,'Capital Energy Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31490,775,'Small Energy Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1225,0),(31491,787,'Small Energy Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1255,0),(31492,775,'Medium Energy Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1226,0),(31493,787,'Medium Energy Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1256,0),(31494,775,'Capital Energy Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1735,0),(31495,787,'Capital Energy Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1725,0),(31496,775,'Small Energy Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1225,0),(31497,787,'Small Energy Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31498,775,'Medium Energy Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1226,0),(31499,787,'Medium Energy Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31500,775,'Capital Energy Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of a ship\'s energy turrets at the expense of increased power grid need for them.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1735,0),(31501,787,'Capital Energy Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31502,776,'Small Algid Hybrid Administrations Unit I','This ship modification is designed to decrease the CPU need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,5,0,1,NULL,0.0000,1,1228,0),(31503,787,'Small Algid Hybrid Administrations Unit I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1258,0),(31504,776,'Medium Algid Hybrid Administrations Unit I','This ship modification is designed to decrease the CPU need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,10,0,1,NULL,0.0000,1,1229,0),(31505,787,'Medium Algid Hybrid Administrations Unit I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1259,0),(31506,776,'Capital Algid Hybrid Administrations Unit I','This ship modification is designed to decrease the CPU need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,40,0,1,NULL,0.0000,1,1734,0),(31507,787,'Capital Algid Hybrid Administrations Unit I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1726,0),(31508,776,'Small Algid Hybrid Administrations Unit II','This ship modification is designed to decrease the CPU need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,5,0,1,NULL,0.0000,1,1228,0),(31509,787,'Small Algid Hybrid Administrations Unit II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31510,776,'Medium Algid Hybrid Administrations Unit II','This ship modification is designed to decrease the CPU need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,10,0,1,NULL,0.0000,1,1229,0),(31511,787,'Medium Algid Hybrid Administrations Unit II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31512,776,'Capital Algid Hybrid Administrations Unit II','This ship modification is designed to decrease the CPU need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,40,0,1,NULL,0.0000,1,1734,0),(31513,787,'Capital Algid Hybrid Administrations Unit II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31514,776,'Small Hybrid Ambit Extension I','This ship modification is designed to increase the accuracy falloff range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,5,0,1,NULL,0.0000,1,1228,0),(31515,787,'Small Hybrid Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1258,0),(31516,776,'Medium Hybrid Ambit Extension I','This ship modification is designed to increase the accuracy falloff range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,10,0,1,NULL,0.0000,1,1229,0),(31517,787,'Medium Hybrid Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1259,0),(31518,776,'Capital Hybrid Ambit Extension I','This ship modification is designed to increase the accuracy falloff range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,40,0,1,NULL,0.0000,1,1734,0),(31519,787,'Capital Hybrid Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1726,0),(31520,776,'Small Hybrid Ambit Extension II','This ship modification is designed to increase the accuracy falloff range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,5,0,1,NULL,0.0000,1,1228,0),(31521,787,'Small Hybrid Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31522,776,'Medium Hybrid Ambit Extension II','This ship modification is designed to increase the accuracy falloff range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,10,0,1,NULL,0.0000,1,1229,0),(31523,787,'Medium Hybrid Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31524,776,'Capital Hybrid Ambit Extension II','This ship modification is designed to increase the accuracy falloff range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,40,0,1,NULL,0.0000,1,1734,0),(31525,787,'Capital Hybrid Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31526,776,'Small Hybrid Burst Aerator I','This ship modification is designed to increase a ship\'s hybrid turret rate of fire at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1228,0),(31527,787,'Small Hybrid Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1258,0),(31528,776,'Medium Hybrid Burst Aerator I','This ship modification is designed to increase a ship\'s hybrid turret rate of fire at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1229,0),(31529,787,'Medium Hybrid Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1259,0),(31530,776,'Capital Hybrid Burst Aerator I','This ship modification is designed to increase a ship\'s hybrid turret rate of fire at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1734,0),(31531,787,'Capital Hybrid Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1726,0),(31532,776,'Small Hybrid Burst Aerator II','This ship modification is designed to increase a ship\'s hybrid turret rate of fire at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1228,0),(31533,787,'Small Hybrid Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31534,776,'Medium Hybrid Burst Aerator II','This ship modification is designed to increase a ship\'s hybrid turret rate of fire at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1229,0),(31535,787,'Medium Hybrid Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31536,776,'Capital Hybrid Burst Aerator II','This ship modification is designed to increase a ship\'s hybrid turret rate of fire at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1734,0),(31537,787,'Capital Hybrid Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31538,776,'Small Hybrid Collision Accelerator I','This ship modification is designed to increase a ship\'s hybrid turret damage at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1228,0),(31539,787,'Small Hybrid Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1258,0),(31540,776,'Medium Hybrid Collision Accelerator I','This ship modification is designed to increase a ship\'s hybrid turret damage at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1229,0),(31541,787,'Medium Hybrid Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1259,0),(31542,776,'Capital Hybrid Collision Accelerator I','This ship modification is designed to increase a ship\'s hybrid turret damage at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1734,0),(31543,787,'Capital Hybrid Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1726,0),(31544,776,'Small Hybrid Collision Accelerator II','This ship modification is designed to increase a ship\'s hybrid turret damage at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1228,0),(31545,787,'Small Hybrid Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31546,776,'Medium Hybrid Collision Accelerator II','This ship modification is designed to increase a ship\'s hybrid turret damage at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1229,0),(31547,787,'Medium Hybrid Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31548,776,'Capital Hybrid Collision Accelerator II','This ship modification is designed to increase a ship\'s hybrid turret damage at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1734,0),(31549,787,'Capital Hybrid Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31550,776,'Small Hybrid Discharge Elutriation I','This ship modification is designed to reduce the capacitor need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,5,0,1,NULL,0.0000,1,1228,0),(31551,787,'Small Hybrid Discharge Elutriation I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1258,0),(31552,776,'Medium Hybrid Discharge Elutriation I','This ship modification is designed to reduce the capacitor need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,10,0,1,NULL,0.0000,1,1229,0),(31553,787,'Medium Hybrid Discharge Elutriation I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1259,0),(31554,776,'Capital Hybrid Discharge Elutriation I','This ship modification is designed to reduce the capacitor need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,40,0,1,NULL,0.0000,1,1734,0),(31555,787,'Capital Hybrid Discharge Elutriation I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1726,0),(31556,776,'Small Hybrid Discharge Elutriation II','This ship modification is designed to reduce the capacitor need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,5,0,1,NULL,0.0000,1,1228,0),(31557,787,'Small Hybrid Discharge Elutriation II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31558,776,'Medium Hybrid Discharge Elutriation II','This ship modification is designed to reduce the capacitor need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,10,0,1,NULL,0.0000,1,1229,0),(31559,787,'Medium Hybrid Discharge Elutriation II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31560,776,'Capital Hybrid Discharge Elutriation II','This ship modification is designed to reduce the capacitor need of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.',200,40,0,1,NULL,0.0000,1,1734,0),(31561,787,'Capital Hybrid Discharge Elutriation II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31562,776,'Small Hybrid Locus Coordinator I','This ship modification is designed to increase the optimal range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1228,0),(31563,787,'Small Hybrid Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1258,0),(31564,776,'Medium Hybrid Locus Coordinator I','This ship modification is designed to increase the optimal range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1229,0),(31565,787,'Medium Hybrid Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1259,0),(31566,776,'Capital Hybrid Locus Coordinator I','This ship modification is designed to increase the optimal range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1734,0),(31567,787,'Capital Hybrid Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1726,0),(31568,776,'Small Hybrid Locus Coordinator II','This ship modification is designed to increase the optimal range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1228,0),(31569,787,'Small Hybrid Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31570,776,'Medium Hybrid Locus Coordinator II','This ship modification is designed to increase the optimal range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1229,0),(31571,787,'Medium Hybrid Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31572,776,'Capital Hybrid Locus Coordinator II','This ship modification is designed to increase the optimal range of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1734,0),(31573,787,'Capital Hybrid Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31574,776,'Small Hybrid Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1228,0),(31575,787,'Small Hybrid Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1258,0),(31576,776,'Medium Hybrid Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1229,0),(31577,787,'Medium Hybrid Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1259,0),(31578,776,'Capital Hybrid Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1734,0),(31579,787,'Capital Hybrid Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1726,0),(31580,776,'Small Hybrid Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1228,0),(31581,787,'Small Hybrid Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31582,776,'Medium Hybrid Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1229,0),(31583,787,'Medium Hybrid Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31584,776,'Capital Hybrid Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of a ship\'s hybrid turrets at the expense of increased power grid need for hybrid weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1734,0),(31585,787,'Capital Hybrid Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31586,779,'Small Bay Loading Accelerator I','This ship modification is designed to increase a ship\'s missile launchers\' rate of fire at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1231,0),(31587,787,'Small Bay Loading Accelerator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1261,0),(31588,779,'Medium Bay Loading Accelerator I','This ship modification is designed to increase a ship\'s missile launchers\' rate of fire at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1232,0),(31589,787,'Medium Bay Loading Accelerator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1262,0),(31590,779,'Capital Bay Loading Accelerator I','This ship modification is designed to increase a ship\'s missile launchers\' rate of fire at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1733,0),(31591,787,'Capital Bay Loading Accelerator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1727,0),(31592,779,'Small Bay Loading Accelerator II','This ship modification is designed to increase a ship\'s missile launchers\' rate of fire at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1231,0),(31593,787,'Small Bay Loading Accelerator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31594,779,'Medium Bay Loading Accelerator II','This ship modification is designed to increase a ship\'s missile launchers\' rate of fire at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1232,0),(31595,787,'Medium Bay Loading Accelerator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31596,779,'Capital Bay Loading Accelerator II','This ship modification is designed to increase a ship\'s missile launchers\' rate of fire at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1733,0),(31597,787,'Capital Bay Loading Accelerator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31598,779,'Small Hydraulic Bay Thrusters I','This ship modification is designed to increase missile velocity at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1231,0),(31599,787,'Small Hydraulic Bay Thrusters I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1261,0),(31600,779,'Medium Hydraulic Bay Thrusters I','This ship modification is designed to increase missile velocity at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1232,0),(31601,787,'Medium Hydraulic Bay Thrusters I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1262,0),(31602,779,'Capital Hydraulic Bay Thrusters I','This ship modification is designed to increase missile velocity at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1733,0),(31603,787,'Capital Hydraulic Bay Thrusters I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1727,0),(31604,779,'Small Hydraulic Bay Thrusters II','This ship modification is designed to increase missile velocity at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1231,0),(31605,787,'Small Hydraulic Bay Thrusters II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31606,779,'Medium Hydraulic Bay Thrusters II','This ship modification is designed to increase missile velocity at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1232,0),(31607,787,'Medium Hydraulic Bay Thrusters II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31608,779,'Small Rocket Fuel Cache Partition I','This ship modification is designed to increase maximum missile flight time at the expense of increased CPU requirements for launchers.',200,5,0,1,NULL,0.0000,1,1231,0),(31609,787,'Small Rocket Fuel Cache Partition I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1261,0),(31610,779,'Medium Rocket Fuel Cache Partition I','This ship modification is designed to increase maximum missile flight time at the expense of increased CPU requirements for launchers.',200,10,0,1,NULL,0.0000,1,1232,0),(31611,787,'Medium Rocket Fuel Cache Partition I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1262,0),(31612,779,'Capital Rocket Fuel Cache Partition I','This ship modification is designed to increase maximum missile flight time at the expense of increased CPU requirements for launchers.',200,40,0,1,NULL,0.0000,1,1733,0),(31613,787,'Capital Rocket Fuel Cache Partition I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1727,0),(31614,779,'Small Rocket Fuel Cache Partition II','This ship modification is designed to increase maximum missile flight time at the expense of increased CPU requirements for launchers.',200,5,0,1,NULL,0.0000,1,1231,0),(31615,787,'Small Rocket Fuel Cache Partition II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31616,779,'Medium Rocket Fuel Cache Partition II','This ship modification is designed to increase maximum missile flight time at the expense of increased CPU requirements for launchers.',200,10,0,1,NULL,0.0000,1,1232,0),(31617,787,'Medium Rocket Fuel Cache Partition II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31618,779,'Capital Rocket Fuel Cache Partition II','This ship modification is designed to increase maximum missile flight time at the expense of increased CPU requirements for launchers.',200,40,0,1,NULL,0.0000,1,1733,0),(31619,787,'Capital Rocket Fuel Cache Partition II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31620,779,'Small Warhead Calefaction Catalyst I','This ship modification is designed to increase missile damage at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1231,0),(31621,787,'Small Warhead Calefaction Catalyst I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1261,0),(31622,779,'Medium Warhead Calefaction Catalyst I','This ship modification is designed to increase missile damage at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1232,0),(31623,787,'Medium Warhead Calefaction Catalyst I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1262,0),(31624,779,'Capital Warhead Calefaction Catalyst I','This ship modification is designed to increase missile damage at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1733,0),(31625,787,'Capital Warhead Calefaction Catalyst I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1727,0),(31626,779,'Small Warhead Calefaction Catalyst II','This ship modification is designed to increase missile damage at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1231,0),(31627,787,'Small Warhead Calefaction Catalyst II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31628,779,'Medium Warhead Calefaction Catalyst II','This ship modification is designed to increase missile damage at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1232,0),(31629,787,'Medium Warhead Calefaction Catalyst II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31630,779,'Capital Warhead Calefaction Catalyst II','This ship modification is designed to increase missile damage at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1733,0),(31631,787,'Capital Warhead Calefaction Catalyst II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31632,779,'Small Warhead Flare Catalyst I','This ship modification is designed to decrease the effect of a target\'s velocity in avoiding the radius of missile explosions at the expense of increased CPU requirements for launchers.',200,5,0,1,NULL,0.0000,1,1231,0),(31633,787,'Small Warhead Flare Catalyst I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1261,0),(31634,779,'Medium Warhead Flare Catalyst I','This ship modification is designed to decrease the effect of a target\'s velocity in avoiding the radius of missile explosions at the expense of increased CPU requirements for launchers.',200,10,0,1,NULL,0.0000,1,1232,0),(31635,787,'Medium Warhead Flare Catalyst I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1262,0),(31636,779,'Capital Warhead Flare Catalyst I','This ship modification is designed to decrease the effect of a target\'s velocity in avoiding the radius of missile explosions at the expense of increased CPU requirements for launchers.',200,40,0,1,NULL,0.0000,1,1733,0),(31637,787,'Capital Warhead Flare Catalyst I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1727,0),(31638,779,'Small Warhead Flare Catalyst II','This ship modification is designed to decrease the effect of a target\'s velocity in avoiding the radius of missile explosions at the expense of increased CPU requirements for launchers.',200,5,0,1,NULL,0.0000,1,1231,0),(31639,787,'Small Warhead Flare Catalyst II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31640,779,'Medium Warhead Flare Catalyst II','This ship modification is designed to decrease the effect of a target\'s velocity in avoiding the radius of missile explosions at the expense of increased CPU requirements for launchers.',200,10,0,1,NULL,0.0000,1,1232,0),(31641,787,'Medium Warhead Flare Catalyst II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31642,779,'Capital Warhead Flare Catalyst II','This ship modification is designed to decrease the effect of a target\'s velocity in avoiding the radius of missile explosions at the expense of increased CPU requirements for launchers.',200,40,0,1,NULL,0.0000,1,1733,0),(31643,787,'Capital Warhead Flare Catalyst II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31644,779,'Small Warhead Rigor Catalyst I','This ship modification is designed to decrease the signature radius factor for missile explosions at the expense of increased CPU requirements for launchers.',200,5,0,1,NULL,0.0000,1,1231,0),(31645,787,'Small Warhead Rigor Catalyst I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1261,0),(31646,779,'Medium Warhead Rigor Catalyst I','This ship modification is designed to decrease the signature radius factor for missile explosions at the expense of increased CPU requirements for launchers.',200,10,0,1,NULL,0.0000,1,1232,0),(31647,787,'Medium Warhead Rigor Catalyst I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1262,0),(31648,779,'Capital Warhead Rigor Catalyst I','This ship modification is designed to decrease the signature radius factor for missile explosions at the expense of increased CPU requirements for launchers.',200,40,0,1,NULL,0.0000,1,1733,0),(31649,787,'Capital Warhead Rigor Catalyst I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1727,0),(31650,779,'Small Warhead Rigor Catalyst II','This ship modification is designed to decrease the signature radius factor for missile explosions at the expense of increased CPU requirements for launchers.',200,5,0,1,NULL,0.0000,1,1231,0),(31651,787,'Small Warhead Rigor Catalyst II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31652,779,'Medium Warhead Rigor Catalyst II','This ship modification is designed to decrease the signature radius factor for missile explosions at the expense of increased CPU requirements for launchers.',200,10,0,1,NULL,0.0000,1,1232,0),(31653,787,'Medium Warhead Rigor Catalyst II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31654,779,'Capital Warhead Rigor Catalyst II','This ship modification is designed to decrease the signature radius factor for missile explosions at the expense of increased CPU requirements for launchers.',200,40,0,1,NULL,0.0000,1,1733,0),(31655,787,'Capital Warhead Rigor Catalyst II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31656,777,'Small Projectile Ambit Extension I','This ship modification is designed to increase a ship\'s projectile turret accuracy falloff range at the expense of increased power grid need for projectile weapons.',200,5,0,1,NULL,0.0000,1,1237,0),(31657,787,'Small Projectile Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1264,0),(31658,777,'Medium Projectile Ambit Extension I','This ship modification is designed to increase a ship\'s projectile turret accuracy falloff range at the expense of increased power grid need for projectile weapons.',200,10,0,1,NULL,0.0000,1,1238,0),(31659,787,'Medium Projectile Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1265,0),(31660,777,'Capital Projectile Ambit Extension I','This ship modification is designed to increase a ship\'s projectile turret accuracy falloff range at the expense of increased power grid need for projectile weapons.',200,40,0,1,NULL,0.0000,1,1731,0),(31661,787,'Capital Projectile Ambit Extension I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1728,0),(31662,777,'Small Projectile Ambit Extension II','This ship modification is designed to increase a ship\'s projectile turret accuracy falloff range at the expense of increased power grid need for projectile weapons.',200,5,0,1,NULL,0.0000,1,1237,0),(31663,787,'Small Projectile Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31664,777,'Medium Projectile Ambit Extension II','This ship modification is designed to increase a ship\'s projectile turret accuracy falloff range at the expense of increased power grid need for projectile weapons.',200,10,0,1,NULL,0.0000,1,1238,0),(31665,787,'Medium Projectile Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31666,777,'Capital Projectile Ambit Extension II','This ship modification is designed to increase a ship\'s projectile turret accuracy falloff range at the expense of increased power grid need for projectile weapons.',200,40,0,1,NULL,0.0000,1,1731,0),(31667,787,'Capital Projectile Ambit Extension II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31668,777,'Small Projectile Burst Aerator I','This ship modification is designed to increase a ship\'s projectile turret rate of fire at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1237,0),(31669,787,'Small Projectile Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1264,0),(31670,777,'Medium Projectile Burst Aerator I','This ship modification is designed to increase a ship\'s projectile turret rate of fire at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1238,0),(31671,787,'Medium Projectile Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1265,0),(31672,777,'Capital Projectile Burst Aerator I','This ship modification is designed to increase a ship\'s projectile turret rate of fire at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1731,0),(31673,787,'Capital Projectile Burst Aerator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1728,0),(31674,777,'Small Projectile Burst Aerator II','This ship modification is designed to increase a ship\'s projectile turret rate of fire at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1237,0),(31675,787,'Small Projectile Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31676,777,'Medium Projectile Burst Aerator II','This ship modification is designed to increase a ship\'s projectile turret rate of fire at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1238,0),(31677,787,'Medium Projectile Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31678,777,'Capital Projectile Burst Aerator II','This ship modification is designed to increase a ship\'s projectile turret rate of fire at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1731,0),(31679,787,'Capital Projectile Burst Aerator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31680,777,'Small Projectile Collision Accelerator I','This ship modification is designed to increase a ship\'s projectile turret damage output at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1237,0),(31681,787,'Small Projectile Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1264,0),(31682,777,'Medium Projectile Collision Accelerator I','This ship modification is designed to increase a ship\'s projectile turret damage output at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1238,0),(31683,787,'Medium Projectile Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1265,0),(31684,777,'Capital Projectile Collision Accelerator I','This ship modification is designed to increase a ship\'s projectile turret damage output at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1731,0),(31685,787,'Capital Projectile Collision Accelerator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1728,0),(31686,777,'Small Projectile Collision Accelerator II','This ship modification is designed to increase a ship\'s projectile turret damage output at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1237,0),(31687,787,'Small Projectile Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31688,777,'Medium Projectile Collision Accelerator II','This ship modification is designed to increase a ship\'s projectile turret damage output at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1238,0),(31689,787,'Medium Projectile Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31690,777,'Capital Projectile Collision Accelerator II','This ship modification is designed to increase a ship\'s projectile turret damage output at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1731,0),(31691,787,'Capital Projectile Collision Accelerator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31692,777,'Small Projectile Locus Coordinator I','This ship modification is designed to increase the optimal range of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1237,0),(31693,787,'Small Projectile Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1264,0),(31694,777,'Medium Projectile Locus Coordinator I','This ship modification is designed to increase the optimal range of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1238,0),(31695,787,'Medium Projectile Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1265,0),(31696,777,'Capital Projectile Locus Coordinator I','This ship modification is designed to increase the optimal range of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1731,0),(31697,787,'Capital Projectile Locus Coordinator I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1728,0),(31698,777,'Small Projectile Locus Coordinator II','This ship modification is designed to increase the optimal range of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1237,0),(31699,787,'Small Projectile Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31700,777,'Medium Projectile Locus Coordinator II','This ship modification is designed to increase the optimal range of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1238,0),(31701,787,'Medium Projectile Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31702,777,'Capital Projectile Locus Coordinator II','This ship modification is designed to increase the optimal range of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1731,0),(31703,787,'Capital Projectile Locus Coordinator II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31704,777,'Small Projectile Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1237,0),(31705,787,'Small Projectile Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1264,0),(31706,777,'Medium Projectile Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1238,0),(31707,787,'Medium Projectile Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1265,0),(31708,777,'Capital Projectile Metastasis Adjuster I','This ship modification is designed to increase the tracking speed of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1731,0),(31709,787,'Capital Projectile Metastasis Adjuster I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1728,0),(31710,777,'Small Projectile Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1237,0),(31711,787,'Small Projectile Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31712,777,'Medium Projectile Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1238,0),(31713,787,'Medium Projectile Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31714,777,'Capital Projectile Metastasis Adjuster II','This ship modification is designed to increase the tracking speed of all projectile turrets at the expense of increased power grid need for projectile weapons.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1731,0),(31715,787,'Capital Projectile Metastasis Adjuster II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31716,774,'Small Anti-EM Screen Reinforcer I','This ship modification is designed to increase the EM resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1234,0),(31717,787,'Small Anti-EM Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1267,0),(31718,774,'Medium Anti-EM Screen Reinforcer I','This ship modification is designed to increase the EM resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1235,0),(31719,787,'Medium Anti-EM Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1268,0),(31720,774,'Capital Anti-EM Screen Reinforcer I','This ship modification is designed to increase the EM resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1732,0),(31721,787,'Capital Anti-EM Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1729,0),(31722,774,'Small Anti-EM Screen Reinforcer II','This ship modification is designed to increase the EM resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1234,0),(31723,787,'Small Anti-EM Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31724,774,'Medium Anti-EM Screen Reinforcer II','This ship modification is designed to increase the EM resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1235,0),(31725,787,'Medium Anti-EM Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31726,774,'Capital Anti-EM Screen Reinforcer II','This ship modification is designed to increase the EM resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1732,0),(31727,787,'Capital Anti-EM Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31728,774,'Small Anti-Explosive Screen Reinforcer I','This ship modification is designed to increase the explosive resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1234,0),(31729,787,'Small Anti-Explosive Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1267,0),(31730,774,'Medium Anti-Explosive Screen Reinforcer I','This ship modification is designed to increase the explosive resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1235,0),(31731,787,'Medium Anti-Explosive Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1268,0),(31732,774,'Capital Anti-Explosive Screen Reinforcer I','This ship modification is designed to increase the explosive resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1732,0),(31733,787,'Capital Anti-Explosive Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1729,0),(31734,774,'Small Anti-Explosive Screen Reinforcer II','This ship modification is designed to increase the explosive resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1234,0),(31735,787,'Small Anti-Explosive Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31736,774,'Medium Anti-Explosive Screen Reinforcer II','This ship modification is designed to increase the explosive resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1235,0),(31737,787,'Medium Anti-Explosive Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31738,774,'Capital Anti-Explosive Screen Reinforcer II','This ship modification is designed to increase the explosive resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1732,0),(31739,787,'Capital Anti-Explosive Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31740,774,'Small Anti-Kinetic Screen Reinforcer I','This ship modification is designed to increase the kinetic resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1234,0),(31741,787,'Small Anti-Kinetic Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1267,0),(31742,774,'Medium Anti-Kinetic Screen Reinforcer I','This ship modification is designed to increase the kinetic resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1235,0),(31743,787,'Medium Anti-Kinetic Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1268,0),(31744,774,'Capital Anti-Kinetic Screen Reinforcer I','This ship modification is designed to increase the kinetic resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1732,0),(31745,787,'Capital Anti-Kinetic Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1729,0),(31746,774,'Small Anti-Kinetic Screen Reinforcer II','This ship modification is designed to increase the kinetic resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1234,0),(31747,787,'Small Anti-Kinetic Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31748,774,'Medium Anti-Kinetic Screen Reinforcer II','This ship modification is designed to increase the kinetic resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1235,0),(31749,787,'Medium Anti-Kinetic Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31750,774,'Capital Anti-Kinetic Screen Reinforcer II','This ship modification is designed to increase the kinetic resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1732,0),(31751,787,'Capital Anti-Kinetic Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31752,774,'Small Anti-Thermal Screen Reinforcer I','This ship modification is designed to increase the thermal resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1234,0),(31753,787,'Small Anti-Thermal Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1267,0),(31754,774,'Medium Anti-Thermal Screen Reinforcer I','This ship modification is designed to increase the thermal resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1235,0),(31755,787,'Medium Anti-Thermal Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1268,0),(31756,774,'Capital Anti-Thermal Screen Reinforcer I','This ship modification is designed to increase the thermal resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1732,0),(31757,787,'Capital Anti-Thermal Screen Reinforcer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1729,0),(31758,774,'Small Anti-Thermal Screen Reinforcer II','This ship modification is designed to increase the thermal resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1234,0),(31759,787,'Small Anti-Thermal Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31760,774,'Medium Anti-Thermal Screen Reinforcer II','This ship modification is designed to increase the thermal resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1235,0),(31761,787,'Medium Anti-Thermal Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31762,774,'Capital Anti-Thermal Screen Reinforcer II','This ship modification is designed to increase the thermal resistance of ship shields at the expense of increased signature radius.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1732,0),(31763,787,'Capital Anti-Thermal Screen Reinforcer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31764,774,'Small Core Defense Capacitor Safeguard I','This ship modification is designed to reduce the capacitor need of modules which require shield operation skills at the expense of increased signature radius.',200,5,0,1,NULL,0.0000,1,1234,0),(31765,787,'Small Core Defense Capacitor Safeguard I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1267,0),(31766,774,'Medium Core Defense Capacitor Safeguard I','This ship modification is designed to reduce the capacitor need of modules which require shield operation skills at the expense of increased signature radius.\r\r\n',200,10,0,1,NULL,0.0000,1,1235,0),(31767,787,'Medium Core Defense Capacitor Safeguard I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1268,0),(31768,774,'Capital Core Defense Capacitor Safeguard I','This ship modification is designed to reduce the capacitor need of modules which require shield operation skills at the expense of increased signature radius.',200,40,0,1,NULL,0.0000,1,1732,0),(31769,787,'Capital Core Defense Capacitor Safeguard I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1729,0),(31770,774,'Small Core Defense Capacitor Safeguard II','This ship modification is designed to reduce the capacitor need of modules which require shield operation skills at the expense of increased signature radius.',200,5,0,1,NULL,0.0000,1,1234,0),(31771,787,'Small Core Defense Capacitor Safeguard II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31772,774,'Medium Core Defense Capacitor Safeguard II','This ship modification is designed to reduce the capacitor need of modules which require shield operation skills at the expense of increased signature radius.',200,10,0,1,NULL,0.0000,1,1235,0),(31773,787,'Medium Core Defense Capacitor Safeguard II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31774,774,'Capital Core Defense Capacitor Safeguard II','This ship modification is designed to reduce the capacitor need of modules which require shield operation skills at the expense of increased signature radius.',200,40,0,1,NULL,0.0000,1,1732,0),(31775,787,'Capital Core Defense Capacitor Safeguard II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31776,774,'Small Core Defense Charge Economizer I','This ship modification is designed to reduce the power need of all shield upgrade modules at the expense of increased signature radius.',200,5,0,1,NULL,0.0000,1,1234,0),(31777,787,'Small Core Defense Charge Economizer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1267,0),(31778,774,'Medium Core Defense Charge Economizer I','This ship modification is designed to reduce the power need of all shield upgrade modules at the expense of increased signature radius.',200,10,0,1,NULL,0.0000,1,1235,0),(31779,787,'Medium Core Defense Charge Economizer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1268,0),(31780,774,'Capital Core Defense Charge Economizer I','This ship modification is designed to reduce the power need of all shield upgrade modules at the expense of increased signature radius.',200,40,0,1,NULL,0.0000,1,1732,0),(31781,787,'Capital Core Defense Charge Economizer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1729,0),(31782,774,'Small Core Defense Charge Economizer II','This ship modification is designed to reduce the power need of all shield upgrade modules at the expense of increased signature radius.',200,5,0,1,NULL,0.0000,1,1234,0),(31783,787,'Small Core Defense Charge Economizer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31784,774,'Medium Core Defense Charge Economizer II','This ship modification is designed to reduce the power need of all shield upgrade modules at the expense of increased signature radius.',200,10,0,1,NULL,0.0000,1,1235,0),(31785,787,'Medium Core Defense Charge Economizer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31786,774,'Capital Core Defense Charge Economizer II','This ship modification is designed to reduce the power need of all shield upgrade modules at the expense of increased signature radius.',200,40,0,1,NULL,0.0000,1,1732,0),(31787,787,'Capital Core Defense Charge Economizer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31788,774,'Small Core Defense Field Extender I','This ship modification is designed to increase shield capacity at the expense of increased signature radius.',200,5,0,1,NULL,0.0000,1,1234,0),(31789,787,'Small Core Defense Field Extender I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1267,0),(31790,774,'Medium Core Defense Field Extender I','This ship modification is designed to increase shield capacity at the expense of increased signature radius.',200,10,0,1,NULL,0.0000,1,1235,0),(31791,787,'Medium Core Defense Field Extender I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1268,0),(31792,774,'Capital Core Defense Field Extender I','This ship modification is designed to increase shield capacity at the expense of increased signature radius.',200,40,0,1,NULL,0.0000,1,1732,0),(31793,787,'Capital Core Defense Field Extender I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1729,0),(31794,774,'Small Core Defense Field Extender II','This ship modification is designed to increase shield capacity at the expense of increased signature radius.',200,5,0,1,NULL,0.0000,1,1234,0),(31795,787,'Small Core Defense Field Extender II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31796,774,'Medium Core Defense Field Extender II','This ship modification is designed to increase shield capacity at the expense of increased signature radius.',200,10,0,1,NULL,0.0000,1,1235,0),(31797,787,'Medium Core Defense Field Extender II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31798,774,'Capital Core Defense Field Extender II','This ship modification is designed to increase shield capacity at the expense of increased signature radius.',200,40,0,1,NULL,0.0000,1,1732,0),(31799,787,'Capital Core Defense Field Extender II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31800,774,'Small Core Defense Field Purger I','This ship modification is designed to improve shield recharge rate at the expense of increased signature radius.',200,5,0,1,NULL,0.0000,1,1234,0),(31801,787,'Small Core Defense Field Purger I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1267,0),(31802,774,'Medium Core Defense Field Purger I','This ship modification is designed to improve shield recharge rate at the expense of increased signature radius.',200,10,0,1,NULL,0.0000,1,1235,0),(31803,787,'Medium Core Defense Field Purger I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1268,0),(31804,774,'Capital Core Defense Field Purger I','This ship modification is designed to improve shield recharge rate at the expense of increased signature radius.',200,40,0,1,NULL,0.0000,1,1732,0),(31805,787,'Capital Core Defense Field Purger I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1729,0),(31810,774,'Small Core Defense Field Purger II','This ship modification is designed to improve shield recharge rate at the expense of increased signature radius.',200,5,0,1,NULL,0.0000,1,1234,0),(31811,787,'Small Core Defense Field Purger II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31812,774,'Medium Core Defense Field Purger II','This ship modification is designed to improve shield recharge rate at the expense of increased signature radius.',200,10,0,1,NULL,0.0000,1,1235,0),(31813,787,'Medium Core Defense Field Purger II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31814,774,'Capital Core Defense Field Purger II','This ship modification is designed to improve shield recharge rate at the expense of increased signature radius.',200,40,0,1,NULL,0.0000,1,1732,0),(31815,787,'Capital Core Defense Field Purger II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31816,774,'Small Core Defense Operational Solidifier I','This ship modification is designed to reduce the duration of shield booster cycles at the expense of increased signature radius.',200,5,0,1,NULL,0.0000,1,1234,0),(31817,787,'Small Core Defense Operational Solidifier I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1267,0),(31818,774,'Medium Core Defense Operational Solidifier I','This ship modification is designed to reduce the duration of shield booster cycles at the expense of increased signature radius.',200,10,0,1,NULL,0.0000,1,1235,0),(31819,787,'Medium Core Defense Operational Solidifier I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1268,0),(31820,774,'Capital Core Defense Operational Solidifier I','This ship modification is designed to reduce the duration of shield booster cycles at the expense of increased signature radius.',200,40,0,1,NULL,0.0000,1,1732,0),(31821,787,'Capital Core Defense Operational Solidifier I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1729,0),(31822,774,'Small Core Defense Operational Solidifier II','This ship modification is designed to reduce the duration of shield booster cycles at the expense of increased signature radius.',200,5,0,1,NULL,0.0000,1,1234,0),(31823,787,'Small Core Defense Operational Solidifier II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(31824,774,'Medium Core Defense Operational Solidifier II','This ship modification is designed to reduce the duration of shield booster cycles at the expense of increased signature radius.',200,10,0,1,NULL,0.0000,1,1235,0),(31825,787,'Medium Core Defense Operational Solidifier II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(31826,774,'Capital Core Defense Operational Solidifier II','This ship modification is designed to reduce the duration of shield booster cycles at the expense of increased signature radius.',200,40,0,1,NULL,0.0000,1,1732,0),(31827,787,'Capital Core Defense Operational Solidifier II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(31864,100,'Imperial Navy Acolyte','Light Scout Drone',3000,5,0,1,4,2094.0000,1,837,0),(31865,176,'Imperial Navy Acolyte Blueprint',' ',0,0.01,0,1,NULL,200000.0000,0,NULL,0),(31866,100,'Imperial Navy Infiltrator','Medium Scout Drone',5000,10,0,1,4,20794.0000,1,838,0),(31867,176,'Imperial Navy Infiltrator Blueprint',' ',0,0.01,0,1,NULL,1700000.0000,0,NULL,0),(31868,100,'Imperial Navy Curator','Sentry Drone',12000,25,0,1,4,229968.0000,1,911,0),(31869,176,'Imperial Navy Curator Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,0,NULL,0),(31870,100,'Imperial Navy Praetor','Heavy Attack Drone',10000,25,0,1,4,88424.0000,1,839,0),(31871,176,'Imperial Navy Praetor Blueprint',' ',0,0.01,0,1,NULL,6000000.0000,0,NULL,0),(31872,100,'Caldari Navy Hornet','Light Scout Drone',3500,5,0,1,1,3164.0000,1,837,0),(31873,176,'Caldari Navy Hornet Blueprint',' ',0,0.01,0,1,NULL,300000.0000,0,NULL,0),(31874,100,'Caldari Navy Vespa','Medium Scout Drone',5000,10,0,1,1,21406.0000,1,838,0),(31875,176,'Caldari Navy Vespa Blueprint',' ',0,0.01,0,1,NULL,1600000.0000,0,NULL,0),(31876,100,'Caldari Navy Wasp','Heavy Attack Drone',10000,25,0,1,1,74430.0000,1,839,0),(31877,176,'Caldari Navy Wasp Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,0,NULL,0),(31878,100,'Caldari Navy Warden','Sentry Drone',12000,25,0,1,1,229968.0000,1,911,0),(31879,176,'Caldari Navy Warden Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,0,NULL,0),(31880,100,'Federation Navy Hobgoblin','Light Scout Drone',3000,5,0,1,8,2610.0000,1,837,0),(31881,176,'Federation Navy Hobgoblin Blueprint',' ',0,0.01,0,1,NULL,250000.0000,0,NULL,0),(31882,100,'Federation Navy Hammerhead','Medium Scout Drone',5000,10,0,1,8,23610.0000,1,838,0),(31883,176,'Federation Navy Hammerhead Blueprint',' ',0,0.01,0,1,NULL,1800000.0000,0,NULL,0),(31884,100,'Federation Navy Ogre','Heavy Attack Drone',12000,25,0,1,8,106788.0000,1,839,0),(31885,176,'Federation Navy Ogre Blueprint',' ',0,0.01,0,1,NULL,7000000.0000,0,NULL,0),(31886,100,'Federation Navy Garde','Sentry Drone',12000,25,0,1,8,229968.0000,1,911,0),(31887,176,'Federation Navy Garde Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,0,NULL,0),(31888,100,'Republic Fleet Warrior','Light Scout Drone',4000,5,0,1,2,4230.0000,1,837,0),(31889,176,'Republic Fleet Warrior Blueprint',' ',0,0.01,0,1,NULL,400000.0000,0,NULL,0),(31890,100,'Republic Fleet Valkyrie','Medium Scout Drone',5000,10,0,1,2,16392.0000,1,838,0),(31891,176,'Republic Fleet Valkyrie Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,0,NULL,0),(31892,100,'Republic Fleet Berserker','Heavy Attack Drone',10000,25,0,1,2,51744.0000,1,839,0),(31893,176,'Republic Fleet Berserker Blueprint',' ',0,0.01,0,1,NULL,4000000.0000,0,NULL,0),(31894,100,'Republic Fleet Bouncer','Sentry Drone',12000,25,0,1,2,229968.0000,1,911,0),(31895,176,'Republic Fleet Bouncer Blueprint',' ',0,0.01,0,1,NULL,14000000.0000,0,NULL,0),(31896,329,'Imperial Navy 100mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,23886.0000,1,1672,0),(31897,349,'Imperial Navy 100mm Steel Plates Blueprint',' ',0,0.01,0,1,4,200000.0000,0,NULL,0),(31898,329,'Federation Navy 100mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,5,0,1,4,23886.0000,1,1672,0),(31899,349,'Federation Navy 100mm Steel Plates Blueprint',' ',0,0.01,0,1,4,200000.0000,0,NULL,0),(31900,329,'Imperial Navy 1600mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,4,832436.0000,1,1676,0),(31901,349,'Imperial Navy 1600mm Steel Plates Blueprint',' ',0,0.01,0,1,4,7000000.0000,0,NULL,0),(31902,329,'Federation Navy 1600mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,20,0,1,8,832436.0000,1,1676,0),(31903,349,'Federation Navy 1600mm Steel Plates Blueprint',' ',0,0.01,0,1,4,7000000.0000,0,NULL,0),(31904,329,'Imperial Navy 200mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,101624.0000,0,1673,0),(31905,349,'Imperial Navy 200mm Steel Plates Blueprint',' ',0,0.01,0,1,4,800000.0000,0,NULL,0),(31906,329,'Federation Navy 200mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,10,0,1,4,101624.0000,0,1673,0),(31907,349,'Federation Navy 200mm Steel Plates Blueprint',' ',0,0.01,0,1,4,800000.0000,0,NULL,0),(31908,329,'Imperial Navy 400mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,25,0,1,4,198230.0000,1,1674,0),(31909,349,'Imperial Navy 400mm Steel Plates Blueprint',' ',0,0.01,0,1,4,1600000.0000,0,NULL,0),(31910,329,'Federation Navy 400mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,25,0,1,4,198230.0000,1,1674,0),(31911,349,'Federation Navy 400mm Steel Plates Blueprint',' ',0,0.01,0,1,4,1600000.0000,0,NULL,0),(31916,329,'Imperial Navy 800mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,50,0,1,4,466500.0000,1,1675,0),(31917,349,'Imperial Navy 800mm Steel Plates Blueprint',' ',0,0.01,0,1,4,4000000.0000,0,NULL,0),(31918,329,'Federation Navy 800mm Steel Plates','Increases the maximum strength of the Armor.\r\r\n\r\r\nPenalty:  Adds to your ship\'s mass, making it less agile and maneuverable in addition to decreasing the factor of thrust gained from speed modules like Afterburners and MicroWarpdrives.',0,50,0,1,4,466500.0000,1,1675,0),(31919,349,'Federation Navy 800mm Steel Plates Blueprint',' ',0,0.01,0,1,4,4000000.0000,0,NULL,0),(31922,38,'Caldari Navy Small Shield Extender','Increases the maximum strength of the shield.',0,5,0,1,NULL,5320.0000,1,605,0),(31923,118,'Caldari Navy Small Shield Extender Blueprint',' ',0,0.01,0,1,NULL,49920.0000,0,NULL,0),(31924,38,'Republic Fleet Small Shield Extender','Increases the maximum strength of the shield.',0,5,0,1,NULL,5320.0000,1,605,0),(31925,118,'Republic Fleet Small Shield Extender Blueprint',' ',0,0.01,0,1,NULL,49920.0000,0,NULL,0),(31926,38,'Caldari Navy Medium Shield Extender','Increases the maximum strength of the shield.',0,10,0,1,NULL,13924.0000,1,606,0),(31927,118,'Caldari Navy Medium Shield Extender Blueprint',' ',0,0.01,0,1,NULL,124740.0000,0,NULL,0),(31928,38,'Republic Fleet Medium Shield Extender','Increases the maximum strength of the shield.',0,10,0,1,NULL,13924.0000,1,606,0),(31929,118,'Republic Fleet Medium Shield Extender Blueprint',' ',0,0.01,0,1,NULL,124740.0000,0,NULL,0),(31930,38,'Caldari Navy Large Shield Extender','Increases the maximum strength of the shield.',0,20,0,1,NULL,34710.0000,1,608,0),(31931,118,'Caldari Navy Large Shield Extender Blueprint',' ',0,0.01,0,1,NULL,312420.0000,0,NULL,0),(31932,38,'Republic Fleet Large Shield Extender','Increases the maximum strength of the shield.',0,20,0,1,NULL,34710.0000,1,608,0),(31933,118,'Republic Fleet Large Shield Extender Blueprint',' ',0,0.01,0,1,NULL,312420.0000,0,NULL,0),(31936,339,'Navy Micro Auxiliary Power Core','Supplements the main Power core providing more power',0,20,0,1,NULL,150000.0000,1,660,0),(31942,646,'Federation Navy Omnidirectional Tracking Link','Improves the optimal range and tracking of all drones. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,18160.0000,1,938,0),(31943,408,'Federation Navy Omnidirectional Tracking Link Blueprint',' ',0,0.01,0,1,NULL,99000.0000,0,NULL,0),(31944,379,'Republic Fleet Target Painter','A targeting subsystem that projects an electronic \"Tag\" on the target thus making it easier to target and Hit. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized. ',0,5,0,1,NULL,51464.0000,1,757,0),(31945,504,'Republic Fleet Target Painter Blueprint',' ',0,0.01,0,1,NULL,298240.0000,0,NULL,0),(31946,67,'Imperial Navy Large Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,50,0,1,NULL,248764.0000,1,697,0),(31947,147,'Imperial Navy Large Remote Capacitor Transmitter Blueprint',' ',0,0.01,0,1,NULL,788400.0000,0,NULL,0),(31948,67,'Imperial Navy Medium Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,25,0,1,NULL,102806.0000,1,696,0),(31949,147,'Imperial Navy Medium Remote Capacitor Transmitter Blueprint',' ',0,0.01,0,1,NULL,300000.0000,0,NULL,0),(31950,67,'Imperial Navy Small Remote Capacitor Transmitter','Transfers capacitor energy to another ship.',1000,25,0,1,NULL,40448.0000,1,695,0),(31951,147,'Imperial Navy Small Remote Capacitor Transmitter Blueprint',' ',0,0.01,0,1,NULL,125000.0000,0,NULL,0),(31952,766,'Caldari Navy Power Diagnostic System','Monitors and optimizes the power grid. Gives a slight boost to power core output and a minor increase in shield and capacitor recharge rate.',20,5,0,1,NULL,14544.0000,1,658,0),(31953,137,'Caldari Navy Power Diagnostic System Blueprint',' ',0,0.01,0,1,NULL,99200.0000,0,NULL,0),(31954,300,'High-grade Grail Alpha','This ocular filter has been modified by Amarr scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +4 Bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% bonus to ship\'s radar sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Grail implant secondary effects. Set effect not cumulative with low-grade Grail implants',0,1,0,1,NULL,0.0000,1,618,0),(31955,300,'High-grade Grail Beta','This memory augmentation has been modified by Amarr scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +4 Bonus to Memory\r\r\n\r\r\nSecondary Effect: 2% bonus to ship\'s radar sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Grail implant secondary effects. Set effect not cumulative with low-grade Grail implants',0,1,0,1,NULL,0.0000,1,619,0),(31956,300,'High-grade Grail Delta','This cybernetic subprocessor has been modified by Amarr scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 Bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 4% bonus to ship\'s radar sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Grail implant secondary effects. Set effect not cumulative with low-grade Grail implants',0,1,0,1,NULL,0.0000,1,621,0),(31957,300,'High-grade Grail Epsilon','This social adaptation chip has been modified by Amarr scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +4 Bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to ship\'s radar sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Grail implant secondary effects. Set effect not cumulative with low-grade Grail implants',0,1,0,1,NULL,0.0000,1,622,0),(31958,300,'High-grade Grail Gamma','This neural boost has been modified by Amarr scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +4 Bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to ship\'s radar sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Grail implant secondary effects. Set effect not cumulative with low-grade Grail implants',0,1,0,1,NULL,0.0000,1,620,0),(31959,300,'High-grade Grail Omega','This implant does nothing in and of itself, but when used in conjunction with other high-grade Grail implants it will boost their effect.\r\r\n\r\r\n100% bonus to the strength of all high-grade Grail implant secondary effects.\r\r\n\r\r\nEffect is not cumulative with low-grade Grail implants.',0,1,0,1,NULL,0.0000,1,1506,0),(31960,283,'Mina Darabi','The eldest child of Lord Darabi, Mina Darabi is quick witted, intelligent, and--lucky for you--highly observant.',65,1,0,1,NULL,0.0000,1,NULL,0),(31961,306,'Cargo Container - Mina Darabi','This cargo container is flimsily constructed and will not survive the rigors of space for long.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(31962,300,'High-grade Talon Alpha','This ocular filter has been modified by Caldari scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% bonus to ship\'s gravimetric sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Talon implant secondary effects. Set effect not cumulative with low-grade Talon implants',0,1,0,1,NULL,0.0000,1,618,0),(31963,300,'High-grade Talon Beta','This memory augmentation has been modified by Caldari scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Memory\r\r\n\r\r\nSecondary Effect: 2% bonus to ship\'s gravimetric sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Talon implant secondary effects. Set effect not cumulative with low-grade Talon implants',0,1,0,1,NULL,0.0000,1,619,0),(31964,300,'High-grade Talon Delta','This cybernetic subprocessor has been modified by Caldari scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 4% bonus to ship\'s gravimetric sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Talon implant secondary effects. Set effect not cumulative with low-grade Talon implants',0,1,0,1,NULL,0.0000,1,621,0),(31965,300,'High-grade Talon Epsilon','This social adaptation chip has been modified by Caldari scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to ship\'s gravimetric sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Talon implant secondary effects. Set effect not cumulative with low-grade Talon implants',0,1,0,1,NULL,0.0000,1,622,0),(31966,300,'High-grade Talon Gamma','This neural boost has been modified by Caldari scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to ship\'s gravimetric sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Talon implant secondary effects. Set effect not cumulative with low-grade Talon implants',0,1,0,1,NULL,0.0000,1,620,0),(31967,300,'High-grade Talon Omega','This implant does nothing in and of itself, but when used in conjunction with other high-grade Talon implants it will boost their effect. \r\r\n\r\r\n100% bonus to the strength of all high-grade Talon implant secondary effects.\r\r\n\r\r\nEffect not cumulative with low-grade Talon implants.',0,1,0,1,NULL,0.0000,1,1506,0),(31968,300,'High-grade Spur Alpha','This ocular filter has been modified by Gallente scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% bonus to ship\'s magnetometric sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Spur implant secondary effects. Set effect not cumulative with low-grade Spur implants',0,1,0,1,NULL,0.0000,1,618,0),(31969,300,'High-grade Spur Beta','This memory augmentation has been modified by Gallente scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Memory\r\r\n\r\r\nSecondary Effect: 2% bonus to ship\'s magnetometric sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Spur implant secondary effects. Set effect not cumulative with low-grade Spur implants',0,1,0,1,NULL,0.0000,1,619,0),(31970,300,'High-grade Spur Delta','This cybernetic subprocessor has been modified by Gallente scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 4% bonus to ship\'s magnetometric sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Spur implant secondary effects. Set effect not cumulative with low-grade Spur implants',0,1,0,1,NULL,0.0000,1,621,0),(31971,300,'High-grade Spur Epsilon','This social adaptation chip has been modified by Gallente scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to ship\'s magnetometric sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Spur implant secondary effects. Set effect not cumulative with low-grade Spur implants',0,1,0,1,NULL,0.0000,1,622,0),(31972,300,'High-grade Spur Gamma','This neural boost  has been modified by Gallente scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +4 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to ship\'s magnetometric sensor strength\r\r\n\r\r\nSet Effect: 15% bonus to the strength of all high-grade Spur implant secondary effects. Set effect not cumulative with low-grade Spur implants',0,1,0,1,NULL,0.0000,1,620,0),(31973,300,'High-grade Spur Omega','This implant does nothing in and of itself, but when used in conjunction with other high-grade Spur implants it will boost their effect. \r\r\n\r\r\n100% bonus to the strength of all high-grade Spur implant secondary effects.\r\r\n\r\r\nEffect not cumulative with low-grade Spur implants.',0,1,0,1,NULL,0.0000,1,1506,0),(31974,300,'High-grade Jackal Alpha','This ocular filter has been modified by Minmatar scientists for use by their elite officers. \r\n\r\nPrimary Effect: +4 bonus to Perception\r\n\r\nSecondary Effect: 1% bonus to ship\'s Ladar sensor strength\r\n\r\nSet Effect: 15% bonus to the strength of all high-grade Jackal implant secondary effects. Set effect not cumulative with low-grade Jackal implants',0,1,0,1,NULL,0.0000,1,618,0),(31975,300,'High-grade Jackal Beta','This memory augmentation has been modified by Minmatar scientists for use by their elite officers. \r\n\r\nPrimary Effect: +4 bonus to Memory\r\n\r\nSecondary Effect: 2% bonus to ship\'s Ladar sensor strength\r\n\r\nSet Effect: 15% bonus to the strength of all high-grade Jackal implant secondary effects. Set effect not cumulative with low-grade Jackal implants',0,1,0,1,NULL,0.0000,1,619,0),(31976,300,'High-grade Jackal Delta','This cybernetic subprocessor has been modified by Minmatar scientists for use by their elite officers. \r\n\r\nPrimary Effect: +4 bonus to Intelligence\r\n\r\nSecondary Effect: 4% bonus to ship\'s Ladar sensor strength\r\n\r\nSet Effect: 15% bonus to the strength of all high-grade Jackal implant secondary effects. Set effect not cumulative with low-grade Jackal implants',0,1,0,1,NULL,0.0000,1,621,0),(31977,300,'High-grade Jackal Epsilon','This social adaptation chip has been modified by Minmatar scientists for use by their elite officers. \r\n\r\nPrimary Effect: +4 bonus to Charisma\r\n\r\nSecondary Effect: 5% bonus to ship\'s Ladar sensor strength\r\n\r\nSet Effect: 15% bonus to the strength of all high-grade Jackal implant secondary effects. Set effect not cumulative with low-grade Jackal implants',0,1,0,1,NULL,0.0000,1,622,0),(31978,300,'High-grade Jackal Gamma','This neural boost  has been modified by Minmatar scientists for use by their elite officers. \r\n\r\nPrimary Effect: +4 bonus to Willpower\r\n\r\nSecondary Effect: 3% bonus to ship\'s Ladar sensor strength\r\n\r\nSet Effect: 15% bonus to the strength of all Jackal implant secondary effects. Set effect not cumulative with low-grade Jackal implants',0,1,0,1,NULL,0.0000,1,620,0),(31979,300,'High-grade Jackal Omega','This implant does nothing in and of itself, but when used in conjunction with other high-grade Jackal implants it will boost their effect. \r\r\n\r\r\n100% bonus to the strength of all high-grade Jackal implant secondary effects.\r\r\n\r\r\nEffect is not cumulative with low-grade Jackal implants.',0,1,0,1,NULL,0.0000,1,1506,0),(31982,87,'Navy Cap Booster 100','Provides a quick injection of power into your capacitor. Good for tight situations!',10,3,100,10,NULL,10390.0000,1,139,0),(31990,87,'Navy Cap Booster 150','Provides a quick injection of power into your capacitor. Good for tight situations!',1,4.5,100,10,NULL,18622.0000,1,139,0),(31998,87,'Navy Cap Booster 200','Provides a quick injection of power into your capacitor. Good for tight situations!',1,6,100,10,NULL,26382.0000,1,139,0),(32006,87,'Navy Cap Booster 400','Provides a quick injection of power into your capacitor. Good for tight situations!',40,12,100,10,NULL,39384.0000,1,139,0),(32014,87,'Navy Cap Booster 800','Provides a quick injection of power into your capacitor. Good for tight situations!',80,24,100,10,NULL,51964.0000,1,139,0),(32020,474,'Rahsa\'s Security Card','This security card is manufactured by Sansha\'s Nation and allows the user to unlock a specific acceleration gate.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32025,778,'Small Drone Control Range Augmentor I','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32026,787,'Small Drone Control Range Augmentor I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1243,0),(32027,778,'Medium Drone Control Range Augmentor I','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32028,787,'Medium Drone Control Range Augmentor I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1244,0),(32029,778,'Small Drone Control Range Augmentor II','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32030,787,'Small Drone Control Range Augmentor II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(32031,778,'Medium Drone Control Range Augmentor II','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32032,787,'Medium Drone Control Range Augmentor II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(32033,778,'Small Drone Durability Enhancer I','This ship modification is designed to increase a ship\'s drone shield, armor and structure hit points at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32034,787,'Small Drone Durability Enhancer I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1243,0),(32035,778,'Medium Drone Durability Enhancer I','This ship modification is designed to increase a ship\'s drone shield, armor and structure hit points at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32036,787,'Medium Drone Durability Enhancer I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1244,0),(32037,778,'Small Drone Durability Enhancer II','This ship modification is designed to increase a ship\'s drone shield, armor and structure hit points at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32038,787,'Small Drone Durability Enhancer II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(32039,778,'Medium Drone Durability Enhancer II','This ship modification is designed to increase a ship\'s drone shield, armor and structure hit points at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32040,787,'Medium Drone Durability Enhancer II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(32041,778,'Small Drone Mining Augmentor I','This ship modification is designed to increase a ship\'s mining drone yield at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32042,787,'Small Drone Mining Augmentor I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1243,0),(32043,778,'Medium Drone Mining Augmentor I','This ship modification is designed to increase a ship\'s mining drone yield at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32044,787,'Medium Drone Mining Augmentor I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1244,0),(32045,778,'Small Drone Mining Augmentor II','This ship modification is designed to increase a ship\'s mining drone yield at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32046,787,'Small Drone Mining Augmentor II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(32047,778,'Medium Drone Mining Augmentor II','This ship modification is designed to increase a ship\'s mining drone yield at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32048,787,'Medium Drone Mining Augmentor II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(32049,778,'Small Drone Repair Augmentor I','This ship modification is designed to increase a ship\'s drone repair amount at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32050,787,'Small Drone Repair Augmentor I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1243,0),(32051,778,'Medium Drone Repair Augmentor I','This ship modification is designed to increase a ship\'s drone repair amount at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32052,787,'Medium Drone Repair Augmentor I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1244,0),(32053,778,'Small Drone Repair Augmentor II','This ship modification is designed to increase a ship\'s drone repair amount at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32054,787,'Small Drone Repair Augmentor II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(32055,778,'Medium Drone Repair Augmentor II','This ship modification is designed to increase a ship\'s drone repair amount at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32056,787,'Medium Drone Repair Augmentor II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(32057,778,'Small Drone Speed Augmentor I','This ship modification is designed to increase a ship\'s drone max velocity at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',200,5,0,1,NULL,0.0000,1,1213,0),(32058,787,'Small Drone Speed Augmentor I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1243,0),(32059,778,'Medium Drone Speed Augmentor I','This ship modification is designed to increase a ship\'s drone max velocity at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',200,10,0,1,NULL,0.0000,1,1214,0),(32060,787,'Medium Drone Speed Augmentor I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1244,0),(32061,778,'Small Drone Speed Augmentor II','This ship modification is designed to increase a ship\'s drone max velocity at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1213,0),(32062,787,'Small Drone Speed Augmentor II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(32063,778,'Medium Drone Speed Augmentor II','This ship modification is designed to increase a ship\'s drone max velocity at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1214,0),(32064,787,'Medium Drone Speed Augmentor II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(32065,778,'Small EW Drone Range Augmentor I','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,0,NULL,0),(32066,787,'Small EW Drone Range Augmentor I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(32067,778,'Medium EW Drone Range Augmentor I','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,0,NULL,0),(32068,787,'Medium EW Drone Range Augmentor I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(32069,778,'Small Drone Scope Chip I','This ship modification is designed to increase a ship\'s drone optimal range at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32070,787,'Small Drone Scope Chip I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1243,0),(32071,778,'Medium Drone Scope Chip I','This ship modification is designed to increase a ship\'s drone optimal range at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32072,787,'Medium Drone Scope Chip I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1244,0),(32073,778,'Small Drone Scope Chip II','This ship modification is designed to increase a ship\'s drone optimal range at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32074,787,'Small Drone Scope Chip II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(32075,778,'Medium Drone Scope Chip II','This ship modification is designed to increase a ship\'s drone optimal range at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32076,787,'Medium Drone Scope Chip II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(32077,778,'Small EW Drone Range Augmentor II','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,0,NULL,0),(32078,787,'Small EW Drone Range Augmentor II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(32079,778,'Medium EW Drone Range Augmentor II','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,0,NULL,0),(32080,787,'Medium EW Drone Range Augmentor II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,0,NULL,0),(32081,778,'Small Sentry Damage Augmentor I','This ship modification is designed to increase a ship\'s sentry drone damage at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1213,0),(32082,787,'Small Sentry Damage Augmentor I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1243,0),(32083,778,'Medium Sentry Damage Augmentor I','This ship modification is designed to increase a ship\'s sentry drone damage at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1214,0),(32084,787,'Medium Sentry Damage Augmentor I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1244,0),(32085,778,'Small Sentry Damage Augmentor II','This ship modification is designed to increase a ship\'s sentry drone damage at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1213,0),(32086,787,'Small Sentry Damage Augmentor II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(32087,778,'Medium Sentry Damage Augmentor II','This ship modification is designed to increase a ship\'s sentry drone damage at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1214,0),(32088,787,'Medium Sentry Damage Augmentor II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(32089,778,'Small Stasis Drone Augmentor I','This ship modification is designed to increase a ship\'s stasis web drones\' factor of velocity decrease at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32090,787,'Small Stasis Drone Augmentor I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1243,0),(32091,778,'Medium Stasis Drone Augmentor I','This ship modification is designed to increase a ship\'s stasis web drones\' factor of velocity decrease at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32092,787,'Medium Stasis Drone Augmentor I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1244,0),(32093,778,'Small Stasis Drone Augmentor II','This ship modification is designed to increase a ship\'s stasis web drones\' factor of velocity decrease at the expense of the ship\'s CPU capacity.',200,5,0,1,NULL,0.0000,1,1213,0),(32094,787,'Small Stasis Drone Augmentor II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(32095,778,'Medium Stasis Drone Augmentor II','This ship modification is designed to increase a ship\'s stasis web drones\' factor of velocity decrease at the expense of the ship\'s CPU capacity.',200,10,0,1,NULL,0.0000,1,1214,0),(32096,787,'Medium Stasis Drone Augmentor II Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,NULL,0),(32097,283,'Rahsa, Sansha Commander','After numerous escapes, Rahsa\'s luck has finally run out. Despite his precarious situation, he wants to make you an offer.',80,1,0,1,NULL,0.0000,1,NULL,0),(32098,517,'Arsten Takalo\'s Republic Fleet Tempest','A Republic Fleet Tempest piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(32099,314,'Olfei Medallion','What this medallion represents is unclear. A small passage has been engraved on the underside. It reads:<br><br>\r\r\n\r\r\n Many had come to this war, hardened warriors looking for a quick kredit and some front line combat experience. Then they had seen, and they had stayed. \r\r\n',1,0.1,0,1,NULL,100.0000,1,754,0),(32100,306,'Forgotten Debris','This piece of floating debris looks intriguing, but requires relic analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32101,300,'Low-grade Grail Alpha','This ocular filter has been modified by Amarr scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 Bonus to Perception\r\r\n\r\r\nSecondary Effect: +1 to ship\'s radar sensor strength',0,1,0,1,NULL,0.0000,1,618,0),(32102,300,'Low-grade Grail Beta','This memory augmentation has been modified by Amarr scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 Bonus to Memory\r\r\n\r\r\nSecondary Effect: +1 to ship\'s radar sensor strength',0,1,0,1,NULL,0.0000,1,619,0),(32103,300,'Low-grade Grail Delta','This cybernetic subprocessor has been modified by Amarr scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Intelligence\r\r\n\r\r\nSecondary Effect: +1 to ship\'s radar sensor strength',0,1,0,1,NULL,0.0000,1,621,0),(32104,300,'Low-grade Grail Epsilon','This social adaptation chip has been modified by Amarr scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 Bonus to Charisma\r\r\n\r\r\nSecondary Effect: +1 to ship\'s radar sensor strength',0,1,0,1,NULL,0.0000,1,622,0),(32105,300,'Low-grade Grail Gamma','This neural boost has been modified by Amarr scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 Bonus to Willpower\r\r\n\r\r\nSecondary Effect: +1 to ship\'s radar sensor strength',0,1,0,1,NULL,0.0000,1,620,0),(32106,314,'Sansha Command Signal Receiver','This device can boost the incoming or outgoing signals to a Sansha device.',40,1,0,1,NULL,750.0000,1,NULL,0),(32107,300,'Low-grade Spur Alpha','This ocular filter has been modified by Gallente scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Perception\r\r\n\r\r\nSecondary Effect: +1 to ship\'s magnetometric sensor strength',0,1,0,1,NULL,0.0000,1,618,0),(32108,300,'Low-grade Spur Beta','This memory augmentation has been modified by Gallente scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Memory\r\r\n\r\r\nSecondary Effect: +1 to ship\'s magnetometric sensor strength',0,1,0,1,NULL,0.0000,1,619,0),(32109,300,'Low-grade Spur Delta','This cybernetic subprocessor has been modified by Gallente scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Intelligence\r\r\n\r\r\nSecondary Effect: +1 to ship\'s magnetometric sensor strength',0,1,0,1,NULL,0.0000,1,621,0),(32110,300,'Low-grade Spur Epsilon','This social adaptation chip has been modified by Gallente scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Charisma\r\r\n\r\r\nSecondary Effect: +1 to ship\'s magnetometric sensor strength',0,1,0,1,NULL,0.0000,1,622,0),(32111,300,'Low-grade Spur Gamma','This neural boost  has been modified by Gallente scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Willpower\r\r\n\r\r\nSecondary Effect: +1 to ship\'s magnetometric sensor strength',0,1,0,1,NULL,0.0000,1,620,0),(32112,300,'Low-grade Talon Alpha','This ocular filter has been modified by Caldari scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Perception\r\r\n\r\r\nSecondary Effect: +1 to ship\'s gravimetric sensor strength',0,1,0,1,NULL,0.0000,1,618,0),(32113,300,'Low-grade Talon Beta','This memory augmentation has been modified by Caldari scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Memory\r\r\n\r\r\nSecondary Effect: +1 to ship\'s gravimetric sensor strength',0,1,0,1,NULL,0.0000,1,619,0),(32114,300,'Low-grade Talon Delta','This cybernetic subprocessor has been modified by Caldari scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Intelligence\r\r\n\r\r\nSecondary Effect: +1 to ship\'s gravimetric sensor strength',0,1,0,1,NULL,0.0000,1,621,0),(32115,300,'Low-grade Talon Epsilon','This social adaptation chip has been modified by Caldari scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Charisma\r\r\n\r\r\nSecondary Effect: +1 to ship\'s gravimetric sensor strength',0,1,0,1,NULL,0.0000,1,622,0),(32116,300,'Low-grade Talon Gamma','This neural boost has been modified by Caldari scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Willpower\r\r\n\r\r\nSecondary Effect: +1 to ship\'s gravimetric sensor strength',0,1,0,1,NULL,0.0000,1,620,0),(32117,300,'Low-grade Jackal Alpha','This ocular filter has been modified by Minmatar scientists for use by their elite officers. \r\n\r\nPrimary Effect: +2 Bonus to Perception\r\n\r\nSecondary Effect: +1 to ship\'s Ladar sensor strength',0,1,0,1,NULL,0.0000,1,618,0),(32118,300,'Low-grade Jackal Beta','This memory augmentation has been modified by Minmatar scientists for use by their elite officers. \r\n\r\nPrimary Effect: +2 Bonus to Memory\r\n\r\nSecondary Effect: +1 to ship\'s Ladar sensor strength',0,1,0,1,NULL,0.0000,1,619,0),(32119,300,'Low-grade Jackal Delta','This cybernetic subprocessor has been modified by Minmatar scientists for use by their elite officers. \r\n\r\nPrimary Effect: +2 Bonus to Intelligence\r\n\r\nSecondary Effect: +1 to ship\'s Ladar sensor strength',0,1,0,1,NULL,0.0000,1,621,0),(32120,300,'Low-grade Jackal Epsilon','This social adaptation chip has been modified by Minmatar scientists for use by their elite officers. \r\n\r\nPrimary Effect: +2 Bonus to Charisma\r\n\r\nSecondary Effect: +1 to ship\'s Ladar sensor strength',0,1,0,1,NULL,0.0000,1,622,0),(32121,300,'Low-grade Jackal Gamma','This neural boost  has been modified by Minmatar scientists for use by their elite officers. \r\n\r\nPrimary Effect: +2 Bonus to Willpower\r\n\r\nSecondary Effect: +1 to ship\'s Ladar sensor strength',0,1,0,1,NULL,0.0000,1,620,0),(32122,300,'Low-grade Grail Omega','This implant does nothing in and of itself, but when used in conjunction with other low-grade Grail implants it will boost their effect.\r\r\n\r\r\n40% bonus to the strength of all low-grade Grail implant secondary effects.\r\r\n\r\r\nNot cumulative with high-tier Grail implant set.',0,1,0,1,NULL,0.0000,1,1506,0),(32123,300,'Low-grade Jackal Omega','This implant does nothing in and of itself, but when used in conjunction with other low-grade Jackal implants it will boost their effect. \r\r\n\r\r\n40% bonus to the strength of all low-grade Jackal implant secondary effects.\r\r\n\r\r\nNot cumulative with high-tier Jackal implant set.',0,1,0,1,NULL,0.0000,1,1506,0),(32124,300,'Low-grade Spur Omega','This implant does nothing in and of itself, but when used in conjunction with other low-grade Spur implants it will boost their effect. \r\r\n\r\r\n40% bonus to the strength of all low-grade Spur implant secondary effects.\r\r\n\r\r\nNot cumulative with high-tier Spur implant set.',0,1,0,1,NULL,0.0000,1,1506,0),(32125,300,'Low-grade Talon Omega','This implant does nothing in and of itself, but when used in conjunction with other low-grade Talon implants it will boost their effect. \r\r\n\r\r\n40% bonus to the strength of all low-grade Talon implant secondary effects.\r\r\n\r\r\nNot cumulative with high-tier Talon implant set.',0,1,0,1,NULL,0.0000,1,1506,0),(32126,526,'Homemade Sansha Beacon','This wonder of science was made with a Sansha command signal receiver, the head of Rahsa, and pounds of electrician\'s tape.',1,1,0,1,NULL,0.0000,1,NULL,0),(32127,952,'Linked Broadcast Array Hub','These arrays provide considerable added power output, allowing for an increased number of deployable structures in the starbase\'s field of operation.',100,27500,2700,1,NULL,0.0000,0,NULL,0),(32128,226,'Fortified Partially Constructed Megathron','This Megathron battleship is partially complete, with decks and inner-hull systems exposed to the cold of surrounding space.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(32129,226,'Small Armory','This small armory has a thick layer of reinforced tritanium and a customized shield module for deflecting incoming fire.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(32131,226,'Fortified Starbase Capital Shipyard','A large hangar structure with divisional compartments, for easy separation and storage of materials and modules.',100000,4000,200000,1,4,0.0000,0,NULL,0),(32132,226,'Fortified Starbase Hangar','A stand-alone deep-space construction designed to allow pilots to dock and refit their ships on the fly.',100000,1150,8850,1,4,0.0000,0,NULL,0),(32133,226,'Gallente Megathron Battleship','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.',0,0,0,1,8,0.0000,0,NULL,0),(32134,226,'Gallente Thorax Cruiser','The Thorax-class cruiser is the latest combat ship commissioned by the Federation. While the Thorax is a very effective ship at any range, typical of modern Gallente design philosophy it is most effective when working at extreme close range where its blasters and hordes of combat drones tear through even the toughest of enemies.',0,0,0,1,8,0.0000,0,NULL,0),(32135,226,'Gallente Occator Industrial','Roden Shipyards Deep space transports are designed with the depths of lawless space in mind. Possessing defensive capabilities far in excess of standard industrial ships, they provide great protection for whatever cargo is being transported in their massive holds. They are, however, some of the slowest ships to be found floating through space.',0,0,0,1,8,0.0000,0,NULL,0),(32136,226,'Gallente Incursus Frigate','The Incursus is commonly found spearheading Gallentean military operations. Its speed and surprising strength make it excellent for skirmishing duties. Incursus-class ships move together in groups and can quickly and effectively gang up on ships many times their size and overwhelm them. In recent years the Incursus has increasingly found its way into the hands of pirates, who love its aggressive appearance.',0,0,0,1,8,0.0000,0,NULL,0),(32137,226,'Gallente Obelisk Freighter','The Obelisk was designed by the Federation in response to the Caldari State\'s Charon freighter. Possessing similar characteristics but placing a greater emphasis on resilience, this massive juggernaut represents the latest, and arguably finest, step in Gallente transport technology.',11150000,190000,0,1,8,0.0000,0,NULL,0),(32138,517,'Roineron Aviviere\'s Epithal','An Epithal piloted by an agent.',0,0,0,1,8,0.0000,0,NULL,0),(32139,517,'Mourmarie Mone\'s Helios',' The preservation of the Federation, its interests abroad, its culture and peoples, and the respect and pride in its traditions, are priority one for any true Gallente citizen. We are here to ensure that our way of life is not threatened, our livelihood is extant, and the freedom that we so love is available to every citizen. For this purpose, the freedom to enforce security is at our disposal. <br><br>- Mourmarie Mone, Constellation Director, Black Eagles ',1700000,19700,305,1,8,0.0000,0,NULL,0),(32140,517,'Karde Romu \'s Armageddon','An Armageddon piloted by Karde Romu of the MIO.',0,0,0,1,4,0.0000,0,NULL,0),(32189,474,'Shanty Town Gate Clearance','This gate clearance allows the user to unlock a specific acceleration gate.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32190,705,'The Elder','The Elder of the shanty town colony, and the representative of this group.',10900000,109000,120,1,2,0.0000,0,NULL,0),(32192,631,'Underground Circus Ringmaster','The owner and operator of the Underground Circus.',11200000,112000,480,1,8,0.0000,0,NULL,0),(32193,283,'The Ringmaster','A strong, lithe Jin-Mei, scantily clad and badly bruised. She refuses to take the feminine name of her position, preferring the masculine  Ringmaster  more disconcerting to authorities. Though defeated, she smiles constantly, her eyes burning with something akin to desire and yet, at the same time, cold, bitter hatred.',50,1,0,1,NULL,0.0000,1,NULL,0),(32194,319,'Gallente Starbase Control Tower Tough','Gallente Control Towers are more pleasing to the eye than they are strong or powerful. They have above average electronic countermeasures, average CPU output, and decent power output compared to towers from the other races, but are quite lacking in sophisticated defenses.',100000,1150,8850,1,8,0.0000,0,NULL,0),(32195,517,'Riff Hebian\'s Armageddon','This battleship is commanded by Riff Hebian, head of Lord Miyan\'s security forces.',0,0,0,1,4,0.0000,0,NULL,0),(32196,517,'Krethar Mann\'s Crusader','A vacationing Amarr noble.',0,0,0,1,4,0.0000,0,NULL,0),(32198,474,'Destablizer Datacore','The Pator 6 stole this technology from Matari scientists and use it to keep outsiders away from their hideouts.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32199,520,'Scope Interceptor','An investigative reporter for the Scope.',2650000,26500,140,1,8,0.0000,0,NULL,0),(32200,314,'Covert Recording Device','When planted in the mainframe of any structure, this device will record all communications, no matter how encrypted they may be.',1,1,0,1,NULL,58624.0000,1,NULL,0),(32201,314,'Archives Passkey','These electronic devices are commonly used as long-range digital passkeys, allowing access to secure facilities directly from space.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32202,314,'Hauteker Memoirs','Painstakingly written by hand in an antiquated Nefantar script, these memoirs outline the short-lived fortunes of an Ammatar clan known as the Hauteker   long since lost to time. The memoir\'s focus seems to be on the preservation of family tradition; the highly detailed passages document everything from the way the Hauteker family dressed to where they were all buried.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32204,314,'Wildfire Khumaak','This fragile Khumaak appears to be over a century old, and could perhaps date back to the Starkmanir rebellion itself. <br><br>There are unique markings along the side; tiny holes that appear to have fastened the scepter to a wall at one point. In the centre of the flared orb there is another unique distinguishing mark, the visage of an Amarrian man draped in the robes of a Saint. His name, Torus Arzad, is not mentioned in any contemporary history, Amarrian or otherwise. Below his face a single line of text reads:<br><br> Understand His mercy, and you will know enough. \r\r\n',2,0.3,0,1,NULL,10000.0000,1,NULL,0),(32205,306,'Central Burial Tomb','This shrine entombs someone of significant standing within the Hauteker family, most likely one of their last leaders before the bloodline vanished into obscurity.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32206,952,'Defiants Storage Facility','Storage warehouses like this are a common sight in space, and are employed by all kinds of people for all kinds of reasons. From storing wheat for Empire colonies to hiding vast stockpiles of drugs for resale, storage facilities serve a number of roles and as a result they are one of the most frequently deployed structures.',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(32207,324,'Freki','Developed along with the first wave of Minmatar assault frigates but later abandoned due to cost, the Freki is known for its extremely well designed warp core that enables it to arrive first on the scene to snare and eliminate its target.\r\r\n\r\r\nIt is rarely seen on the battlefield, as only a limited number have ever gone into production. It is usually given to pilots as a reward for their excellence in combat.',1309000,27289,165,1,2,3746712.0000,1,1623,0),(32208,105,'Freki Blueprint',' ',0,0.01,0,1,NULL,1500000.0000,0,NULL,0),(32209,358,'Mimir','A highly experimental prototype created by Minmatar scientists, intended to combine the qualities of their front line heavy assault cruisers. Heavily plated and sporting additional thrusters, this ship is not to be taken lightly.\r\r\n\r\r\nRarely seen these days, the ship is typically given out only to select pilots as a reward for their excellence in combat.\r\r\n\r\r\n',11650000,96000,450,1,2,10233908.0000,1,1621,0),(32210,106,'Mimir Blueprint',' ',0,0.01,0,1,NULL,68750000.0000,0,NULL,0),(32211,306,'Archives','Archival facilities can sometimes be found dotted around the spacelanes of New Eden. Although it is rare for them to be established out here, it is not unknown for various companies and individuals to store valuable documents in such places. Some are motivated by logistical factors; it\'s always easier to move things from system to system when they\'re already in space. Others simply favor the privacy and security that endless kilometers of darkness and vacuum offers. ',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32216,226,'Fortified Amarr Cathedral','This impressive structure operates as a place for religious practice and the throne of a high ranking member within the clergy.',0,0,0,1,4,0.0000,0,NULL,0),(32217,306,'Damaged Radio Telescope','Communications Array',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32218,314,'Encrypted Data Fragment','This data node guards its secrets with a powerful encryption cipher. The unique design of the encryption is clearly proprietary and not something used elsewhere. The security software driving the protection represents a strange mixture of Gallente and Caldari designs. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32219,319,'Pator 6 HQ','A decrepit wreck of a structure, the HQ for the Pator 6 is full of junk, debris, and rubble. Children\'s clothes are strewn throughout the headquarters. This gang may be behind more kidnappings and human trafficking cases than at first glance.',0,0,0,1,NULL,0.0000,0,NULL,0),(32220,314,'Ralie Ardanne\'s Belongings','Though only a teenager, Ralie Ardanne has quite a few endorsement deals with major clothing labels. This jacket is part of his signature look. Based on your file on him, you know that Ralie goes nowhere without his jacket. The bloodstains and other marks on the fabric do not bode well, but at least this will provide evidence that the authorities can track.',1,1,0,1,NULL,0.0000,1,NULL,0),(32221,319,'Scope Station','One of Scope\'s satellite stations in the area.',0,0,0,1,8,0.0000,0,NULL,0),(32222,520,'Mourmarie Mone\'s Covert Ops Frigate','Mourmarie Mone, Constellation Director, Black Eagles.',2650000,26500,140,1,8,0.0000,0,NULL,0),(32223,314,'Kidnapping Evidence','Veine Coructie has collected the evidence you collected from the Pator 6, as well as some of the data found from the bug you planted. With this in hand, they\'re ready to smoke the kid out by causing a big media stir. There\'s no hiding when an entire population is out to get you. Sure, you should probably take this to the FIO, but who knows how effective this will be?',0.75,0.1,0,1,NULL,0.0000,1,NULL,0),(32224,952,'Conference Center ','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32225,314,'Encoded Message','This message is encoded in a familiar hybrid cipher. Only those who are already in the know about the arrangements in Black Rise will be able to make sense of it.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32226,1003,'Territorial Claim Unit','This unit contains a large fluid router array. By establishing an alternate data route to CONCORD networks, it grants de-facto administrative control of the system it\'s in to its owners.\r\r\n\r\r\nOnce online, it installs defensive protocols into the local data net which cause targeting systems to consider it an invalid target. The only way to remove this structure once it is established is to seed override protocols into more than half of the stargates in a system simultaneously. This is done by using Sovereignty Blockade Units.',1000000,5000,0,1,NULL,100000000.0000,1,1273,0),(32228,283,'Vira Mikano','Although looking slightly shaken, this Deteis man appears calm and resigned to his fate. Said to be one of Ishukone Watch\'s best cryptographers, Mikano represents everything that is admired about the Watch; efficiency, loyalty and honor. There would be severe repercussions for anyone found responsible for his disappearance.',85,3,0,1,NULL,0.0000,1,NULL,0),(32229,314,'Singed Datapad','This barely-functioning piece of personal electronics turns out to contain ledger upon ledger of financial statements, high-level meeting transcripts and company rosters from several public and private Minmatar organizations. A large portion of the data is encoded in some sort of advanced cipher, leaving it completely unintelligible.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32230,875,'Republic Freighter Vessels','The large navy forces of the Empires regularly use freighters to transport a wide variety of military items and personnel en masse.  Such vulnerable ships are usually heavily guarded as they traverse the space lanes.',1025000000,15500000,720000,1,2,0.0000,0,NULL,0),(32233,306,'Tili\'s Brothel','The architectural design for the CreoDron Habitation Module started out as a contract deal from the Expert Housing Corporation to standardize the modular drifter homes normally used by miners and deep space explorers. When the project was cancelled due to insufficient funding, CreoDron utilized their design for the open market as high-orbit department buildings for commercial use. The marketing was a tremendous hit, making the Habitation Module a common sight across the universe. Common uses include anything from bars, casinos and brothels, to police stations and interrogation facilities.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(32234,314,'Encrypted Transmission','This is an encrypted transmission from the RSS agent\'s Ammatar spy. It is a wholly incomprehensible string of 1s and 0s.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32235,314,'Tattered Doll','Formerly belonging to a young child, this doll has been through rough times. Tattered and worn, the synthetic material is stained with odd markings, presumably blood or tears from the doll\'s former owner.',10,3,0,1,NULL,0.0000,1,NULL,0),(32237,314,'Octomet Dog Tags','These dog tags are crudely constructed and chipped at the edges. The words are scrawled across the metal in a rough fashion, which feel hasty in their inscription. The name on the dog tag appears to be Caldari, though it is difficult to tell. A serial number also appears, as well as the acronym  D-IDS/IS. ',10,3,0,1,NULL,0.0000,1,NULL,0),(32238,319,'Biodome','This biodome is used for cultivation of plants and animals alike.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(32239,319,'Gallentean Deadspace Mansion','Though not quite large enough to be a station, this ornate, lavish establishment contains furnishings for any multi-purpose deadspace location. From cutting edge laboratories, to private studios and entertainment facilities, the services available in this structure are applicable for professionals and elite socialites alike.',100000,100000000,10000,1,8,0.0000,0,NULL,0),(32240,306,'Data Bank','If you have the right equipment you might be able to hack into the databank and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32241,314,'Drive Cluster EDF-285','This is a cluster of drives, each of which contains several exabytes worth of encoded data. Somewhere in here is vital information on the Wildfire Khumaak.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32242,474,'Carry On Token','This item appears to be either a medal or a token of some kind. Either way, it\'s shiny.',1,0.1,0,1,NULL,0.0000,0,NULL,0),(32243,517,'Cosmos Rapier','A Rapier piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(32244,517,'Nilf Abruskur\'s Rapier','A Rapier piloted by an agent.',0,0,0,1,2,0.0000,0,NULL,0),(32245,413,'Hyasyoda Research Laboratory','Portable laboratory facilities, anchorable within control tower fields. This structure has Material Efficiency research and Time Efficiency research activities.\r\r\n\r\r\nActivity bonuses:\r\r\n35% reduction in research ME required time\r\r\n35% reduction in research TE required time',100000000,3000,25000,1,NULL,100000000.0000,1,933,0),(32246,479,'RSS Core Scanner Probe','A scanner probe used for scanning down <a href=\"http://wiki.eveonline.com/en/wiki/Cosmic_Signatures\">Cosmic Signatures</a> in space.\r\r\n\r\r\nCan be launched from <a href=showinfo:17938>Core Probe Launchers</a> and <a href=showinfo:18639>Expanded Probe Launchers</a>.',1,0.1,0,1,NULL,4470.0000,1,1199,0),(32248,303,'Nugoehuvi Synth Blue Pill Booster','This booster relaxes a pilot\'s ability to control certain shield functions, among other things. It creates a temporary feeling of euphoria that counteracts the unpleasantness inherent in activating shield boosters, and permits the pilot to force the boosters to better performance without suffering undue pain.',1,1,0,1,NULL,8192.0000,1,977,0),(32250,1005,'Sovereignty Blockade Unit','This computing unit will interface with any nearby stargate, and attempt to restore default operating protocols to it. This process takes three hours to accomplish, and will only succeed when more than half the stargates in the system have been overriden in this manner.\r\n\r\nOnce a successful override has been made, any Infrastructure Hubs and outposts will become vulnerable.',1000000,2500,0,1,NULL,250000000.0000,1,1274,0),(32252,314,'Amphere 9','A synthetic drug long banned by the Empires, Amphere 9 can still be found in the border regions and outlawed territories of New Eden. The drug contains bits of nitrazepam, amphetamine, sodium pentothal, and synthetically rendered dopamine, plus a number of other potentially lethal substances. <br><br>\r\r\n\r\r\nThere is still a thriving black market for the pill, which many consider to be a dirtier version of Vitoc, keeping workers sedate and stable yet remarkably open to suggestion by others. The drug is especially effective on children under the age of twelve with no serious physical side effects, though no conclusive medical study has been conducted to support this claim.',10,1,0,1,NULL,0.0000,1,NULL,0),(32253,314,'Counterfeit Minmatar Faction Ammo','Crafted in illicit child labor factories, this counterfeit ammo is designed to mirror the ammo utilized in the Minmatar Navy in look, feel, and power. Because of its black market creation, though, the ammo is highly unstable, and not suitable for use in any ship. Black marketers make a modest fortune selling this ammo to unsuspecting customers with no eye for high-powered munitions.',10,2.5,0,1,NULL,0.0000,0,NULL,0),(32254,738,'Imperial Navy Modified \'Noble\' Implant','A neural Interface upgrade that boosts the pilot\'s skill at maintaining their ship\'s midlevel defenses and analyzing and repairing starship damage.\r\r\n\r\r\n3% bonus to armor hit points.\r\r\n3% bonus to repair system repair amount.\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,200000.0000,1,1518,0),(32255,749,'Sansha Modified \'Gnome\' Implant','Improved skill at regulating shield capacity and recharge rate.\r\r\n\r\r\n3% bonus to shield capacity.\r\r\n3% bonus to shield recharge rate.',0,1,0,1,NULL,200000.0000,1,1481,0),(32256,306,'RSS Radio Telescope','Communications Array',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32257,314,'Report R:081-9560','This data fragment was pulled from an RSS Radio Telescope. It appears to be just one part of a larger intelligence dossier. <br><br> The Consulate is able to, of course, but I\'m confident that the current situation won\'t escalate. Even still, we need to keep pushing for the location of the [unidentified encryption   string undecipherable]   the Angels have smelled Jovian involvement and are now throwing all kinds of ISK around to catch up to us. They will, eventually. Don\'t doubt it. I almost wish Boufin sold us out to them in the end, they\'d realize there is nothing of value to them there and screw off. But then I guess anything we value, they\'ll want to lord over us too. I\'ve noticed a few people of theirs are assigned to me too. I\'ll be taking slightly longer to get to our meetings as a result; I don\'t want to be leading them anywhere we don\'t want. <br><br>She asked to meet Boufin again today by the way, and again I had to explain the risks and make her promise to lie low. I\'m not completely trusting that she will let me handle things. She needs to keep up her public appearances in court, not go off meeting Gallentean historians in secret. Her career would be over in a second if we got made, and I\'d have serious problems of my own. <br><br>She\'s growing increasingly frustrated though, so we may have to look into some kind of arrangement. Surely we can set up a secure FTL line for them both? I know how to do it myself; I just need your clearance to proceed. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32258,314,'Report R:081-9568 ','This data fragment was pulled from an RSS Radio Telescope. It appears to be just one part of a larger communication. The intended recipient is unknown, but is presumably someone within the upper echelons of the Republic Security Services. <br><br> you dare try and cut me out of the loop again. If you wanted to run operations without me knowing or caring then you should\'ve brought in someone with half my skill. <br><br>I\'ve given six years of my life to this. Try that shit again and I\'ll be out of here. The last thing you\'ll see before the sip of Pator Whiskey you keep in the 2nd drawer kills you will be me waving a Wildfire Khumaak on The Scope news. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32259,314,'Operation Stillwater: Synopsis','This small data storage unit contains a swathe of operational information, offering insights into an ongoing RSS investigation known as  Stillwater . <br><br>Although the report logs number in the hundreds of pages, a few key details become immediately apparent. The name of a highly-ranked Ammatar Consulate official recurs frequently, and references to her as  sister  reveal a secret loyalty to the Republic. Despite the prominence of this Ammatar defector in the reports, her name and any other identifying details have been omitted. <br><br>Page after page of the synopsis is filled with meticulous documentation of the agent\'s daily life; every meeting they had, every stakeout they sat through, and every other lead they chased up   it is all here. The problem isn\'t the lack of detail, more the overwhelming amount of it. It will take some time to make sense of it all.\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32260,330,'Syndicate Cloaking Device','This prototype of an advanced cloaking mechanism was one of the last major technological breakthroughs to come out of Crielere Labs. Although it does work it is not really a finished product and has some serious drawbacks, most notably the fact that the module creates high sensor disruption while fitted and can not operate unless at minimum velocity.\r\r\n\r\r\nNote: Fitting two or more cloaking devices to a ship negates their use, as unsynchronized light deflection causes interference.',0,100,0,1,NULL,802680.0000,1,675,0),(32262,647,'Black Eagle Drone Link Augmentor','Increases drone control range.',200,25,0,1,NULL,213360.0000,1,938,0),(32264,319,'Warp Core Hotel','Formerly an old  armory, this building has been refurbished to accommodate weary travelers for a peaceful nights rest, or at least a temporary reprieve while on the jump between systems. The accommodations are efficient, designed to maintain a steady stream of customers. The rooms are sparse, the staff light, and the entire structure is rather unkempt. An odd smell permeates the walls, and most everything operates by ISK-slots. Older men and women loom around the lobby. Their attire would be provocative if they weren\'t so haggard and worn, though they always seem ready for a good time.<br><BR>\r\r\n\r\r\nWarp Core Hotel: Hourly rates only',100000,100000000,10000,1,1,0.0000,0,NULL,0),(32265,314,'Spintric Coin','A curious feature of The Spintrix is their admission system. The men and women working at this establishment do not accept ISK or any other sort of planetary currency. Rather, these workers accept only Spintrix coins, specially designed and highly desirable copper coins purchased through the agents of the Spintrix\'s owners.',10,1,0,1,NULL,0.0000,1,NULL,0),(32266,314,'Spintrixiate Rewards Coin','Special customers to the Spintrix are often rewarded with this unique coin, dubbed the  Spintrixiate.   Little is known about the benefits of this rewards token, though rumors among former clients circulate that the coin allows access to the mysterious  Room B. ',10,1,0,1,NULL,0.0000,0,NULL,0),(32267,314,'Ishukone Operational Reports','Bluechip devices like these serve a similar role to the \"black boxes\" used aboard planetary aircraft. They are capable of storing vast amounts of information, and protecting it in a secure shell that can withstand immense destructive forces. Due to their resilience, they are also the favored data storage unit of military companies who need vital operational data to be safeguarded from attack. <br><br>\r\r\n\r\r\nThis particular bluechip has been modified to protect the contents in even more ways. A distinctively unique hybrid cipher has reduced the contents of each report to a series of 1\'s and 0\'s. \r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32268,667,'Harkan\'s Behemoth','Lord Harkan\'s ship is an impressive example of Amarr engineering. It appears after his retirement his ship was refit with cobalt-plated armor. It is unclear if this was a personal decision or the sign of an even darker alliance.',20500000,1100000,525,1,4,0.0000,0,NULL,0),(32269,668,'Lord Miyan','Lord Miyan\'s cruiser is packed with the latest Amarr technology. Still not advanced enough to stop the guns of a capsuleer.',11800000,118000,235,1,4,0.0000,0,NULL,0),(32270,283,'Artificial Miyan','This amalgamation of Amarr and Sansha technology is the spitting image of Lord Miyan. Once activated it could fool anyone into believe it was the real, living Holder.',90,2,0,1,NULL,0.0000,1,NULL,0),(32271,952,'Business Associate','Business Associate.',13500000,27500,2700,1,4,0.0000,0,NULL,0),(32272,314,'Primordial Biomass','This vat of biomass is slightly soupier than most.',1,1,0,1,NULL,0.0000,0,NULL,0),(32273,952,'Safe House Ruins','This structure has seen better days.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32275,226,'Fortified Amarr Chapel','This decorated structure serves as a place for religious practice.',0,0,0,1,4,0.0000,0,NULL,0),(32276,306,'Office Facility','These small compounds can house hundreds of office workers, and are typically used as a cost-efficient temporary solution for large corporations moving their workforce between stations.  ',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(32277,314,'Deteis Family','A normal, if somewhat familiar-looking Deteis family. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32278,517,'Hiva Shesha\'s Shuttle',' The sands of time is a complex metaphor, and as historians, we must understand its meaning. We are not here to play in a sandbox and find all the hidden rocks. History is not the unraveling of truth or unearthing forgotten knowledge. Rather, \'the sands of time\' are mixed with our rational minds to form glass. We are opticians, further carving that glass into lenses, which are layered together. Sometimes the view becomes clearer; other times, opaque. We cannot change the sands of time: We can only sharpen our lenses. <Br><Br>-Hiva Sheesha, <i>A History of the Matari People</i>',0,0,0,1,2,0.0000,0,NULL,0),(32279,306,'Chapel of the Obsidian ','Chapel of the Obsidian',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32280,314,'Blood Obsidian Orb','The Church of the Obsidian has kept this relic for nearly four hundred years, though its original meaning was never truly discovered. The orb is carved from blood obsidian, the same material found in the head of the Wildfire Khumaak. The orb\'s surface is completely smooth, though it is lighter than it appears. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32281,306,'Secure Communications Tower','This huge communications tower contains fragile but advanced sensory equipment.',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(32282,1207,'Ammatar Relics','This massive hulk of debris seems to have once been a part of the outer hull of a battleship or station.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32283,314,'Engraved Blood Obsidian tablet','A small tablet, made entirely of blood obsidian, engraved with writing. The words on the tablet are not entirely clear, and the dialect is familiar, though unreadable. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32284,314,'St. Arzad','A tattered document, presumably a part of a larger manuscript. The text is written neatly, though much of it is faded. An excerpt from this piece, titled  Chapter 1   St. Arzad  reads as follows:<br><br>\r\r\n And so it was that Arzad Hamri, son of Ezzara Hamri, grandson of Yuzier Hamri, ascended to the title of Holder of the most holy grounds on Starkman Prime. Though only a young man, Arzad held the wisdom of the ages, granted to him by the celestial Maker, and carried with him the burden of creation. <br><br>\r\r\n His first act as Holder was to grant a day of celebration to all his slaves, calling that day holy by the Amarr religion. The slaves, members of the Starkmanir tribe, referred to that day as the  Hand of Solace  or  Khu-arzad.  Unlike his father before him, Arzad was instantly loved by his slaves, and his benevolence sowed the seeds of righteous love between Holder and slave. \r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32285,314,'The Benevolent','A tattered document, presumably a part of a larger manuscript. The text is written neatly, though much of it is faded. An excerpt from this piece, titled  Chapter 6   The Benevolent  reads as follows:<br><br>\r\r\n The fields and hills of Starkman Prime are harsh and demanding, especially for those working indentured servants tied directly to the land by the holy bonds of slavery. Arzad Hamri understood their plight and pitied them. As a boy, he would often work alongside the Starkmanir in the fields, immersing himself with the tribe to better understand their customs and traditions, much to the chagrin of his father and elders. <br><br>\r\r\n As a Holder, Arzad offered many forms of restitution and bereavement for the Starkmanir during their often long and difficult days. Regular rest periods were common during his rule, as well as days of parlay and rest, including high holy days and other Amarr religious festivals, deeming these occasions to be too holy. The Starkmanir loved him for these decisions, often working extra hours when necessary because they respected Arzad and wished for him to be pleased with their efforts. \r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32286,314,'The Education of the Starkmanir','A tattered document, presumably a part of a larger manuscript. The text is written neatly, though much of it is faded. An excerpt from this piece, titled  Chapter 12   The Education of the Starkmanir  reads as follows:<br><br>\r\r\n By the end of his tenth year as Holder on Starkman Prime, Arzad had finished the educational infrastructure for the Starkmanir with the establishment of the final slave college on his continent. The focus of these education centers, aimed at young members of the Starkmanir tribes, was in assimilating the slaves into the greater Amarr society. The focus was primarily in basic business matters, science and technology, and all aspects of the Amarr religion. Attendance at this school was not entirely elective, and slaves were given time to study, though they would often have to make up for lost time in the fields. Despite this, many Starkmanir entered into the slave colleges in order to better their station in life, especially with respect to the high, holy Amarr religion.<br><Br>\r\r\n The Starkmanir also educated their beloved Holder in kind, as well as other members of the Hamri family. The tradeoff in education was often mutual between the tribal leaders and Arzad. When the slave colleges began teaching business matters, the Holder learned ancient Starkmanir woodworking; astronomy education led to the Starkmanir martial arts; and the teaching of the Amarr religion initiated Arzad\'s own edification of the Starkmanir\'s tribal spiritualism. \r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32287,314,'Hand of Arzad','A tattered document, presumably a part of a larger manuscript. The text is written neatly, though much of it is faded. An excerpt from this piece, titled  Chapter 20   Hand of Arzad  reads as follows:<br><br>\r\r\n The Hand of Arzad grew to become the most popular festival on Starkman Prime, so beloved was this day of rest granted by Arzad Hamri. On this day, Hamri presided acted as pastor of religious services, in which most of the Starkmanir attended. His sermons from these festivals were collected and distributed among the tribe, often used by the elders to educate the young people of the importance of benevolence and good grace to people of all stations. <br><br>\r\r\nThe theme of Arzad\'s sermons was almost always of the inherent dignity of the Starkmanir, their precious qualities, and the hope of salvation through servitude. This message did not fall on deaf ears, and many ambitious, young Starkmanir took his words as inspiration for independence and rebellion against the greater Amarr Empire, though Arzad was always able to quell the burgeoning pride and self-esteem of the slaves.  Salvation comes through servitude, the grace of your masters, the dignity of your being,\' was Arzad\'s common response, his refrain found throughout his sermons.  \r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32288,314,'The Fire in Our Hearts','A tattered document, presumably a part of a larger manuscript. The text is written neatly, though much of it is faded. An excerpt from this piece, titled  Chapter 37   The Fire in Our Hearts  reads as follows:<br><br>\r\r\n Lord Arkon Ardishapur, though a longtime friend of Arzad, oversaw the popular Holder\'s execution for treason and blasphemy. Arzad had requisitioned an Amarr symbol of authority, a scepter,  as a symbol for lowly slaves. Arzad\'s granted the scepter to his slaves as a symbol for enlightenment and salvation. Ardishapur ordered that all copies of this scepter   dubbed Wildfire scepters for its blood obsidian orb, a rock native to Starkman Prime   be destroyed. The Starkmanir were angry at his execution. Arzad\'s book of sermons inspired the troubled tribe. <br><br>\r\r\n Three months after his death, Arzad appeared to Drupar Maak while the slave was alone in the fields. The Starkmanir youth was afraid at first, though once he saw the shimmering eyes of his former Holder, he was at peace. Arzad handed a Wildfire scepter to Maak, telling him,  The fire in our hearts burns for salvation, redemption, and grace. May the Word of God grant you the courage to save yourself and your people.\' With those words, Arzad disappeared, but the scepter was still with Maak. Years later, he would wield a similar item and avenge the death of his beloved Holder on the day of Khu-arzad. After that day, the scepter would be forever known as Khumaak. \r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32289,314,'Holoreel: Wanted for Love','A low-quality holoreel titled  Wanted for Love.  The description on the back of the shoddy packaging reads: <br><br>\r\r\n\r\r\n A Gallente women, recently divorced and fired from her high-paying job at Combined Harvest, is framed for murdering her ex-husband. On the run from CONCORD, she delves deep into the heart of New Eden\'s underworld, where she discovers what she\'s truly made of. Hot on her trails is her ex-lover, a deputy officer in the Directive Enforcement Department. Inspired by love, he goes undercover in search of his one and only soulmate, who is truly wanted for love. This sultry, uncensored journey of self-discovery and the limits of romance stimulates mind, body, and soul. Starring Elois Ottin in her most scintillating performance yet. ',10,1,0,1,NULL,0.0000,1,NULL,0),(32290,314,'Obsidian Datacore','Found inside the Blood Obsidian Orb, this datacore is supposed to reveal the location of the lost <i>Book of St. Arzad</i>.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32291,952,'Chapel Container','This decorated structure serves as a place for religious practice.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32292,283,'Ralie Ardanne','Battered, bruised, worn, but ultimately alive. Ralie sits there, staring straight in front of him, his eyes glazed over. The kid\'s alive, but who knows how long he will be recovering from these scars.',60,1,0,1,NULL,0.0000,1,NULL,0),(32293,706,'Rosulf Fririk','This variant of the frontline battleship of the Minmatar Republic has been heavily modified with only one purpose in mind: Destruction.  It has been supplemented with decks of top-of the-line-fire control systems, and its entire power distribution structure has been redesigned to provide as much power as possible to its weapons, resulting in a truly fearsome battleship.',19000000,850000,550,1,2,0.0000,0,NULL,0),(32294,314,'Book of St. Arzad','This book is in tatters, and some of its page are worn or missing, but much of its contents is still readable. The book describes the life of Arzad Hamri, an Amarr Holder on Starkman Prime. It is supposedly a relic from the Starkmanir Rebellion.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32296,674,'Ishukone Watch Commander','In every Ishukone Watch base there is a single Commander who oversees operations. The men and women selected for this honored duty represent the most capable military minds outside of the Caldari Navy. The service records of these Commanders typically show a long and distinguished career fighting against the many threats facing their parent Corporation, and often the Caldari people as a whole. It is not uncommon for people in such positions to rise into minor celebrity status, as their deeds grant them a glimpse of the almost mythological status held by the State\'s great military names.',1080000,22000000,235,1,1,0.0000,0,NULL,0),(32297,674,'Nugoeihuvi Caretaker','Those who watch over Nugoeihuvi\'s secret storage facilities are entrusted with secrets that run deep inside the shadowed histories of the NOH staff. Valued for their loyalty, discretion and endless hunger for ISK, these men and women serve Nugoeihuvi\'s darkest interests without question.',1080000,22000000,235,1,1,0.0000,0,NULL,0),(32298,594,'Karkoti Rend','A rogue RSS agent, working for the Cartel.',19000000,19000000,120,1,2,0.0000,0,NULL,0),(32299,952,'Senator Pillius Ardanne','Senator\'s Viator.',13500000,27500,2700,1,4,0.0000,0,NULL,0),(32300,1003,'QA Territorial Claim Unit','This structure does not exist.',65000,1,10,1,NULL,100000000.0000,0,NULL,0),(32302,1005,'QA Sovereignty Blockade Unit','This structure does not exist.',32000,1,10,1,NULL,250000000.0000,0,NULL,0),(32304,517,'Harkan\'s Apocalypse','An Apocalypse piloted by an agent.',0,0,0,1,4,0.0000,0,NULL,0),(32305,27,'Armageddon Navy Issue','An improved version of the feared Armageddon-class battleship, this vessel is probably one of the deadliest war machines ever built by the hand of man. Commanding one is among the greatest honors one can attain in the Amarr Empire, and suffering the fury of its turret batteries is surely the fastest way to reunite with the void.',105200000,486000,700,1,4,251111582.0000,1,1379,0),(32306,107,'Armageddon Navy Issue Blueprint',' ',0,0.01,0,1,NULL,662500000.0000,1,NULL,0),(32307,27,'Dominix Navy Issue','The Dominix Navy Issue\'s past is prominently interwoven with history, as it is known to have directly participated in the blockade and bombardment of Caldari Prime along with the Dracofeu orbital-class bomber two centuries ago. Engineered for capsule compliance, and refitted to serve more traditional combat roles, the Dominix Navy Issue today remains an extremely effective vessel and an invaluable asset in close- to mid-range battle situations.',97100000,454500,675,1,8,220059424.0000,1,1379,0),(32308,107,'Dominix Navy Issue Blueprint',' ',0,0.01,0,1,NULL,625000000.0000,1,NULL,0),(32309,27,'Scorpion Navy Issue','This ship\'s design represents a radical turnaround in Caldari philosophy, particularly when compared to that of its regular Scorpion-class counterpart. Abandoning the concept of an electronic warfare platform, this vessel\'s creators instead set their sights on direct combat, with superior shielding and offensive capabilities giving this monster the undeniable upper hand in a vast range of tactical situations.',103600000,468000,650,1,1,186230718.0000,1,1379,0),(32310,107,'Scorpion Navy Issue Blueprint',' ',0,0.01,0,1,NULL,712500000.0000,1,NULL,0),(32311,27,'Typhoon Fleet Issue','Possibly the most versatile vessel in New Eden, the Typhoon Fleet Issue is a true wonder in design adaptability. Boasting improved fittings, speed and weapon hardpoints over its standard counterpart, this ship is widely known as an invaluable wild card in any small-scale engagement.',102600000,414000,600,1,2,178394358.0000,1,1379,0),(32312,107,'Typhoon Fleet Issue Blueprint',' ',0,0.01,0,1,NULL,750000000.0000,1,NULL,0),(32313,1012,'QA Infrastructure Hub','This structure does not exist.',100,1,110,1,NULL,40.0000,0,NULL,0),(32325,1023,'Cyclops','Gallente Fighter Bomber Craft',12000,10000,0,1,8,62672424.0000,1,1310,0),(32326,1145,'Cyclops Blueprint',' ',0,0.01,0,1,NULL,300000000.0000,1,1313,0),(32339,273,'Fighter Bombers','Allows operation of fighter bomber craft. 20% increase in fighter bomber damage per level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,100000000.0000,1,366,0),(32340,1023,'Malleus','Amarr Fighter Bomber Craft',12000,10000,0,1,4,66122330.0000,1,1310,0),(32341,1145,'Malleus Blueprint',' ',0,0.01,0,1,NULL,300000000.0000,1,1313,0),(32342,1023,'Tyrfing','Minmatar Fighter Bomber Craft',12000,10000,0,1,2,62405340.0000,1,1310,0),(32343,1145,'Tyrfing Blueprint',' ',0,0.01,0,1,NULL,300000000.0000,1,1313,0),(32344,1023,'Mantis','Caldari Fighter Bomber Craft',12000,10000,0,1,1,67652746.0000,1,1310,0),(32345,1145,'Mantis Blueprint',' ',0,0.01,0,1,NULL,300000000.0000,1,1313,0),(32347,306,'Exploration Supplies','This storage facility contains a basic supply of exploration scanning equipment for use by capsuleers-in-training.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32348,927,'Agent Rulie Isoryn','This ship poses no immediate threat.',11750000,275000,6000,1,8,0.0000,0,NULL,0),(32349,319,'Proximity Charge','Standard mine with nuclear payload.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(32350,314,'Proof of Discovery: Anomalies','This document has been placed inside a Cosmic Anomaly secured by Empire agents. It serves as physical proof that a capsuleer-in-training has been able to locate the anomaly through the use of On-Board Scanning.',1,1,0,1,NULL,0.0000,1,NULL,0),(32351,314,'Proof of Discovery: Ore','This document has been placed inside a Ore site secured by Empire agents. It serves as physical proof that a capsuleer-in-training has been able to locate the signature through the use of Core Scanner Probes.',1,1,0,1,NULL,0.0000,1,NULL,0),(32352,314,'Proof of Discovery: Ore Passkey','This electronic passkey is provided by tutorial agents as part of a capsuleer training program. It is used to unlock an acceleration gate inside the Ore site training area, where the  Proof of Discovery  documents can be found stored inside containers. The  Proof of Discovery  documents serve as physical evidence that the capsuleer was able to discover a particular type of site. \r\r\n\r\r\nThis passkey is used to unlock Acceleration gates found inside <b>Ore</b> sites only.',1,1,0,1,NULL,0.0000,1,NULL,0),(32353,306,'Training Container - Anomalies','This container houses the <b> Proof of Discovery: Anomalies </b> document, which serves as physical proof that a capsuleer-in-training has been able to locate the anomaly through the use of On-Board Scanning. It must be retrieved to complete the first tutorial mission. \r\r\n\r\r\nIf at first the container appears empty, please wait a few minutes for a new document to be provided.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32357,1010,'Compact Doom Torpedo I','Representing the latest in miniaturization technology, Compact Citadel Torpedoes are designed specifically to be used by Fighter Bombers.\r\r\n\r\r\nNocxium atoms captured in morphite matrices form this missile\'s devastating payload. A volley of these is able to completely obliterate most everything that floats in space, be it vehicle or structure.',1500,0.3,0,100,NULL,250000.0000,0,NULL,0),(32359,1010,'Compact Purgatory Torpedo I','Representing the latest in miniaturization technology, Compact Citadel Torpedoes are designed specifically to be used by Fighter Bombers.\r\r\n\r\r\nPlasma suspended in an electromagnetic field gives this torpedo the ability to deliver a flaming inferno of destruction, wreaking almost unimaginable havoc.',1500,0.3,0,100,NULL,325000.0000,0,NULL,0),(32361,1010,'Compact Rift Torpedo I','Representing the latest in miniaturization technology, Compact Citadel Torpedoes are designed specifically to be used by Fighter Bombers.\r\r\n\r\r\nFitted with a graviton pulse generator, this weapon causes massive damage as it overwhelms ships\' internal structures, tearing bulkheads and armor plating apart with frightening ease.',1500,0.3,0,100,NULL,300000.0000,0,NULL,0),(32363,1010,'Compact Thor Torpedo I','Representing the latest in miniaturization technology, Compact Citadel Torpedoes are designed specifically to be used by Fighter Bombers.\r\r\n\r\r\nNothing more than a baby nuclear warhead, this guided missile wreaks havoc with the delicate electronic systems aboard a starship. Specifically designed to damage shield systems, it is able to ravage heavily shielded targets in no time.',1500,0.3,0,100,NULL,350000.0000,0,NULL,0),(32365,314,'Proof of Discovery: Relic','This document has been placed inside a Relic site secured by Empire agents. It serves as physical proof that a capsuleer-in-training has been able to locate the signature and properly performed analysis in the area.',1,1,0,1,NULL,0.0000,1,NULL,0),(32366,314,'Proof of Discovery: Data','This document has been placed inside a Data site secured by Empire agents. It serves as physical proof that a capsuleer-in-training has been able to locate the signature and successfully perform a hacking attempt inside the area.',1,1,0,1,NULL,0.0000,1,NULL,0),(32367,1207,'Training Container - Relic','This container must be accessed using a <b>Civilian Relic Analyzer</b>. As soon as a successful attempt is detected, it will unlock. Inside, the <b> Proof of Discovery: Relic </b> document can be retrieved.\r\r\n\r\r\nIf at first the container appears empty, please wait a few minutes for a new document to be provided.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32368,306,'Training Container - Salvaging','This container must be accessed using a <b>Civilian Salvager</b>. As soon as a successful salvage attempt is detected, it will unlock. Inside, the <b> Proof of Discovery: Magnetometric </b> document can be retrieved.\r\r\n\r\r\nIf at first the container appears empty, please wait a few minutes for a new document to be provided.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32369,1207,'Training Container - Data','This container must be accessed using a <b>Civilian Data Analyzer</b>. As soon as a successful hacking attempt is detected, it will unlock. Inside, the <b> Proof of Discovery: Data </b> document can be retrieved.\r\r\n\r\r\nIf at first the container appears empty, please wait a few minutes for a new document to be provided.',10000,27500,2700,1,1,0.0000,0,NULL,0),(32370,306,'Assembly Station DC105-A','This shipyard was probably moved here recently. For now, parts for large vessels are stored in easily accessible silos jutting from the station\'s surface.',100000,100000000,10000,1,2,0.0000,0,NULL,0),(32371,314,'Capital Ship Design    Dictator ','The Caldari Navy have purportedly worked on this project for the past decade, but lack of funding has kept this new type of capital ship from reaching the pre-production stage. These designs are deemed highly classified and have been kept under wraps in this remote station.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32372,283,'Minedrill   E518 Crew','This unfortunate crew will supply the Guristas with the intelligence for future raids, assuming they can be made to cooperate. That shouldn\'t be an issue, though.',100,3,0,1,NULL,0.0000,1,NULL,0),(32374,280,'Holoreel GRS-81A','The holoreel plays a short message. A man\'s voice can be heard: \r\r\n\r\r\nI need you to listen very carefully, because I don\'t have much time. When I was with her, she had a woman there, as well. I know this to be true because I could hear her interrogating the crew. I couldn\'t see her until the last days, but when I got loose and crossed to where they were holding her, I saw that there wasn\'t much left. It was like that egger had ordered her face to be burnt away or removed.\r\r\n\r\r\nI don\'t know what she\'s planning. Since the accident, she could very well have assumed any identity. It\'s possible she doesn\'t even- \r\r\n\r\r\nThe message ends abruptly. There is something scrawled on the back:  Even devils will have their day. \r\r\n',100,0.5,0,1,NULL,250.0000,1,NULL,0),(32375,314,'Proof of Discovery: Gas Passkey','This electronic passkey is provided by tutorial agents as part of a capsuleer training programming. It is used to unlock an acceleration gate inside the Gas site training area, where the  Proof of Discovery  documents can be found stored inside containers. The  Proof of Discovery  documents serve as physical evidence that the capsuleer was able to discover a particular type of site. \r\r\n\r\r\nThis passkey is used to unlock Acceleration gates found inside <b>Gas</b> sites only.',1,1,0,1,NULL,0.0000,1,NULL,0),(32376,314,'Proof of Discovery: Gas','This document has been placed inside a Gas site secured by Empire agents. It serves as physical proof that a capsuleer-in-training has been able to locate the signature through the use of Core Scanner Probes.',1,1,0,1,NULL,0.0000,1,NULL,0),(32377,306,'Venal Regional Comms Tower','A structure tasked with relaying, boosting, and encrypting data. It seems to be operating at full capacity.',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(32378,306,'Training Container - Ore','This container houses the <b> Proof of Discovery: Ore </b> document, which serves as physical proof that a capsuleer-in-training has been able to locate the site through the use of Core Scanner Probes. It must be retrieved to complete the Ore site training mission. \r\r\n\r\r\nIf at first the container appears empty, please wait a few minutes for a new document to be provided.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32379,306,'Training Container - Gas','This container houses the <b> Proof of Discovery: Gas </b> document, which serves as physical proof that a capsuleer-in-training has been able to locate the Gas site through the use of Core Scanner Probes. It must be retrieved to complete the Gas training mission.  \r\n\r\nIf at first the container appears empty, please wait a few minutes for a new document to be provided.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32380,182,'Roden Police Major','The Gallente government contracted this vessel from Roden Shipyards in order to bolster security in Federation space. It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Extreme',20000000,1080000,14000,1,8,0.0000,0,NULL,0),(32381,182,'Roden Police Sergeant','The Gallente government contracted this vessel from Roden Shipyards in order to bolster the security in Federation space . It is patrolling this sector and will respond to any combat it detects. It can call in reinforcements from nearby sectors if the need arises. Threat level: Very high',2040000,20400,160,1,8,0.0000,0,NULL,0),(32382,306,'Damaged Caldari Shuttle','This tiny craft is badly damaged. All propulsion units have been completely disabled.',1450000,16120,145,1,1,0.0000,0,NULL,0),(32383,314,'Guristas  Dirty\' Explosive System','A rudimentary, though effective, explosion matrix, used specifically for Guristas special operation tactical strikes. Once inside a ship\'s cargo bay, this  dirty  bomb will, upon detonation, cause massive damage to any ship, structure, or starship base. It\'s volatility, however, is also a liability: Getting the bomb to its destination is more dangerous than actually utilizing the explosion system.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32384,671,'Captured Caldari State Shuttle','A captured Caldari state shuttle',1600000,5000,10,1,1,0.0000,0,NULL,0),(32385,612,'Guristas Battleship Vessel','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',21000000,1040000,235,1,1,0.0000,0,NULL,0),(32386,226,'Violent Wormhole','Though the wormhole seems stable, the exotic radicals pouring from the tear imply that using it would be catastrophic.',1,0,0,1,NULL,0.0000,0,NULL,0),(32387,226,'Stable Wormhole','This wormhole appears to be relatively new. For the time being, it is stable, though excessive traffic and time will eventually cause it to vanish.',1,0,0,1,NULL,0.0000,0,NULL,0),(32388,927,'Angel Recovery Team','Sometimes a combat encounter doesn\'t go the Cartel\'s way, and men and resources are left behind. Rather than leave their fates to scavengers, the Cartel employs its own recovery teams specializing in battlefield salvage and extraction.',12500000,255000,5625,1,NULL,0.0000,0,NULL,0),(32389,283,'Dread Guristas Strike Force','A troupe of trained specialists, skilled at overtaking stations for the Guristas. This team, calling themselves the  Dread Naughts,  are a rough bunch, hellfires in the restrictive confines of your cargohold, hardly a disciplined lot during downtime. However, once they are in action, they have the precision to match any elite Empire task force.',80,1,0,1,NULL,0.0000,1,NULL,0),(32390,672,'Gath Renton','Renton is the CEO of a small capsuleer corporation. For years, he\'s managed to stay off the radar of the major alliances. One day, he may achieve his dreams of bigger things; but today, all he has to look forward to is the wrath of the Cartel.',10100000,101000,235,1,1,0.0000,0,NULL,0),(32391,615,'Yukiro Demense','One of the younger commanders in the Guristas Fleet, Yukiro Demense has proven himself capable and aggressive. He and his wingmen are known for their daring raids into State space, as well as their constant harassment of CONCORD and other police forces. Lately, he\'s been leading raids on the Angel Cartel and Serpentis in Fountain, becoming quite a thorn in the side of the two larger criminal factions. As yet, he hasn\'t drawn any special attention, but it won\'t be long until his powerful enemies do something about him.',1650000,16500,235,1,1,0.0000,0,NULL,0),(32392,671,'Eroma Eralen','For whatever reason, Eroma Eralen has never risen very far within the Guristas ranks, despite his nearly twenty year membership in the pirate organization. His superiors blame his erratic behavior, particularly in dealing with small group operations, though others fault his addictions, ranging from interspatial radio technology to low-end boosters to black market pornographic holoreels. He currently acts as Kori Latamaki\'s operative, specializing in covert techno-raids and synthaesthetic manipulation schemes. He can barely be trusted, but he knows what he\'s doing, though he could just be creating an elaborate practical joke for his own amusement.',1600000,5000,10,1,1,0.0000,0,NULL,0),(32393,314,'Sealed Research Cache','The contents of this container remain sealed behind some kind of proprietary Cartel technology. A thin, red film of hardened fullerene alloys forms a perfect, unbreakable seal around the contents. As if that wasn\'t enough to deter attackers, the surface underneath the film is covered in tiny nanite-plasma explosives. Any attempt at forced entry past the film would produce enough explosive power to level a small town.',10,2,0,1,NULL,0.0000,1,NULL,0),(32394,952,'Serpentis Transport Hub','This facility is used by Serpentis research teams to ship goods out of Cartel space and back towards Fountain.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(32395,517,'Atma Aulato\'s Falcon','A Falcon piloted by an agent.\r\r\n\r\r\n\r\r\n',0,0,0,1,1,0.0000,0,NULL,0),(32396,517,'Arment Caute\'s Lachesis','A Lachesis piloted by an agent.',12500000,116000,320,1,8,0.0000,0,NULL,0),(32397,517,'Yada Vinjivas\'s Gila','A Gila piloted by an agent.',10100000,101000,250,1,1,0.0000,0,NULL,0),(32398,283,'Lieutenant Kipo  Foxfire  Tekira','Cilis Leglise\'s missing Lieutenant is barely conscious. His legs are no longer functional, and a great deal of his right arm has been removed, almost to the shoulder. Irichi said he\'s modified this man the same way he\'d been modified by Cilis, but this is a bit extreme.<br><br>Kipo is obviously under heavy medication. He stares at you, and though he is drugged, his eyes relate a sickening uncertainty. Though he cannot talk, his body language insinuates that he is begging for mercy.',80,1,0,1,NULL,100.0000,1,NULL,0),(32399,226,'Statehood Incarnate Monument','The Guristas erected this monument years ago, in direct mockery of the massive State-funded public works programs, beautification initiatives, and patriotic displays seen throughout Caldari space. Dubbing this monument,  Statehood Incarnate,  the entire area is a mockery of the sacred, the glorification of the profane, littered with the true ideals of the Gurista pirates: abject nihilism.',0,0,0,1,NULL,0.0000,0,NULL,0),(32400,597,'Angel Frigate Vessel','This is a fighter for the Angel Cartel. It is protecting the assets of the Angel Cartel and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1970000,19700,235,1,2,0.0000,0,NULL,0),(32401,595,'Angel Cruiser Vessel','This is a fighter for the Angel Cartel. It is protecting the assets of the Angel Cartel and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',10100000,101000,235,1,1,0.0000,0,NULL,0),(32402,594,'Angel Battleship Vessel','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,2,0.0000,0,NULL,0),(32403,314,'Caldari Navy Overlay Transponder','This transponder, taken from Kori\'s operative, is your ticket to the rendezvous with the Navy. Barely functional after the destruction of the operative\'s ship, it contains identification data that will scramble security frequencies, tricking them into identifying your ship as Eroma\'s. ',1,0.1,0,1,NULL,0.0000,1,NULL,0),(32404,952,'Cilis Leglise\'s Headquarters','Cilis Leglise\'s Headquarters.',100000,27500,2700,1,NULL,0.0000,0,NULL,0),(32405,226,'Serpentis Research Facility','This research facility is use by the Serpentis to conduct experiments considered too dangerous or too secretive to perform in one of their larger stations. It seems that didn\'t keep the Guristas from finding out about it, however.',0,0,0,1,8,0.0000,0,NULL,0),(32406,306,'Caldari Storage Warehouse','This is a standard storage facility.',1000000,1150,8850,1,NULL,0.0000,0,NULL,0),(32407,314,'Holoreel   Torture Log I15B','The grainy footage on this holoreel depicts a young man standing in a small room, his arms bound and his legs chained to the ground, spread apart as far as they can go. His face cannot be seen. The man is bleeding from cuts all across his body. A woman\'s voice asks him an inaudible question. He answers,  No.  The voice asks another question, also inaudible. The man gives the same response. <br><br>\r\r\nThis repeats for a few more questions. After the last question, a woman dressed in a Gallente Federation uniform appears. She approaches the man. The man lifts his head, showing his face: It is Irichi. The woman holds his face in his hands, kisses him softly on the lips, and turns to the holoprojector: It is Cilis. She reaches off camera for something. Behind her, Irichi\'s head drops, tears streaming down his face. Cilis returns, holding a remote in her hands. She pushes a button. Mechanical noises reverberate throughout the room. A panel opens beneath Irichi\'s feet. He winces, screams in pain. Loud sawing noises interrupt the scene. The footage goes blank.\r\r\n',100,0.5,0,1,NULL,250.0000,1,NULL,0),(32408,314,'Correspondence Log KL-513','A collection of datacores, holoreels, dossiers, and assorted recordings logging the interactions between Kori Latamaki and the Caldari Navy. This information is vital in establishing a treason case against Kori for his dealings with the Navy, with which he has forsaken his brethren in the Guristas. ',1,0.5,0,1,NULL,100.0000,1,NULL,0),(32409,517,'Aton Hordner\'s Tempest','Despite flying with a Republic license, this agent radiates \"shady.\"',0,0,0,1,2,0.0000,0,NULL,0),(32410,517,'Arajna Ashia\'s Arbitrator','Arajna is known to have contacts within the Angel Cartel for those willing to expand their horizons.',0,0,0,1,4,0.0000,0,NULL,0),(32411,517,'Ellar Stin\'s Dramiel','Ellar Stin, unapologetic Angel.',0,0,0,1,8,0.0000,0,NULL,0),(32412,319,'Boundless Creations Data Center','This massive complex houses hundreds of supercomputers, all dedicated to research and storage. One such superconductor contains the latest Sleepers research from Boundless Creations.',100000,100000000,10000,1,1,0.0000,0,NULL,0),(32413,208,'Shadow Serpentis Remote Sensor Dampener','Reduces the range and speed of a targeted ship\'s sensors. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,8,13948.0000,1,679,0),(32414,379,'Domination Target Painter','A targeting subsystem that projects an electronic \"Tag\" on the target thus making it easier to target and Hit. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized. ',0,5,0,1,NULL,51464.0000,1,757,0),(32415,504,'Domination Target Painter Blueprint',' ',0,0.01,0,1,NULL,298240.0000,0,NULL,0),(32416,291,'Dark Blood Tracking Disruptor','Disrupts the turret range and tracking speed of the target ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,2,14828.0000,0,NULL,0),(32417,291,'True Sansha Tracking Disruptor','Disrupts the turret range and tracking speed of the target ship. This module can be loaded with scripts to increase its effectiveness in certain areas. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,2,14828.0000,0,NULL,0),(32418,314,'Boundless Creations Security Codes','Boundless Creations Security Codes.',1,1,0,1,NULL,0.0000,1,NULL,0),(32419,226,'Caldari Charon Freighter','As the makers of the Charon, the Caldari State are generally credited with pioneering the freighter class. \r\r\nRecognizing the need for a massive transport vehicle as deep space installations constantly increase in number, \r\r\nthey set about making the ultimate in efficient mass transport - and were soon followed by the other empires. \r\r\nRegardless, the Charon still stands out as the benchmark by which the other freighters were measured. \r\r\nIts massive size and titanic cargo hold are rivalled by none.',11150000,190000,0,1,1,0.0000,0,NULL,0),(32420,226,'Fortified Orca','The Orca was developed as a joint venture between Outer Ring Excavations and Deep Core Mining Inc as a vessel to help meet the demands of New Eden\'s industry and provide a flexible platform from which mining operations can be more easily managed. The Orca uses much of the technology developed by ORE for the Rorqual and integrated with the latest advancements from Deep Core Mining research division has developed a vessel which offers a diverse role to all sizes of operations and needs.',0,0,0,1,4,0.0000,0,NULL,0),(32421,226,'Fortified Hulk','The Hulk is the largest craft in the second generation of mining vessels created by the ORE Syndicate. Exhumers, like their mining barge cousins, are equipped with electronic subsystems specifically designed to accommodate Strip Mining modules. They are also far more resilient, better able to handle the dangers of deep space. The Hulk is, bar none, the most efficient mining vessel available. ',11500000,195000,0,1,4,0.0000,0,NULL,0),(32422,1016,'Advanced Logistics Network','This upgrade allows alliances to anchor Jump Bridges at their starbases in a solar system.',1000,200000,0,1,NULL,150000000.0000,1,1282,0),(32423,226,'Caldari Kestrel Frigate','The Kestrel is a heavy missile boat with a fairly large cargo space and one of the most sophisticated sensor arrays around. Interestingly enough, it has been used by both the Caldari Navy and several wealthy trade corporations as a cargo-hauling vessel. It is one of few trading vessels with good punching power, making it ideal for solo trade-runs in dangerous areas. The Kestrel was designed so that it could take up to four missile launchers but instead it can not be equipped with turret weapons nor mining lasers.',1700000,19700,305,1,1,0.0000,0,NULL,0),(32435,256,'Citadel Cruise Missiles','Skill at the handling and firing of Citadel Cruise Missiles. 5% bonus to Citadel Cruise Missile damage per skill level. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,15000000.0000,1,373,0),(32436,1019,'Scourge Citadel Cruise Missile','Citadel Cruise Missiles are designed for long range bombardment of capital ships and installations. They are a specialized design usable only by capital ships.\r\r\n\r\r\nFitted with a graviton pulse generator, this weapon causes massive damage as it overwhelms ships\' internal structures, tearing bulkheads and armor plating apart with frightening ease.',1500,0.3,0,100,NULL,627336.0000,1,1287,0),(32437,166,'Scourge Citadel Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,80000000.0000,1,1286,0),(32438,1019,'Nova Citadel Cruise Missile','Citadel Cruise Missiles are designed for long range bombardment of capital ships and installations. They are a specialized design usable only by capital ships.\r\r\n\r\r\nNocxium atoms captured in morphite matrices form this missile\'s devastating payload. A volley of these is able to completely obliterate almost everything that floats in space, be it vehicle or structure.',1500,0.3,0,100,NULL,415674.0000,1,1287,0),(32439,166,'Nova Citadel Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,70000000.0000,1,1286,0),(32440,1019,'Inferno Citadel Cruise Missile','Citadel Cruise Missiles are designed for long range bombardment of capital ships and installations. They are a specialized design usable only by capital ships.\r\r\n\r\r\nPlasma suspended in an electromagnetic field gives this missile the ability to deliver a flaming inferno of destruction, wreaking almost unimaginable havoc.',1500,0.3,0,100,NULL,383274.0000,1,1287,0),(32441,166,'Inferno Citadel Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,90000000.0000,1,1286,0),(32442,1019,'Mjolnir Citadel Cruise Missile','Citadel Cruise Missiles are designed for long range bombardment of capital ships and installations. They are a specialized design usable only by capital ships.\r\r\n\r\r\nNothing more than a baby nuclear warhead, this guided missile wreaks havoc with the delicate electronic systems aboard a starship. Specifically designed to damage shield systems, it is able to ravage heavily shielded targets in no time.',1500,0.3,0,100,NULL,656504.0000,1,1287,0),(32443,166,'Mjolnir Citadel Cruise Missile Blueprint',' ',1,0.01,0,1,NULL,100000000.0000,1,1286,0),(32444,524,'Citadel Cruise Launcher I','The size of a small cruiser, this massive launcher is designed for extended sieges of stationary installations and other large targets.\r\r\nNote: May only be fitted to capital class ships.',0,4000,4.5,1,NULL,65222582.0000,1,777,0),(32445,136,'Citadel Cruise Launcher I Blueprint',' ',0,0.01,0,1,NULL,54371388.0000,1,340,0),(32446,927,'Hostile Hulk','The Hulk is the largest craft in the second generation of mining vessels created by the ORE Syndicate. Exhumers, like their mining barge cousins, are equipped with electronic subsystems specifically designed to accommodate Strip Mining modules. They are also far more resilient, better able to handle the dangers of deep space. The Hulk is, bar none, the most efficient mining vessel available.',40000000,200000,8000,1,8,0.0000,0,NULL,0),(32447,927,'Civilian Hulk','The Hulk is the largest craft in the second generation of mining vessels created by the ORE Syndicate. Exhumers, like their mining barge cousins, are equipped with electronic subsystems specifically designed to accommodate Strip Mining modules. They are also far more resilient, better able to handle the dangers of deep space. The Hulk is, bar none, the most efficient mining vessel available.',40000000,200000,8000,1,8,0.0000,0,NULL,0),(32448,875,'Hostile Orca','The Orca was developed as a joint venture between Outer Ring Excavations and Deep Core Mining Inc as a vessel to help meet the demands of New Eden\'s industry and provide a flexible platform from which mining operations can be more easily managed. The Orca uses much of the technology developed by ORE for the Rorqual and integrated with the latest advancements from Deep Core Mining research division has developed a vessel which offers a diverse role to all sizes of operations and needs.',250000000,10250000,30000,1,1,0.0000,0,NULL,0),(32449,875,'Civilian Orca','The Orca was developed as a joint venture between Outer Ring Excavations and Deep Core Mining Inc as a vessel to help meet the demands of New Eden\'s industry and provide a flexible platform from which mining operations can be more easily managed. The Orca uses much of the technology developed by ORE for the Rorqual and integrated with the latest advancements from Deep Core Mining research division has developed a vessel which offers a diverse role to all sizes of operations and needs.',250000000,10250000,30000,1,1,0.0000,0,NULL,0),(32455,927,'Ishukone Hauler','Industrials are a common sight in the universe of EVE, connecting supply points to each other. Convoys usually have armed escorts, so attacking them is risky.',13500000,270000,5250,1,1,0.0000,0,NULL,0),(32456,701,'Mordus Escort','Contracted for security purposes, Mordu\'s Legion sent this escort in order to protect the interests of Ishukone in the Intaki system. This ship is on sentry duty. Though it has orders to allow traffic through the system, it will fight back if provoked.',9600000,96000,450,1,1,0.0000,0,NULL,0),(32457,1006,'Ishukone Escort','Ishukone has sent part of its internal security force to protect the corporation\'s interests in the Intaki system. The megacorporation purchased the system during Tibus Heth\'s blind auction.',10100000,101000,235,1,1,0.0000,0,NULL,0),(32458,1012,'Infrastructure Hub','An Infrastructure Hub is the cornerstone of any empire s expansion into nullsec territory.\r\r\n\r\r\nOnce online, it allows the owner to cultivate the system it is placed in by applying one of the upgrades available. These upgrades range from simple improvements to a system s financial infrastructure, to defensive upgrades giving the system owner significant advantages.\r\r\n\r\r\nAs an added bonus, the Infrastructure Hub functions as a defensive structure as well, as sovereignty cannot be taken while it is still online.',1000000,60000,10000,1,4,500000000.0000,1,1275,0),(32459,52,'Civilian Warp Disruptor','Warp Disruptors are used to disrupt a target ship\'s navigation computer, which prevents it from warping.<br><br>These specially-designed Civilian variants are not strong enough to be used in live combat and are sufficient for instructional purposes only. ',0,5,0,1,NULL,786.0000,1,1935,0),(32461,509,'Civilian Light Missile Launcher','Favored by many for its average capacity and firing rate. Useful in both fast attack raids and longer battles.\r\r\n',0,5,0.6,1,NULL,6000.0000,1,NULL,0),(32463,384,'Civilian Scourge Light Missile','From its humble beginnings in tiny Minmatar design labs, the Scourge light missile has quickly established itself throughout the star cluster as a premier missile for light launchers.\r\r\n',700,0.015,0,100,NULL,500.0000,1,NULL,0),(32465,100,'Civilian Hobgoblin','Light Scout Drone',3000,5,0,1,8,2500.0000,1,NULL,0),(32467,41,'Civilian Small Remote Shield Booster','Transfers shield power over to the target ship, aiding in its defense.',0,5,0,1,NULL,4996.0000,1,NULL,0),(32469,325,'Civilian Small Remote Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the Target ship.',20,5,0,1,NULL,4996.0000,1,NULL,0),(32471,286,'Damaged Vessel','This luxury space liner appears to have suffered heavy damage in an earlier firefight. Although still intact, it will need some repairs before the Warp Drive becomes functional again.',13075000,115000,3200,1,8,0.0000,0,NULL,0),(32571,935,'TempPublish_01','This worldspace is used as an artist sandbox to test new Incarna assets.',0,0,0,1,NULL,0.0000,0,NULL,0),(32574,935,'Amarr Establishment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32575,935,'Caldari Establishment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32576,935,'Gallente Establishment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32577,935,'Minmatar Establishment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32578,935,'Amarr Captains Quarters',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32579,935,'Gallente Captains Quarters',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32580,935,'Minmatar Captains Quarters',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32581,935,'Caldari Captains Quarters',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32614,1105,'C_Blue_Long_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32615,1107,'Test Steam',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32617,940,'Universal Agent Finder',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32618,1108,'Animated Loaded Lights',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32619,940,'Gallente Sofa',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32620,940,'Gallente Corporation Recruitment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32621,940,'Gallente Planetary Interaction',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32622,940,'Gallente Main Screen',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32623,1107,'Falling Vapor',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32624,1107,'Soft Myst',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32627,940,'Gallente Character Recustomization',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32628,1107,'Pressure Steam',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32630,940,'Universal Undock Button',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32633,1111,'Default Box Light',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32634,1110,'Default Point Light',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(32635,1112,'Default Spot Light',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32636,1107,'Right_Balcony_Mist_01_Min',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32637,1107,'Left_Balcony_Mist_01_Min',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32638,1107,'Large_Atmo_Cloud_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32640,940,'Amarr Ship Interface',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32641,940,'Gallente Ship Interface',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32642,1105,'S_Orange_Round_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32643,935,'swarren',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(32644,1107,'PressureSteam02',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32646,1105,'Simple Flare Long 01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32650,940,'Minmatar Character Recustomization',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32652,1079,'Dummy Ship Lookat Object',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32653,1079,'Station Logo',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32654,940,'Caldari Character Recustomization',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32658,1105,'C_Orange_Long_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32665,940,'Universal Station Door Button',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32666,1107,'Left_Walkway_Steam_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32667,1107,'Right_Walkway_Steam_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32669,1105,'S_Orange_Long_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32670,1105,'Simple Flare 03',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32673,1105,'S_Orange_Oval_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32674,1105,'S_Orange_Oval_H_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32675,1105,'C_Blue_long_ns_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32678,1105,'S_Orange_Small_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32679,1107,'Pod_Smoke_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32680,1105,'S_Orange_Small_H_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32681,1105,'S_Orange_Fixed_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32682,1121,'Ship Perception Point',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32683,1105,'C_Blue_Long_02',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32684,940,'Minmatar Balcony Ship Interface',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32685,1105,'C_Orange_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32686,1105,'C_Blue_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32687,1105,'S_Blue_Fixed_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32688,1105,'S_Blue_Fixed_Chack',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32689,1105,'S_Blue_Fixed_Large',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32690,1105,'S_Blue_Oval_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32691,1105,'S_Blue_Small_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32692,1105,'S_Blue_VStretch_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32693,1105,'S_Blue_Oval_02',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32694,1105,'S_Blue_Oval_03',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32695,1105,'C_Blue_Long_03',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32696,1105,'C_Blue_Long_04',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32697,940,'Caldari Balcony Ship Interface',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32701,1105,'S_Green_Oval_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32702,1105,'S_Green_Small_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32703,1105,'S_Green_Fixed_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32704,1105,'C_Green_Long_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32705,1105,'S_Yellow_Fixed_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32706,1105,'S_Yellow_Oval_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32707,1105,'S_Yellow_Small_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32708,1105,'C_Green_Long_02',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32709,1105,'C_Yellow_long_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32710,1105,'S_Yellow_Fixed_H_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32711,940,'Amarr Character Recustomization',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32712,940,'Amarr Sofa',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32713,940,'Amarr Corporation Recruitment',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32714,940,'Amarr Main Screen',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32715,940,'Amarr Planetary Interaction',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32716,940,'Amarr Balcony Ship Interface',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32717,940,'Gallente Balcony Ship Interface',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32719,1105,'S_Yellow_Large_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32720,1105,'S_Yellow_Fixed_V_02',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32721,1105,'C_Green_Long_03',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32722,1105,'S_Yellow_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32723,1105,'S_Pale_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32724,1105,'S_Green_01',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32725,1107,'Vapor',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32727,1107,'Noise',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32728,1107,'Collision',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32729,1107,'Sparks',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32730,1107,'Smoke_Atlas',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32731,1126,'Default Physical Portal',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32734,1107,'Left_Walkway_Steam_02',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32735,1107,'Left_Walkway_Steam_03',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32736,1107,'Right_Walkway_Steam_02',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32737,1107,'Right_Walkway_Steam_03',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32738,1108,'Caldari Hangar Blink',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32739,940,'Caldari Undock Button',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32740,940,'Minmatar Undock Button',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32741,940,'Gallente Undock Button',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32742,940,'Amarr Undock Button',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32746,935,'WreckPrototyping',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32748,935,'resource harvesting and combat prototype',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32751,935,'wrecktest',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32752,935,'pipeline testing',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(32772,1156,'Medium Ancillary Shield Booster','Provides a quick boost in shield strength. The module takes Cap Booster charges and will start consuming the ship\'s capacitor upon the charges running out. Deactivating the module while it has no cap boosters loaded starts reloading, if there are cap boosters available in cargo hold.\r\r\n\r\r\nNote: Can use Cap Booster 50, 75 and 100 as fuel. Reloading time is 60 seconds. Prototype Inferno Module.\r\r\n',0,10,14,1,NULL,40472.0000,1,610,0),(32773,1157,'Medium Ancillary Shield Booster Blueprint',' ',0,0.01,0,1,NULL,1458560.0000,1,1552,0),(32774,1156,'Small Ancillary Shield Booster','Provides a quick boost in shield strength. The module takes Cap Booster charges and will start consuming the ship\'s capacitor upon the charges running out. Deactivating the module while it has no cap boosters loaded starts reloading, if there are cap boosters available in cargo hold.\r\r\n\r\r\nNote: Can use Cap Booster 25 as fuel. Reloading time is 60 seconds. Prototype Inferno Module.\r\r\n',0,5,7,1,NULL,10118.0000,1,609,0),(32775,1157,'Small Ancillary Shield Booster Blueprint',' ',0,0.01,0,1,NULL,1458560.0000,1,1552,0),(32780,1156,'X-Large Ancillary Shield Booster','Provides a quick boost in shield strength. The module takes Cap Booster charges and will start consuming the ship\'s capacitor upon the charges running out. Deactivating the module while it has no cap boosters loaded starts reloading, if there are cap boosters available in cargo hold.\r\r\n\r\r\nNote: Can use Cap Booster 400 and 800 as fuel. Reloading time is 60 seconds. Prototype Inferno Module.\r\r\n\r\r\n\r\r\n',0,50,112,1,NULL,883072.0000,1,612,0),(32781,1157,'X-Large Ancillary Shield Booster Blueprint',' ',0,0.01,0,1,NULL,1458560.0000,1,1552,0),(32782,88,'Light Defender Missile I','Defensive missile used to destroy incoming missiles.\r\r\n\r\r\nNote: This missile fits into light missile launchers.',700,0.015,0,100,NULL,352.0000,1,116,0),(32783,170,'Light Defender Missile I Blueprint',' ',0,0.01,0,1,NULL,120000.0000,1,316,0),(32784,924,'Karsten Lundham\'s Typhoon','Karsten Lundham is a microbiologist working for the Sebiestor Tribe. Currently in his fifties, he worked in the field of immunology for ten years before deciding to dedicate the rest of his life to the search for a cure to vitoxin.\r\r\n',19000000,19000000,120,1,2,0.0000,0,NULL,0),(32785,1006,'Rohan Shadrak\'s Scythe','Rohan Shadrak is a Vherokior Shaman of somewhat eccentric repute - he was once described by Isardsund Urbrald, CEO of Vherokior tribe to be \"Mad as a biscuit\". A staunch traditionalist, he is a vocal - and occasionally physical - opponent of CONCORD laws against drug transportation.\r\r\n',9900000,99000,1900,1,2,0.0000,0,NULL,0),(32786,1007,'Patrikia Noirild\'s Reaper','Patrikia Noirild is a Professor of Evolutionary Genetics at Republic University. Regarded as one of the foremost minds in her field, her early achievements include pioneering a revolutionary gene therapy for Toluuk\'s Syndrome - a genetic disorder that causes excess bone growth in Brutor descended from slaves bred to work on high-gravity worlds. For the last two years, however, she has worked in the field of anti-vitoxin research.',2112000,21120,100,1,2,0.0000,0,NULL,0),(32787,1159,'Salvage Drone I','Once launched and given the order to salvage, this drone will automatically seek out your wrecks in the vicinity, salvage from them any useable materials and deposit those materials in your ship\'s cargohold. It will not, however, loot any valuables contained within the wrecks.\r\r\n<br>\r\r\nA salvage drone respects wreck ownership and will focus on its operator\'s wrecks unless explicitly ordered otherwise. Whether or not its operator chooses to display that same respect is another question entirely.',0,5,0,1,NULL,84432.0000,1,1646,0),(32788,324,'Cambion','The Cambion is the result of Caldari State Executor Tibus Heth\'s insistence that modern weapons of war be able to continually outperform previous standardized versions. While that effort is rumored to have been hit-and-miss (resulting in great scientific advances at the cost of a stunning array of misfortunes), it is absolutely undeniable that the Cambion has been one of its great successes, a feat that likely could not have been achieved in a different political milieu. \r\r\n\r\r\nThe Cambion is an out-and-out brawler. Taking note from the Merlin   a versatile combat frigate in its own right   this ship is intended to rush in, overheat everything it runs, hit hard with everything it has and get out moments before death can find it.',997000,16500,150,1,1,334766.0000,1,1623,0),(32789,105,'Cambion Blueprint',' ',0,0.01,0,1,NULL,2850000.0000,1,NULL,0),(32790,832,'Etana','The Etana came into existence as one of numerous secret projects under Tibus Heth\'s rule. As part of those revolutionary and paranoid times in the Caldari State, political emphasis on technological research was split between a need for inexpensive improvements in warfare and a need for advances in espionage and the arts of secrecy. \r\r\n\r\r\nOne of the outcomes of that research was an improvement on the Osprey, whose versatility and low manufacturing cost made it a natural candidate for improvements. The resulting vessel maintained the shield defenses known among similar ships of its type, while adding an array of remarkable black ops capabilities. In fact, it is reputed that initial prototypes were employed to spy on interstellar activities near the recaptured Caldari Prime, as part of Tibus Heth\'s continually growing espionage initiative.\r\r\n\r\r\n\r\r\n',13130000,107000,485,1,1,31488206.0000,1,1624,0),(32791,106,'Etana Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(32792,943,'100 Aurum Token','This item can be redeemed for 100 Aurum (AUR).<br><br><font color=\"yellow\">To Redeem:</font> Right-click the Aurum Token and select \"Redeem for AUR\".<br><br><font color=\"yellow\">On the Aurum Token:</font> Originally designed for Noble Appliances in YC 113, the aurum token is a physical chit that can be redeemed for a predefined amount of AUR currency.<br><br>Though at first blush it appears to be a large coin, the aurum token shares more in common with high-security datacores. At the center of the token is digital ID paired with a series of suspended entangled electrons. When the token is redeemed, the entangled electrons are engaged, altering their partners located at an off-site bank. Not only does this ensure the exchange occurs instantly, but when combined with a proprietary security shell it renders attempts to tamper or counterfeit the token useless.<br><br>Though the gold and silver case is merely an aesthetic addition, the coin-like appearance has become synonymous with the device, leading to nicknames of \"gold aurum\", or \"golden token\".<br><i>Source: SCOPE fluff piece (unprinted)</i>',0,0.01,0,1,NULL,0.0000,1,1427,0),(32793,943,'500 Aurum Token','This item can be redeemed for 500 Aurum (AUR).<br><br><font color=\"yellow\">To Redeem:</font> Right-click the Aurum Token and select \"Redeem for AUR\".<br><br><font color=\"yellow\">On the Aurum Token:</font> Originally designed for Noble Appliances in YC 113, the aurum token is a physical chit that can be redeemed for a predefined amount of AUR currency.<br><br>Though at first blush it appears to be a large coin, the aurum token shares more in common with high-security datacores. At the center of the token is digital ID paired with a series of suspended entangled electrons. When the token is redeemed, the entangled electrons are engaged, altering their partners located at an off-site bank. Not only does this ensure the exchange occurs instantly, but when combined with a proprietary security shell it renders attempts to tamper or counterfeit the token useless.<br><br>Though the gold and silver case is merely an aesthetic addition, the coin-like appearance has become synonymous with the device, leading to nicknames of \"gold aurum\", or \"golden token\".<br><i>Source: SCOPE fluff piece (unprinted)</i>',0,0.01,0,1,NULL,0.0000,1,1427,0),(32797,1210,'Armor Resistance Phasing','Improves control over, and flow between, nano membranes that react to damage by shifting resistances.\r\n\r\nReduces duration time of Reactive Armor Hardeners by 10% per level and capacitor need by 10% per level.',0,0.01,0,1,NULL,500000.0000,1,1745,0),(32798,310,'Cynosural Jammer Beacon',' ',1,1,0,1,NULL,0.0000,0,NULL,0),(32799,86,'Orbital Laser S','This highly specialized space to ground ammunition can penetrate the atmosphere of planets. It is only useful against ground targets and relies on special targeting data provided by ground troops.\r\r\n\r\r\nThe laser strike deals high damage in a tight radius at high speed. The tactical laser is devastating but its precise nature means it does not cover wide areas. ',1,1,0,1,NULL,34126.0000,1,1599,0),(32800,168,'Tactical Laser S Blueprint',' ',0,0.01,0,1,NULL,12500.0000,1,1602,0),(32801,83,'Orbital EMP S','This highly specialized space to ground ammunition can penetrate the atmosphere of planets. It is only useful against ground targets and relies on special targeting data provided by ground troops.\r\r\n\r\r\nThe Electro Magnetic strike has the broadest radius of all small orbital strikes and wipes out the shields of anything unfortunate enough to come in to contact with it. For a team fitted primarily with armor this can provide a significant combat advantage in the heat of battle.',0.01,0.0025,0,100,NULL,33824.0000,1,1598,0),(32802,165,'Tactical EMP S Blueprint',' ',0,0.01,0,1,NULL,100000.0000,1,1603,0),(32803,85,'Orbital Hybrid S','This highly specialized space to ground ammunition can penetrate the atmosphere of planets. It is only useful against ground targets and relies on special targeting data provided by ground troops.\r\r\n\r\r\nThe Hybrid strike has a radius double that of the tactical laser. This enables it to bombard more ground but combined with a slower fire interval than the laser there is a greater chance for targets to escape. ',0.01,0.0025,0,100,NULL,33292.0000,1,1600,0),(32804,167,'Tactical Hybrid S Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,1601,0),(32809,98,'Ammatar Navy Thermic Plating','Attempts to distribute thermal energy over the entire plating. Grants a bonus to thermal resistance. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,5508.0000,1,1665,0),(32810,163,'Ammatar Navy Thermic Plating Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(32811,28,'Miasmos Amastris Edition','The Miasmos (originally Iteron Mark IV) Amastris Edition is a limited edition cargo hauler awarded to pilots who have displayed extraordinary aptitude in capsuleer training. \r\r\n\r\r\nIt boasts a more powerful warp engine and a bigger cargo hold capacity than the Miasmos design on which it is based, in addition to state-of-the-art lateral thrusters allowing for improved agility.\r\r\n\r\r\nAmong recent capsuleer graduates from New Eden\'s academic institutions, this vessel is considered a distinguished status symbol, although the quiet presence of certain unmarked, sealed containers at the back of the ship\'s hull tends to unnerve some of the crews.',11250000,265000,5250,1,8,789952.0000,1,1614,0),(32812,108,'Miasmos Amastris Edition Blueprint',' ',0,0.01,0,1,NULL,4287500.0000,1,NULL,0),(32817,1232,'Medium Mercoxit Mining Crystal Optimization I','This ship modification is designed to increase the yield modifier of those modules using Mercoxit mining crystals.',200,10,0,1,NULL,0.0000,1,1783,0),(32818,787,'Medium Mercoxit Mining Crystal Optimization I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1799,0),(32819,1232,'Medium Ice Harvester Accelerator I','This ship modification is designed to reduce the duration of ice harvester cycles.',200,10,0,1,NULL,0.0000,1,1783,0),(32820,787,'Medium Ice Harvester Accelerator I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1799,0),(32821,428,'Unrefined Vanadium Hafnite','A stable binary compound composed of vanadium and hafnium. Performs a variety of catalytic functions, and is an important intermediate for more complex construction processes.',0,1,0,1,NULL,320.0000,1,500,0),(32822,428,'Unrefined Platinum Technite','An intensely resilient alloy composed of platinum and technetium. Highly sought-after in the machinery and armament industries.',0,1,0,1,NULL,80.0000,1,500,0),(32823,428,'Unrefined Solerium','When chromium and caesium are combined with raw silicates in the proper proportions, Solerium is created. Since its initial discovery, Solerium\'s uniquely shifting dark-to-bright red hue has prompted poet and musician alike to create hymns in praise of its uniquely shifting deep red hue.',0,1,0,1,NULL,120.0000,1,500,0),(32824,428,'Unrefined Caesarium Cadmide','A dark-golden hued alloy composed of cadmium and caesium. Often confused with tritanium due to its tint. An essential ingredient in various composites and condensates.',0,1,0,1,NULL,80.0000,1,500,0),(32825,428,'Unrefined Hexite','A chemical compound, formed through electrosporadic oxidization of chromium and platinum. Has a wide range of applications in the production of advanced technology and is highly sought-after by industrial manufacturers.',0,1,0,1,NULL,120.0000,1,500,0),(32826,428,'Unrefined Rolled Tungsten Alloy','An extremely strong compound, made from tungsten rolled in a sheath of platinum. A crucial component in the creation of carbides which have a wide field of utility in the manufacture of various equipment.',0,1,0,1,NULL,40.0000,1,500,0),(32827,428,'Unrefined Titanium Chromide','Titanium Chromide is in high demand among technicians and manufacturers for its unique combination of strength, light weight and catalytic potential.',0,1,0,1,NULL,40.0000,1,500,0),(32828,428,'Unrefined Fernite Alloy','An intensely durable and extremely versatile alloy, Fernite, when combined with certain other materials, is a crucial stepping stone in the creation of a whole host of advanced technologies.',0,1,0,1,NULL,40.0000,1,500,0),(32829,428,'Unrefined Crystallite Alloy','A polynuclear heterometallic compound created from cobalt and cadmium. Crystallite alloys are a fundamental building block in the creation of crystalline composites.',0,1,0,1,NULL,40.0000,1,500,0),(32830,436,'Unrefined Vanadium Hafnite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(32831,436,'Unrefined Platinum Technite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(32832,436,'Unrefined Solerium Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(32833,436,'Unrefined Caesarium Cadmide Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(32834,436,'Unrefined Hexite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(32835,436,'Unrefined Rolled Tungsten Alloy Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(32836,436,'Unrefined Titanium Chromide Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(32837,436,'Unrefined Fernite Alloy Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(32838,436,'Unrefined Crystallite Alloy Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(32839,1160,'Quest Survey Probe I Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,1521,0),(32840,420,'InterBus Catalyst','Ideally suited for both skirmish warfare and fleet support, the Catalyst is touted as one of the best anti-frigate platforms out there. Faced with its top-of-the-line tracking equipment, not many can argue.\r\r\n\r\r\nOstensibly a civilian transport corporation, InterBus claims it possesses no military capabilities. Despite this, small numbers of Catalyst hulls bearing the corporation\'s distinctive yellow color scheme continue to circulate among capsuleers. InterBus has thus far declined to make any comment on their provenance, which if anything has raised their value among collectors.',1550000,55000,450,1,8,2.0000,0,NULL,0),(32841,487,'InterBus Catalyst Blueprint',' ',0,0.01,0,1,NULL,7887800.0000,1,NULL,0),(32842,420,'Intaki Syndicate Catalyst','Ideally suited for both skirmish warfare and fleet support, the Catalyst is touted as one of the best anti-frigate platforms out there. Faced with its top-of-the-line tracking equipment, not many can argue.\r\r\n\r\r\nThe Intaki Syndicate fields large numbers of Catalysts as deep-space patrol craft. Its heavy armament lets it punch well above their weight, and its expansive cargo bay allows it to cruise for months between supply stops. Recently though, the Syndicate has retired a considerable number of its older hulls, with rumors suggesting their imminent replacement by a newer destroyer design. Regardless, their extensive military service gives them particular cachet among capsuleer collectors.',1550000,55000,450,1,8,2.0000,0,NULL,0),(32843,487,'Intaki Syndicate Catalyst Blueprint',' ',0,0.01,0,1,NULL,7887800.0000,1,NULL,0),(32844,420,'Inner Zone Shipping Catalyst','Ideally suited for both skirmish warfare and fleet support, the Catalyst is touted as one of the best anti-frigate platforms out there. Faced with its top-of-the-line tracking equipment, not many can argue.\r\r\n\r\r\nInner Zone Shipping\'s main claim to fame is as the Bank of Luminaire\'s preferred courier for high-value shipments. Catalysts are their preferred escort craft, combining high speed and maneuverability with an extremely heavy punch. For its highest-value runs, IZS prefers to use brand-new hulls, which are then immediately sold off after use to prevent unscrupulous elements from tracking their ID numbers. While most of these ships are repainted and sold as stock, Inner Zone has discovered a lucrative sideline in selling a few on to capsuleer collectors, who place a premium on ships with interesting histories.',1550000,55000,450,1,8,2.0000,0,NULL,0),(32845,487,'Inner Zone Shipping Catalyst Blueprint',' ',0,0.01,0,1,NULL,7887800.0000,1,NULL,0),(32846,420,'Quafe Catalyst','Ideally suited for both skirmish warfare and fleet support, the Catalyst is touted as one of the best anti-frigate platforms out there. Faced with its top-of-the-line tracking equipment, not many can argue.\r\r\n\r\r\nIn its continuing campaign to gain 100% brand awareness, Quafe is constantly looking for new ways to draw attention. One of their recent successes has been the distribution of limited-edition Quafe ships to eager capsuleers, and this Catalyst is one of their latest offerings. While functionally just a stock Catalyst, this ship\'s iridescent blue paint job and prominent Quafe logos makes it a highly sought-after collector\'s item - as well as an unmissable advert for Quafe\'s market-leading range of thirst-quenching beverages!',1550000,55000,450,1,8,2.0000,0,NULL,0),(32847,487,'Quafe Catalyst Blueprint',' ',0,0.01,0,1,NULL,7887800.0000,1,NULL,0),(32848,420,'Aliastra Catalyst','Ideally suited for both skirmish warfare and fleet support, the Catalyst is touted as one of the best anti-frigate platforms out there. Faced with its top-of-the-line tracking equipment, not many can argue.\r\r\n\r\r\nAliastra purchased a large fleet of Catalysts several years ago, to protect its inter-Empire shipping routes. Subsequent evaluations determined that the Catalyst was considerably over-gunned for many of its safer routes, so 30% of their hulls were sold off and replaced by cheaper frigates. Some of these ships have since been retro-fitted for capsuleer use, and their distinctive color scheme makes them something of a collector\'s item.',1550000,55000,450,1,8,2.0000,0,NULL,0),(32849,487,'Aliastra Catalyst Blueprint',' ',0,0.01,0,1,NULL,7887800.0000,1,NULL,0),(32853,1083,'SPZ-3 \"Torch\" Laser Sight Combat Ocular Enhancer (right/black)','The product of a collaborative effort between the State Protectorate and Zainou, the \"Torch\" is already seeing adoption in military circles, where it functions as a precision-guidance tool for a covert class of sharpshooters working either in low-light conditions or with explosive ordinance.\r\r\n\r\r\nSurprisingly, it has also seen increased adoption by other sections of the warfaring population, even cropping up among capsuleers. Superstition has already bound to it in use in orbital bombardment; there is no practical reason to believe that it actually aids in the process, but capsuleers have sworn that it helps ensure the precision-point contact necessary for successful bombardment and the ensuing explosive ignition of the correct groups of people.\r\r\n',0,0.1,0,1,NULL,0.0000,1,1408,0),(32854,1160,'Discovery Survey Probe I Blueprint',' ',0,0.01,0,1,NULL,3000000.0000,1,1521,0),(32855,1160,'Gaze Survey Probe I Blueprint',' ',0,0.01,0,1,NULL,7000000.0000,1,1521,0),(32856,255,'Tactical Strike','Skill at Tactical Strike Accuracy.\r\r\n\r\r\nAccuracy of Tactical Strike increased by 5% per level',0,0.01,0,1,NULL,20000.0000,0,NULL,0),(32858,1162,'Station Container Blueprint',' ',0,0.01,0,1,NULL,180000.0000,1,1008,0),(32859,1162,'Small Standard Container Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,1008,0),(32860,1162,'Medium Standard Container Blueprint',' ',0,0.01,0,1,NULL,120000.0000,1,1008,0),(32861,1162,'Large Standard Container Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1008,0),(32862,1162,'Giant Freight Container Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,1008,0),(32863,1162,'Giant Secure Container Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,1008,0),(32864,1162,'Huge Secure Container Blueprint',' ',0,0.01,0,1,NULL,1200000.0000,1,1008,0),(32865,1162,'Large Secure Container Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,1008,0),(32866,1162,'Medium Secure Container Blueprint',' ',0,0.01,0,1,NULL,230000.0000,1,1008,0),(32867,1162,'Small Secure Container Blueprint',' ',0,0.01,0,1,NULL,80000.0000,1,1008,0),(32868,1162,'Small Audit Log Secure Container Blueprint',' ',0,0.01,0,1,NULL,180000.0000,1,1008,0),(32869,1162,'Medium Audit Log Secure Container Blueprint',' ',0,0.01,0,1,NULL,2000000.0000,1,1008,0),(32870,1162,'Large Audit Log Secure Container Blueprint',' ',0,0.01,0,1,NULL,4000000.0000,1,1008,0),(32871,1162,'Station Vault Container Blueprint',' ',0,0.01,0,1,NULL,1800000.0000,1,1008,0),(32872,420,'Algos','The Algos, as is custom with the Gallente, relies on swiftness of action - preferably at a respectable distance - to accomplish its goals. In this it reflects well-honed Gallente values, which include taking independent action without taking forever to wait for a committee decision, and also doing so, if at all possible, in a fashion that allows for a nice, safe buffer for immediate retreat; because theory is one thing, and practice is sometimes quite another.\r\r\n\r\r\nAs such, the Algos focuses on being able to hit its targets in rapid-fire fashion, with guns that fire fast and drones that race through space with destruction in mind.',1600000,55000,350,1,8,916752.0000,1,467,0),(32873,487,'Algos Blueprint',' ',0,0.01,0,1,NULL,8242751.0000,1,585,0),(32874,420,'Dragoon','The Dragoon follows old religious tenets - ones thought rather dark by the majority of the cluster, but found perfectly normal by Amarr minds - that to exist as God\'s chosen people means fulfilling a very definite and often forceful role. This includes not only imposing the will of God, often through the time-honored methods of mindless proxies, but also profiting, even being nourished, off the energies of others.\r\r\n\r\r\nAs such, the Dragoon focuses on sending out a mass of drones, ones capable not only of swiftly hunting down their targets but also of inflicting tons of damage once contact is made. Moreover, the Dragoon is able to drain the target\'s energy in the meanwhile, all with the aim of leaving it little more than a trembling husk.',1700000,47000,300,1,4,954136.0000,1,465,0),(32875,487,'Dragoon Blueprint',' ',0,0.01,0,1,NULL,9023825.0000,1,583,0),(32876,420,'Corax','The Corax adheres to the well-established Caldari design philosophy that there is strength in numbers, and that the messages sent to an enemy should be strong and unequivocal. This applies equally to peace talks as it does to actual engagements on the battlefield - there should be no doubt in the strength of Caldari spirit, nor in the fact that when one blow has been struck, others are going to follow.\r\r\n\r\r\nAs such, the Corax does not pepper its opponents with pellets from a gun, nor does it toast them with continuous beams of light. Instead, it delivers strong, hard-hitting payloads at a pace that\'s not only steady, but rapid enough to rock its targets and knock them off-balance.',1900000,52000,450,1,1,925264.0000,1,466,0),(32877,487,'Corax Blueprint',' ',0,0.01,0,1,NULL,8795138.0000,1,584,0),(32878,420,'Talwar','The Talwar is redolent of the renowned Minmatar practicality in terms of battle. Irrespective of numbers, firepower and circumstances, their strategy when engaged in combat often revolves around the same central tenet: Stay untouchable as much as you can, either by sneaking around or rushing in, do as much damage as fast as you can, and get out before you get killed.\r\r\n\r\r\nAs such, the Talwar does not come equipped to hang around forever on the battlefield. It is built to rush around at speed without getting caught, and to hit very hard and very, very fast.',1650000,43000,400,1,2,994168.0000,1,468,0),(32879,487,'Talwar Blueprint',' ',0,0.01,0,1,NULL,7837500.0000,1,586,0),(32880,25,'Venture','Recognizing the dire need for a ship capable of fast operation in unsafe territories, ORE created the Venture. It was conceived as a vessel primed and ready for any capsuleer, no matter how new to the dangers of New Eden they might be, who wishes to engage in the respectable trade of mining.\r\r\n\r\r\nThe Venture has amazing abilities to quickly drill through to the ores and gases it\'s after, harvesting them at the speed necessary for mining in hostile space, and getting out relatively unscathed.',1200000,29500,50,1,128,260626.0000,1,1616,0),(32881,105,'Venture Blueprint',' ',0,0.01,0,1,NULL,2825000.0000,1,1617,0),(32884,1165,'District Satellite','Satellites identify the position in orbit around a planet which are used for interacting with districts on the ground.',1,1,0,1,NULL,0.0000,0,NULL,0),(32885,314,'Empire Emissary Medallion','This medal was awarded to those who aided the Amarr Empire emissaries in their mission to bring sensitive diplomatic documents, concerning the coupling of interstellar communication relays between capsuleers and other non-celestial soldiers of fortune, to CONCORD in Yulai.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(32886,314,'Republic Emissary Medallion','This medal was awarded to those who aided the Minmatar Republic emissaries in their mission to bring sensitive diplomatic documents, concerning the coupling of interstellar communication relays between capsuleers and other non-celestial soldiers of fortune, to CONCORD in Yulai.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(32887,314,'Federation Emissary Medallion','This medal was awarded to those who aided the Gallente Federation emissaries in their mission to bring sensitive diplomatic documents, concerning the coupling of interstellar communication relays between capsuleers and other non-celestial soldiers of fortune, to CONCORD in Yulai.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(32888,314,'State Emissary Medallion','This medal was awarded to those who aided the Caldari State emissaries in their mission to bring sensitive diplomatic documents, concerning the coupling of interstellar communication relays between capsuleers and other non-celestial soldiers of fortune, to CONCORD in Yulai.',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(32889,314,'Empire Diplomatic Documents','This missive is a sternly worded diplomatic request from the Amarr Empire, asking that CONCORD seriously reconsider its planned coupling of communicative technology between capsuleers and other, non-celestial soldiers of fortune.\r\r\n\r\r\nThe request is encased in protective sheathing, giving it a marginally higher chance of surviving the travails of celestial transportation than a piece of paper might usually enjoy.\r\r\n',1,1,0,1,NULL,0.0000,1,NULL,0),(32890,314,'Republic Diplomatic Documents','This missive is a sternly worded diplomatic request from the Minmatar Republic, asking that CONCORD seriously reconsider its planned coupling of communicative technology between capsuleers and other, non-celestial soldiers of fortune.\r\r\n\r\r\nThe request is encased in protective sheathing, giving it a marginally higher chance of surviving the travails of celestial transportation than a piece of paper might usually enjoy.\r\r\n',1,1,0,1,NULL,0.0000,1,NULL,0),(32891,314,'Federation Diplomatic Documents','This missive is a sternly worded diplomatic request from the Gallente Federation, asking that CONCORD seriously reconsider its planned coupling of communicative technology between capsuleers and other, non-celestial soldiers of fortune.\r\r\n\r\r\nThe request is encased in protective sheathing, giving it a marginally higher chance of surviving the travails of celestial transportation than a piece of paper might usually enjoy.\r\r\n',1,1,0,1,NULL,0.0000,1,NULL,0),(32892,314,'State Diplomatic Documents','This missive is a sternly worded diplomatic request from the Caldari State, asking that CONCORD seriously reconsider its planned coupling of communicative technology between capsuleers and other, non-celestial soldiers of fortune.\r\r\n\r\r\nThe request is encased in protective sheathing, giving it a marginally higher chance of surviving the travails of celestial transportation than a piece of paper might usually enjoy.\r\r\n',1,1,0,1,NULL,0.0000,1,NULL,0),(32894,988,'QA Wormhole A','This wormhole does not exist.',0,0,0,1,NULL,0.0000,0,NULL,0),(32895,988,'QA Wormhole B','This wormhole does not exist',0,0,0,1,NULL,0.0000,0,NULL,0),(32901,760,'Rogue Drone Carrier','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,NULL,0.0000,0,NULL,0),(32902,760,'Rogue Drone Convoy','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,NULL,0.0000,0,NULL,0),(32903,760,'Rogue Drone Trailer','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,NULL,0.0000,0,NULL,0),(32904,760,'Rogue Drone Hauler','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',19000000,19000000,120,1,NULL,0.0000,0,NULL,0),(32905,760,'Rogue Drone Bulker','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,NULL,0.0000,0,NULL,0),(32906,760,'Rogue Drone Transporter','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,NULL,0.0000,0,NULL,0),(32907,760,'Rogue Drone Trucker','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,NULL,0.0000,0,NULL,0),(32908,760,'Rogue Drone Courier','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,NULL,0.0000,0,NULL,0),(32909,760,'Rogue Drone Loader','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1645000,16450,120,1,NULL,0.0000,0,NULL,0),(32910,760,'Rogue Drone Ferrier','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: Very high',1910000,19100,80,1,NULL,0.0000,0,NULL,0),(32911,760,'Rogue Drone Gatherer','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1645000,16450,110,1,NULL,0.0000,0,NULL,0),(32912,760,'Rogue Drone Harvester','This is a fighter for the Rogue Drones. It is protecting the assets of Rogue Drones and may attack anyone it perceives as a threat or easy pickings. Threat level: High',1910000,19100,120,1,NULL,0.0000,0,NULL,0),(32913,1166,'Republic Frigate','A frigate of the Minmatar Republic.',1645000,16450,110,1,2,0.0000,0,NULL,0),(32914,1167,'State Frigate','A frigate of the Caldari State.',2025000,20250,65,1,1,0.0000,0,NULL,0),(32915,1168,'Federation Frigate','A frigate of the Gallente Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(32916,1169,'Imperial Frigate','A frigate of the Amarr Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(32918,257,'Mining Frigate','Skill at operating ORE Mining Frigates.',0,0.01,0,1,NULL,40000.0000,1,377,0),(32919,645,'Unit D-34343\'s Modified Drone Damage Amplifier','The Drone Damage Amplifier projects a multi-node quantum entanglement onto the ship\'s drone communications net, creating a bridged processor between ship and drones that allows for better real-time trajectory projections.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',1,5,0,1,NULL,41982.0000,1,938,0),(32921,645,'Unit F-435454\'s Modified Drone Damage Amplifier','The Drone Damage Amplifier projects a multi-node quantum entanglement onto the ship\'s drone communications net, creating a bridged processor between ship and drones that allows for better real-time trajectory projections.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',1,5,0,1,NULL,41982.0000,1,938,0),(32923,645,'Unit P-343554\'s Modified Drone Damage Amplifier','The Drone Damage Amplifier projects a multi-node quantum entanglement onto the ship\'s drone communications net, creating a bridged processor between ship and drones that allows for better real-time trajectory projections.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',1,5,0,1,NULL,41982.0000,1,938,0),(32925,645,'Unit W-634\'s Modified Drone Damage Amplifier','The Drone Damage Amplifier projects a multi-node quantum entanglement onto the ship\'s drone communications net, creating a bridged processor between ship and drones that allows for better real-time trajectory projections.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,41982.0000,1,938,0),(32927,647,'Unit D-34343\'s Modified Drone Link Augmentor','Increases drone control range.',200,25,0,1,NULL,213360.0000,1,938,0),(32929,647,'Unit F-435454\'s Modified Drone Link Augmentor','Increases drone control range.',200,25,0,1,NULL,213360.0000,1,938,0),(32931,647,'Unit P-343554\'s Modified Drone Link Augmentor','Increases drone control range.',200,25,0,1,NULL,213360.0000,1,938,0),(32933,647,'Unit W-634\'s Modified Drone Link Augmentor','Increases drone control range.',200,25,0,1,NULL,213360.0000,1,938,0),(32935,646,'Unit D-34343\'s Modified Omnidirectional Tracking Link','Improves the optimal range and tracking of all drones. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9792.0000,1,938,0),(32937,646,'Unit F-435454\'s Modified Omnidirectional Tracking Link','Improves the optimal range and tracking of all drones. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9792.0000,1,938,0),(32939,646,'Unit P-343554\'s Modified Omnidirectional Tracking Link','Improves the optimal range and tracking of all drones. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9792.0000,1,938,0),(32941,646,'Unit W-634\'s Modified Omnidirectional Tracking Link','Improves the optimal range and tracking of all drones. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9792.0000,1,938,0),(32943,644,'Unit D-34343\'s Modified Drone Navigation Computer','Increases mwd speed of drones.',200,25,0,1,NULL,139232.0000,1,938,0),(32945,644,'Unit F-435454\'s Modified Drone Navigation Computer','Increases mwd speed of drones.',200,25,0,1,NULL,139232.0000,1,938,0),(32947,644,'Unit P-343554\'s Modified Drone Navigation Computer','Increases mwd speed of drones.',200,25,0,1,NULL,139232.0000,1,938,0),(32949,644,'Unit W-634\'s Modified Drone Navigation Computer','Increases mwd speed of drones.',200,25,0,1,NULL,139232.0000,1,938,0),(32951,407,'Unit D-34343\'s Modified Drone Control Unit','Gives you one extra drone. You need Advanced Drone Interfacing to use this module, it gives you the ability to fit one drone control unit per level.\r\r\n\r\r\nCan only be fit to Carriers and Supercarriers.',200,800,0,1,NULL,47354196.0000,1,938,0),(32953,407,'Unit F-435454\'s Modified Drone Control Unit','Gives you one extra drone. You need Advanced Drone Interfacing to use this module, it gives you the ability to fit one drone control unit per level.\r\r\n\r\r\nCan only be fit to Carriers and Supercarriers.',200,600,0,1,NULL,47354196.0000,1,938,0),(32955,407,'Unit P-343554\'s Modified Drone Control Unit','Gives you one extra drone. You need Advanced Drone Interfacing to use this module, it gives you the ability to fit one drone control unit per level.\r\r\n\r\r\nCan only be fit to Carriers and Supercarriers.',200,400,0,1,NULL,47354196.0000,1,938,0),(32957,407,'Unit W-634\'s Modified Drone Control Unit','Gives you one extra drone. You need Advanced Drone Interfacing to use this module, it gives you the ability to fit one drone control unit per level.\r\r\n\r\r\nCan only be fit to Carriers and Supercarriers.',200,200,0,1,NULL,47354196.0000,1,938,0),(32959,1174,'Unit D-34343','This unit is violently opposed to all life, to the point where the merest hint of its existence is enough to drive its circuits into violent spasms.  Any movement, any twitch, must be silenced, as though life itself were a cacophony blasting at unbearable volume in the unit\'s admittedly quite unstable mind. Threat level: Deadly',19000000,19000000,120,1,NULL,0.0000,0,NULL,0),(32960,1174,'Unit F-435454','This unit marvels at the continued persistence of life under adverse conditions and believes it would, if circumstances were different, have devoted its time to investigating just how long, in fact, life could possibly be made to endure. Unfortunately, other parts of its rather complicated and messy circuitry delight in immediate destruction of anything that crosses its path. Threat level: Deadly',19000000,19000000,120,1,NULL,0.0000,0,NULL,0),(32961,1174,'Unit P-343554','This unit finds life a kaleidoscopic amazement of possibilities and had previously devoted its existence to its study, albeit through some very unorthodox methods. After the drone hive discovered these methods, and the writhing, blinking, gaping outcomes, Unit P-343554 found itself reassigned to celestial patrol. Threat level: Deadly',19000000,19000000,120,1,NULL,0.0000,0,NULL,0),(32962,1174,'Unit W-634','This unit finds pleasure, if it can be said that a drone experiences such a thing, not in the cessation of life but in the violent preamble. The lights and the fury enliven what is otherwise, to unit W-634, a rather monotonous existence. Threat level: Deadly',19000000,19000000,120,1,NULL,0.0000,0,NULL,0),(32963,1175,'Imperial Destroyer','A destroyer of the Amarr Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(32964,1176,'State Destroyer','A destroyer of the Caldari State.',2025000,20250,65,1,1,0.0000,0,NULL,0),(32965,1177,'Federation Destroyer','A destroyer of the Gallente Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(32966,1178,'Republic Destroyer','A destroyer of the Minmatar Republic.',1645000,16450,110,1,2,0.0000,0,NULL,0),(32967,1179,'Imperial Cruiser','A cruiser of the Amarr Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(32968,1180,'State Cruiser','A cruiser of the Caldari State.',2025000,20250,65,1,1,0.0000,0,NULL,0),(32969,1181,'Federation Cruiser','A cruiser of the Gallente Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(32970,1182,'Republic Cruiser','A cruiser of the Minmatar Republic.',1645000,16450,110,1,2,0.0000,0,NULL,0),(32971,1183,'Imperial Battlecruiser','A battlecruiser of the Amarr Empire.',2860000,28600,235,1,4,0.0000,0,NULL,0),(32972,1184,'State Battlecruiser','A battlecruiser of the Caldari State.',2025000,20250,65,1,1,0.0000,0,NULL,0),(32973,1185,'Federation Battlecruiser','A battlecruiser of the Gallente Federation.',2650000,26500,235,1,8,0.0000,0,NULL,0),(32974,1186,'Republic Battlecruiser','A battlecruiser of Minmatar Republic.',1645000,16450,110,1,2,0.0000,0,NULL,0),(32982,1190,'Salvage Drone I Blueprint',' ',0,0.01,0,1,NULL,29986000.0000,1,1643,0),(32983,25,'Sukuuvestaa Heron','The Heron has good computer and electronic systems, giving it the option of participating in electronic warfare. But it has relatively poor defenses and limited weaponry, so it\'s more commonly used for scouting and exploration.\r\r\n\r\r\nThis Heron bears the distinctive appearance of a vessel built for the Sukuuvestaa megacorporation. Known for extremely aggressive business practices, Sukuuvestaa is a powerful megacorporation with dealings in many sectors, most notably real estate and agriculture.',1150000,18900,400,1,1,2.0000,0,NULL,0),(32984,105,'Sukuuvestaa Heron Blueprint',' ',0,0.01,0,1,NULL,2750000.0000,1,NULL,0),(32985,25,'Inner Zone Shipping Imicus','The Imicus is a slow but hard-shelled frigate, ideal for any type of scouting activity. Used by merchant, miner and combat groups, the Imicus is usually relied upon as the operation\'s eyes and ears when traversing low security sectors.\r\r\n\r\r\nThis Imicus has served as a forward scout for Inner Zone Shipping\'s high value courier operations, as indicated by its distinctive corporate coloring.',997000,21500,400,1,8,2.0000,0,NULL,0),(32986,105,'Inner Zone Shipping Imicus Blueprint',' ',0,0.01,0,1,NULL,2725000.0000,1,NULL,0),(32987,25,'Sarum Magnate','This Magnate-class frigate is one of the most decoratively designed ship classes in the Amarr Empire,  considered to be a pet project for a small, elite group of royal ship engineers for over a decade. The frigate\'s design has gone through several stages over the past decade, and new models of the Magnate appear every few years. The most recent versions of this ship   the Silver Magnate and the Gold Magnate   debuted as rewards in the Amarr Championships in YC105, though the original Magnate design is still a popular choice among Amarr pilots. \r\r\n\r\r\nThis Magnate is emblazoned with the coloring and insignia of the Sarum royal family. A visible beacon of Amarrian superiority, it was built to serve as a vanguard of the next great Reclaiming.',1072000,22100,400,1,4,125752.0000,0,NULL,0),(32988,105,'Sarum Magnate Blueprint',' ',0,0.01,0,1,NULL,2775000.0000,1,NULL,0),(32989,25,'Vherokior Probe','The Probe is large compared to most Minmatar frigates and is considered a good scout and cargo-runner.  Uncharacteristically for a Minmatar ship, its hard outer coating makes it difficult to destroy, while the limited weapon hardpoints force it to rely on fighter assistance if engaged in combat.\r\r\n\r\r\nThis Probe was commissioned by the Vherokior tribal leadership and bears their colors and insignia. The Vherokior have less political influence than many other tribes, but have become an integral part of both the public and private sectors of the Republic economy.',1123000,19500,400,1,2,2.0000,0,NULL,0),(32990,105,'Vherokior Probe Blueprint',' ',0,0.01,0,1,NULL,2700000.0000,1,NULL,0),(32993,500,'Sodium Firework CXIV',' ',100,0.1,0,100,NULL,0.0000,1,1663,0),(32994,500,'Barium Firework CXIV',' ',100,0.1,0,100,NULL,0.0000,1,1663,0),(32995,500,'Copper Firework CXIV',' ',100,0.1,0,100,NULL,0.0000,1,1663,0),(32999,1213,'Magnetometric Sensor Compensation','Skill at hardening Magnetometric Sensors against hostile Electronic Counter Measure modules. 4% improved Magnetometric Sensor Strength per skill level.\r\r\n\r\r\nMagnetometric Sensors are primarily found on Gallente, Serpentis, ORE, and Sisters of EVE ships.',0,0.01,0,1,NULL,200000.0000,1,1748,0),(33000,1213,'Gravimetric Sensor Compensation','Skill at hardening Gravimetric Sensors against hostile Electronic Counter Measure modules. 4% improved Gravimetric Sensor Strength per skill level.\r\r\n\r\r\nGravimetric Sensors are primarily found on Caldari, Guristas and Mordu\'s Legion ships.',0,0.01,0,1,NULL,200000.0000,1,1748,0),(33001,1213,'Ladar Sensor Compensation','Skill at hardening Ladar Sensors against hostile Electronic Counter Measure modules. 4% improved Ladar Sensor Strength per skill level.\r\r\n\r\r\nLadar Sensors are primarily found on Minmatar and Angel ships.',0,0.01,0,1,NULL,200000.0000,1,1748,0),(33002,1213,'Radar Sensor Compensation','Skill at hardening Radar Sensors against hostile Electronic Counter Measure modules. 4% improved Radar Sensor Strength per skill level.\r\r\n\r\r\nRadar Sensors are primarily found on Amarr, Blood Raider and Sanshas ships.',0,0.01,0,1,NULL,200000.0000,1,1748,0),(33003,649,'Enormous Freight Container','A massive cargo container, used for inter-regional freight; most commonly used in freighter cargo bays.',1000000,250000,250000,1,NULL,110000.0000,1,1653,0),(33004,1162,'Enormous Freight Container Blueprint',' ',0,0.01,0,1,NULL,4000000.0000,1,1008,0),(33005,649,'Huge Freight Container','A massive cargo container, used for inter-regional freight; most commonly used in freighter cargo bays.',1000000,50000,50000,1,NULL,110000.0000,1,1653,0),(33006,1162,'Huge Freight Container Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,1008,0),(33007,649,'Large Freight Container','A massive cargo container, used for inter-regional freight; most commonly used in freighter cargo bays.',1000000,10000,10000,1,NULL,110000.0000,1,1653,0),(33008,1162,'Large Freight Container Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,1008,0),(33009,649,'Medium Freight Container','A massive cargo container, used for inter-regional freight; most commonly used in freighter cargo bays.',1000000,5000,5000,1,NULL,110000.0000,1,1653,0),(33010,1162,'Medium Freight Container Blueprint',' ',0,0.01,0,1,NULL,250000.0000,1,1008,0),(33011,649,'Small Freight Container','A massive cargo container, used for inter-regional freight; most commonly used in freighter cargo bays.',1000000,1000,1000,1,NULL,110000.0000,1,1653,0),(33012,1162,'Small Freight Container Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1008,0),(33014,227,'Amarr Prime Station Cloud',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(33015,1194,'The Mini Monolith','Refines into: A handful of tiny stars.',50000,500,0,1,NULL,0.0000,1,1661,0),(33016,1194,'A Handful of Tiny Stars','Good thing you can\'t actually refine stars or this would just keep going for far too long.',50,10,0,1,NULL,0.0000,1,1661,0),(33017,1194,'Deactivated Station Key Pass','At the end of YC114, station managers across New Eden were surprised and shocked by the accidental delivery of station key passes to large numbers of pilots due to an inventory error in the InterBus central database. With recall next to impossible, the recommendation of veteran station manager Scotty, now consulting with the SCC, was to simply send out a general deactivation order and replace the master key passes used by station staff. The mistakenly delivered passes are now nothing more than souvenirs of an odd but ultimately harmless incident.',0.01,0.01,0,1,NULL,455036.2500,1,1661,0),(33018,1194,'Ship Fitting Guide','My Raven was equipped with the following:\r\r\n\r\r\nHIGH\r\r\n06 x Cruise Missile Launcher I\r\r\n01 x SMALL TRACTOR BEAM 1\r\r\n01 x SALVAGER I\r\r\n\r\r\nMEDIUM\r\r\n04 x LARGE SHIELD EXTENDERS\r\r\n01 x \'HYPHNOS\' ECM\r\r\n01 x MEDIUM SHIELD BOOSTER\r\r\n\r\r\nLOW\r\r\n01 x EMERGENCY DAMAGE CONTROL\r\r\n01 x ARMOR KINETIC HARDENER I\r\r\n01 x ARMOR THREMIC HARDENER I\r\r\n02 x WARP CORE STABILIZER I \r\r\n\r\r\nDRONES\r\r\n02 x WARRIOR I DRONES\r\r\n03 x HAMMERHEAD I DRONES\r\r\n\r\r\nUPGRADES\r\r\n01 x ROCKET FUEL CACHE PARTINTION I\r\r\n01 x BAY LOADING ACCELERATOR I',0.01,0.01,0,1,NULL,0.0000,1,1661,0),(33019,1194,'Scotty the Docking Manager\'s Clone','How did you think he ran all those stations?',90,0.01,0,1,NULL,0.0000,1,1661,0),(33020,1194,'A Big Red Button','This button apparently restarts a central mainframe somewhere. An attached note indicates that it is not the personal computing device of someone apparently known by the callsign \"Tuxford\", though who this individual is remains a mystery.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33021,1194,'Unit of Lag','Made of an unusually dense piece of material. Time seems to slow down around it.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33022,1194,'Postcard From Poitot','Interesting fact: <url=showinfo:5//30003271>Poitot</url> is the only named system in the <url=showinfo:3//10000041>Syndicate</url> region.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33023,1194,'A Tank of Honor','An expanded glass tank filled with a substance that, scientific classification aside, looks and feels genuinely like honor.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33024,1194,'Animal Medical Expert','Tastes rather sour.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33025,1194,'Military Experts and You','From its first publication date, this magazine has seen very successful sale rates in the Gallente Federation. It explains many war theories using detailed pictures, with no less than one third of its contents dedicated to how to best spot a Cynosural Field.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33026,1194,'Rules of Engagement','Every time someone reads this book it seems to get bigger and bigger.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33027,1194,'Little Helper, Female','These are renowned for a unique style of exotic dancing. Slavers descended on their home world of Hothomouh X and they are now considered an endangered race.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33028,1194,'Little Helper, Male','These are renowned for a unique style of exotic dancing. Slavers descended on their home world of Hothomouh X and they are now considered an endangered race.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33029,1194,'Replica Gallente Cruiser','A detailed, handheld miniature of the famously well-known <url=showinfo:627>Thorax</url> Cruiser, this is a well reputed and high quality collector\'s item. It has settings to emit a low humming sound or glow in the dark if needed.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33030,1194,'Model of a Fighter','That\'s a <url=showinfo:23055>Templar</url>, the Amarr fighter. It\'s a combat drone used by carriers.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33031,1195,'NEO YC 114: Team Ineluctable','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Team Ineluctable\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> <url=showinfo:1386//91739168>Jim Rogers Dutch</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//1795255388>AndreWanJinn</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//90928810>Alena Mythic</url>\r\r\n<url=showinfo:1377//1390781515>ant1212</url>\r\r\n<url=showinfo:1377//580525770>calladus</url>\r\r\n<url=showinfo:1377//846417692>Chou Saru</url>\r\r\n<url=showinfo:1377//924016925>DaBouncer</url>\r\r\n<url=showinfo:1377//844630404>Darth Greg</url>\r\r\n<url=showinfo:1377//1011293040>jamesoverlord</url>\r\r\n<url=showinfo:1377//1374215855>Jason Triumph</url>\r\r\n<url=showinfo:1377//1930644029>JD No7</url>\r\r\n<url=showinfo:1377//91447040>Jezus vanOstade</url>\r\r\n<url=showinfo:1377//91739168>Jim Rogers Dutch</url>\r\r\n<url=showinfo:1377//1474065142>Nehebkau Fetkoz</url>\r\r\n<url=showinfo:1377//92226944>NULL</url>\r\r\n<url=showinfo:1377//681869059>overlordknight</url>\r\r\n<url=showinfo:1377//1740259095>PACO TIME</url>\r\r\n<url=showinfo:1377//1739026934>reaper2479</url>\r\r\n<url=showinfo:1377//1843928089>Skrunkle</url>\r\r\n<url=showinfo:1377//90430233>Stampertje\'n</url>\r\r\n<url=showinfo:1377//380719545>themad boatman</url>\r\r\n<url=showinfo:1377//930671491>tsukubasteve</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33032,1195,'NEO YC 114: Raiden. 58th Squadron','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Raiden. 58th Squadron\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//727098092>Hey You</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//1085177298>aclemor</url>\r\r\n<url=showinfo:1377//973994359>Baltze</url>\r\r\n<url=showinfo:1377//889549656>Belenkas</url>\r\r\n<url=showinfo:1377//521166537>Belfalas</url>\r\r\n<url=showinfo:1377//749568087>Drift Spec</url>\r\r\n<url=showinfo:1377//1604098723>Eznaidar</url>\r\r\n<url=showinfo:1377//1355154222>iPodNani</url>\r\r\n<url=showinfo:1377//348929413>Kaisur</url>\r\r\n<url=showinfo:1377//1191007792>Kajdil</url>\r\r\n<url=showinfo:1377//871706498>Klezz</url>\r\r\n<url=showinfo:1377//982124107>LakeEnd</url>\r\r\n<url=showinfo:1377//232508341>Lee Jarrett</url>\r\r\n<url=showinfo:1377//865913547>MachZERO</url>\r\r\n<url=showinfo:1377//185951892>Moonjedi</url>\r\r\n<url=showinfo:1377//1654212636>Namof Zomgbag</url>\r\r\n<url=showinfo:1377//1355964973>Nikolay Tesla</url>\r\r\n<url=showinfo:1377//1614947314>Radianze</url>\r\r\n<url=showinfo:1377//516835064>Roland Marr</url>\r\r\n<url=showinfo:1377//930725828>sarsa</url>\r\r\n<url=showinfo:1377//176943238>ShivanNL</url>\r\r\n<url=showinfo:1377//1334571618>thoraxius demioses</url>\r\r\n<url=showinfo:1377//1827677181>Xolipha</url>\r\r\n<url=showinfo:1377//289581748>Zeekar</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33033,1195,'NEO YC 114: Last Huzzah','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Last Huzzah\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> <url=showinfo:1380//1354759515>eaglecrys</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//1348110218>Sashenka</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//843764474>Aplescin</url>\r\r\n<url=showinfo:1377//1480462847>Bdericks</url>\r\r\n<url=showinfo:1377//271504868>Chib</url>\r\r\n<url=showinfo:1377//1177281505>Crackhour</url>\r\r\n<url=showinfo:1377//1354759515>eaglecrys</url>\r\r\n<url=showinfo:1377//1073252715>Emi May</url>\r\r\n<url=showinfo:1377//90042585>Korsica Phoenix</url>\r\r\n<url=showinfo:1377//1229931486>MadMonkey</url>\r\r\n<url=showinfo:1377//358466481>Marillio</url>\r\r\n<url=showinfo:1377//924232947>Noxxey</url>\r\r\n<url=showinfo:1377//1123477665>PatrickStarEX</url>\r\r\n<url=showinfo:1377//499747810>Rogerios</url>\r\r\n<url=showinfo:1377//1521956123>Ryan\'s Revenge</url>\r\r\n<url=showinfo:1377//810805302>Shara Kantome</url>\r\r\n<url=showinfo:1377//1250923985>swervy</url>\r\r\n<url=showinfo:1377//101663101>Tana Pleiades</url>\r\r\n<url=showinfo:1377//205582049>Tiberius Funk</url>\r\r\n<url=showinfo:1377//1569842543>Trained2kill</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33034,1195,'NEO YC 114: Why Dash','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Why Dash\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> <url=showinfo:16159//386292982>Pandemic Legion</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//820303498>Elise Randolph</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//973959715>Admiral Goberius</url>\r\r\n<url=showinfo:1377//1209287917>Alekto Descendant</url>\r\r\n<url=showinfo:1377//981265915>Atara</url>\r\r\n<url=showinfo:1377//872389613>Blast x</url>\r\r\n<url=showinfo:1377//159558725>B\'reanna</url>\r\r\n<url=showinfo:1377//927756779>Coug</url>\r\r\n<url=showinfo:1377//818755119>Creyn Hawk</url>\r\r\n<url=showinfo:1377//722651537>Dancul1001</url>\r\r\n<url=showinfo:1377//1809290295>Destoya</url>\r\r\n<url=showinfo:1377//854746727>Destr0math</url>\r\r\n<url=showinfo:1377//147590286>Fantome</url>\r\r\n<url=showinfo:1377//1973381112>Hatsumi Kobayashi</url>\r\r\n<url=showinfo:1377//934833731>joefishy</url>\r\r\n<url=showinfo:1377//972020788>KadaEl</url>\r\r\n<url=showinfo:1377//977188436>LOPEZ</url>\r\r\n<url=showinfo:1377//185935021>Lucas Quaan</url>\r\r\n<url=showinfo:1377//1257326017>Revoluti0nx</url>\r\r\n<url=showinfo:1377//1642226012>Rn Bonnet</url>\r\r\n<url=showinfo:1377//537400441>Sevaru</url>\r\r\n<url=showinfo:1377//158094437>Shamis Orzoz</url>\r\r\n<url=showinfo:1377//1070875766>Tarnag</url>\r\r\n<url=showinfo:1377//1422605896>Tijuana</url>\r\r\n<url=showinfo:1377//1189811121>Tinkeng</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33035,1195,'NEO YC 114: RONIN and pixies','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> RONIN and pixies\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//265158358>Dwimm</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//506102106>Alex Medvedov</url>\r\r\n<url=showinfo:1377//243967462>Charakterowitch</url>\r\r\n<url=showinfo:1377//748337660>Darth Rabban</url>\r\r\n<url=showinfo:1377//543997013>Enertis</url>\r\r\n<url=showinfo:1377//1457049996>gargous V</url>\r\r\n<url=showinfo:1377//708999704>Guados</url>\r\r\n<url=showinfo:1377//282168732>JirikAS</url>\r\r\n<url=showinfo:1377//1034825826>Kalimero 1</url>\r\r\n<url=showinfo:1377//976756463>Krivas</url>\r\r\n<url=showinfo:1377//1672727616>Kufik</url>\r\r\n<url=showinfo:1377//1227135384>Kululu</url>\r\r\n<url=showinfo:1377//977094169>Morgol</url>\r\r\n<url=showinfo:1377//309393735>NERGAL</url>\r\r\n<url=showinfo:1377//326447299>Palolko Dwimer</url>\r\r\n<url=showinfo:1377//161528503>Princess Koumee</url>\r\r\n<url=showinfo:1377//214388243>Shivaja</url>\r\r\n<url=showinfo:1377//262716825>voc III</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33036,1195,'NEO YC 114: Expendables','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Expendables\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//1668126374>HaartSp</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//1336805437>Aen Sidhe</url>\r\r\n<url=showinfo:1377//122105870>Ais Hellia</url>\r\r\n<url=showinfo:1377//729603203>Blan</url>\r\r\n<url=showinfo:1377//1139764481>BSL</url>\r\r\n<url=showinfo:1377//1547677125>GTusk</url>\r\r\n<url=showinfo:1377//1927626606>Hecater</url>\r\r\n<url=showinfo:1377//489181245>Helen Connor</url>\r\r\n<url=showinfo:1377//349065936>HornyAlice</url>\r\r\n<url=showinfo:1377//811539166>Ice Tim</url>\r\r\n<url=showinfo:1377//1179921979>M0ridin</url>\r\r\n<url=showinfo:1377//784487372>Miss Zyd</url>\r\r\n<url=showinfo:1377//661185116>Nebula XII</url>\r\r\n<url=showinfo:1377//1369756867>Nemizdrimatii w</url>\r\r\n<url=showinfo:1377//1341664472>P0cket Rocket</url>\r\r\n<url=showinfo:1377//1014318101>Pandi</url>\r\r\n<url=showinfo:1377//750940483>Quorthon Seth</url>\r\r\n<url=showinfo:1377//1613019230>Roger Dodger</url>\r\r\n<url=showinfo:1377//909414289>Stilet</url>\r\r\n<url=showinfo:1377//182617505>ThePiratEbay</url>\r\r\n<url=showinfo:1377//816718482>Vizirion</url>\r\r\n<url=showinfo:1377//296009786>VoZzZic</url>\r\r\n<url=showinfo:1377//1459021925>xo3e</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33037,1195,'NEO YC 114: The HUNS','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> The HUNS\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//1985109453>Justice forHungary</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//703729843>Brinn Yerdola</url>\r\r\n<url=showinfo:1377//168247770>Bubba12</url>\r\r\n<url=showinfo:1377//825971128>Deesnow</url>\r\r\n<url=showinfo:1377//939407187>dlui</url>\r\r\n<url=showinfo:1377//1758197872>DonatxAK47</url>\r\r\n<url=showinfo:1377//1190773066>Feitosa</url>\r\r\n<url=showinfo:1377//726227457>Fistandilus</url>\r\r\n<url=showinfo:1377//964772265>Humor Harold</url>\r\r\n<url=showinfo:1377//105673158>Isanoe nothwood</url>\r\r\n<url=showinfo:1377//324034293>Jim Turner</url>\r\r\n<url=showinfo:1377//1392603142>KAaaffe</url>\r\r\n<url=showinfo:1377//680912464>Kard Fater</url>\r\r\n<url=showinfo:1377//408756638>Kunos01</url>\r\r\n<url=showinfo:1377//1240188226>Leah Hun</url>\r\r\n<url=showinfo:1377//329579757>Mistress Ice</url>\r\r\n<url=showinfo:1377//531691900>Onexis</url>\r\r\n<url=showinfo:1377//614233879>pongi</url>\r\r\n<url=showinfo:1377//1045491953>Pr3t0r</url>\r\r\n<url=showinfo:1377//424874169>Shonion</url>\r\r\n<url=showinfo:1377//890447482>Terios Corvalis</url>\r\r\n<url=showinfo:1377//240257184>The HALAL</url>\r\r\n<url=showinfo:1377//154392629>Tusko Hopkins</url>\r\r\n<url=showinfo:1377//162158736>Yago Yuhn</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33038,1195,'NEO YC 114: Tinkerhell and Alts','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Tinkerhell and Alts\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//1259355159>TinkerHell</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//463248171>Blonda Mea</url>\r\r\n<url=showinfo:1377//1456210623>Captain Torlek</url>\r\r\n<url=showinfo:1377//682555677>Daemon Lucifus</url>\r\r\n<url=showinfo:1377//944384444>Durstan</url>\r\r\n<url=showinfo:1377//822502137>Elissim4U</url>\r\r\n<url=showinfo:1377//1940748647>Illusionate</url>\r\r\n<url=showinfo:1377//1994965919>Jubb Lees</url>\r\r\n<url=showinfo:1377//1545824669>Korg Leaf</url>\r\r\n<url=showinfo:1377//527470268>leich</url>\r\r\n<url=showinfo:1377//233991150>Maelgar</url>\r\r\n<url=showinfo:1377//637841902>mr undertakers</url>\r\r\n<url=showinfo:1377//350337780>Nergart</url>\r\r\n<url=showinfo:1377//1663731407>Regina Wylde</url>\r\r\n<url=showinfo:1377//616735792>Sister Luna</url>\r\r\n<url=showinfo:1377//973521350>Snooze</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33039,1195,'NEO YC 114: Tengu Terror','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Tengu Terror\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//797291804>StarCrash</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//429496034>Chiro San</url>\r\r\n<url=showinfo:1377//1473268406>Geospirit</url>\r\r\n<url=showinfo:1377//1226817327>madpsychc0killer</url>\r\r\n<url=showinfo:1377//1955354132>Mikella Ki\'Theki</url>\r\r\n<url=showinfo:1377//273670623>Natrium Au</url>\r\r\n<url=showinfo:1377//1922788260>Pri0r0fthe0ri</url>\r\r\n<url=showinfo:1377//1704262111>RAPOPOV</url>\r\r\n<url=showinfo:1377//253796325>Redia</url>\r\r\n<url=showinfo:1377//2031652638>Sylviria</url>\r\r\n<url=showinfo:1377//265458580>The Yzzerman</url>\r\r\n<url=showinfo:1377//251844188>Vladd Talltos</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33040,1195,'NEO YC 114: Oxygen Isonopes','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Oxygen Isonopes\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//751832309>Warr Akini</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//821185360>BlackSabbath</url>\r\r\n<url=showinfo:1377//1399211800>Braygo Khallazar</url>\r\r\n<url=showinfo:1377//826128382>Diogenes Diaspora</url>\r\r\n<url=showinfo:1377//167352969>eC Cade</url>\r\r\n<url=showinfo:1377//1523206482>Firvain</url>\r\r\n<url=showinfo:1377//1760421798>FOl2TY8</url>\r\r\n<url=showinfo:1377//1469734517>Fyzick</url>\r\r\n<url=showinfo:1377//1091875696>Halosponge</url>\r\r\n<url=showinfo:1377//680120572>Jaroslav</url>\r\r\n<url=showinfo:1377//928536456>Jenya Lin</url>\r\r\n<url=showinfo:1377//90613965>Kyle Myr</url>\r\r\n<url=showinfo:1377//1136947120>Lasius</url>\r\r\n<url=showinfo:1377//435846426>Leykab</url>\r\r\n<url=showinfo:1377//1883470581>Liam Jacobs</url>\r\r\n<url=showinfo:1377//1853733254>Lord Regent</url>\r\r\n<url=showinfo:1377//1821356839>Masra lor</url>\r\r\n<url=showinfo:1377//958372469>Rehtom Lamina</url>\r\r\n<url=showinfo:1377//248529845>Teljkon Nugs</url>\r\r\n<url=showinfo:1377//1868446148>Tiberizzle</url>\r\r\n<url=showinfo:1377//376185646>Titmando</url>\r\r\n<url=showinfo:1377//564586053>Travis Wells</url>\r\r\n<url=showinfo:1377//916015256>Vena Saris</url>\r\r\n<url=showinfo:1377//858761439>Xolve</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33041,1195,'NEO YC 114: Africa s Finest','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much broader audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Africa s Finest\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//901341854>Rengas</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//996446131>90JpHoule90</url>\r\r\n<url=showinfo:1377//1702139014>Anita1</url>\r\r\n<url=showinfo:1377//610194671>Billy Beans</url>\r\r\n<url=showinfo:1377//659845015>borgliht</url>\r\r\n<url=showinfo:1377//1276897779>Captain S04p</url>\r\r\n<url=showinfo:1377//981268112>Darknesss</url>\r\r\n<url=showinfo:1377//1612433053>David Godfrey</url>\r\r\n<url=showinfo:1377//757402567>Edenmain</url>\r\r\n<url=showinfo:1377//2027748143>Fatyn</url>\r\r\n<url=showinfo:1377//1283022477>Gibbo3771</url>\r\r\n<url=showinfo:1377//769212335>Gods Coldblood</url>\r\r\n<url=showinfo:1377//252160961>knifee</url>\r\r\n<url=showinfo:1377//1499188071>Noobjuice</url>\r\r\n<url=showinfo:1377//438615800>Optical Illusion</url>\r\r\n<url=showinfo:1377//1086224349>pritch1</url>\r\r\n<url=showinfo:1377//843562916>QUPNDIE</url>\r\r\n<url=showinfo:1377//193095646>Robert Fish</url>\r\r\n<url=showinfo:1377//2009346981>Royal Jedi</url>\r\r\n<url=showinfo:1377//467531345>simcor</url>\r\r\n<url=showinfo:1377//1843493649>smaster</url>\r\r\n<url=showinfo:1377//940911300>StarFleetCommander</url>\r\r\n<url=showinfo:1377//351826446>SupaFlyTNT</url>\r\r\n<url=showinfo:1377//726367684>WarGod</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33042,1195,'NEO YC 114: Something Else','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Something Else\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//815145416>SpeedY G0nZaleZ</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//726481710>Alexxei</url>\r\r\n<url=showinfo:1377//1170266611>cheeze35</url>\r\r\n<url=showinfo:1377//1250297728>Dukrat</url>\r\r\n<url=showinfo:1377//978356444>Gaia Thorn</url>\r\r\n<url=showinfo:1377//1201424960>Guillane Itaril</url>\r\r\n<url=showinfo:1377//1942580856>Jake Elwood</url>\r\r\n<url=showinfo:1377//106543216>Mar Drakar</url>\r\r\n<url=showinfo:1377//1286094767>Max Wilson</url>\r\r\n<url=showinfo:1377//930322863>Mechaet</url>\r\r\n<url=showinfo:1377//345532262>Mhua dib</url>\r\r\n<url=showinfo:1377//109598227>Moxyll</url>\r\r\n<url=showinfo:1377//204545620>Nahjar Qu\'in</url>\r\r\n<url=showinfo:1377//325278451>Ritualiztic Suizide</url>\r\r\n<url=showinfo:1377//1154438924>sevyn nine</url>\r\r\n<url=showinfo:1377//91783674>Sophia Ratos</url>\r\r\n<url=showinfo:1377//357178303>suicide</url>\r\r\n<url=showinfo:1377//592491959>Taco Rice</url>\r\r\n<url=showinfo:1377//1808639381>Time Funnel</url>\r\r\n<url=showinfo:1377//1592447944>Varsaavik</url>\r\r\n<url=showinfo:1377//756796080>Xaesta</url>\r\r\n<url=showinfo:1377//683618135>Xiaodown</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33043,1195,'NEO YC 114: The Exiled Gaming','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> The Exiled Gaming\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//1561889551>Imbor</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//2078455254>Antonius Lee</url>\r\r\n<url=showinfo:1377//1985608872>Arilyth</url>\r\r\n<url=showinfo:1377//91770769>Gabrielle Padecain</url>\r\r\n<url=showinfo:1377//1089210341>Sairuika</url>\r\r\n<url=showinfo:1377//1848470189>Sairuikon</url>\r\r\n<url=showinfo:1377//593142863>Zura zame</url>\r\r\n<url=showinfo:1377//1925809190>Zurazame</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33044,1195,'NEO YC 114: Perihelion Beryllium Duralumin','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Perihelion Beryllium Duralumin\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//602884289>IceGuerilla</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//1127664288>3AXAPbI4</url>\r\r\n<url=showinfo:1377//1562087767>Alkash1</url>\r\r\n<url=showinfo:1377//1478485683>canoneerT</url>\r\r\n<url=showinfo:1377//477244479>Carvel Socks</url>\r\r\n<url=showinfo:1377//111553251>cobra695</url>\r\r\n<url=showinfo:1377//777599420>Cpt Advile</url>\r\r\n<url=showinfo:1377//1184494464>Deprival</url>\r\r\n<url=showinfo:1377//693954949>El Spinktor</url>\r\r\n<url=showinfo:1377//958146119>Explorus</url>\r\r\n<url=showinfo:1377//289158383>inaroADUN</url>\r\r\n<url=showinfo:1377//90624058>Jack Heklar</url>\r\r\n<url=showinfo:1377//1384485000>Kadra</url>\r\r\n<url=showinfo:1377//798683536>Khar Velsox</url>\r\r\n<url=showinfo:1377//154962618>Maque</url>\r\r\n<url=showinfo:1377//501575251>Minuteman</url>\r\r\n<url=showinfo:1377//1674416072>Pasteboard Hero</url>\r\r\n<url=showinfo:1377//2008305924>Saar Gunnar</url>\r\r\n<url=showinfo:1377//288310228>Scythus Aratan</url>\r\r\n<url=showinfo:1377//1593920574>siberian beast</url>\r\r\n<url=showinfo:1377//1794505148>Stars Skrim</url>\r\r\n<url=showinfo:1377//91388570>vitalik Antollare</url>\r\r\n<url=showinfo:1377//1298182193>Vrarldudnatrch</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33045,1195,'NEO YC 114: Goggle Wearing Internet Crime Fighters','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Goggle Wearing Internet Crime Fighters\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//147294630>Seldarine</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//581822577>Araris Valerian</url>\r\r\n<url=showinfo:1377//161408497>BLOOD THIRSTY</url>\r\r\n<url=showinfo:1377//889732885>Bluemelon</url>\r\r\n<url=showinfo:1377//348465386>Buhhdust Princess</url>\r\r\n<url=showinfo:1377//379766118>Conmen</url>\r\r\n<url=showinfo:1377//625199800>DHB WildCat</url>\r\r\n<url=showinfo:1377//609537637>DietrichDieBarber</url>\r\r\n<url=showinfo:1377//1847305125>EagleNoFace</url>\r\r\n<url=showinfo:1377//596756116>Fafer</url>\r\r\n<url=showinfo:1377//519743396>Jassmin Joy</url>\r\r\n<url=showinfo:1377//166578912>Kothar Ra</url>\r\r\n<url=showinfo:1377//174332471>Redon</url>\r\r\n<url=showinfo:1377//696276220>Virrgo</url>\r\r\n<url=showinfo:1377//401806432>W4RR10R</url>\r\r\n<url=showinfo:1377//706113692>Weener</url>\r\r\n<url=showinfo:1377//986748328>Wilhelm Caster</url>\r\r\n<url=showinfo:1377//217669330>Zelota</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33046,1195,'NEO YC 114: ISN   Incursion Shiny Network','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> ISN   Incursion Shiny Network\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//187608062>Bozl1n</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//90749099>Blunt Smoker269</url>\r\r\n<url=showinfo:1377//91333247>Chronic Hypnotic</url>\r\r\n<url=showinfo:1377//90269130>Daniva Moon</url>\r\r\n<url=showinfo:1377//337065609>DutchGunner</url>\r\r\n<url=showinfo:1377//1633020830>goldiiee</url>\r\r\n<url=showinfo:1377//91347843>High Times Smoker</url>\r\r\n<url=showinfo:1377//90006653>Jebsar</url>\r\r\n<url=showinfo:1377//91180419>Justina Box</url>\r\r\n<url=showinfo:1377//734839308>Kodavor</url>\r\r\n<url=showinfo:1377//754637464>Maraudian</url>\r\r\n<url=showinfo:1377//1608210160>MR Rhy</url>\r\r\n<url=showinfo:1377//2030065899>Nituspar</url>\r\r\n<url=showinfo:1377//1278052858>Noble Ranger</url>\r\r\n<url=showinfo:1377//91349210>Obvious Pun</url>\r\r\n<url=showinfo:1377//91112983>RandomHero 9001</url>\r\r\n<url=showinfo:1377//738733883>rhying</url>\r\r\n<url=showinfo:1377//1588383258>Tonali</url>\r\r\n<url=showinfo:1377//1438007559>Xeda Jotan</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33047,1195,'NEO YC 114: Baaaramu','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Baaaramu\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//755050830>Qicia</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//1018985560>Altiar Savien</url>\r\r\n<url=showinfo:1377//1122329298>blade190</url>\r\r\n<url=showinfo:1377//971866180>Cearul</url>\r\r\n<url=showinfo:1377//674421329>Crethan</url>\r\r\n<url=showinfo:1377//389541380>DrWockles</url>\r\r\n<url=showinfo:1377//284682057>Electro Gypsy</url>\r\r\n<url=showinfo:1377//1073801539>Fenix Returned</url>\r\r\n<url=showinfo:1377//1716964112>HellssAngell</url>\r\r\n<url=showinfo:1377//1772460758>itchymeek</url>\r\r\n<url=showinfo:1377//549207597>Jonathan Pryde</url>\r\r\n<url=showinfo:1377//645194352>Mar Shall</url>\r\r\n<url=showinfo:1377//145199643>Muad\' Dib</url>\r\r\n<url=showinfo:1377//1369186239>Mycia</url>\r\r\n<url=showinfo:1377//776992488>PandoraKnight</url>\r\r\n<url=showinfo:1377//890780197>retzalot</url>\r\r\n<url=showinfo:1377//1435272939>Riela Tanal</url>\r\r\n<url=showinfo:1377//290710755>RobinAnne</url>\r\r\n<url=showinfo:1377//627592223>ScreamerJoe</url>\r\r\n<url=showinfo:1377//90243043>Sparta93xb</url>\r\r\n<url=showinfo:1377//1128334497>Synomah boy</url>\r\r\n<url=showinfo:1377//90468759>Zerox Kon</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33048,1195,'NEO YC 114: Asine Hitama s team','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Asine Hitama s team\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//915883762>Vlada Silni</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//91143079>Benjamin Basstable</url>\r\r\n<url=showinfo:1377//1048301189>C\' Luigi</url>\r\r\n<url=showinfo:1377//1190169509>Chorien</url>\r\r\n<url=showinfo:1377//913608804>Durar</url>\r\r\n<url=showinfo:1377//406805804>Exe Luis</url>\r\r\n<url=showinfo:1377//567698930>Girt v2</url>\r\r\n<url=showinfo:1377//385111411>Gvraget Anun</url>\r\r\n<url=showinfo:1377//876695132>Helljumper117</url>\r\r\n<url=showinfo:1377//631248910>jobee</url>\r\r\n<url=showinfo:1377//877086113>Kaleesh</url>\r\r\n<url=showinfo:1377//1359183503>LeCyborg</url>\r\r\n<url=showinfo:1377//645678119>Mirkonix</url>\r\r\n<url=showinfo:1377//890613107>Nikuno</url>\r\r\n<url=showinfo:1377//90852398>Nwimie Sklor</url>\r\r\n<url=showinfo:1377//1083148663>Paladin 1995</url>\r\r\n<url=showinfo:1377//2083940425>quiki1</url>\r\r\n<url=showinfo:1377//339475781>RedGeneral</url>\r\r\n<url=showinfo:1377//483920752>sardumaquon</url>\r\r\n<url=showinfo:1377//1519234517>Sergeant Brut</url>\r\r\n<url=showinfo:1377//274422072>Sojic</url>\r\r\n<url=showinfo:1377//1281542726>Staffo 0</url>\r\r\n<url=showinfo:1377//298313631>TotoRiina</url>\r\r\n<url=showinfo:1377//675604185>WeirdOne</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33049,1195,'NEO YC 114: EFS','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> EFS\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//551999455>Ivanrus</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//90125628>Burgul</url>\r\r\n<url=showinfo:1377//91130442>i Beast</url>\r\r\n<url=showinfo:1377//90525943>Ivandoc Ibragimov</url>\r\r\n<url=showinfo:1377//775926683>Ivanrus 5</url>\r\r\n<url=showinfo:1377//113153038>KARAR2D2</url>\r\r\n<url=showinfo:1377//721169171>King Instagate</url>\r\r\n<url=showinfo:1377//1714557790>Kintaro Tan</url>\r\r\n<url=showinfo:1377//595987381>Kitana StarWind</url>\r\r\n<url=showinfo:1377//1059081514>Korvin</url>\r\r\n<url=showinfo:1377//1249403815>Kutris</url>\r\r\n<url=showinfo:1377//1735944981>LLIAPHXOCT</url>\r\r\n<url=showinfo:1377//1519590514>Red Ingram</url>\r\r\n<url=showinfo:1377//154343196>rr vertigo</url>\r\r\n<url=showinfo:1377//1888486619>Sophie Telrunya</url>\r\r\n<url=showinfo:1377//1919810151>StainLess Blade</url>\r\r\n<url=showinfo:1377//90214943>Wadimich</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33050,1195,'NEO YC 114: Much Crying Old Experts','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Much Crying Old Experts\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//122087689>Tyrus Tenebros</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//165044004>Bacchanalian</url>\r\r\n<url=showinfo:1377//124135561>Dirk Magnum</url>\r\r\n<url=showinfo:1377//515754787>Dradius Calvantia</url>\r\r\n<url=showinfo:1377//838815107>EntroX</url>\r\r\n<url=showinfo:1377//666537358>Inora Aknaria</url>\r\r\n<url=showinfo:1377//525152718>Lord\'s Servant</url>\r\r\n<url=showinfo:1377//832130268>Master OlavPancrazio</url>\r\r\n<url=showinfo:1377//1686798036>MiaKaa</url>\r\r\n<url=showinfo:1377//323933210>Rory Pruzis</url>\r\r\n<url=showinfo:1377//1407228740>Snake O\'Connor</url>\r\r\n<url=showinfo:1377//982400232>Snake O\'Donell</url>\r\r\n<url=showinfo:1377//847450727>StevieTopSiders</url>\r\r\n<url=showinfo:1377//219366417>Vel Kyri</url>\r\r\n<url=showinfo:1377//918912716>Vlad Cetes</url>\r\r\n<url=showinfo:1377//1297372323>xoXFatCatXox</url>\r\r\n<url=showinfo:1377//785678890>xXHeRoInERaBBiTXx</url>\r\r\n<url=showinfo:1377//1892453967>Zach Donnell</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33051,1195,'NEO YC 114: DeepWater','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> DeepWater\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//1288411893>HED KANDIR</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//766140277>Ajwas Tawar</url>\r\r\n<url=showinfo:1377//1932753796>Alma Nielly</url>\r\r\n<url=showinfo:1377//1203142626>AXBU3PA</url>\r\r\n<url=showinfo:1377//1212349403>Ceasari</url>\r\r\n<url=showinfo:1377//315192802>Jerhan Croy</url>\r\r\n<url=showinfo:1377//1239421489>Karl XI</url>\r\r\n<url=showinfo:1377//218048403>Lsd777</url>\r\r\n<url=showinfo:1377//542131876>MAFIOZOxNAHODKA</url>\r\r\n<url=showinfo:1377//639369240>MaxKalkin</url>\r\r\n<url=showinfo:1377//90046127>mikecher</url>\r\r\n<url=showinfo:1377//847314618>MonkeyDrummer</url>\r\r\n<url=showinfo:1377//91360398>sl Garsk</url>\r\r\n<url=showinfo:1377//1656597111>Susen Kelven</url>\r\r\n<url=showinfo:1377//781706584>Trash Ice</url>\r\r\n<url=showinfo:1377//621327708>vNSOv</url>\r\r\n<url=showinfo:1377//164282686>Wiker</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33052,1195,'NEO YC 114: Blue Ballers','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Blue Ballers\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//1355771118>Ivan Jakanov</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//1872791627>amy becker</url>\r\r\n<url=showinfo:1377//926158871>azealea</url>\r\r\n<url=showinfo:1377//370516475>Crack On</url>\r\r\n<url=showinfo:1377//115594603>Drosstein Fitch</url>\r\r\n<url=showinfo:1377//1322057538>ETSJAMMER</url>\r\r\n<url=showinfo:1377//845871254>fdal</url>\r\r\n<url=showinfo:1377//1653393159>Fork Off</url>\r\r\n<url=showinfo:1377//1797166302>Gittsum</url>\r\r\n<url=showinfo:1377//91063345>Green Backs</url>\r\r\n<url=showinfo:1377//899059734>Hirosaki Intaki</url>\r\r\n<url=showinfo:1377//1527227094>Kronthar Lionkur</url>\r\r\n<url=showinfo:1377//1551823685>Lana Banely</url>\r\r\n<url=showinfo:1377//942463188>Leeloo Alizee</url>\r\r\n<url=showinfo:1377//490266390>MAJOR LeeConfuzd</url>\r\r\n<url=showinfo:1377//738510828>Mason Datar</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33053,1195,'NEO YC 114: The Gentlemen Renegades','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> The Gentlemen Renegades\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//764290004>luckyccs</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//90022626>Admiral Rufus</url>\r\r\n<url=showinfo:1377//745816628>Amantus</url>\r\r\n<url=showinfo:1377//1631193943>Bob Shaftoes</url>\r\r\n<url=showinfo:1377//254127709>Cartheron Crust</url>\r\r\n<url=showinfo:1377//1895499686>Cavalira</url>\r\r\n<url=showinfo:1377//535700289>Cyber Ten</url>\r\r\n<url=showinfo:1377//495572827>Duckslayer</url>\r\r\n<url=showinfo:1377//303197728>Jeronica</url>\r\r\n<url=showinfo:1377//925082989>Jintra Jin\'tak</url>\r\r\n<url=showinfo:1377//542843132>Killdu</url>\r\r\n<url=showinfo:1377//893754576>l0rd carlos</url>\r\r\n<url=showinfo:1377//747856020>Lex Fasces</url>\r\r\n<url=showinfo:1377//1843882582>Malaes</url>\r\r\n<url=showinfo:1377//928259005>maximus babbarus</url>\r\r\n<url=showinfo:1377//272898591>Mortvvs</url>\r\r\n<url=showinfo:1377//393010147>n4d444</url>\r\r\n<url=showinfo:1377//1333479515>Pord</url>\r\r\n<url=showinfo:1377//122254646>Radgette</url>\r\r\n<url=showinfo:1377//1988826684>Recoil IV</url>\r\r\n<url=showinfo:1377//1862643650>Rhadit</url>\r\r\n<url=showinfo:1377//437565553>Ripperljohn</url>\r\r\n<url=showinfo:1377//215244213>Stoffl</url>\r\r\n<url=showinfo:1377//808557125>Zekk Pacus</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33054,1195,'NEO YC 114: Guiding Hand Social Club','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> Guiding Hand Social Club\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//144870255>Tyrrax Thorrk</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//998615087>Bunnehrawr Rawr</url>\r\r\n<url=showinfo:1377//149867865>Hamish</url>\r\r\n<url=showinfo:1377//873374907>Istvaan Shogaatsu</url>\r\r\n<url=showinfo:1377//129998842>Kumq uat</url>\r\r\n<url=showinfo:1377//146180942>NTRabbit</url>\r\r\n<url=showinfo:1377//144840252>Vegeta</url>\r\r\n<url=showinfo:1377//243021251>Zeraph Dregamon</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33055,1195,'NEO YC 114: XXXMity','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> XXXMity\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//1934370072>KwarK uK</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//90323169>Aeth Gemulus</url>\r\r\n<url=showinfo:1377//90418742>Body Shield</url>\r\r\n<url=showinfo:1377//1428789491>Captain Dolphin</url>\r\r\n<url=showinfo:1377//1715821878>Chessur</url>\r\r\n<url=showinfo:1377//112201268>denevv\'e</url>\r\r\n<url=showinfo:1377//1641696421>Dr Narud</url>\r\r\n<url=showinfo:1377//1910683147>Gal Axian</url>\r\r\n<url=showinfo:1377//2053796889>Gorski Car</url>\r\r\n<url=showinfo:1377//1259128935>Greggles Midboss</url>\r\r\n<url=showinfo:1377//90338575>Im Jed</url>\r\r\n<url=showinfo:1377//580737454>Karah Serrigan</url>\r\r\n<url=showinfo:1377//1573202732>Kirk Hammet</url>\r\r\n<url=showinfo:1377//518701682>Lost Lemo</url>\r\r\n<url=showinfo:1377//90776712>Mandini Arcturus</url>\r\r\n<url=showinfo:1377//90148173>Michael Harari</url>\r\r\n<url=showinfo:1377//924826903>Nejota</url>\r\r\n<url=showinfo:1377//1579843784>Not Orious</url>\r\r\n<url=showinfo:1377//1078628165>Pangell</url>\r\r\n<url=showinfo:1377//1071150539>Rakwa</url>\r\r\n<url=showinfo:1377//90869683>Tawa Suyo</url>\r\r\n<url=showinfo:1377//90111666>tofucake prime</url>\r\r\n<url=showinfo:1377//1091103230>Wrathful Penguins</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33056,1195,'NEO YC 114: My Little Nulli','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> My Little Nulli\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//553999427>Cas mania</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//724016352>Amaradus Caligula</url>\r\r\n<url=showinfo:1377//2051093724>Andrew Curtin</url>\r\r\n<url=showinfo:1377//1013998476>Angeliq</url>\r\r\n<url=showinfo:1377//90153070>Aram Kachaturian</url>\r\r\n<url=showinfo:1377//880064320>Asyrdin Harate</url>\r\r\n<url=showinfo:1377//1965402759>Casey Hija</url>\r\r\n<url=showinfo:1377//1719018964>Dalton Russel</url>\r\r\n<url=showinfo:1377//110788359>Fedaykin055</url>\r\r\n<url=showinfo:1377//736229961>Gorga</url>\r\r\n<url=showinfo:1377//1794754095>Guderian3</url>\r\r\n<url=showinfo:1377//939827463>Kitt JT</url>\r\r\n<url=showinfo:1377//1570240979>Lynnly Rorschach</url>\r\r\n<url=showinfo:1377//362446237>MODA EFE</url>\r\r\n<url=showinfo:1377//1755901088>Novalis X</url>\r\r\n<url=showinfo:1377//317012339>progodlegend</url>\r\r\n<url=showinfo:1377//171153897>Real Poison</url>\r\r\n<url=showinfo:1377//707274811>Rhodin Lazarith</url>\r\r\n<url=showinfo:1377//683970188>Space McCool</url>\r\r\n<url=showinfo:1377//1753024461>stu007</url>\r\r\n<url=showinfo:1377//1014510684>Tadeu718</url>\r\r\n<url=showinfo:1377//721268368>tempo gigante</url>\r\r\n<url=showinfo:1377//235473438>Tinman256</url>\r\r\n<url=showinfo:1377//929757329>transcom caldari</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33057,1195,'NEO YC 114: 8 CAS','One of twenty-seven different cards created for the first ever New Eden Open tournament of YC 114. While not the first ever capsuleer tournament it was the first of its kind to be sponsored by a private media organization and broadcast to a much larger audience. It was also set a new benchmark for prizes in a capsuleer tournament.\r\r\n\r\r\nThe New Eden Open broke the tradition of previous capsuleer tournaments by allowing teams to form at will, without the need to be bound to the same alliance.\r\r\n\r\r\nThis card represents the following team and sponsor:\r\r\n<font color=\"0xff00CC00\">Team Name:</font> 8 CAS\r\r\n<font color=\"0xff00CC00\">Sponsor Name:</font> No team sponsor.\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Captain:</b></font>\r\r\n<url=showinfo:1377//560738347>Nopolar</url>\r\r\n\r\r\n<font size=\"14\" color=\"0xff0099FF\"><b>Team Members:</b></font>\r\r\n<url=showinfo:1377//567779495>Boiglio</url>\r\r\n<url=showinfo:1377//90802873>CaptConaN</url>\r\r\n<url=showinfo:1377//91015351>Chastity Lynn</url>\r\r\n<url=showinfo:1377//822886919>Chip Flux</url>\r\r\n<url=showinfo:1377//664624429>Cyna Copper</url>\r\r\n<url=showinfo:1377//91541731>Deimos Ovaert</url>\r\r\n<url=showinfo:1377//1290000640>Dorian Ramius</url>\r\r\n<url=showinfo:1377//90964462>Ethienne Dallocort</url>\r\r\n<url=showinfo:1377//451509056>Jackal Lord</url>\r\r\n<url=showinfo:1377//2059443230>Jarek Ramius</url>\r\r\n<url=showinfo:1377//90842122>Kill 8ill</url>\r\r\n<url=showinfo:1377//91103512>Plejaden</url>\r\r\n<url=showinfo:1377//1721710166>Tabimatha</url>\r\r\n<url=showinfo:1377//1769655014>Vic Steeleyes</url>\r\r\n<url=showinfo:1377//91635684>Xevik Thiesant</url>\r\r\n\r\r\n<i>Can you collect them all?</i>',0,0.01,0,1,NULL,0.0000,1,1813,0),(33058,1194,'Concordokken','A funny educational video created in YC 108 to teach pilots of New Eden about the powers of the Concord police force.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33059,1194,'Shuttle Piloting For Dummies','The definitive guide on how best to pilot all shuttles in New Eden.\r\r\n\r\r\nNo matter what you read within this manual, please keep in mind that shuttles can\'t web targets, their lock time is slow, they can be shot, and if perhaps you were unaware, I hear they don\'t tank particularly well.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33060,1194,'*Sneaks in a classic*','A comic series released to New Eden from YC 110 onward. In certain elite circles the comic was regarded as one of the best pieces of comedy entertainment written in recent times. Critics everywhere else never seemed to grasp its particular brand of jokes and as a result it never truly took off outside the capsuleer community.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33061,1194,'Public Portrait: How To','During the year YC 111 there was an incident in which a capsuleer posted a truly legitimate question on the public network and asked for some assistance in answering it. Shortly after posting his question the public network was filled with jokes about the man\'s chin. It is unknown if he ever got an answer to his question but we know for sure that for a period of time after his public post the only words to follow the man were \"dude, your chin!\"\r\r\n\r\r\nIt is for reasons like this that one must be careful about choosing what portrait they present to the public. By the end of this book you will understand how to properly select a good public portrait that properly represents you.\r\r\n\r\r\nThe person in the above story has since had surgery that changed his appearance and so we dedicate the cover of this book to his original look.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33062,1089,'Men\'s \'Red Star\' T-shirt','Stand out in a crowd with this crisp, elegant design, designed exclusively for those who want their wear to be casual and comfortable while simultaneously having it send a stark message of the celebration of freedom and brotherhood. This t-shirt, pitch black as the dark of space, is adorned with a single red star, standing as the symbol both of a dying sun in the last throes of its cooling embers, and a rebirth of life in star-lit New Eden.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(33063,1089,'Women\'s \'Red Star\' T-shirt','Stand out in a crowd with this crisp, elegant design, designed exclusively for those who want their wear to be casual and comfortable while simultaneously having it send a stark message of the celebration of freedom and brotherhood. This t-shirt, pitch black as the dark of space, is adorned with a single red star, standing as the symbol both of a dying sun in the last throes of its cooling embers, and a rebirth of life in star-lit New Eden.',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(33064,1091,'Boots.ini','We found where they all went.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(33065,1194,'Donut Holder','Finally a place to put the donuts.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33066,1194,'New Eden Soundbox','This antiquated music-playing device sure has seen better days. Not only is the outer shell cracked, with wires and inner circuitry running loose, but some power cells seem to be missing as well. All attempts to fix or reconnect this strange device have failed, resulting only in a deafeningly loud static noise coming out of the ship\'s sound synthesizers. Better leave this off, then.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33067,1197,'Deactivated Station Key Pass Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,1664,0),(33068,300,'QA SpaceAnchor Implant','This implant does not exist',0,1,0,1,NULL,0.0000,0,NULL,0),(33069,1198,'Orbital Target','Telemetry broadcast by forces fighting on a nearby planetary body enables allied ships in range to unleash a terrifying orbital bombardment against the designated target.',0,0,0,1,NULL,0.0000,1,NULL,0),(33070,314,'New Eden Open Gold Medal','Awarded to the first place team in the New Eden Open.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(33071,314,'New Eden Open Silver Medal','Awarded to the second place team in the New Eden Open.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(33072,314,'New Eden Open Bronze Medal','Awarded to the third place team in the New Eden Open.',1,0.1,0,1,NULL,0.0000,1,NULL,0),(33073,314,'New Eden Open Fourth Place Medal','Because in the game of self respect, everyone\'s a winner!',1,0.1,0,1,NULL,0.0000,1,NULL,0),(33076,1199,'Small Ancillary Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship. The module can optionally use Nanite Repair Paste to increase repair effectiveness. Deactivating the module while it has no Nanite Repair Paste loaded starts reloading, if there is Nanite Repair Paste available in cargo hold. \r\r\n\r\r\nNote: Can use Nanite Repair Paste as fuel. Reloading time is 60 seconds. Prototype Inferno Module.',500,5,0.08,1,NULL,36788.0000,1,1049,0),(33077,1200,'Small Ancillary Armor Repairer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,1536,0),(33078,1210,'Armor Layering','Skill at installing upgraded armor plates efficiently and securely, reducing the impact they have on agility and speed. Grants a 5% reduction to armor plate mass penalty per level.',0,0.01,0,1,NULL,1000000.0000,1,1745,0),(33079,237,'Hematos','The Hematos is one of the smallest Blood Raider vessels in existence, though that doesn\'t make its appearance any less terrifying to the hapless innocents it may encounter. Like a spider, it is built to trap and drain any victim careless enough to wander into its clutches.\r\r\n\r\r\nThe Hematos is often employed by novice ship captains and staffed with crew that may not quite have mastered the art of bloodletting, which goes some way to explain its saturation of onboard cleaning systems.',1148000,28100,115,1,4,0.0000,1,1619,0),(33080,105,'Hematos Blueprint',' ',0,0.01,0,1,4,9999999.0000,0,NULL,0),(33081,237,'Taipan','The Taipan is one of the smaller types of Gurista vessels. While the design is based on a pre-existing Caldari ship type - the Guristas delight in stealing anything they can from their hated enemies - its internal workings have been heavily modified. Not content to rely on the Caldari\'s focus on missile combat, the Guristas have added the drone power of the Gallente.',1163000,15000,125,1,1,0.0000,1,1619,0),(33082,105,'Taipan Blueprint',' ',0,0.01,0,1,1,9999999.0000,0,NULL,0),(33083,237,'Violator','The Violator is one of the smallest of the Serpentis vessels. Its design was unceremoniously stolen from the Gallente, though its inner workings have been adapted to fit the piratical lifestyle of the Serpentis: In addition to its excellent hybrid damage, it is capable of webbing its opponents and holding them down for a further beating.',1148000,24500,135,1,8,0.0000,1,1619,0),(33084,105,'Violator Blueprint',' ',0,0.01,0,1,8,9999999.0000,0,NULL,0),(33087,303,'Advanced Cerebral Accelerator','Cerebral accelerators are military-grade boosters that significantly increase a new pilot\'s skill development. This technology is usually available only to naval officers, but CONCORD has authorized the release of a small number to particularly promising freelance capsuleers.<br><br>This booster primes the brain\'s neural pathways and hippocampus, making it much more receptive to intensive remapping. This allows new capsuleers to more rapidly absorb information of all kinds.<br><br>The only drawback to this booster is that capsuleer training renders it ineffective after a while; as such, it will cease to function for pilots who have been registered for more than 7 days.<br><br>\r\r\nBonuses: +17 to all attributes',1,1,0,1,NULL,65536.0000,1,NULL,0),(33088,718,'Advanced Cerebral Accelerator Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33091,257,'Amarr Destroyer','Skill at operating Amarr destroyers.',0,0.01,0,1,4,100000.0000,1,377,0),(33092,257,'Caldari Destroyer','Skill at operating Caldari destroyers.',0,0.01,0,1,1,100000.0000,1,377,0),(33093,257,'Gallente Destroyer','Skill at operating Gallente destroyers.',0,0.01,0,1,8,100000.0000,1,377,0),(33094,257,'Minmatar Destroyer','Skill at operating Minmatar destroyers.',0,0.01,0,1,2,100000.0000,1,377,0),(33095,257,'Amarr Battlecruiser','Skill at operating Amarr battlecruisers.',0,0.01,0,1,4,1000000.0000,1,377,0),(33096,257,'Caldari Battlecruiser','Skill at operating Caldari battlecruisers.',0,0.01,0,1,1,1000000.0000,1,377,0),(33097,257,'Gallente Battlecruiser','Skill at operating Gallente battlecruisers.',0,0.01,0,1,8,1000000.0000,1,377,0),(33098,257,'Minmatar Battlecruiser','Skill at operating Minmatar battlecruisers.',0,0.01,0,1,2,1000000.0000,1,377,0),(33099,420,'Nefantar Thrasher','Engineered as a supplement to its big brother the Cyclone, the Thrasher\'s tremendous turret capabilities and advanced tracking computers allow it to protect its larger counterpart from smaller, faster menaces. The integration of the newly re-established <a href=\"http://wiki.eveonline.com/en/wiki/Nefantar\">Nefantar tribe</a> into Minmatar society has been a trying process for all involved. One recent success has been the commissioning of a fledgling patrol fleet to protect the tribe\'s new spaceborne assets: as other tribes have stocked up on newer Talwar-class destroyers, the Nefantar have managed to acquire a large stock of older Thrashers for their own use. Keen to raise their visibility within the Minmatar Republic, they have been more than happy to allow willing capsuleers to acquire surplus hulls on the condition that they remain painted in Nefantar colors.',1600000,43000,400,1,2,2.0000,0,NULL,0),(33101,1199,'Medium Ancillary Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship. The module can optionally use Nanite Repair Paste to increase repair effectiveness. Deactivating the module while it has no Nanite Repair Paste loaded starts reloading, if there is Nanite Repair Paste available in cargo hold. \r\r\n\r\r\nNote: Can use Nanite Repair Paste as fuel. Reloading time is 60 seconds. Prototype Inferno Module.',500,10,0.32,1,NULL,44214.0000,1,1050,0),(33102,1200,'Medium Ancillary Armor Repairer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,1536,0),(33103,1199,'Large Ancillary Armor Repairer','This module uses nano-assemblers to repair damage done to the armor of the ship. The module can optionally use Nanite Repair Paste to increase repair effectiveness. Deactivating the module while it has no Nanite Repair Paste loaded starts reloading, if there is Nanite Repair Paste available in cargo hold. \r\r\n\r\r\nNote: Can use Nanite Repair Paste as fuel. Reloading time is 60 seconds. ',500,50,0.64,1,NULL,88788.0000,1,1051,0),(33104,1200,'Large Ancillary Armor Repairer Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,1536,0),(33107,1089,'Men\'s \'Quafe\' T-shirt YC 115','Stand out in a crowd with your comfortable new Quafe Commemorative Casual Wear, designed exclusively for attendees of the YC 115 Impetus Annual Holoreel Convention. \r\r\n\r\r\nNote: While occasionally worn by holoreel stars, Quafe Commemorative Casual Wear is not guaranteed to net you a role in any kind of visual production, at least not one that involves any dialogue. ',0.5,0.1,0,1,4,0.0000,1,1398,0),(33109,1089,'Women\'s \'Quafe\' T-shirt YC 115','Stand out in a crowd with your comfortable new Quafe Commemorative Casual Wear, designed exclusively for attendees of the YC 115 Impetus Annual Holoreel Convention. \r\r\n\r\r\nNote: While occasionally worn by holoreel stars, Quafe Commemorative Casual Wear is not guaranteed to net you a role in any kind of visual production, at least not one that involves any dialogue. ',0.5,0.1,0,1,4,0.0000,1,1406,0),(33111,303,'Prototype Cerebral Accelerator','Cerebral accelerators are military-grade boosters that significantly increase a new pilot\'s skill development. This technology is usually available only to naval officers, but CONCORD has authorized the release of a small number to particularly promising freelance capsuleers.<br><br>This booster primes the brain\'s neural pathways and hippocampus, making it much more receptive to intensive remapping. This allows new capsuleers to more rapidly absorb information of all kinds.<br><br>The only drawback to this booster is that capsuleer training renders it ineffective after a while; as such, it will cease to function for pilots who have been registered for more than 14 days.<br><br>\r\r\nBonuses: +9 to all attributes',1,1,0,1,NULL,65536.0000,1,NULL,0),(33112,718,'Prototype Cerebral Accelerator Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33117,314,'Bronze Order of the Mountain','The Bronze Order of the Mountain is an ancient Caldari establishment, dating back to the Raata Empire. Those who did great service were inducted into its ranks and initiated into the rites of Mountain Wind. While it has lost the mystic aspects over the centuries, it remains a high honor to be inducted into its ranks.<br><br>\r\r\n Only I can make myself fail.  - Caldari proverb\r\r\n',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(33118,314,'Iron Order of the Storm','Made up of those Caldari who stand resolute in the face of great hardship, the Iron Order of the Storm is considered one of the greatest awards the State can bestow. It draws on the imagery of Storm Wind, whose ferocity cannot be stopped, no matter how many stand against him.<br><br> \r\r\n I shall not stand aside. I must hold; not for my own sake, but for the sake of others.    Yakiya Tovil-Toba\r\r\n',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(33119,314,'Steel Order of the Cold','Created in the early days of the Caldari-Gallente War, the Steel Order of the Cold was awarded to those brave men and women who sacrificed themselves for the Caldari people. It is the greatest capsuleer honor that can be awarded in the State, being given to those who stand resolute and persevere despite all risk.<br><br> \r\r\n Does it matter if we are remembered? Our sacrifice matters.  - Admiral Yakiya Tovil-Toba\'s last speech',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(33120,314,'Badge of Prophet Kuria','The Badge of Prophet Kuria is given to those who show dedication and loyalty to the Amarr Empire. In recent years it has been given to capsuleers who assist the Empire in tasks of great importance.<br><br>\r\r\n Though dissuaded, I came. Though perilous, I served. Though beset, I persevered. Though denied, I believed.  - The Scriptures, Prophet Kuria 12:18\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(33121,314,'Star of the Sefrim','The Star of the Sefrim is awarded to those who go above and beyond the call of duty in service to the Empire, particularly those whose actions place them into mortal danger. While capsuleers rarely risk permanent death, the Empire sometimes acknowledges the loss of body regardless.<br><br>\r\r\n From on high, they came with wisdom and mercy. They delivered greatness to the people. But when provoked, their wroth was immutable. - The Scriptures, Book of Missions, 45:3\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(33122,314,'Senatorial Silver Star','Traditionally, the Senatorial Silver Star was awarded only to those who passed a special vote of the entire Senate. In recent decades, however, a special committee was formed to award it to any capsuleer who toiled to spread and encourage the ideals of the Gallente Federation.<br><br>  \r\r\n Never falter in your ideals.  - Senator Fronte Belliare ',0.1,1,0,1,NULL,0.0000,1,NULL,0),(33123,314,'Gold Medallion of Liberty','The Federation has long encouraged its citizens to stand up against oppression, plight, and wrongdoing. For those capsuleers who, at promise of no gain to themselves, stand brave against tyranny, the Gold Medallion of Liberty is a small acknowledgment of the Federation\'s gratitude.<br><br> \r\r\n It is our duty to spread justice. We cannot allow anyone to oppose that.  - President Arlette Villers \r\r\n',0.1,1,0,1,NULL,0.0000,1,NULL,0),(33124,314,'Platinum Medallion of Freedom','Freedom is the highest ideal of the Gallente Federation and the Platinum Medallion of Freedom is bestowed only on those selected by the President himself. To be awarded this prestigious honor requires the potential for extreme personal harm in order to advance the Federation\'s values throughout New Eden.<br><br> \r\r\n If we do not stand up for peace, how can anyone else?  - President Aidonis Elabon',0.1,1,0,1,NULL,0.0000,1,NULL,0),(33125,314,'Dagger of Coricia','Representing those who have gone through hardship and persevered, the Dagger of Coricia is awarded to individuals who do great service to the Minmatar people. While normally awarded to civil servants, it has been extended to others who fight and suffer on behalf of the Republic as well.<br><br> \r\r\n From the Sobaki Sands a man came with but rags and a dagger. Yet he lived still.  - Excerpt from Vherokior Oral History',1,0.1,0,1,NULL,0.0000,1,NULL,0),(33126,314,'Spear of Matar','It is a rare combination of courage and dedication that earns an individual the Spear of Matar. It is awarded to any person a tribal elder considers worthy of great respect and reverence for their duties to the tribes or the Minmatar people.<br><br>  \r\r\n When the day was dark, it was the million flickers of firelight off the spearheads that gave us courage.  - Excerpt from Krusual Oral History\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(33127,314,'Sword of Pator','Only recently created by act of Sanmatar Shakor, the Sword of Pator is the highest honor that can be awarded capsuleers for service to the Republic. At least four of the seven tribes must be in agreement before it can be awarded, making its conferment a rare and auspicious occasion.<br><br>  \r\r\n Tribe, clan, and family. Together, they are our home. And when they are taken, we will stop at nothing to reclaim them.  - Excerpt from Starkmanir Oral History\r\r\n',1,0.1,0,1,NULL,0.0000,1,NULL,0),(33128,314,'Defense of Caldari Prime Ribbon','This ribbon was awarded to the brave patriots who aided the most against the unprovoked assault against the Titan in orbit of Caldari Prime by the Gallente Federation in YC115. Your bravery and courage will not go unforgotten.<br><br> \r\r\n\"We will not permit you to tell us how to be Caldari, and so you leave us with no choice.\" - Excerpt from the Caldari Proclamation of Secession. CE 23154.11.22',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(33129,314,'Assault on Caldari Prime Ribbon','This ribbon was awarded to the righteous capsuleers who most ably answered the call of duty and assaulted the Titan in orbit of Caldari Prime in YC115. Your efforts to safeguard the lives of Federal citizens will always be remembered.<br><br> \r\r\n\"The savages have murdered the only ones with any sense among them. They lit the fire, now they will burn in it.\" - Senator Fronte Belliare, Morning of Reasoning. CE 23155.2.10\r\r\n',0.1,0.1,0,1,NULL,0.0000,1,NULL,0),(33132,551,'Angel Clone Soldier Trainer ','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations.\r\r\n\r\r\nThis Angel Cartel pirate is a trainer, in charge of funds, equipment and locales used in the preparation and deployment of clone soldiers loyal to the faction. For the Cartel this primarily means keeping the requisite technologies up to date, so that the clone soldiers gain experience with advanced weaponry and learn to operate - or dismantle and destroy - complex machineries while under fire.\r\r\n\r\r\n\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(33134,561,'Guristas Clone Soldier Trainer','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations.\r\r\n\r\r\nThis Guristas pirate is a trainer, in charge of funds, equipment and locales used in the preparation and deployment of clone soldiers loyal to the faction. For the Guristas this involves overseeing training for high-risk high-return operations and ensuring that for the soldiers in training, every shred of the fear of death will be eradicated from their minds by the time they leave the program. For those who survive the training, that is. ',10100000,101000,235,1,1,0.0000,0,NULL,0),(33135,555,'Blood Clone Soldier Trainer','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations.\r\r\n\r\r\nThis Blood Raider pirate is a trainer, in charge of funds, equipment and locales used in the preparation and deployment of clone soldiers loyal to the faction. For the Blood Raiders this mainly involves keeping up a steady supply of nourishing blood of the absolute highest quality, preferably tapped from capsuleers. Or children. ',11800000,118000,235,1,4,0.0000,0,NULL,0),(33136,566,'Sansha Clone Soldier Trainer','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations.\r\r\n\r\r\nThis Sansha\'s Nation pirate is a trainer, in charge of funds, equipment and locales used in the preparation and deployment of clone soldiers loyal to the faction. For the Sansha this involves making sure there\'s a steady supply of slaves who are able to function in various ancillary services, up to and including equipment checks, training grounds maintenance, and training dummies.',10010000,100100,235,1,4,0.0000,0,NULL,0),(33137,571,'Serpentis Clone Soldier Trainer','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations.\r\r\n\r\r\nThis Serpentis pirate is a trainer, in charge of funds, equipment and locales used in the preparation and deployment of clone soldiers loyal to the faction. For the Serpentis this means heavy training in highly involved tactics so that the troops - which are expected to be used extensively - can bring success in a myriad of different circumstances. ',11200000,112000,480,1,8,0.0000,0,NULL,0),(33138,1206,'Clone Soldier Trainer Tag','This tag came from a pirate who had been negotiating combat contracts for pirate-trained clone soldiers.\r\r\n\r\r\nGiven the extraordinary dangers that result from clone soldiers, CONCORD has taken a firm stance against anyone involved with them, and will award a security status boost to the person who brings in these tags. They may be handed in at station Security Offices in low-security space.',0.1,0.1,0,1,NULL,1500000.0000,1,1700,0),(33139,1206,'Clone Soldier Recruiter Tag','This tag came from a pirate who had been negotiating combat contracts for pirate-trained clone soldiers.\r\r\n\r\r\nGiven the extraordinary dangers that result from clone soldiers, CONCORD has taken a firm stance against anyone involved with them, and will award a security status boost to the person who brings in these tags. They may be handed in at station Security Offices in low-security space.',0.1,0.1,0,1,NULL,2000000.0000,1,1700,0),(33140,1206,'Clone Soldier Transporter Tag','This tag came from a pirate who had been negotiating combat contracts for pirate-trained clone soldiers.\r\r\n\r\r\nGiven the extraordinary dangers that result from clone soldiers, CONCORD has taken a firm stance against anyone involved with them, and will award a security status boost to the person who brings in these tags. They may be handed in at station Security Offices in low-security space.',0.1,0.1,0,1,NULL,2500000.0000,1,1700,0),(33141,1206,'Clone Soldier Negotiator Tag','This tag came from a pirate who had been negotiating combat contracts for pirate-trained clone soldiers.\r\r\n\r\r\nGiven the extraordinary dangers that result from clone soldiers, CONCORD has taken a firm stance against anyone involved with them, and will award a security status boost to the person who brings in these tags. They may be handed in at station Security Offices in low-security space.',0.1,0.1,0,1,NULL,3000000.0000,1,1700,0),(33142,566,'Sansha Clone Soldier Recruiter','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Sansha\'s Nation pirate is a recruiter, in charge of scouting vulnerable areas - remote planets, isolated outposts, interstellar colonies and other places that hold human life - with the aim of bringing in new recruits for the pirates\' clone soldier programs. The Sansha have trouble acquiring voluntary recruits at the best of times, and so they\'ve put a lot of effort in finding and training people who can continue fighting beyond even death itself. ',10010000,100100,235,1,4,0.0000,0,NULL,0),(33143,551,'Angel Clone Soldier Recruiter','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Angel Cartel pirate is a recruiter, in charge of scouting vulnerable areas - remote planets, isolated outposts, interstellar colonies and other places that hold human life - with the aim of bringing in new recruits for the pirates\' clone soldier programs. The Cartel are always trying to perfect their technologies, the clone soldier program included, and need new people to test their theories on. \r\r\n\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(33144,555,'Blood Clone Soldier Recruiter ','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Blood Raider pirate is a recruiter, in charge of scouting vulnerable areas - remote planets, isolated outposts, interstellar colonies and other places that hold human life - with the aim of bringing in new recruits for the pirates\' clone soldier programs. The Blood Raiders are always hungry for new blood. ',11800000,118000,235,1,4,0.0000,0,NULL,0),(33145,561,'Guristas Clone Soldier Recruiter','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Guristas pirate is a recruiter, in charge of scouting vulnerable areas - remote planets, isolated outposts, interstellar colonies and other places that hold human life - with the aim of bringing in new recruits for the pirates\' clone soldier programs. The Guristas are constantly in need of those who dare go further than most, and who have no fear of death. ',10100000,101000,235,1,1,0.0000,0,NULL,0),(33146,571,'Serpentis Clone Soldier Recruiter ','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations.\r\r\n\r\r\nThis Serpentis pirate is a recruiter, in charge of scouting vulnerable areas - remote planets, isolated outposts, interstellar colonies and other places that hold human life - with the aim of bringing in new recruits for the pirates\' clone soldier programs. The Serpentis are involved in a complex web of warfare and need a constant supply of good, loyal soldiers to back up their devious plans. ',11200000,112000,480,1,8,0.0000,0,NULL,0),(33147,1207,'Angel Remains','This piece of floating remains look intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33149,1212,'Personal Hangar Array','A large hangar structure, for easy storage of materials and modules.\r\r\n\r\r\nThis hangar is designed for personal storage of moderate volume items, and each individual only has access to their own section of the storage space.',100000000,4000,50000,1,NULL,3744298.0000,1,1702,0),(33150,1048,'Personal Hangar Array Blueprint',' ',0,0.01,0,1,NULL,300000000.0000,1,1701,0),(33151,419,'Brutix Navy Issue','This ship was born out of the experience gained by the Federation after the launch of the Talos-Class Attack Battlecruiser. Sensing that the Brutix hull could be refined further, it was decided to remove all notion of active defense from it to favor improvements to its already significant damage potential. The final outcome of this experiment resulted in the Brutix Navy Issue, a vessel that already shows great potential from the few skirmishes it has been into so far.',11875000,270000,475,1,8,41546462.0000,1,1704,0),(33152,489,'Brutix Navy Issue Blueprint',' ',0,0.01,0,1,NULL,570000000.0000,1,NULL,0),(33153,419,'Drake Navy Issue','After the resounding success tied to the launch of the Drake-class Battlecruiser, the Caldari Navy signed up a massive order to acquire a specific version for its own arsenals. The outcome, the Drake Navy Issue, while sharing a similar look with its step-father, serves a completely different purpose on the battlefield. Being more mobile, able to project missiles more effectively at range, against smaller targets and on a wider selection of damage types, this ship is ideal to support small scale conflicts and raids.',13329000,252000,450,1,1,58052940.0000,1,1704,0),(33154,489,'Drake Navy Issue Blueprint',' ',0,0.01,0,1,NULL,580000000.0000,1,NULL,0),(33155,419,'Harbinger Navy Issue','While the Harbinger is a formidable vessel on its own, recent reports have raised its lack of flexibility as a noteworthy concern in the ever-shifting fleet tactic doctrines. Working hard to correct this problem, Imperial engineers came up with the improved Navy Issue variant. Boasting upgraded tracking systems, enhanced resilience and an advanced medium slot configuration layout, the Harbinger Navy Issue is a radical change over its predecessor, capable of astounding performance in a much wider spectrum of engagements.',13800000,234000,375,1,4,59992552.0000,1,1704,0),(33156,489,'Harbinger Navy Issue Blueprint',' ',0,0.01,0,1,NULL,585000000.0000,1,NULL,0),(33157,419,'Hurricane Fleet Issue','In YC 115, after much heated discussion, CONCORD issued a decree stating the Hurricane-Class Battlecruiser was far too effective to stay under its current technological label, and demanded the Minmatar Republic to either cease production or sort it as a more technologically advanced craft. The Tribal Council grudgingly complied by releasing a simplified version of the Hurricane, then quickly exploited a loophole in the legislation and began using the original overpowered hull as part of its active fleet force. And that is how, after a new paint coat and renaming fees that the Hurricane Fleet Issue came to be.',12500000,216000,425,1,2,57118016.0000,1,1704,0),(33158,489,'Hurricane Fleet Issue Blueprint',' ',0,0.01,0,1,NULL,565000000.0000,1,NULL,0),(33163,566,'Sansha Clone Soldier Transporter','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Sansha\'s Nation pirate is a transporter, responsible for the swift conveyance of clone soldiers to their intended destination. With the Sansha this tends to involve small clusters of isolated populations that are fighting back with every shred of strength they have, and need to be softened up before Nation comes in to bring a final, quiet peace.  ',10010000,100100,235,1,4,0.0000,0,NULL,0),(33164,571,'Serpentis Clone Soldier Transporter','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations.\r\r\n\r\r\nThis Serpentis pirate is a transporter, responsible for the swift conveyance of clone soldiers to their intended destination. With the Serpentis this generally involves areas that, due to high risk, strategic importance or various other cryptic military reasons, need to be assaulted by groups that are small, highly qualified and utterly unrelenting. ',11200000,112000,480,1,8,0.0000,0,NULL,0),(33172,555,'Blood Clone Soldier Transporter','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Blood Raider pirate is a transporter, responsible for the swift conveyance of clone soldiers to their intended destination. With the Blood Raiders that usually means dropping in on areas whose citizens possess an abundance of valuable blood, particularly in the bodies of young children, but who have proven irritatingly resistant to invasion until now.',11800000,118000,235,1,4,0.0000,0,NULL,0),(33173,551,'Angel Clone Soldier Transporter','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Angel Cartel pirate is a transporter, responsible for the swift conveyance of clone soldiers to their intended destination. With the Cartel that usually involves places containing a preponderance of unknown and possibly dangerous technologies to salvage, under circumstances where the enemy is scrambling either to hide those technologies or use them on the Angels.\r\r\n\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(33174,561,'Guristas Clone Soldier Transporter','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Guristas pirate is a transporter, responsible for the swift conveyance of clone soldiers to their intended destination. With the Guristas those destinations tend to be areas so thoroughly abundant in danger, shrouded in uncertainty, and densely populated with enemy numbers that even the most hotheaded pirate faction in the cluster still hesitates to enter the fray with anything less than immortal soldiers.',10100000,101000,235,1,1,0.0000,0,NULL,0),(33175,551,'Angel Clone Soldier Negotiator','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Angel Cartel pirate is a negotiator, a fixer who establishes contracts between pirate-trained clone soldiers and those who have sought out the most technologically advanced pirate faction for a reason - often to do with the extraction of delicate materials under adverse conditions - and who will only trust the most technologically complex forces that the faction has to offer.\r\r\n\r\r\n',10900000,109000,120,1,2,0.0000,0,NULL,0),(33176,1238,'Scan Acquisition Array I','Reduces the scan time of scan probes.\r\r\n\r\r\nOnly one Scan Acquisition Array module can be fitted at max.\r\r\n\r\r\n',0,5,1,1,NULL,82504.0000,1,1709,0),(33177,1239,'Scan Acquisition Array I Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,1707,0),(33178,1223,'Scan Pinpointing Array I','Reduces the scan deviation when scanning with scan probes.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules or rigs that affect the same attribute on the ship will result in diminishing returns.',0,5,1,1,NULL,82504.0000,1,1709,0),(33179,1224,'Scan Pinpointing Array I Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,1707,0),(33180,1223,'Scan Rangefinding Array I','Increases the scan strength when scanning with scan probes.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules or rigs that affect the same attribute on the ship will result in diminishing returns.',0,5,1,1,NULL,82504.0000,1,1709,0),(33181,1224,'Scan Rangefinding Array I Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,1707,0),(33182,555,'Blood Clone Soldier Negotiator','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Blood Raider pirate is a negotiator, a fixer who establishes contracts between pirate-trained clone soldiers and those whose ways of acquiring fresh blood are too dark, violent or dangerous to be stomached by regular soldiers, even in a faction renowned for its gruesome brutality.',11800000,118000,235,1,4,0.0000,0,NULL,0),(33183,566,'Sansha Clone Soldier Negotiator','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Sansha\'s Nation pirate is a negotiator, a fixer who establishes contracts between pirate-trained clone soldiers and those who, despite the horrors of Nation, are drawn like flies to a powerful, unyielding empire staffed by an upper level of geniuses, a lower level of unstoppable drones, and now a section of soldiers that cannot be killed.',10010000,100100,235,1,4,0.0000,0,NULL,0),(33185,571,'Serpentis Clone Soldier Negotiator','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations.\r\r\n\r\r\nThis Serpentis pirate is a negotiator, a fixer who establishes contracts between pirate-trained clone soldiers and those who, like the Serpentis, are playing the long game of strategy and counter-strategy, and whose tactical needs are served best by shadowy associations with a small but unstoppable force of death.',11200000,112000,480,1,8,0.0000,0,NULL,0),(33186,1207,'Angel Debris','This piece of floating debris looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33187,1207,'Angel Mainframe','If you have the right equipment you might be able to hack into the mainframe and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33188,1207,'Angel Info Shard','If you have the right equipment you might be able to hack into the info shard and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33189,561,'Guristas Clone Soldier Negotiator','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. \r\r\n\r\r\nThis Guristas pirate is a negotiator, a fixer who establishes contracts between pirate-trained clone soldiers and those whose missions are so dangerous, so volatile or outright crazy that even the notorious faction of thrillseekers and madmen won\'t dare risk them - except for the small but rapidly growing section that no longer truly needs have any fear of death.',10100000,101000,235,1,1,0.0000,0,NULL,0),(33190,25,'Tash-Murkon Magnate','This Magnate-class frigate is one of the most decoratively designed ship classes in the Amarr Empire, considered to be a pet project for a small, elite group of royal ship engineers for over a decade. The frigate\'s design has gone through several stages over the past decade, and new models of the Magnate appear every few years.<br><br>In recent times the royal Amarr Houses have shown increased interest in the design. House Tash-Murkon came to the fore in Amarr politics only after the fall of another, disgraced house, and while they possess great wealth and considerable power, some feel they do not command the respect of the original, highborn royal Houses. This Magnate is a clear statement by house Tash-Murkon that they possess all the grandeur and powerful grace required to stand beside the most pious of Amarr, and despite a few nattering voices claiming they are yet again trying to purchase divinity, most people applaud the vessel as a proper effort to honor the glory of the Almighty.',1072000,22100,400,1,4,125752.0000,0,NULL,0),(33191,105,'Tash-Murkon Magnate Blueprint',' ',0,0.01,0,1,NULL,2775000.0000,1,NULL,0),(33195,334,'Spatial Attunement Unit','Sensor Component used primarily for scanning equipment. \r\r\n\r\r\nMainly found in Relic sites.     ',1,1,0,1,NULL,6740.0000,1,1147,0),(33196,447,'Spatial Attunement Unit Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,NULL,0),(33197,1238,'Scan Acquisition Array II','Reduces the scan time of scan probes.\r\r\n\r\r\nOnly one Scan Acquisition Array module can be fitted at max.\r\r\n',0,5,1,1,NULL,178151.0000,1,1709,0),(33198,1239,'Scan Acquisition Array II Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,NULL,0),(33199,1223,'Scan Pinpointing Array II','Reduces the scan deviation when scanning with scan probes.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules or rigs that affect the same attribute on the ship will result in diminishing returns.',0,5,1,1,NULL,178151.0000,1,1709,0),(33200,1224,'Scan Pinpointing Array II Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,NULL,0),(33201,1223,'Scan Rangefinding Array II','Increases the scan strength when scanning with scan probes.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules or rigs that affect the same attribute on the ship will result in diminishing returns.',0,5,1,1,NULL,178151.0000,1,1709,0),(33202,1224,'Scan Rangefinding Array II Blueprint',' ',0,0.01,0,1,NULL,600000.0000,1,NULL,0),(33213,1194,'A piece of Steve','Metal scrap retrieved from the destroyed <url=showinfo:11567>Avatar</url> class Titan named Steve.\r\r\n\r\r\nConstructed by the <url=showinfo:16159//327815755>Ascendant Frontier</url> (ASCN) capsuleer alliance with final construction completed on September 9th 2006. Steve was the first ever Titan vessel to be constructed and piloted by a capsuleer.\r\r\n\r\r\nIts primary pilot was <url=showinfo:1376//211311803>CYVOK</url>, <url=showinfo:16159//327815755>ASCN\'</url> executor. Steve was eventually destroyed by the <url=showinfo:16159//632866070>Band of Brothers</url> capsuleer alliance on December 11th 2006 at 18:36 in the <url=showinfo:5//30003109>C9N-CC</url> solar system.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33214,1194,'Band of Brothers Director Access Key','A director level access key for the now closed <url=showinfo:16159//632866070>Band of Brothers</url> capsuleer alliance.\r\r\n\r\r\nNormally deactivated upon the respected owners departure from an alliance, historical events have shown that certain access keys sometimes just never get deactivated.\r\r\n\r\r\nSince the alliance is closed these keys are of no value except to historians.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33215,1194,'Press pass to Prometheus Station opening','An old press pass to the grand opening of the first capsuleer built outpost in New Eden.\r\r\n\r\r\n<url=showinfo:21646//61000002>Prometheus Station</url>, a <url=showinfo:21646>Minmatar Service Outpost</url>, was constructed by the <url=showinfo:16159//327815755>Ascendant Frontier</url> alliance and opened for operational use on August 20th 2005 above <url=showinfo:2016//40283493>planet X</url> of the <url=showinfo:5//30004477>5P-AIP</url> solar system.\r\r\n\r\r\nNote: The stations name has changed since it\'s initial opening and may continue to change over time.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33217,1194,'Lost reminder to pay sov bill','On January 26th 2010 <url=showinfo:2//1000125>CONCORD</url> collected ISK from capsuleer alliances claiming territory in null security space. While most alliances received the reminder to pay their bills certain alliances either chose to ignore it or claimed to have never gotten the reminder.\r\r\n\r\r\nDue to these lost reminders and the subsequent failure to pay by several alliances <loc><url=showinfo:2//1000125>CONCORD</url> revoked their territorial claim on multiple solar systems. Several alliances were effected by this including <url=showinfo:16159//1899990246>Wildly Inappropriate.</url>, <url=showinfo:16159//1411711376>Legion of xXDEATHXx</url>, and most notably <url=showinfo:16159//824518128>GoonSwarm</url>. For both <url=showinfo:16159//1899990246>Wildly Inappropriate.</url> and <url=showinfo:16159//1411711376>Legion of xXDEATHXx</url> the response was simply to pay the bills and reclaim the solar systems. <url=showinfo:16159//824518128>GoonSwarm</url> however was in the middle of a war with <url=showinfo:16159//878776074>IT Alliance</url> over the ownership of <url=showinfo:3//10000060>Delve</url>.\r\r\n\r\r\n<url=showinfo:16159//878776074>IT Alliance</url> used <url=showinfo:16159//824518128>GoonSwarm\'s</url> failure to pay as an opportunity to conquer key systems including what many considered to be the core system of Delve, <url=showinfo:5//30004712>NOL-M9</url>.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33218,1194,'Assassination Contract: Mirial','Target: <url=showinfo:1373//147548395>Mirial</url>\r\r\nContractor: <url=showinfo:2//1280094373>Guiding Hand Social Club</url>\r\r\nFee: 1,000,000,000 ISK\r\r\nRequired proof: Frozen corpse of <url=showinfo:1373//147548395>Mirial</url>\r\r\n\r\r\nDetails: To assassinate and deal as much financial and emotional damage as possible to <url=showinfo:1373//147548395>Mirial</url> - CEO of <url=showinfo:2//1859190473>Ubiqua Seraph</url> and executor of the <url=showinfo:16159//239739827>Aegis Militia</url> alliance.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33219,1194,'Premier ticket for: The last G campaign','Chronicles of War: The last G campaign was released on June 22, 2006 by the capsuleer <url=showinfo:1377//1116448155>Bratwurst0r</url> to great critical acclaim.\r\r\n\r\r\n<url=showinfo:1377//1116448155>Bratwurst0r</url> describes the video as being \"not about ganks, its not about small fights, its not about action only...its more about how the last campaign evolved to the ending of <url=showinfo:16159//521550159>G Alliance</url> and <url=showinfo:16159//295773986>Imperial Republic Of the North</url>.\"\r\r\n\r\r\nThe director of this film wished to offer special thanks to fellow capsuleers <url=showinfo:1377//816290058>RaYmEn</url>, Wuzz, and <url=showinfo:1378//422248131>Seppel da\'FinNI</url>.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33220,1194,'Premier ticket for: Clear Skies','Clear Skies is a three part story created by director <url=showinfo:1376//144571276>John Rourke</url>.\r\r\n\r\r\nUpon the initial release of Clear Skies on May 29, 2008 <url=showinfo:1376//144571276>John Rourke</url> had this to say: \"Two years of my hard work culminated in this, I\'m very proud of it and I hope you like it.\"\r\r\n\r\r\nA year later New Eden was graced with the release of Clear Skies 2 on May 10, 2009. It would be another two years until finally, Clear Skies 3, was released on May 29, 2011; 3 years to the day from when the first Clear Skies was released.\r\r\n\r\r\nUnfortunately for those wanting more Clear Skies <url=showinfo:1376//144571276>John Rourke</url> announced that Clear Skies 3 would be the last and final film in the series.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33221,1194,'Premier ticket for: Day of Darkness','Released by <url=showinfo:1376//700586825>Dire Lauthris</url> (deceased) on April 23, 2007.\r\r\n\r\r\nLater followed by the even more successful Day of Darkness II which was released on March 30, 2009.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33223,1225,'Alliance Tournament I: Band of Brothers','In claiming the title of the first ever Alliance Tournament Champions, <url=showinfo:16159//632866070>Band of Brothers</url> began the first great Tournament dynasty. They would remain undefeated in tournament play for the next two years.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33224,1225,'Alliance Tournament II: Band of Brothers','Establishing themselves as the dominant force in the early tournament years, <url=showinfo:16159//632866070>Band of Brothers</url> had a stellar run in the Second Alliance Tournament capped off with their victory in the first and only Tournament final decided by a 1v1 Interceptor duel tiebreaker.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33225,1225,'Alliance Tournament III: Band of Brothers','<url=showinfo:16159//632866070>Band of Brothers</url> ensured their place in Alliance Tournament history by securing the gold medal in the Third Alliance Tournament. Their three consecutive victories stands as a record that has been tied, but never broken as of YC 115.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33226,1225,'Alliance Tournament III: Cult of War','<url=showinfo:16159//99001003>Cult of War</url> stunned the population of New Eden in their quarter-final match of the Third Alliance Tournament against <url=showinfo:16159//2031941852>Interstellar Alcohol Conglomerate</url> when they destroyed <url=showinfo:16159//2031941852>IAC\'s</url> rare and priceless <url=showinfo:11936>Apocalypse Imperial Issue</url> live on air. The dramatic destruction of this legendary vessel has gone down as one of the memorable moments in Alliance Tournament history.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33227,1225,'Alliance Tournament IV: HUN Reloaded','<url=showinfo:16159//1399057309>HUN Reloaded</url> came out of nowhere to dominate and win the Fourth Alliance Tournament using a novel and effective strategy based around stealth bombers. This performance forever cemented the role of creative setup design as a key focus of top contender teams.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33228,1225,'Alliance Tournament IV: Star Fraction','By the time the Fourth Alliance Tournament began, many pundits in New Eden considered the <url=showinfo:16159//632866070>Band of Brothers</url> team unstoppable. After three years of undefeated dominance and running a team setup claimed as  unbeatable  by their captain, it seemed like nobody could defeat <url=showinfo:16159//632866070>Band of Brothers</url>. That is, until the former champions came up against the <url=showinfo:16159//1439416485>The Star Fraction</url> on the final day of the tournament. With a swift charge of <url=showinfo:627>Thorax</url> cruisers in one of the most memorable matches to ever grace EVE TV, <url=showinfo:16159//1439416485>The Star Fraction</url> defeated the undefeatable and ended the first great Tournament dynasty.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33229,1225,'Alliance Tournament V: Ev0ke','After an excellent run that included victories over defending champions <url=showinfo:16159//1399057309>HUN Reloaded</url> in the quarter-finals and upstart contender <url=showinfo:16159//703129312>Cry Havoc.</url> in the semi-finals, <url=showinfo:16159//1438160193>Ev0ke</url> took the gold medal in the Fifth Alliance Tournament with a viscous <url=showinfo:629>Rupture</url> charge in one of the most exciting finals in Tournament history.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33230,1225,'Alliance Tournament VI: Pandemic Legion','After narrowly missing the crown in the Fourth and Fifth Tournaments, <url=showinfo:16159//386292982>Pandemic Legion</url> began their run of championships with an spectacularly close victory over the venerable  <url=showinfo:16159//627268059>R.U.R.</url> in the finals.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33231,1225,'Alliance Tournament VII: Pandemic Legion','Firmly establishing themselves as one of the great Tournament dynasties, <url=showinfo:16159//386292982>Pandemic Legion</url> appeared to effortlessly push aside their competition in the Seventh Alliance Tournament, punctuated by masterful use of the underrated stealth bombers.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33232,1225,'Alliance Tournament VIII: Pandemic Legion','In the Eighth Alliance Tournament <url=showinfo:16159//386292982>Pandemic Legion</url> became the first alliance to tie the <url=showinfo:16159//632866070>Band of Brothers</url> record with three consecutive gold medals. Their dominant performance was capped off with a finals victory over the emerging Tournament superpower of <url=showinfo:16159//551692893>HYDRA RELOADED</url>.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33233,1207,'Angel Ruins','This piece of floating ruins looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33234,1207,'Angel Rubble','This piece of floating rubble looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33235,1207,'Angel Databank','If you have the right equipment you might be able to hack into the databank and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33236,1207,'Angel Com Tower','If you have the right equipment you might be able to hack into the com tower and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33237,1207,'Blood Debris','This piece of floating debris looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33238,1207,'Blood Rubble','This piece of floating rubble looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33239,1207,'Blood Remains','This piece of floating remains look intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33240,1207,'Blood Ruins','This piece of floating ruins looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33241,1207,'Blood Info Shard','If you have the right equipment you might be able to hack into the info shard and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33242,1207,'Blood Com Tower','If you have the right equipment you might be able to hack into the com tower and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33243,1207,'Blood Mainframe','If you have the right equipment you might be able to hack into the mainframe and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33244,1207,'Blood Databank','If you have the right equipment you might be able to hack into the databank and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33245,1207,'Guristas Debris','This piece of floating debris looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33246,1207,'Guristas Rubble','This piece of floating rubble looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33247,1207,'Guristas Remains','This piece of floating remains look intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33248,1207,'Guristas Ruins','This piece of floating ruins looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33249,1207,'Guristas Info Shard','If you have the right equipment you might be able to hack into the info shard and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33251,1207,'Guristas Com Tower','If you have the right equipment you might be able to hack into the com tower and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33252,1207,'Guristas Mainframe','If you have the right equipment you might be able to hack into the mainframe and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33253,1207,'Guristas Databank','If you have the right equipment you might be able to hack into the databank and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33254,1207,'Serpentis Debris','This piece of floating debris looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33255,1207,'Serpentis Rubble','This piece of floating rubble looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33256,1207,'Serpentis Remains','This piece of floating remains look intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33257,1207,'Serpentis Ruins','This piece of floating ruins looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33258,1207,'Serpentis Info Shard','If you have the right equipment you might be able to hack into the info shard and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33259,1207,'Serpentis Com Tower','If you have the right equipment you might be able to hack into the com tower and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33260,1207,'Serpentis Mainframe','If you have the right equipment you might be able to hack into the mainframe and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33261,1207,'Serpentis Databank','If you have the right equipment you might be able to hack into the databank and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33262,1207,'Sansha Debris','This piece of floating debris looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33263,1207,'Sansha Rubble','This piece of floating rubble looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33264,1207,'Sansha Remains','This piece of floating remains look intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33265,1207,'Sansha Ruins','This piece of floating ruins looks intriguing, but requires analyzing equipment before it yields any of its secrets.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33266,1207,'Sansha Info Shard','If you have the right equipment you might be able to hack into the info shard and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33267,1207,'Sansha Com Tower','If you have the right equipment you might be able to hack into the com tower and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33268,1207,'Sansha Mainframe','If you have the right equipment you might be able to hack into the mainframe and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33269,1207,'Sansha Databank','If you have the right equipment you might be able to hack into the databank and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33270,1226,'Survey Probe Launcher I','Launcher for <a href=showinfo:18635>Survey Probes</a>.\r\r\n\r\r\n<a href=showinfo:18635>Survey Probes</a> are used to analyze the material composition of moons.\r\r\n\r\r\nNote: Only one survey probe launcher can be fitted per ship.',0,5,10,1,NULL,6670.0000,1,1717,0),(33271,1227,'Survey Probe Launcher I Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,1716,0),(33272,1226,'Survey Probe Launcher II','Launcher for <a href=showinfo:18635>Survey Probes</a>.\r\r\n\r\r\n<a href=showinfo:18635>Survey Probes</a> are used to analyze the material composition of moons.\r\r\n\r\r\nNote: Only one survey probe launcher can be fitted per ship.\r\r\n',0,5,10,1,NULL,114738.0000,1,1717,0),(33273,1227,'Survey Probe Launcher II Blueprint',' ',0,0.01,0,1,NULL,60000.0000,1,NULL,0),(33277,778,'Capital Drone Control Range Augmentor I','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33278,787,'Capital Drone Control Range Augmentor I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1721,0),(33279,778,'Capital Drone Control Range Augmentor II','This ship modification is designed to increase a ship\'s drone control range at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33280,787,'Capital Drone Control Range Augmentor II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(33281,778,'Capital Drone Durability Enhancer I','This ship modification is designed to increase a ship\'s drone shield, armor and structure hit points at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33282,787,'Capital Drone Durability Enhancer I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1721,0),(33283,778,'Capital Drone Durability Enhancer II','This ship modification is designed to increase a ship\'s drone shield, armor and structure hit points at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33284,787,'Capital Drone Durability Enhancer II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(33285,778,'Capital Drone Mining Augmentor I','This ship modification is designed to increase a ship\'s mining drone yield at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33286,787,'Capital Drone Mining Augmentor I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1721,0),(33287,778,'Capital Drone Mining Augmentor II','This ship modification is designed to increase a ship\'s mining drone yield at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33288,787,'Capital Drone Mining Augmentor II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(33289,778,'Capital Drone Repair Augmentor I','This ship modification is designed to increase a ship\'s drone repair amount at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33290,787,'Capital Drone Repair Augmentor I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1721,0),(33291,778,'Capital Drone Repair Augmentor II','This ship modification is designed to increase a ship\'s drone repair amount at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33292,787,'Capital Drone Repair Augmentor II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(33293,778,'Capital Drone Scope Chip I','This ship modification is designed to increase a ship\'s drone optimal range at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33294,787,'Capital Drone Scope Chip I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1721,0),(33295,778,'Capital Drone Scope Chip II','This ship modification is designed to increase a ship\'s drone optimal range at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33296,787,'Capital Drone Scope Chip II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(33297,778,'Capital Drone Speed Augmentor I','This ship modification is designed to increase a ship\'s drone max velocity at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',200,40,0,1,NULL,0.0000,1,1739,0),(33298,778,'Capital Drone Speed Augmentor II','This ship modification is designed to increase a ship\'s drone max velocity at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1739,0),(33299,787,'Capital Drone Speed Augmentor I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1721,0),(33300,787,'Capital Drone Speed Augmentor II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(33301,779,'Capital Hydraulic Bay Thrusters II','This ship modification is designed to increase missile velocity at the expense of increased CPU requirements for launchers.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1733,0),(33302,787,'Capital Hydraulic Bay Thrusters II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(33303,781,'Capital Processor Overclocking Unit I','This ship modification is designed to increase a ship\'s CPU.\r\r\n\r\r\nPenalty: - 5% Shield Recharge Rate Bonus.\r\r\n',200,40,0,1,NULL,0.0000,1,1736,0),(33304,787,'Capital Processor Overclocking Unit I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1724,0),(33305,781,'Capital Processor Overclocking Unit II','This ship modification is designed to increase a ship\'s CPU.\r\r\n\r\r\nPenalty: - 10% Shield Recharge Rate Bonus.',200,40,0,1,NULL,0.0000,1,1736,0),(33306,787,'Capital Processor Overclocking Unit II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(33307,778,'Capital Sentry Damage Augmentor I','This ship modification is designed to increase a ship\'s sentry drone damage at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1739,0),(33308,787,'Capital Sentry Damage Augmentor I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1721,0),(33309,778,'Capital Sentry Damage Augmentor II','This ship modification is designed to increase a ship\'s sentry drone damage at the expense of the ship\'s CPU capacity.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,NULL,0.0000,1,1739,0),(33310,787,'Capital Sentry Damage Augmentor II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(33311,778,'Capital Stasis Drone Augmentor I','This ship modification is designed to increase a ship\'s stasis web drones\' factor of velocity decrease at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33312,787,'Capital Stasis Drone Augmentor I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1721,0),(33313,778,'Capital Stasis Drone Augmentor II','This ship modification is designed to increase a ship\'s stasis web drones\' factor of velocity decrease at the expense of the ship\'s CPU capacity.',200,40,0,1,NULL,0.0000,1,1739,0),(33314,787,'Capital Stasis Drone Augmentor II Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,NULL,0),(33315,728,'Occult Parity','Balanced decryptor for Amarr that increases the likelihood of successful invention considerably, while still providing nice supplementary benefits with just a slight increase in production time.<br><br>Probability Multiplier: +50% <br> Max. Run Modifier: +3 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: -2',1,1,0,1,NULL,0.0000,1,NULL,0),(33316,728,'Optimized Occult Augmentation','A rare and valuable Amarr decryptor that gives solid boost to number of runs an invented BPC will have, plus improved mineral efficiency, with just a slight decrease in invention success.<br><br>Probability Multiplier: -10% <br>Max. Run Modifier: +7 <br>Material Efficiency Modifier: +2 <br>Time Efficiency Modifier: 0',1,1,0,1,NULL,0.0000,1,NULL,0),(33317,728,'Optimized Occult Attainment','A rare and valuable Amarr decryptor that dramatically increases your chance for success at invention. Gives minor benefit to material efficiency at the expense of slight increase in production time.<br><br>Probability Multiplier: +90% <br>Max. Run Modifier: +2 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: -2',1,1,0,1,NULL,0.0000,1,NULL,0),(33318,729,'Cryptic Parity','Balanced decryptor for Minmatar that increases the likelihood of successful invention considerably, while still providing nice supplementary benefits with just a slight increase in production time.<br><br>Probability Multiplier: +50% <br>Max. Run Modifier: +3 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: -2',1,1,0,1,NULL,0.0000,1,NULL,0),(33319,731,'Esoteric Parity','Balanced decryptor for Caldari that increases the likelihood of successful invention considerably, while still providing nice supplementary benefits with just a slight increase in production time.<br><br>Probability Multiplier: +50% <br>Max. Run Modifier: +3 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: -2',1,1,0,1,NULL,0.0000,1,NULL,0),(33320,730,'Incognito Parity','Balanced Gallente decryptor that increases the likelihood of successful invention considerably, while still providing nice supplementary benefits with just a slight increase in production time.<br><br>Probability Multiplier: +50% <br>Max. Run Modifier: +3 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: -2',1,1,0,1,NULL,0.0000,1,NULL,0),(33321,729,'Optimized Cryptic Augmentation','A rare and valuable Minmatar decryptor that gives solid boost to number of runs an invented BPC will have, plus improved material efficiency, with just a slight decrease in invention success.<br><br>Probability Multiplier: -10% <br>Max. Run Modifier: +7 <br>Material Efficiency Modifier: +2 <br>Time Efficiency Modifier: 0',1,1,0,1,NULL,0.0000,1,NULL,0),(33322,731,'Optimized Esoteric Augmentation','A rare and valuable Caldari decryptor that gives solid boost to number of runs an invented BPC will have, plus improved material efficiency, with just a slight decrease in invention success.<br><br>Probability Multiplier: -10% <br>Max. Run Modifier: +7 <br>Material Efficiency Modifier: +2 <br>Time Efficiency Modifier: 0',1,1,0,1,NULL,0.0000,1,NULL,0),(33323,730,'Optimized Incognito Augmentation','A rare and valuable Gallente decryptor that gives solid boost to number of runs an invented BPC will have, plus improved mineral efficiency, with just a slight decrease in invention success.<br><br>Probability Multiplier: -10% <br>Max. Run Modifier: +7 <br>Material Efficiency Modifier: +2 <br>Time Efficiency Modifier: 0',1,1,0,1,NULL,0.0000,1,NULL,0),(33324,729,'Optimized Cryptic Attainment','A rare and valuable Minmatar decryptor that dramatically increases your chance for success at invention. Gives minor benefit to material efficiency at the expense of slight increase in production time.<br><br>Probability Multiplier: +90% <br>Max. Run Modifier: +2 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: -2',1,1,0,1,NULL,0.0000,1,NULL,0),(33325,731,'Optimized Esoteric Attainment','A rare and valuable Caldari decryptor that dramatically increases your chance for success at invention. Gives minor benefit to mineral efficiency at the expense of slight increase in production time.<br><br>Probability Multiplier: +90% <br>Max. Run Modifier: +2 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: -2',1,1,0,1,NULL,0.0000,1,NULL,0),(33326,730,'Optimized Incognito Attainment','A rare and valuable Gallente decryptor that dramatically increases your chance for success at invention. Gives minor benefit to material efficiency at the expense of slight increase in production time.<br><br>Probability Multiplier: +90% <br>Max. Run Modifier: +2 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: -2',1,1,0,1,NULL,0.0000,1,NULL,0),(33327,489,'Gnosis Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33328,29,'Capsule - Genolution \'Auroral\' 197-variant','This hydrostatic capsule is a unique variant on the standard model. Its golden sheen is nominally decorative material, whose role and purpose are highly classified and which dissipates entirely upon reprocessing. It is known that the capsule\'s regular building materials are intermixed with traces of another matter, the exact nature of which remains unknown to everyone outside Genolution\'s research facilities, even the capsuleers themselves. \r\r\n\r\r\nTheories on the subject include Fullerene Intercalated Graphite polymer for better function of internal parts without the added heat of internal friction; a meld of Fullerite-C320 and Fullerite-C540 for an extra-strength shell that can better withstand the rigors of continued operation under stress (albeit not, sadly, withstand a few direct hits from another vessel\'s weapon), or just a thin coating of some newly invented sheen compound.\r\r\n\r\r\nThe capsule\'s primary function remains to keep the capsuleer alive - even to the point of sending their consciousness to a nearby cloning vat, in the event of imminent obliteration - and allowing for the operation of the massive interstellar vessels in which the capsule is usually encased. This variant can only be operated by those capsuleers wearing the <a href=showinfo:33329>Genolution \'Auroral\' AU-79</a> implant, and will be automatically replaced upon destruction.',32000,1000,0,1,16,0.0000,0,NULL,0),(33329,300,'Genolution \'Auroral\' AU-79','This implant allows the bearer to operate the <a href=showinfo:33328>Genolution \'Auroral\' 197-variant</a> capsule instead of the standard type. Once installed, the implant is a permanent part of the capsuleer\'s brain (unless intentionally removed by the wearer), and according to contracts with the Genolution corp a fresh copy will be reinserted in every new clone activated by the capsuleer.\r\r\n\r\r\nThis implant is not removed during podding or clone jumping.',0,1,0,1,16,800000.0000,1,1814,0),(33330,87,'Navy Cap Booster 25','Provides a quick injection of power into your capacitor. Good for tight situations!',2.5,0.75,100,10,NULL,1098.0000,1,139,0),(33332,87,'Navy Cap Booster 50','Provides a quick injection of power into your capacitor. Good for tight situations!',5,1.5,100,10,NULL,2824.0000,1,139,0),(33334,87,'Navy Cap Booster 75','Provides a quick injection of power into your capacitor. Good for tight situations!',7.5,2.25,100,10,NULL,5582.0000,1,139,0),(33336,428,'Thulium Hafnite','Despite its unremarkable gray appearance, Thulium Hafnite has proven to be extremely effective as shielding against electromagnetic radiation and free neutrons. It is a valuable component in the production of processor and capacitor technologies, especially in the Gallente Federation.',0,1,0,1,NULL,320.0000,1,500,0),(33337,428,'Promethium Mercurite','A metallic radioactive compound, Promethium Mercurite emits a faint green glow visible to the naked eye. It is a crucial part of a new generation of processors and capacitor units being developed by the Amarr Empire.',0,1,0,1,NULL,320.0000,1,500,0),(33338,428,'Unrefined Promethium Mercurite','A metallic radioactive compound, Promethium Mercurite emits a faint green glow visible to the naked eye. It is a crucial part of a new generation of processors and capacitor units being developed by the Amarr Empire.',0,1,0,1,NULL,320.0000,1,500,0),(33339,428,'Unrefined Thulium Hafnite','Despite its unremarkable gray appearance, Thulium Hafnite has proven to be extremely effective as shielding against electromagnetic radiation and free neutrons. It is a valuable component in the production of processor and capacitor technologies, especially in the Gallente Federation.',0,1,0,1,NULL,320.0000,1,500,0),(33340,436,'Thulium Hafnite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(33341,436,'Promethium Mercurite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(33342,436,'Unrefined Thulium Hafnite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(33343,436,'Unrefined Promethium Mercurite Reaction',' ',0,1,0,1,NULL,1000000.0000,1,1850,0),(33352,571,'Serpentis Cruiser','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(33359,429,'Photonic Metamaterials','A carefully engineered latticework designed to for precise optical control, photonic metamaterials are a component in advanced Gallente microprocessors and capacitor units.',0,1,0,1,NULL,3500.0000,1,499,0),(33360,429,'Terahertz Metamaterials','An advanced composite designed to manipulate electromagnetic waves just beyond the microwave band, terahertz metamaterials are found in the latest generation of processors and capacitor units in the Amarr Empire.',0,1,0,1,NULL,3500.0000,1,499,0),(33361,429,'Plasmonic Metamaterials','Carefully fabricated composites of neo mercurite and fernite alloy, plasmonic metamaterials are a key component in advanced Minmatar processors and capacitor units.',0,1,0,1,NULL,3500.0000,1,499,0),(33362,429,'Nonlinear Metamaterials','Labs in the Caldari State have recently managed to construct the first known composites with negative refractive indexes. Known as nonlinear metamaterials, these advanced composites are finding increasing use in the State\'s latest capacitor units and microprocessors.',0,1,0,1,NULL,3500.0000,1,499,0),(33363,484,'Nonlinear Metamaterials Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(33364,484,'Photonic Metamaterials Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(33365,484,'Plasmonic Metamaterials Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(33366,484,'Terahertz Metamaterials Reaction',' ',0,1,0,1,NULL,5000000.0000,1,1851,0),(33367,1207,'Tutorial Hacking','The wrecked container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33368,1207,'Tutorial Archaeology','The wrecked container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33373,1225,'Alliance Tournament IX: HYDRA RELOADED and 0utbreak','After a bitter finals defeat the previous year, <url=showinfo:16159//551692893>HYDRA RELOADED</url> entered the Ninth Alliance Tournament with something to prove. They played the field and metagame masterfully, shrugging aside all their opponents and ensuring a first-second place finish for themselves and their close allies in <url=showinfo:16159//99000648>Outbreak.</url>. A botched attempt to put on a show finals created controversy and forced changes to future Tournament rules, but the skill and dedication of the pilots in these two alliances was undeniable.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33374,1225,'Alliance Tournament X: Verge of Collapse','Underestimated all throughout the Tenth Alliance Tournament, <url=showinfo:16159//99001968>Verge of Collapse</url> proved the power of the underdog with their stunning victories over such heavyweights as <url=showinfo:16159//605845106>DarkSide.</url>, <url=showinfo:16159//1354830081>Goonswarm Federation</url>, <url=showinfo:16159//927292903>Rote Kapelle</url>, <url=showinfo:16159//99000964>Mildly Intoxicated</url> and <url=showinfo:16159//99000852>Exodus.</url>. Their victory over <url=showinfo:16159//1399057309>HUN Reloaded</url> in the finals demonstrated their mastery of the format, and it is unlikely that anyone will underestimate them again. ',0,0.01,0,1,NULL,0.0000,1,1812,0),(33375,353,'QA Cross Protocol Analyzer','This module does not exist',0,5,0,1,NULL,37776.0000,1,NULL,0),(33377,1084,'Sleeve - \'Drone\' (left)','After they merged with the controls of gargantuan space vessels and moved beyond the confines of death itself, it\'s an open question whether capsuleers can even be considered purely human. This tattoo resembles one of New Eden\'s most nightmarish creatures, a relentless force of destruction whose mind has become entirely alien to the civilizations of New Eden. It\'s no wonder some capsuleers feel a strange fellowship with them.',0,0.1,0,1,NULL,0.0000,1,1822,0),(33378,1084,'Sleeve - \'Wreckage\' (left)','For an immortal master of dangerous technological wonders, it can be hard to retain or even recall the connection to the natural cycle of life. This tattoo is a reminder that death for a capsuleer, though only fleeting, is omnipresent and will always leave its mark, and that one person\'s precious, perfect engine of war will eventually - through accident, scheming, or a second\'s forgetfulness  - become someone else\'s wreckage to calmly pick clean.',0,0.1,0,1,NULL,0.0000,1,1822,0),(33379,1084,'Sleeve - \'Prototype\' (left)','The entwining of human and machine defines a capsuleer\'s life - each can\'t function without the other - and it may be argued that together they compose a new organism, one that shucks off both of its skins for fresh ones when needed. Some capsuleers try to express that even though parts of them are composed of machinery - from the implants in their heads all the way up to the massive ships they control - all of it is really only a cover for a human being. Or the other way around.',0,0.1,0,1,NULL,0.0000,1,1822,0),(33380,1084,'Sleeve - \'Nature\' (left)','Amidst all the carnage they see (and sometimes create), capsuleers also rejoice in the beauty of the natural world. In this tattoo, some see the Achuran songbird flitting through the air, amidst the trills of song. Some see the Slaver Hound, its senses like deadly radar, leaping over the grounds of a sunbaked colony. Some even see a thousand stars looking down on living planets hurtling through their orbits. And a few, because there\'s always a few of that sort, doggedly persist in seeing a Fedo.',0,0.1,0,1,NULL,0.0000,1,1822,0),(33381,1084,'Sleeve - \'Drone\' (right)','After they merged with the controls of gargantuan space vessels and moved beyond the confines of death itself, it\'s an open question whether capsuleers can even be considered purely human. This tattoo resembles one of New Eden\'s most nightmarish creatures, a relentless force of destruction whose mind has become entirely alien to the civilizations of New Eden. It\'s no wonder some capsuleers feel a strange fellowship with them.',0,0.1,0,1,NULL,0.0000,1,1822,0),(33382,1084,'Sleeve - \'Wreckage\' (right)','For an immortal master of dangerous technological wonders, it can be hard to retain or even recall the connection to the natural cycle of life. This tattoo is a reminder that death for a capsuleer, though only fleeting, is omnipresent and will always leave its mark, and that one person\'s precious, perfect engine of war will eventually - through accident, scheming, or a second\'s forgetfulness  - become someone else\'s wreckage to calmly pick clean.',0,0.1,0,1,NULL,0.0000,1,1822,0),(33383,1084,'Sleeve - \'Prototype\' (right)','The entwining of human and machine defines a capsuleer\'s life - each can\'t function without the other - and it may be argued that together they compose a new organism, one that shucks off both of its skins for fresh ones when needed. Some capsuleers try to express that even though parts of them are composed of machinery - from the implants in their heads all the way up to the massive ships they control - all of it is really only a cover for a human being. Or the other way around.',0,0.1,0,1,NULL,0.0000,1,1822,0),(33384,1084,'Sleeve - \'Nature\' (right)','Amidst all the carnage they see (and sometimes create), capsuleers also rejoice in the beauty of the natural world. In this tattoo, some see the Achuran songbird flitting through the air, amidst the trills of song. Some see the Slaver Hound, its senses like deadly radar, leaping over the grounds of a sunbaked colony. Some even see a thousand stars looking down on living planets hurtling through their orbits. And a few, because there\'s always a few of that sort, doggedly persist in seeing a Fedo.',0,0.1,0,1,NULL,0.0000,1,1822,0),(33385,1225,'Alliance Tournament I: KAOS Empire','Making their mark in the first ever Alliance Tournament, <url=showinfo:16159//900209169>Kaos Empire</url> won victory after victory with stunning efficiency and coordination. After defeating well respected opponents like <url=showinfo:16159//1220922756>Red Alliance</url> and <url=showinfo:16159//497302911>The Five</url>, <url=showinfo:16159//900209169>Kaos</url> finally met their match in a nailbiter final match against <url=showinfo:16159//632866070>Band of Brothers</url>, winning the first ever Alliance Tournament Silver Medal.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33386,1225,'Alliance Tournament III: Interstellar Alcohol Conglomerate','The <url=showinfo:2//1280094373>Guiding Hand Social Club</url> and <url=showinfo:1373//144870255>Tyrrax Thorrk</url> have flown in the Tournament under multiple alliance banners. They have had a strong presence in the Alliance Tournament from the beginning, including a semi-final performance for their <url=showinfo:16159//2031941852>Interstellar Alcohol Conglomerate</url> team in the Second Alliance Tournament. However it is their ATIII <url=showinfo:16159//2031941852>IAC</url> team that made the biggest mark on history. Building their core strategy around cap warfare supported by the massive capacitor pool of a rare and priceless <url=showinfo:11936>Apocalypse Imperial Issue</url>, <url=showinfo:16159//2031941852>IAC</url> made short work of most opponents until facing off against <url=showinfo:16159//99001003>Cult of War</url> who managed to counter the <url=showinfo:16159//2031941852>IAC</url> nosferatu and destroy the <url=showinfo:11936>Apocalypse Imperial Issue</url> to the amazement of the crowd. No Tournament team before or since has put such a rare ship on the line in their pursuit of victory.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33387,1225,'Alliance Tournament IV: Pandemic Legion','Entering the Tournament world with a bang, <url=showinfo:16159//386292982>Pandemic Legion\'s</url> first ever team took great advantage of sensor dampener tactics to go on an impressive run to the finals, knocking out Tournament stalwarts <url=showinfo:16159//2031941852>Interstellar Alcohol Conglomerate</url>, ending <url=showinfo:16159//1439416485>The Star Fraction\'s</url> string of heroic victories, and defeating a <url=showinfo:16159//488282414>Terra Incognita.</url> team full of legendary PVP pilots. They were swiftly defeated in the finals by <url=showinfo:16159//1399057309>HUN Reloaded</url>, but this early silver medal would turn out to be a portent of future success.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33388,1225,'Alliance Tournament V: Triumvirate','Well known PVP alliance <url=showinfo:16159//933731581>Triumvirate.</url> entered the Fifth Alliance Tournament with high expectations and did not disappoint. <url=showinfo:16159//933731581>Triumvirate.</url> relied on Battleships supported by Disruption Frigates for many victories, including a nail-biter semi-final win over <url=showinfo:16159//386292982>Pandemic Legion</url>. They were narrowly defeated by <url=showinfo:16159//1438160193>Ev0ke\'s</url> <url=showinfo:629>Rupture</url> Cruisers in one of the closest and most exciting finals in Tournament history.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33389,1225,'Alliance Tournament VIII: HYDRA RELOADED','Emerging as a new powerhouse on the Tournament landscape, the <url=showinfo:16159//551692893>HYDRA RELOADED</url> team in the Eighth Alliance Tournament easily stood out from the pack both on and off the field. They crushed all opposition until the finals, and their metagame duels of will with arch-nemesis <url=showinfo:16159//386292982>Pandemic Legion</url> between the matches became the stuff of legend. Although defeated by <url=showinfo:16159//386292982>Pandemic Legion</url> in the finals, they would eventually have their revenge in the subsequent year.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33390,1225,'Alliance Tournament VI: R.U.R.','Alternating between the alliances <url=showinfo:16159//627268059>R.U.R.</url> and <url=showinfo:16159//1002884793>THE R0NIN</url> but remaining a powerful Tournament threat, the members of <url=showinfo:16159//627268059>R.U.R.</url> are the most accomplished tournament team to not yet have a Gold medal (as of YC 115). One of their many strong performances was in the Sixth Alliance Tournament where their impressive run was only ended by <url=showinfo:16159//386292982>Pandemic Legion</url> in an extremely memorable final match that came down to the wire.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33391,1225,'Alliance Tournament IX: Darkside.','Newcomers a year before in the Eighth Alliance Tournament, <url=showinfo:16159//605845106>DarkSide.</url> had quickly made a name for themselves with a quarter-final performance that year. In the Ninth Alliance Tournament they catapulted themselves into Tournament history by ending the reign of <url=showinfo:16159//386292982>Pandemic Legion</url> and knocking them out in convincing fashion. In one fell swoop they blew the Tournament field wide open and made <url=showinfo:1378//717397234>Shadoo</url> the happiest man in the world.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33392,1225,'Alliance Tournament X: HUN Reloaded','After their victory in the Fourth Alliance Tournament, <url=showinfo:16159//1399057309>HUN Reloaded</url> had struggled to return to the top tier of teams for years. By the Tenth Alliance Tournament many had begun to discount them as old news. They proved their stature as long-term Tournament heavyweights with a brilliant performance in ATX, riding a versatile core of <url=showinfo:28665>Vargur</url> Marauders with ever-shifting support to the finals, including a strategic outmaneuvering of <url=showinfo:16159//386292982>Pandemic Legion</url> in the semi-finals. They will be looking to improve on their Silver medal performance in YC 115 s ATXI and return to the pinnacle they once ruled.',0,0.01,0,1,NULL,0.0000,1,1812,0),(33393,300,'Genolution Core Augmentation CA-3','<font color=\"yellow\"><b>Traits</b></font><br>Slot 3<br>Primary Effect: +3 bonus to Willpower<br>Secondary Effect: +1.5% bonus to ship velocity and shield capacity<br>Implant Set Effect: 30% bonus to the strength of all Genolution implant secondary effects<br><br><font color=\"yellow\"><b>Development</b></font><br>\r\r\nSince the introduction of the groundbreaking \"Core Augmentation\" series in YC 113, all eyes have been on Genolution\'s advanced R&D department in anticipation of their next release. Few if any were disappointed with the announcement of the CA-3.<br><br>Rumors that Genolution had managed to reverse-engineer Angel Cartel implant technology continued to spread as the CA-3 successfully allows a capsuleer increased ship velocity, complemented by extra shield capacity and a parietal lobe enhancement for stronger Willpower. Like the CA-1 and CA-2 before them, these new additions to the \"Core Augmentation\" line contain advanced interoperability functions that allows their sum to be greater than their parts.<br><br>Genolution\'s press releases indicated that this new batch of implants would be available to capsuleers in limited numbers, but after the experience of the CA-1 and CA-2 nobody believes them.',0,1,0,1,NULL,800000.0000,1,620,0),(33394,300,'Genolution Core Augmentation CA-4','<font color=\"yellow\"><b>Traits</b></font><br>Slot 2<br>Primary Effect: +3 bonus to Memory<br>Secondary Effect: +1.5% bonus to ship agility and armor hit points<br>Implant Set Effect: 20% bonus to the strength of all Genolution implant secondary effects<br><br><font color=\"yellow\"><b>Development</b></font><br>\r\r\nAlongside the introduction of the CA-3 implant, Genolution further expanded its \"Core Augmentation\" line with the new CA-4. Taking full advantage of Genolution\'s formidable research and development team, the CA-4 continues to squeeze even more powerful features into the most significant implant collection to be released in years.<br><br>The combination of a temporal lobe implant for extra memory augmentation and a new series of armor and agility enhancements makes the CA-4 stand out from the crowd. However, the most impressive feature of the implant is that Genolution has managed to squeeze even more benefits out of their implant integration technology to ensure that each part of the \"Core Augmentation\" line enhances the benefits of each of its peers.<br><br>After the release of these groundbreaking implants there is only one question left on everyone\'s mind: How much further can Genolution safely push the limits of their technology?',0,1,0,1,NULL,800000.0000,1,619,0),(33395,833,'Moracha','The Moracha is what goes bump in the night. Built to be the ultimate tool of piracy and terror, this Recon Ship combines the electronic warfare and covert abilities of its class with the speed and ferocity that Angel Cartel cruisers are known for. The first ever capsuleer ship to use the Ixion ship hull, the distinctive appearance of the Moracha goes along with incredible combat capabilities that make it ideal for both solo and wolfpack hunting.\r\r\n\r\r\n',8700000,100000,320,1,2,11579728.0000,1,1837,0),(33396,106,'Moracha Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33397,830,'Chremoas','The Chremoas is the Angel Cartel\'s take on the Covert Ops ship. Don\'t let the class designation fool you, the Chremoas is a more than capable combat vessel that takes advantage of a covert cloak, advanced targeting systems previously only seen on stealth bombers, and ample medium power module slots to pick and control the fights it knows it can win. By the time you see a Chremoas decloak, the fight is already over.',930000,28000,190,1,2,346080.0000,1,1838,0),(33398,105,'Chremoas Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33399,1220,'Infomorph Synchronizing','Psychological training that strengthens the pilot\'s mental tenacity. Improved ability to synchronize with new clones allows pilots to jump-clone more frequently without risk of neural damage.\r\r\n\r\r\nReduced time between clone jumps by 1 hour per level.\r\r\n\r\r\nNote: Clones can only be installed in stations with medical facilities or in ships with clone vat bays. Installed clones are listed in the character sheet.',0,0.01,0,1,NULL,5000000.0000,1,1746,0),(33400,515,'Bastion Module I','An electronic interface designed to augment and enhance a marauder\'s siege abilities. Through a series of electromagnetic polarity field shifts, the bastion module diverts energy from the ship\'s propulsion and warp systems to lend additional power to its defensive capabilities.\r\r\n\r\r\nThis results in a greatly increased rate of defensive self-sustenance and a boost to the ship\'s overall damage resistances. It also extends the reach of all the vessel\'s weapon systems, allowing it to engage targets at farther ranges. Due to the ionic field created by the bastion module, most remote effects - from friend or foe both - will not affect the ship while in bastion mode.  All weapons, including energy vampires and destabilizers, are unaffected by this field leaving the ship capacitor as one of the only vulnerable points to be found.\r\r\n \r\r\n\r\r\nIn addition, the lack of power to mobility subsystems means that neither standard propulsion nor warp travel are available to the ship, nor is it allowed to dock or jump until out of bastion mode.\r\r\n\r\r\nNote: Only one bastion module can be fitted to a marauder-class ship. The amount of shield boost gained from the bastion module is subject to a stacking penalty when used with other modules that affect the same attribute on the ship.',1,200,0,1,NULL,6519034.0000,1,801,0),(33401,516,'Bastion Module I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,343,0),(33403,744,'Imperial Navy Warfare Mindlink','This advanced interface link produced for the Imperial Navy and its allies drastically improves a commander\'s Armored Warfare and Information Warfare abilities by directly linking to the Structural Integrity Monitors and sensor arrays of all ships in the fleet.\r\r\n\r\r\n25% increase to the command bonus of Armored Warfare and Information Warfare Link modules.\r\r\n\r\r\nReplaces Armored Warfare skill bonus with fixed 15% armor HP bonus.\r\r\nReplaces Information Warfare skill bonus with fixed 15% targeting range bonus.',0,1,0,1,4,200000.0000,1,1505,0),(33404,744,'Federation Navy Warfare Mindlink','This advanced interface link produced for the Federation Navy and its allies drastically improves a commander\'s Armored Warfare and Skirmish Warfare abilities by directly linking to the Structural Integrity Monitors and navigation systems of all ships in the fleet.\r\r\n\r\r\n25% increase to the command bonus of Armored Warfare and Skirmish Warfare Link modules.\r\r\n\r\r\nReplaces Armored Warfare skill bonus with fixed 15% armor HP bonus.\r\r\nReplaces Skirmish Warfare skill bonus with fixed 15% agility bonus.',0,1,0,1,8,200000.0000,1,1505,0),(33405,744,'Republic Fleet Warfare Mindlink','This advanced interface link produced for the Republic Fleet and its allies drastically improves a commander\'s siege warfare and skirmish warfare abilities by directly linking to the active shield systems and navigation systems of all ships in the fleet. \r\r\n\r\r\n25% increase to the command bonus of Siege Warfare and Skirmish Warfare Link modules.\r\r\n\r\r\nReplaces Siege Warfare skill bonus with fixed 15% shield HP bonus.\r\r\nReplaces Skirmish Warfare skill bonus with fixed 15% agility bonus.',0,1,0,1,2,0.0000,1,1505,0),(33406,744,'Caldari Navy Warfare Mindlink','This advanced interface link produced for the Caldari Navy drastically improves a commander\'s siege warfare and information warfare abilities by directly linking to the active shield systems and sensor arrays of all ships in the fleet. \r\r\n\r\r\n25% increase to the command bonus of Siege Warfare and Information Warfare Link modules.\r\r\n\r\r\nReplaces Siege Warfare skill bonus with fixed 15% shield HP bonus.\r\r\nReplaces Information Warfare skill bonus with fixed 15% targeting range bonus.',0,1,0,1,1,0.0000,1,1505,0),(33407,1220,'Advanced Infomorph Psychology','Advanced training for those Capsuleers who want to push clone technology to its limits.\r\r\n\r\r\nAllows 1 additional jump clone per level.\r\r\n\r\r\nNote: Clones can only be installed in stations with medical facilities or in ships with clone vat bays. Installed clones are listed in the character sheet. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font> ',0,0.01,0,1,4,36000000.0000,1,1746,0),(33440,1245,'\'Arbalest\' Rapid Heavy Missile Launcher I','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.72,1,NULL,89998.0000,1,1827,0),(33441,1245,'\'Limos\' Rapid Heavy Missile Launcher I','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.72,1,NULL,89998.0000,1,1827,0),(33442,1245,'\'Malkuth\' Rapid Heavy Missile Launcher I','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.72,1,NULL,89998.0000,1,1827,0),(33446,1245,'Caldari Navy Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.78,1,NULL,288234.0000,1,1827,0),(33447,136,'Caldari Navy Rapid Heavy Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33448,1245,'Rapid Heavy Missile Launcher I','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.72,1,NULL,185676.0000,1,1827,0),(33449,136,'Rapid Heavy Missile Launcher I Blueprint',' ',0,0.01,0,1,NULL,749970.0000,1,340,0),(33450,1245,'Rapid Heavy Missile Launcher II','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.75,1,NULL,874138.0000,1,1827,0),(33451,136,'Rapid Heavy Missile Launcher II Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33452,1245,'Domination Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.78,1,NULL,134944.0000,1,1827,0),(33453,1245,'Dread Guristas Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.78,1,NULL,134944.0000,1,1827,0),(33454,1245,'Estamel\'s Modified Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.85,1,NULL,134944.0000,1,1827,0),(33455,1245,'Gotan\'s Modified Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.85,1,NULL,134944.0000,1,1827,0),(33456,1245,'Hakim\'s Modified Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.85,1,NULL,134944.0000,1,1827,0),(33457,1245,'Kaikka\'s Modified Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.85,1,NULL,134944.0000,1,1827,0),(33458,1245,'Mizuro\'s Modified Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.85,1,NULL,134944.0000,1,1827,0),(33459,1245,'Republic Fleet Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.78,1,NULL,288234.0000,1,1827,0),(33460,136,'Republic Fleet Rapid Heavy Missile Launcher Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33461,1245,'Shaqil\'s Modified Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.85,1,NULL,134944.0000,1,1827,0),(33462,1245,'Thon\'s Modified Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.85,1,NULL,134944.0000,1,1827,0),(33463,1245,'Tobias\' Modified Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.85,1,NULL,134944.0000,1,1827,0),(33464,1245,'True Sansha Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.78,1,NULL,134944.0000,1,1827,0),(33465,1245,'Vepas\' Modified Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.85,1,NULL,134944.0000,1,1827,0),(33466,1245,'YO-5000 Rapid Heavy Missile Launcher','Launcher for battleships intended to counter smaller combat ships such as frigates and cruisers, can only be loaded with heavy missiles.',0,20,0.72,1,NULL,89998.0000,1,1827,0),(33467,274,'Customs Code Expertise','Expertise in cutting through the red tape of customs regulations. Reduces Import and Export empire tax in Customs Offices by 10% per level.\r\r\n\r\r\nThis does not affect InterBus Customs Offices.\r\r\n',0,0.01,0,1,NULL,3000000.0000,1,378,0),(33468,25,'Astero','This was one of the first vessels the Sisters of EVE made available to capsuleers. It had been under development by the Sanctuary corporation, whose interest in exploration includes not only search & rescue operations but also a constant inquiry into the nature of the EVE Gate. Thanks to the Sisters\' efforts and the Sanctuary\'s particular expertise, the Astero is an agile, tenacious ship that aptly adheres to the mantra of both rescuers and explorers: Stay safe, stay hidden, and use every tool at your disposal. \r\r\n\r\r\nIt is particularly adept at venturing into dangerous territories, not merely in recovering whatever may be of interest but also in being able to safely bring it back. Its engines have alternate power sources that come into play should any of its cargo - for which it has plenty of room - cause serious interference with internal systems. Its carapace is extremely well armored for a ship this agile, and covered in sensors capable of letting its crew track a myriad of different organic signatures. The crew itself is safely protected from any number of transmittable ailments from rescues and other unexpected passengers, thanks to special quarantine bays that are conveniently located near jettisonable openings. \r\r\n\r\r\nAnd lastly, an ingenious but cryptic transfer in part of the warp core functionality to an outlying cylindrical structure means the Astero is able to run certain higher-level cloaking functions with very little technical cost, and minimal interference from warp. The Sisters of EVE have refused to comment on this technology, other than to recommend it not be tampered with.',975000,16500,210,1,8,352588.0000,1,1365,0),(33469,105,'Astero Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33470,26,'Stratios','This was one of the first vessels the Sisters of EVE made available to capsuleers. It had been under development by the Sanctuary corporation, whose interest in exploration includes not only search & rescue operations but also a constant inquiry into the nature of the EVE Gate. Thanks to the Sisters\' efforts and the Sanctuary\'s particular expertise, the Stratios is an agile, tenacious ship that aptly adheres to the mantra of both rescuers and explorers: Stay safe, stay hidden, and use every tool at your disposal. \r\r\n\r\r\nIt is particularly adept at venturing into dangerous territories, not merely in recovering whatever may be of interest but also in being able to safely bring it back. Its engines have alternate power sources that come into play should any of its cargo - for which it has plenty of room - cause serious interference with internal systems. Its weaponry runs best on renewable sources, an ideal for a ship that doesn\'t know how long it\'ll be in deep space. Its carapace is extremely well armored for a ship this agile, and covered in sensors capable of letting its crew track a myriad of different organic signatures. The crew itself is safely protected from any number of transmittable ailments from rescues and other unexpected passengers, thanks to special quarantine bays that are conveniently located near jettisonable openings. \r\r\n\r\r\nAnd lastly, an ingenious but cryptic transfer in part of the warp core functionality to an outlying cylindrical structure means the Stratios is able to run certain higher-level cloaking functions with very little technical cost, and minimal interference from warp. The Sisters of EVE have refused to comment on this technology, other than to recommend it not be tampered with.',9350000,101000,550,1,8,11579728.0000,1,1371,0),(33471,106,'Stratios Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33472,27,'Nestor','This was one of the first vessels the Sisters of EVE made available to capsuleers. It had been under development by the Sanctuary corporation, whose interest in exploration includes not only search & rescue operations but also a constant inquiry into the nature of the EVE Gate. Thanks to the Sisters\' efforts and the Sanctuary\'s particular expertise, the Nestor is an agile, tenacious ship that aptly adheres to the mantra of both rescuers and explorers: Stay safe, stay hidden, and use every tool at your disposal. \r\r\n\r\r\nIt is particularly adept at venturing into dangerous territories, not merely in recovering whatever may be of interest but also in being able to safely bring it back. Its engines have alternate power sources that come into play should any of its cargo - for which it has plenty of room - cause serious interference with internal systems. Its weaponry runs best on renewable sources, an ideal for a ship that doesn\'t know how long it\'ll be in deep space. Its carapace is extremely well armored for a ship this agile, and covered in sensors capable of letting its crew track a myriad of different organic signatures. The crew itself is safely protected from any number of transmittable ailments from rescues and other unexpected passengers, thanks to special quarantine bays that are conveniently located near jettisonable openings. \r\r\n\r\r\nThe Sanctuary corporation poured uncountable resources into making the cloaking technology developed for the Stratios fit the Nestor, but were eventually forced to concede that it was impossible.  The effort was not without benefit though, as part of their work focused on reducing the Nestor\'s mass enough that it could make its way into unexplored territories that might\'ve been hazardous to bulkier vessels. This paid off by affording the Nestor unmatched access to wormhole space, and meant that the embedded miniature rescue vessel on the ship\'s hull could be relegated to a decommissioned role. With covert function off the table, the Sanctuary turned their eyes on logistics and now the Nestor serves as one of the best support platforms in New Eden.\r\r\n',20000000,486000,700,1,8,157405934.0000,1,1380,0),(33473,107,'Nestor Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33474,1246,'Mobile Depot','The mobile depot provides capsuleers with their very own base in space. It won\'t offer protection - no one is ever truly safe in New Eden - but once deployed and activated it can, at the very least, allow the capsuleer to store their most valuable belongings when under fire, and to refit their ship to better fight back against assailants.\r\r\n\r\r\nOne minute activation time.\r\r\n\r\r\nMay not be deployed within 6km of another Mobile Depot, within 50km of Stargates or Stations, or within 40km of a Starbase.\r\r\nAutomatically decays if abandoned for thirty days.',10000,50,3000,1,NULL,933344.0000,1,1831,0),(33475,1250,'Mobile Tractor Unit','The mobile tractoring unit takes some of the work out of looting the scorched ruins left by capsuleers, be it pulverized asteroids, wrecked ships, or obliterated inhabitation modules of various kinds. Once it has been deployed and completed its automatic activation process, it will lock on to any containers or wrecks within range, reel them in one by one, and empty their contents into its own cargo bay. All the capsuleer needs to do is keep up the pace of destruction.\r\r\n\r\r\n125km effective range.\r\r\n10 second activation time.\r\r\n\r\r\nMay not be deployed within 5km of another Mobile Tractor Unit, within 50km of Stargates or Stations, or within 40km of a Starbase.\r\r\nAutomatically decays if abandoned for two days.',10000,100,27000,1,NULL,4036356.0000,1,1833,0),(33476,1249,'Mobile Cynosural Inhibitor','This structure, once deployed and having completed its automatic activation process, will prevent nearly all cynosural fields being activated within its range. Covert fields can still be used, which is why it is up to the intrepid capsuleer to maintain a relaxed situational awareness, go about their daily duties, and mercilessly shoot out of the sky any black ops infiltrators who might have made it through.\r\r\n\r\r\n100km effective range\r\r\nTwo minute activation time.\r\r\n\r\r\nMay not be deployed within 200km of another Mobile Cynosural Inhibitor, within 75km of Stargates or Stations, or within 40km of a Starbase. Cannot be retrieved once deployed.\r\r\nSelf-destructs after one hour of operation.',10000,300,0,1,NULL,33230852.0000,1,1832,0),(33477,1247,'Small Mobile Siphon Unit','A small personal deployable that steals material from player owned structures (POS). The Small Mobile Siphon Unit can steal Raw Material from Moon Harvesters and Processed Material from Simple Reactors. The stolen materials are stored in the unit and are accessible by anyone.\r\r\n\r\r\nThe Siphon Unit uses an advanced morphing technology to mask itself as being part of the POS. This allows it to infiltrate the production line of the POS and escape the attention of its defenses.',10000,35,900,1,NULL,9041038.0000,1,1835,0),(33478,1247,'Medium Mobile Siphon Unit','The Siphon Unit uses an advanced morphing technology to mask itself as being part of the POS. This allows it to infiltrate the production line of the POS and escape the attention of its defenses.',10000,100,5000,1,NULL,0.0000,0,NULL,0),(33479,1247,'Large Mobile Siphon Unit','The Siphon Unit uses an advanced morphing technology to mask itself as being part of the POS. This allows it to infiltrate the production line of the POS and escape the attention of its defenses.',10000,500,10000,1,NULL,0.0000,0,NULL,0),(33480,319,'Mobile Shipping Unit','A container with internal transportation mechanism. Used for quick shipments of low-volume items.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(33481,226,'Mobile Shipping Unit','A container with internal transportation mechanism. Used for quick shipments of low-volume items.',0,0,0,1,NULL,0.0000,0,NULL,0),(33482,1248,'Minmatar 1M Bounty Reimbursement Tag','This tag can be sold at a Republic Fleet station. It is worth 1 million ISK.',0.1,0.01,0,1,2,1000000.0000,1,1846,0),(33483,1248,'Caldari 10M Bounty Reimbursement Tag','This tag can be sold at a Caldari Navy station. It is worth 10 million ISK.',0.1,0.01,0,1,1,10000000.0000,1,1846,0),(33484,1248,'Amarr 1M Bounty Reimbursement Tag ','This tag can be sold at an Imperial Navy station. It is worth 1 million ISK.',0.1,0.01,0,1,4,1000000.0000,1,1846,0),(33485,1248,'Gallente 1M Bounty Reimbursement Tag','This tag can be sold at a Federation Navy station. It is worth 1 million ISK.',0.1,0.01,0,1,8,1000000.0000,1,1846,0),(33486,747,'QA Warp Accelerator','This implant does not exist.',0,1,0,1,NULL,200000.0000,0,NULL,0),(33487,1089,'Women\'s \'Luxury\' T-shirt','This item indicates that as part of society\'s very elite - the ones who wear whatever they want, fly wherever they like, and reign over the lives of others like mercurial gods - you are invited to the most exclusive of events in every part of the cluster. Live a life of boundless, reckless, hedonistic luxury, where nothing, not even death itself, stands in the way of your desires.',0.5,0.1,0,1,NULL,0.0000,1,1406,0),(33488,1089,'Men\'s \'Luxury\' T-shirt','This item indicates that as part of society\'s very elite - the ones who wear whatever they want, fly wherever they like, and reign over the lives of others like mercurial gods - you are invited to the most exclusive of events in every part of the cluster. Live a life of boundless, reckless, hedonistic luxury, where nothing, not even death itself, stands in the way of your desires.',0.5,0.1,0,1,NULL,0.0000,1,1398,0),(33489,186,'Ship Maintenance Array Wreck','Destroyed remains of a Ship Maintenance Array; before anything of value can be salvaged from it all surviving ships must be ejected out of the wreck into space.',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(33490,186,'X-Large Ship Maintenance Array Wreck','Destroyed remains of an X-Large Ship Maintenance Array; before anything of value can be salvaged from it all surviving ships must be ejected out of the wreck into space.',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(33491,1252,'Angel Warden','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(33492,1252,'Angel Lookout','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(33493,1252,'Angel Watcher','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(33494,1252,'Angel Sentry','This is a fighter for the Arch Angels. It is protecting the assets of Arch Angels and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10900000,109000,120,1,2,0.0000,0,NULL,0),(33495,1255,'Blood Warden','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(33496,1255,'Blood Lookout','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(33497,1255,'Blood Watcher','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(33498,1255,'Blood Sentry','This is a fighter for the Blood Raiders. It is protecting the assets of Blood Raiders and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11800000,118000,235,1,4,0.0000,0,NULL,0),(33499,1259,'Guristas Warden','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(33500,1259,'Guristas Lookout','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(33501,1259,'Guristas Watcher','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(33502,1259,'Guristas Sentry','This is a fighter for the Guristas. It is protecting the assets of Guristas and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10100000,101000,235,1,1,0.0000,0,NULL,0),(33503,1265,'Sansha\'s Nation Warden','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(33504,1265,'Sansha\'s Nation Lookout','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(33505,1265,'Sansha\'s Nation Watcher','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(33506,1265,'Sansha\'s Nation Sentry','This is a fighter for Sansha\'s Nation. It is protecting the assets of Sansha\'s Nation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',10010000,100100,235,1,4,0.0000,0,NULL,0),(33507,1262,'Serpentis Warden','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(33508,1262,'Serpentis Lookout','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(33509,1262,'Serpentis Watcher','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(33510,1262,'Serpentis Sentry','This is a fighter for the Serpentis Corporation. It is protecting the assets of the Serpentis Corporation and may attack anyone it perceives as a threat or easy pickings. Threat level: Deadly',11200000,112000,480,1,8,0.0000,0,NULL,0),(33512,747,'QA Agility Booster','This implant does not exist.',0,1,0,1,NULL,200000.0000,0,NULL,0),(33513,31,'Leopard','Rumor has it the Leopard originated as a secret project in the Minmatar Republic. In their endless battle against enslavement by the Amarr Empire, the Minmatar have had to develop ways not only to liberate large masses of their people, but also to sneak in and capture individuals of high strategic importance. \r\r\n\r\r\nThese kinds of black ops search-and-rescue missions might be executed for key people who were held by the enemy and possessed either special qualities the resistance needed, or information the Republic couldn\'t afford having tortured out of them. It\'s notable that these individuals might not all have been Minmatar, and that the resistance movement is unlikely to have restrained itself from using the same methods on key Amarr people they\'d captured with the help of the Leopard.\r\r\n\r\r\nIt is an extremely fast ship, meant for quick and stealthy getaways, and while its origins are covered in rumors, chances are the Minmatar leaked it to the capsuleers in order to curry favor with them.',1600000,5000,10,1,2,5556.0000,1,1618,0),(33514,111,'Republic Justice Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,NULL,0),(33515,1267,'Small Mobile Siphon Unit Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1834,0),(33516,300,'High-grade Ascendancy Alpha','This ocular filter has been modified by Sisters of Eve scientists for use by their elite officers.<br><br>Primary Effect: +4 bonus to Perception.<br>Secondary Effect: 1% bonus to warp speed<br>Set Effect: 15% bonus to the strength of all Ascendancy implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33517,1269,'Mobile Depot Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,1828,0),(33518,1268,'Mobile Cynosural Inhibitor Blueprint',' ',0,0.01,0,1,NULL,150000000.0000,1,1829,0),(33519,1270,'Mobile Tractor Unit Blueprint',' ',0,0.01,0,1,NULL,30000000.0000,1,1830,0),(33520,1246,'\'Wetu\' Mobile Depot','The mobile depot provides capsuleers with their very own base in space. It won\'t offer protection - no one is ever truly safe in New Eden - but once deployed and activated it can, at the very least, allow the capsuleer to store their most valuable belongings when under fire, and to refit their ship to better fight back against assailants.\r\r\n\r\r\nOne minute activation time.\r\r\n\r\r\nMay not be deployed within 6km of another Mobile Depot, within 50km of Stargates or Stations, or within 40km of a Starbase.\r\r\nAutomatically decays if abandoned for thirty days.',10000,100,4000,1,NULL,933344.0000,1,1831,0),(33521,1269,'\'Wetu\' Mobile Depot Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,NULL,0),(33522,1246,'\'Yurt\' Mobile Depot','The mobile depot provides capsuleers with their very own base in space. It won\'t offer protection - no one is ever truly safe in New Eden - but once deployed and activated it can, at the very least, allow the capsuleer to store their most valuable belongings when under fire, and to refit their ship to better fight back against assailants.\r\r\n\r\r\nOne minute activation time.\r\r\n\r\r\nMay not be deployed within 6km of another Mobile Depot, within 50km of Stargates or Stations, or within 40km of a Starbase.\r\r\nAutomatically decays if abandoned for thirty days.',10000,50,4000,1,NULL,933344.0000,1,1831,0),(33523,1269,'\'Yurt\' Mobile Depot Blueprint',' ',0,0.01,0,1,NULL,1000000.0000,1,NULL,0),(33525,300,'High-grade Ascendancy Beta','This memory augmentation has been modified by Sisters of Eve scientists for use by their elite officers.<br><br>Primary Effect: +4 bonus to Memory.<br>Secondary Effect: 2% bonus to warp speed<br>Set Effect: 15% bonus to the strength of all Ascendancy implant secondary effects',0,1,0,1,NULL,800000.0000,1,619,0),(33526,300,'High-grade Ascendancy Delta','This cybernetic subprocessor has been modified by Sisters of Eve scientists for use by their elite officers.<br><br>Primary Effect: +4 bonus to Intelligence.<br>Secondary Effect: 4% bonus to warp speed<br>Set Effect: 15% bonus to the strength of all Ascendancy implant secondary effects',0,1,0,1,NULL,800000.0000,1,621,0),(33527,300,'High-grade Ascendancy Epsilon','This social adaptation chip has been modified by Sisters of Eve scientists for use by their elite officers.<br><br>Primary Effect: +4 bonus to Charisma.<br>Secondary Effect: 5% bonus to warp speed<br>Set Effect: 15% bonus to the strength of all Ascendancy implant secondary effects',0,1,0,1,NULL,800000.0000,1,622,0),(33528,300,'High-grade Ascendancy Gamma','This neural boost has been modified by Sisters of Eve scientists for use by their elite officers.<br><br>Primary Effect: +4 bonus to Willpower.<br>Secondary Effect: 3% bonus to warp speed<br>Set Effect: 15% bonus to the strength of all Ascendancy implant secondary effects',0,1,0,1,NULL,800000.0000,1,620,0),(33529,300,'High-grade Ascendancy Omega','This implant does nothing in and of itself, but when used in conjunction with other Ascendancy implants it will boost their effect.<br><br>70% bonus to the strength of all Ascendancy implant secondary effects.',0,1,0,1,NULL,800000.0000,1,1506,0),(33530,306,'Secure Depot','If you have the right equipment you might be able to hack into the com tower and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33531,306,'Secure Lab','If you have the right equipment you might be able to hack into the com tower and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33532,306,'Secure Databank','If you have the right equipment you might be able to hack into the com tower and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33533,306,'Secure Mainframe','If you have the right equipment you might be able to hack into the com tower and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33534,306,'Secure Vault','If you have the right equipment you might be able to hack into the com tower and get some valuable information.',10000,27500,2700,1,NULL,0.0000,0,NULL,0),(33536,724,'High-grade Ascendancy Alpha Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33538,186,'Mobile Structure Wreck','The remains of a destroyed structure. Perhaps with the proper equipment something of value could be salvaged from it.',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(33539,526,'Shattered Villard Wheel','This item appears to be a collection of Villard Wheel parts barely hanging together.<br><br>Villard Wheels are believed to have originated thousands of years ago as highly complex wooden contraptions that were embedded in wagon wheels and various other designs, primarily in areas where sparks and heat might cause catastrophic reactions with local materials both earthbound and airborne. The Villard Wheels allowed for an immensly rapid revolution of moving parts with almost no heat from friction, and the principles behind them were later put to use in the space industries of New Eden\'s various factions. Under normal circumstances they are nearly unbreakable.<br><br>This particular unit, however, is completely shattered, scorched and covered in soot. Some subparts may still be useable for those of a tinkering persuasion, but others can only wonder at what type of madman could or would push a Villard Wheel to go too fast, and for what infernal purpose.',25,1,0,1,NULL,0.0000,1,20,0),(33543,724,'High-grade Ascendancy Beta Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33545,724,'High-grade Ascendancy Gamma Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33546,724,'High-grade Ascendancy Epsilon Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33547,724,'High-grade Ascendancy Delta Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33548,724,'High-grade Ascendancy Omega Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33549,1271,'Women\'s \'Phanca\' Cybernetic Arm (left)','This item, whose full designator is the F-706.574 \'Phanca\' Cybernetic Arm, is unique among heavily mechanized capsuleer accoutrements in that rather than focusing primarily on the future, it draws on a dark part of ancient empire history - one that\'s either completely barbaric or unquestionably devout, depending who you ask.\r\r\n\r\r\nIts origins lie in an Amarr decree where a member of the oligarchy - who was whimsical, powerful and, it is speculated, quite astoundingly insane during the tail end of her life- demanded that all current and future heirs of a particular royal house have their right hand amputated. They acquiesced, but had the hands replaced with cybernetic models in a silver coating.\r\r\n\r\r\nThe first heir who suffered this fate took great pride in it, and his silver hand is on display in the open court of the Amarr Royal palace. When capsuleers - themselves the unquestionable elite of New Eden - started taking to cybernetic arms, it was only natural that this be one of the first models put into public use.',0,0.1,0,1,NULL,0.0000,1,1836,0),(33550,1271,'Women\'s \'Phanca\' Cybernetic Arm (right)','This item, whose full designator is the F-706.574 \'Phanca\' Cybernetic Arm, is unique among heavily mechanized capsuleer accoutrements in that rather than focusing primarily on the future, it draws on a dark part of ancient empire history - one that\'s either completely barbaric or unquestionably devout, depending who you ask.\r\r\n\r\r\nIts origins lie in an Amarr decree where a member of the oligarchy - who was whimsical, powerful and, it is speculated, quite astoundingly insane during the tail end of her life- demanded that all current and future heirs of a particular royal house have their right hand amputated. They acquiesced, but had the hands replaced with cybernetic models in a silver coating.\r\r\n\r\r\nThe first heir who suffered this fate took great pride in it, and his silver hand is on display in the open court of the Amarr Royal palace. When capsuleers - themselves the unquestionable elite of New Eden - started taking to cybernetic arms, it was only natural that this be one of the first models put into public use.',0,0.1,0,1,NULL,0.0000,1,1836,0),(33551,1271,'Men\'s \'Phanca\' Cybernetic Arm (left)','This item, whose full designator is the F-706.574 \'Phanca\' Cybernetic Arm, is unique among heavily mechanized capsuleer accoutrements in that rather than focusing primarily on the future, it draws on a dark part of ancient empire history - one that\'s either completely barbaric or unquestionably devout, depending who you ask.\r\r\n\r\r\nIts origins lie in an Amarr decree where a member of the oligarchy - who was whimsical, powerful and, it is speculated, quite astoundingly insane during the tail end of her life- demanded that all current and future heirs of a particular royal house have their right hand amputated. They acquiesced, but had the hands replaced with cybernetic models in a silver coating.\r\r\n\r\r\nThe first heir who suffered this fate took great pride in it, and his silver hand is on display in the open court of the Amarr Royal palace. When capsuleers - themselves the unquestionable elite of New Eden - started taking to cybernetic arms, it was only natural that this be one of the first models put into public use.',0,0.1,0,1,NULL,0.0000,1,1836,0),(33552,1271,'Men\'s \'Phanca\' Cybernetic Arm (right)','This item, whose full designator is the F-706.574 \'Phanca\' Cybernetic Arm, is unique among heavily mechanized capsuleer accoutrements in that rather than focusing primarily on the future, it draws on a dark part of ancient empire history - one that\'s either completely barbaric or unquestionably devout, depending who you ask.\r\r\n\r\r\nIts origins lie in an Amarr decree where a member of the oligarchy - who was whimsical, powerful and, it is speculated, quite astoundingly insane during the tail end of her life- demanded that all current and future heirs of a particular royal house have their right hand amputated. They acquiesced, but had the hands replaced with cybernetic models in a silver coating.\r\r\n\r\r\nThe first heir who suffered this fate took great pride in it, and his silver hand is on display in the open court of the Amarr Royal palace. When capsuleers - themselves the unquestionable elite of New Eden - started taking to cybernetic arms, it was only natural that this be one of the first models put into public use.',0,0.1,0,1,NULL,0.0000,1,1836,0),(33553,26,'Stratios Emergency Responder','The Stratios Emergency Responder is a variation on the Stratios designed by the Sanctuary specifically for fast assessment and evaluation of major cosmic events in New Eden.  Its official role to quickly appraise incidents of all kinds and relay information back to the Sisters of EVE also serves as an opportunity to take care of any sensitivities before they become apparent to external parties.\r\r\n\r\r\nIt is particularly adept at venturing into dangerous territories, not merely in recovering whatever may be of interest but also in being able to safely bring it back. Its engines have alternate power sources that come into play should any of its cargo - for which it has plenty of room - cause serious interference with internal systems. Its weaponry runs best on renewable sources, an ideal for a ship that doesn\'t know how long it\'ll be in deep space. Its carapace is extremely well armored for a ship this agile, and covered in sensors capable of letting its crew track a myriad of different organic signatures. The crew itself is safely protected from any number of transmittable ailments from rescues and other unexpected passengers, thanks to special quarantine bays that are conveniently located near jettisonable openings. \r\r\n\r\r\nAnd lastly, an ingenious but cryptic transfer in part of the warp core functionality to an outlying cylindrical structure means the Stratios Emergency Responder is able to run certain higher-level cloaking functions with very little technical cost, and minimal interference from warp. The Sisters of EVE have refused to comment on this technology, other than to recommend it not be tampered with.',9350000,101000,550,1,8,11579728.0000,1,NULL,0),(33554,106,'Stratios Emergency Responder Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33555,300,'Mid-grade Ascendancy Alpha','This ocular filter has been modified by Sisters of Eve scientists for use by their elite officers.<br><br>Primary Effect: +3 bonus to Perception.<br>Secondary Effect: 1% bonus to warp speed<br>Set Effect: 10% bonus to the strength of all Ascendancy implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33556,724,'Mid-grade Ascendancy Alpha Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33557,300,'Mid-grade Ascendancy Beta','This memory augmentation has been modified by Sisters of Eve scientists for use by their elite officers.<br><br>Primary Effect: +3 bonus to Memory.<br>Secondary Effect: 2% bonus to warp speed<br>Set Effect: 10% bonus to the strength of all Ascendancy implant secondary effects',0,1,0,1,NULL,800000.0000,1,619,0),(33558,724,'Mid-grade Ascendancy Beta Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33559,300,'Mid-grade Ascendancy Delta','This cybernetic subprocessor has been modified by Sisters of Eve scientists for use by their elite officers.<br><br>Primary Effect: +3 bonus to Intelligence.<br>Secondary Effect: 4% bonus to warp speed<br>Set Effect: 10% bonus to the strength of all Ascendancy implant secondary effects',0,1,0,1,NULL,800000.0000,1,621,0),(33560,724,'Mid-grade Ascendancy Delta Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33561,300,'Mid-grade Ascendancy Epsilon','This social adaptation chip has been modified by Sisters of Eve scientists for use by their elite officers.<br><br>Primary Effect: +3 bonus to Charisma.<br>Secondary Effect: 5% bonus to warp speed<br>Set Effect: 10% bonus to the strength of all Ascendancy implant secondary effects',0,1,0,1,NULL,800000.0000,1,622,0),(33562,724,'Mid-grade Ascendancy Epsilon Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33563,300,'Mid-grade Ascendancy Gamma','This neural boost has been modified by Sisters of Eve scientists for use by their elite officers.<br><br>Primary Effect: +3 bonus to Willpower.<br>Secondary Effect: 3% bonus to warp speed<br>Set Effect: 10% bonus to the strength of all Ascendancy implant secondary effects',0,1,0,1,NULL,800000.0000,1,620,0),(33564,724,'Mid-grade Ascendancy Gamma Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33565,300,'Mid-grade Ascendancy Omega','This implant does nothing in and of itself, but when used in conjunction with other Ascendancy implants it will boost their effect.<br><br>35% bonus to the strength of all Ascendancy implant secondary effects.',0,1,0,1,NULL,800000.0000,1,1506,0),(33566,724,'Mid-grade Ascendancy Omega Blueprint',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(33569,500,'Snowball',' ',100,0.1,0,100,NULL,0.0000,1,1663,0),(33571,500,'Sodium Firework',' ',100,0.1,0,100,NULL,0.0000,1,1663,0),(33572,500,'Barium Firework',' ',100,0.1,0,100,NULL,0.0000,1,1663,0),(33573,500,'Copper Firework',' ',100,0.1,0,100,NULL,0.0000,1,1663,0),(33574,226,'Exploration Monument','This is a monument to Marcus Yeon and all other intrepid explorers who put their lives (and, more often than not, the lives of everyone in the neighboring vicinity) on the line for the glory of exploring the unknown.',1700000,19700,305,1,NULL,0.0000,0,NULL,0),(33575,1194,'Hull Tanking, Elite','This certificate represents an elite level of competence in the infamous practice of \"hull tanking\". It certifies that the holder can fully use all modules relating to hull tanking. The holder is aware that \"real men hull tank\", and also that hull tanking is really dumb. With this certificate, you\'ve maximised your ability to rely on your structural systems to absorb damage, although hopefully you\'re smart enough to know what a daft idea that is.\r\r\n\r\r\nDuring a certificate system restructuring, CONCORD issued a physical copy of this certificate to ensure that those elite hull tankers would always be recognized (at least by themselves).',0.01,0.01,0,1,NULL,0.0000,1,1661,0),(33577,314,'Covert Research Tools','These tools seem to have been prepared for use in low-level experiments of a highly cryptic nature. What exactly will be done with them is an open question, but they appear to be intended for some manner of data gathering under adverse and possibly explosive conditions..',1,0.1,0,1,NULL,500000.0000,1,1840,0),(33578,1089,'Men\'s \'Humanitarian\' T-shirt YC 115','This highly prestigious item of clothing was created in YC 115 and presented to New Eden\'s charitable societies. The shirt stands as undeniable proof that its purchaser is on the side of good in a world that all too often can be cruel and merciless. Wear it with pride, and know that you have made a difference in the lives of strangers.',0,0.1,0,1,NULL,0.0000,1,1398,0),(33579,1089,'Women\'s \'Humanitarian\' T-shirt YC 115','This highly prestigious item of clothing was created in YC 115 and presented to New Eden\'s charitable societies. The shirt stands as undeniable proof that its purchaser is on the side of good in a world that all too often can be cruel and merciless. Wear it with pride, and know that you have made a difference in the lives of strangers.',0,0.1,0,1,NULL,0.0000,1,1406,0),(33581,1247,'Small Mobile \'Hybrid\' Siphon Unit','A small personal deployable that steals material from player owned structures (POS). The Small \'Hybrid\' Mobile Siphon Unit can steal Hybrid Polymers from Polymer Reaction Arrays. The stolen materials are stored in the unit and are accessible by anyone. \r\r\n\r\r\nThe Siphon Unit uses an advanced morphing technology to mask itself as being part of the POS. This allows it to infiltrate the production line of the POS and escape the attention of its defenses.',10000,35,1200,1,NULL,9041038.0000,1,1835,0),(33582,1267,'Small Mobile \'Hybrid\' Siphon Unit Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,1834,0),(33583,1247,'Small Mobile \'Rote\' Siphon Unit','A small personal deployable that steals material from player owned structures (POS). The Small Mobile \'Rote\' Siphon Unit can steal Processed Material from Simple Reactors and Raw Material from Moon Harvesters. The stolen materials are stored in the unit and are accessible by anyone. \r\r\n\r\r\nThe Siphon Unit uses an advanced morphing technology to mask itself as being part of the POS. This allows it to infiltrate the production line of the POS and escape the attention of its defenses.',10000,35,1000,1,NULL,9341296.0000,1,1835,0),(33584,1267,'Small Mobile \'Rote\' Siphon Unit Blueprint',' ',0,0.01,0,1,NULL,120000000.0000,1,1834,0),(33585,1273,'Amarr Encounter Surveillance System','The Encounter Surveillance System can be deployed in any system outside empire jurisdiction. It monitors encounters in the system, allowing the Amarr Empire to supplement the rewards for killing a wanted pirate.\r\r\n\r\r\nWith an active ESS in a system the bounty payout values change and a Loyalty Point payout is added. 80% of bounty is paid directly, with 20% being added to a system-wide pool that can be accessed through the ESS. The 20% can rise up to 25% over time, putting the total bounty payout at 5% above base value. The bonus payout resets to 20% if the ESS is accessed, destroyed or scooped up. For each 1000 ISK in bounties, 0.15 LPs are added. This can rise up to 0.2 LPs over time. \r\r\n\r\r\n',100000,200,0,1,NULL,25000000.0000,1,1847,0),(33586,1277,'Amarr Encounter Surveillance System Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,NULL,0),(33587,1274,'Mobile Decoy Unit',' ',10000,50,0,1,NULL,9670171.0000,1,NULL,0),(33588,1295,'Mobile Decoy Unit Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33589,1275,'Mobile Scan Inhibitor','This structure prevents the normal operation of directional scanners and probes within its 30km radius. Any objects within range of the Mobile Scan Inhibitor will not be visible to these sensors and any ship within the radius will also find their own instruments rendered inoperable.\r\r\nThe massive energy required to project this field causes the Inhibitor structure itself to be extremely visible to combat probes and directional scans.\r\r\n\r\r\nOne minute activation time. May not be deployed within 100km of another Mobile Scan Inhibitor, within 75km of Stargates, Wormholes or Stations, or within 40km of a Starbase. Cannot be retrieved once deployed. Self-destructs after one hour of operation.',10000,100,0,1,NULL,4746207.0000,1,1845,0),(33590,1293,'Mobile Scan Inhibitor Blueprint',' ',0,0.01,0,1,NULL,150000000.0000,1,1843,0),(33591,1276,'Mobile Micro Jump Unit','This small deployable structure provides all nearby ships with the ability to launch themselves 100km in any direction. Twelve seconds after any ship makes use of this structure they will be jumped 100km in their direction of travel.\r\r\n\r\r\nHundreds of researchers around the New Eden Cluster have spent over a year attempting to expand upon the works of the late Avagher Xarasier after a tragic Micro Jump accident took his life. This structure represents the cutting edge in portable Micro Jump technology and is widely considered to be acceptably safe.\r\r\n\r\r\nThis structure can be used by any ship with less than 1,000,000,000kg mass.\r\r\nOne minute activation time. May not be deployed within 10km of another Mobile Micro Jump Unit, within 20km of Stargates or Stations, or within 40km of a Starbase. Cannot be retrieved once deployed. Self-destructs after two days of operation.',10000,50,27000,1,NULL,2325571.0000,1,1844,0),(33592,1294,'Mobile Micro Jump Unit Blueprint',' ',0,0.01,0,1,NULL,30000000.0000,1,1842,0),(33595,1273,'Caldari Encounter Surveillance System','The Encounter Surveillance System can be deployed in any system outside empire jurisdiction. It monitors encounters in the system, allowing the Caldari State to supplement the rewards for killing a wanted pirate.\r\r\n\r\r\nWith an active ESS in a system the bounty payout values change and a Loyalty Point payout is added. 80% of bounty is paid directly, with 20% being added to a system-wide pool that can be accessed through the ESS. The 20% can rise up to 25% over time, putting the total bounty payout at 5% above base value. The bonus payout resets to 20% if the ESS is accessed, destroyed or scooped up. For each 1000 ISK in bounties, 0.15 LPs are added. This can rise up to 0.2 LPs over time. ',100000,200,0,1,NULL,25000000.0000,1,1847,0),(33596,1277,'Caldari Encounter Surveillance System Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,NULL,0),(33597,1248,'Amarr 100K Bounty Reimbursement Tag ','This tag can be sold at an Imperial Navy station. It is worth 100.000 ISK.',0.1,0.01,0,1,4,100000.0000,1,1846,0),(33598,1248,'Caldari 100K Bounty Reimbursement Tag','This tag can be sold at a Caldari Navy station. It is worth 100.000 ISK.',0.1,0.01,0,1,1,100000.0000,1,1846,0),(33599,1248,'Gallente 100K Bounty Reimbursement Tag','This tag can be sold at a Federation Navy station. It is worth 100.000 ISK.',0.1,0.01,0,1,8,100000.0000,1,1846,0),(33600,1248,'Minmatar 100K Bounty Reimbursement Tag','This tag can be sold at a Republic Fleet station. It is worth 100.000 ISK.',0.1,0.01,0,1,2,100000.0000,1,1846,0),(33601,1248,'Amarr 10K Bounty Reimbursement Tag ','This tag can be sold at an Imperial Navy station. It is worth 10.000 ISK.',0.1,0.01,0,1,4,10000.0000,1,1846,0),(33602,1248,'Caldari 10K Bounty Reimbursement Tag','This tag can be sold at a Caldari Navy station. It is worth 10.000 ISK.',0.1,0.01,0,1,1,10000.0000,1,1846,0),(33603,1248,'Gallente 10K Bounty Reimbursement Tag','This tag can be sold at a Federation Navy station. It is worth 10.000 ISK.',0.1,0.01,0,1,8,10000.0000,1,1846,0),(33604,1248,'Minmatar 10K Bounty Reimbursement Tag','This tag can be sold at a Republic Fleet station. It is worth 10.000 ISK.',0.1,0.01,0,1,2,10000.0000,1,1846,0),(33605,1248,'Amarr 10M Bounty Reimbursement Tag ','This tag can be sold at an Imperial Navy station. It is worth 10 million ISK.',0.1,0.01,0,1,4,10000000.0000,1,1846,0),(33606,1248,'Gallente 10M Bounty Reimbursement Tag','This tag can be sold at a Federation Navy station. It is worth 10 million ISK.',0.1,0.01,0,1,8,10000000.0000,1,1846,0),(33607,1248,'Minmatar 10M Bounty Reimbursement Tag','This tag can be sold at a Republic Fleet station. It is worth 10 million ISK.',0.1,0.01,0,1,2,10000000.0000,1,1846,0),(33608,1273,'Gallente Encounter Surveillance System','The Encounter Surveillance System can be deployed in any system outside empire jurisdiction. It monitors encounters in the system, allowing the Gallente Federation to supplement the rewards for killing a wanted pirate.\r\r\n\r\r\nWith an active ESS in a system the bounty payout values change and a Loyalty Point payout is added. 80% of bounty is paid directly, with 20% being added to a system-wide pool that can be accessed through the ESS. The 20% can rise up to 25% over time, putting the total bounty payout at 5% above base value. The bonus payout resets to 20% if the ESS is accessed, destroyed or scooped up. For each 1000 ISK in bounties, 0.15 LPs are added. This can rise up to 0.2 LPs over time. ',100000,200,0,1,NULL,25000000.0000,1,1847,0),(33609,1277,'Gallente Encounter Surveillance System Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,NULL,0),(33610,1273,'Minmatar Encounter Surveillance System','The Encounter Surveillance System can be deployed in any system outside empire jurisdiction. It monitors encounters in the system, allowing the Minmatar Republic to supplement the rewards for killing a wanted pirate.\r\r\n\r\r\nWith an active ESS in a system the bounty payout values change and a Loyalty Point payout is added. 80% of bounty is paid directly, with 20% being added to a system-wide pool that can be accessed through the ESS. The 20% can rise up to 25% over time, putting the total bounty payout at 5% above base value. The bonus payout resets to 20% if the ESS is accessed, destroyed or scooped up. For each 1000 ISK in bounties, 0.15 LPs are added. This can rise up to 0.2 LPs over time. ',100000,200,0,1,NULL,25000000.0000,1,1847,0),(33611,1277,'Minmatar Encounter Surveillance System Blueprint',' ',0,0.01,0,1,NULL,100000000.0000,1,NULL,0),(33612,1248,'Caldari 1M Bounty Reimbursement Tag','This tag can be sold at a Caldari Navy station. It is worth 1 million ISK.',0.1,0.01,0,1,1,1000000.0000,1,1846,0),(33618,314,'Rogue Drone 46-X Nexus Chip','This chip is part of little-understood evolved rogue drone technology. It apparently connects both to the drones\' propulsion systems and to their sensory equipment, and thus plays a part in allowing them to detect and pursue objects, sites, or victims of interest.\r\r\n\r\r\nUnfortunately, it is extremely fragile and doesn\'t react well to being forced into any machinery other than its native habitat, meaning that its uses as a research object are strongly limited by its availability. Some organizations in New Eden, particularly those interested in exploration and dark sciences, are rumored to pay well for this kind of item. \r\r\n\r\r\nThe 46-X chip is designed for frigate class vessels.',1,0.1,0,1,NULL,500000.0000,1,738,0),(33619,314,'Rogue Drone 43-X Nexus Chip','This chip is part of little-understood evolved rogue drone technology. It apparently connects both to the drones\' propulsion systems and to their sensory equipment, and thus plays a part in allowing them to detect and pursue objects, sites, or victims of interest.\r\r\n\r\r\nUnfortunately, it is extremely fragile and doesn\'t react well to being forced into any machinery other than its native habitat, meaning that its uses as a research object are strongly limited by its availability. Some organizations in New Eden, particularly those interested in exploration and dark sciences, are rumored to pay well for this kind of item.  \r\r\n\r\r\nThe 43-X chip is designed for cruiser class vessels.',1,0.1,0,1,NULL,2000000.0000,1,738,0),(33620,314,'Rogue Drone 42-X Nexus Chip','This chip is part of little-understood evolved rogue drone technology. It apparently connects both to the drones\' propulsion systems and to their sensory equipment, and thus plays a part in allowing them to detect and pursue objects, sites, or victims of interest.\r\r\n\r\r\nUnfortunately, it is extremely fragile and doesn\'t react well to being forced into any machinery other than its native habitat, meaning that its uses as a research object are strongly limited by its availability. Some organizations in New Eden, particularly those interested in exploration and dark sciences, are rumored to pay well for this kind of item.\r\r\n\r\r\nThe 42-X chip is designed for battleship class vessels.',1,0.1,0,1,NULL,8000000.0000,1,738,0),(33621,310,'Titanomachy','Here lie the wrecks of monstrous ships, commemorating a battle that blotted out the sky on Jan 27-28 in YC 116. \r\r\n\r\r\nTwo coalitions of capsuleers clashed in vessels numbering in the thousands, causing destruction on a scale of war never before seen by human eyes. CONCORD elected - after advising with the various empires - to leave a few wrecks left on the field for all spacefarers to see. Ostensibly this was a warning to capsuleers of where their folly would lead them, but those who\'ve encountered the immortals will know it was more likely taken as an ideal of death and destruction to which they can aspire from now until the end of time.\r\r\n',1,1,0,1,NULL,0.0000,0,NULL,0),(33622,226,'Titanomachy Monument','This monument serves to honor the 74 capsuleers who sacrificed their Titan-class starships in the Battle of B-R5RB. It was conceived of and funded by an informal coalition of the Tritanium miners of New Eden.\r\r\n\r\r\nAerallo\r\r\nAiyashia Morgan\r\r\nAnna Valerios\r\r\nAnndy\'s Wife\r\r\nAphillo\r\r\nArwyon\r\r\nBjoern\r\r\nBrother Justice\r\r\nbushy2\r\r\nChango Atacama\r\r\nChris baileyy\r\r\nClam Spunj\r\r\nCyclon\r\r\nDarth Jahib\r\r\nDaStampede\r\r\nDeathMarshellKerensky\r\r\nDevix Sorax\r\r\nDjabra\'il\r\r\nDziubusia\r\r\nEnoch Dagor\r\r\nFlow Befort\r\r\nGumba Smith\r\r\nHermaphrodiety\r\r\nI\'m Harmless\r\r\nJebsar\r\r\nJirad TiSalver\r\r\nKaede Yamaguchi\r\r\nKillerhound\r\r\nLa Sannel\r\r\nLady GoodLeather\r\r\nLord Thraakath\r\r\nMaggy Lycander\r\r\nMandrake Seriya\r\r\nMargido\r\r\nMasc Suiza\r\r\nMelony814\r\r\nMhyn Teregone\r\r\nMijstor Jedann\r\r\nMoTiOnXml\r\r\nMurkk\r\r\nMyadra\r\r\nMyal Terego\r\r\nNeeda3\r\r\nRawnar Imtari\r\r\nRed Violence\r\r\nRistano\r\r\nRobbie Boozecruise\r\r\nRoyal Bliss\r\r\nRyan Coolness\r\r\nSala Cameron\r\r\nSelaik\r\r\nSeleucus\r\r\nSharkith\r\r\nShinjiKonai\r\r\nShrike\r\r\nSmirnoff\r\r\nsnutt\r\r\nSorrows Shadow\r\r\nSort Dragon\r\r\nSpaceRangerJoe\r\r\nSteph D\'reux\r\r\nTakra\r\r\nTarithell\r\r\nThe Kan\r\r\nTIXOHJI\r\r\nTrinitrous\r\r\nVarak Silvertone\r\r\nVince Draken\r\r\nvon Schreck\r\r\nWrath of Achilles\r\r\nxeneon\r\r\nXoJIoD\r\r\nZ Man\r\r\nZungen',0,0,0,1,NULL,0.0000,0,NULL,0),(33623,27,'Abaddon Tash-Murkon Edition','The Abaddon class ship is a celestial tool of destruction. It is designed to enter combat from the outset, targeting enemies at range and firing salvo after salvo at them, and to remain intact on the battlefield until every heretic in sight has been torn to shreds.',103200000,495000,525,1,4,232044778.0000,0,NULL,0),(33624,107,'Abaddon Tash-Murkon Edition Blueprint',' ',0,0.01,0,1,NULL,1800000000.0000,1,NULL,0),(33625,27,'Abaddon Kador Edition','The Abaddon class ship is a celestial tool of destruction. It is designed to enter combat from the outset, targeting enemies at range and firing salvo after salvo at them, and to remain intact on the battlefield until every heretic in sight has been torn to shreds.',103200000,495000,525,1,4,232044778.0000,0,NULL,0),(33626,107,'Abaddon Kador Edition Blueprint',' ',0,0.01,0,1,NULL,1800000000.0000,1,NULL,0),(33627,27,'Rokh Nugoeihuvi Edition','Having long suffered the lack of an adequate hybrid platform, the Caldari State\'s capsule pilots found themselves rejoicing as the Rokh\'s design specs were released. A fleet vessel if ever there was one, this far-reaching and durable beast is expected to see a great deal of service on battlefields near and far.',105300000,486000,625,1,1,228452150.0000,0,NULL,0),(33628,107,'Rokh Nugoeihuvi Edition Blueprint',' ',0,0.01,0,1,NULL,1650000000.0000,1,NULL,0),(33629,27,'Rokh Wiyrkomi Edition','Having long suffered the lack of an adequate hybrid platform, the Caldari State\'s capsule pilots found themselves rejoicing as the Rokh\'s design specs were released. A fleet vessel if ever there was one, this far-reaching and durable beast is expected to see a great deal of service on battlefields near and far.',105300000,486000,625,1,1,228452150.0000,0,NULL,0),(33630,107,'Rokh Wiyrkomi Edition Blueprint',' ',0,0.01,0,1,NULL,1650000000.0000,1,NULL,0),(33631,27,'Maelstrom Nefantar Edition','With the Maelstrom, versatility is the name of the game. Its defensive capabilities make it ideally suited for small raid groups or solo work, while its 8 turret hardpoints present opportunities for untold carnage on the fleet battlefield. ',103600000,472500,550,1,2,202108588.0000,0,NULL,0),(33632,107,'Maelstrom Nefantar Edition Blueprint',' ',0,0.01,0,1,NULL,1450000000.0000,1,NULL,0),(33633,27,'Maelstrom Krusual Edition','With the Maelstrom, versatility is the name of the game. Its defensive capabilities make it ideally suited for small raid groups or solo work, while its 8 turret hardpoints present opportunities for untold carnage on the fleet battlefield. ',103600000,472500,550,1,2,202108588.0000,0,NULL,0),(33634,107,'Maelstrom Krusual Edition Blueprint',' ',0,0.01,0,1,NULL,1450000000.0000,1,NULL,0),(33635,27,'Hyperion Aliastra Edition','Recognizing the necessity for a blaster platform to round out their high-end arsenal, the Federation Navy brought in top-level talent to work on the Hyperion. The result: one of the most lethal and versatile gunboats ever to take to the dark skies.',100200000,495000,675,1,8,235223264.0000,0,NULL,0),(33636,107,'Hyperion Aliastra Edition Blueprint',' ',0,0.01,0,1,NULL,1760000000.0000,1,NULL,0),(33637,27,'Hyperion Inner Zone Shipping Edition','Recognizing the necessity for a blaster platform to round out their high-end arsenal, the Federation Navy brought in top-level talent to work on the Hyperion. The result: one of the most lethal and versatile gunboats ever to take to the dark skies.',100200000,495000,675,1,8,235223264.0000,0,NULL,0),(33638,107,'Hyperion Inner Zone Shipping Edition Blueprint',' ',0,0.01,0,1,NULL,1760000000.0000,1,NULL,0),(33639,26,'Omen Kador Edition','The Omen is a stereotypical example of the Amarrian School of thinking when it comes to ship design: thick armor and hard hitting lasers. Advancements in heat dissipation allow the Omen to fire its lasers faster than other ships without this technology.',13000000,118000,400,1,4,12315518.0000,0,NULL,0),(33640,106,'Omen Kador Edition Blueprint',' ',0,0.01,0,1,NULL,82750000.0000,1,NULL,0),(33641,26,'Omen Tash-Murkon Edition','The Omen is a stereotypical example of the Amarrian School of thinking when it comes to ship design: thick armor and hard hitting lasers. Advancements in heat dissipation allow the Omen to fire its lasers faster than other ships without this technology.',13000000,118000,400,1,4,12315518.0000,0,NULL,0),(33642,106,'Omen Tash-Murkon Edition Blueprint',' ',0,0.01,0,1,NULL,82750000.0000,1,NULL,0),(33643,26,'Caracal Nugoeihuvi Edition','The Caracal is a powerful vessel that specializes in missile deployment. It has excellent shield defenses, but poor armor plating. Its missile arsenal, when fully stocked, is capable of making mincemeat of almost anyone.',11910000,92000,450,1,1,13705288.0000,0,NULL,0),(33644,106,'Caracal Nugoeihuvi Edition Blueprint',' ',0,0.01,0,1,NULL,82500000.0000,1,NULL,0),(33645,26,'Caracal Wiyrkomi Edition','The Caracal is a powerful vessel that specializes in missile deployment. It has excellent shield defenses, but poor armor plating. Its missile arsenal, when fully stocked, is capable of making mincemeat of almost anyone.',11910000,92000,450,1,1,13705288.0000,0,NULL,0),(33646,106,'Caracal Wiyrkomi Edition Blueprint',' ',0,0.01,0,1,NULL,82500000.0000,1,NULL,0),(33647,26,'Stabber Nefantar Edition','The Stabber is the mainstay of the Minmatar fleet. It is light and extremely fast, yet surprisingly powerful, with a wide variety of weapons. It is one of few Minmatar vessels that have reached popularity outside Minmatar space.',11400000,80000,420,1,2,11104854.0000,0,NULL,0),(33648,106,'Stabber Nefantar Edition Blueprint',' ',0,0.01,0,1,NULL,82000000.0000,1,NULL,0),(33649,26,'Stabber Krusual Edition','The Stabber is the mainstay of the Minmatar fleet. It is light and extremely fast, yet surprisingly powerful, with a wide variety of weapons. It is one of few Minmatar vessels that have reached popularity outside Minmatar space.',11400000,80000,420,1,2,11104854.0000,0,NULL,0),(33650,106,'Stabber Krusual Edition Blueprint',' ',0,0.01,0,1,NULL,82000000.0000,1,NULL,0),(33651,26,'Thorax Aliastra Edition','The Thorax-class cruiser is the latest combat ship commissioned by the Federation. While the Thorax is a very effective ship at any range, typical of modern Gallente design philosophy it is most effective when working at extreme close range where its blasters and hordes of combat drones tear through even the toughest of enemies.',11280000,112000,465,1,8,11124452.0000,0,NULL,0),(33652,106,'Thorax Aliastra Edition Blueprint',' ',0,0.01,0,1,NULL,82250000.0000,1,NULL,0),(33653,26,'Thorax Inner Zone Shipping Edition','The Thorax-class cruiser is the latest combat ship commissioned by the Federation. While the Thorax is a very effective ship at any range, typical of modern Gallente design philosophy it is most effective when working at extreme close range where its blasters and hordes of combat drones tear through even the toughest of enemies.',11280000,112000,465,1,8,11124452.0000,0,NULL,0),(33654,106,'Thorax Inner Zone Shipping Edition Blueprint',' ',0,0.01,0,1,NULL,82250000.0000,1,NULL,0),(33655,25,'Punisher Kador Edition','The Punisher is considered by many to be one of the best Amarr frigates in existence. As evidenced by its heavy armaments, the Punisher is mainly intended for large-scale military operations, acting in coordination with larger military vessels. With its damage output, however, it is also perfectly capable of punching its way right through unwary opponents.',1190000,28600,135,1,4,353292.0000,0,NULL,0),(33656,105,'Punisher Kador Edition Blueprint',' ',0,0.01,0,1,NULL,2875000.0000,1,NULL,0),(33657,25,'Punisher Tash-Murkon Edition','The Punisher is considered by many to be one of the best Amarr frigates in existence. As evidenced by its heavy armaments, the Punisher is mainly intended for large-scale military operations, acting in coordination with larger military vessels. With its damage output, however, it is also perfectly capable of punching its way right through unwary opponents.',1190000,28600,135,1,4,353292.0000,0,NULL,0),(33658,105,'Punisher Tash-Murkon Edition Blueprint',' ',0,0.01,0,1,NULL,2875000.0000,1,NULL,0),(33659,25,'Merlin Nugoeihuvi Edition','The Merlin is the most powerful combat frigate of the Caldari. Its role has evolved through the years, and while its defenses have always remained exceptionally strong for a Caldari vessel, its offensive capabilities have evolved from versatile, jack-of-all-trades attack patterns into focused and deadly gunfire tactics. The Merlin\'s primary aim is to have its turrets punch holes in opponents\' hulls.',997000,16500,150,1,1,330262.0000,0,NULL,0),(33660,105,'Merlin Nugoeihuvi Edition Blueprint',' ',0,0.01,0,1,NULL,2850000.0000,1,NULL,0),(33661,25,'Merlin Wiyrkomi Edition','The Merlin is the most powerful combat frigate of the Caldari. Its role has evolved through the years, and while its defenses have always remained exceptionally strong for a Caldari vessel, its offensive capabilities have evolved from versatile, jack-of-all-trades attack patterns into focused and deadly gunfire tactics. The Merlin\'s primary aim is to have its turrets punch holes in opponents\' hulls.',997000,16500,150,1,1,330262.0000,0,NULL,0),(33662,105,'Merlin Wiyrkomi Edition Blueprint',' ',0,0.01,0,1,NULL,2850000.0000,1,NULL,0),(33663,25,'Rifter Nefantar Edition','The Rifter is a very powerful combat frigate and can easily tackle the best frigates out there. It has gone through many radical design phases since its inauguration during the Minmatar Rebellion. The Rifter has a wide variety of offensive capabilities, making it an unpredictable and deadly adversary.',1067000,27289,140,1,2,366116.0000,0,NULL,0),(33664,105,'Rifter Nefantar Edition Blueprint',' ',0,0.01,0,1,NULL,2800000.0000,1,NULL,0),(33665,25,'Rifter Krusual Edition','The Rifter is a very powerful combat frigate and can easily tackle the best frigates out there. It has gone through many radical design phases since its inauguration during the Minmatar Rebellion. The Rifter has a wide variety of offensive capabilities, making it an unpredictable and deadly adversary.',1067000,27289,140,1,2,366116.0000,0,NULL,0),(33666,105,'Rifter Krusual Edition Blueprint',' ',0,0.01,0,1,NULL,2800000.0000,1,NULL,0),(33667,25,'Incursus Aliastra Edition','The Incursus may be found both spearheading and bulwarking Gallente military operations. Its speed makes it excellent for skirmishing duties, while its resilience helps it outlast its opponents on the battlefield. Incursus-class ships move together in groups and can quickly and effectively gang up on ships many times their size and overwhelm them. In recent years the Incursus has increasingly found its way into the hands of pirates, who love its aggressive appearance. ',1028000,29500,165,1,8,281058.0000,0,NULL,0),(33668,105,'Incursus Aliastra Edition Blueprint',' ',0,0.01,0,1,NULL,2825000.0000,1,NULL,0),(33669,25,'Incursus Inner Zone Shipping Edition','The Incursus may be found both spearheading and bulwarking Gallente military operations. Its speed makes it excellent for skirmishing duties, while its resilience helps it outlast its opponents on the battlefield. Incursus-class ships move together in groups and can quickly and effectively gang up on ships many times their size and overwhelm them. In recent years the Incursus has increasingly found its way into the hands of pirates, who love its aggressive appearance. ',1028000,29500,165,1,8,281058.0000,0,NULL,0),(33670,105,'Incursus Inner Zone Shipping Edition Blueprint',' ',0,0.01,0,1,NULL,2825000.0000,1,NULL,0),(33671,640,'Heavy Hull Maintenance Bot I','Hull Maintenance Drone',3000,25,0,1,NULL,111114.0000,1,842,0),(33672,1144,'Heavy Hull Maintenance Bot I Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,1030,0),(33673,831,'Whiptail','When The Scope ran a headline in late YC115 asking \"<i>Has Kaalakiota built the perfect Interceptor?</i>\" most observers viewed it as a provocative ploy to increase readership. \r\r\n\r\r\nThe Rabbit viewed it as a personal challenge.',1000000,18000,150,1,1,2906672.0000,1,1932,0),(33674,105,'Whiptail Blueprint',' ',0,0.01,0,1,NULL,287500.0000,1,NULL,0),(33675,833,'Chameleon',' Some capsuleers claim that ECM is \'dishonorable\' and \'unfair\'.\r\r\nJam those ones first, and kill them last. \r\r\n- <i>Jirai \'Fatal\' Laitanen, Pithum Nullifier Training Manual c. YC104</i>',12000000,96000,350,1,1,30540200.0000,1,1837,0),(33676,106,'Chameleon Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33677,25,'Police Pursuit Comet','The Comet\'s design comes from one Arnerore Rylerave, an engineer and researcher of the Roden Shipyards corporation.  Originally created as a standard-issue police patrol vessel, its tremendous maneuverability and great offensive capabilities catapulted it into the Navy\'s ranks, where it is now a widely-used skirmish vessel.',970000,16500,145,1,8,372184.0000,0,1366,0),(33678,105,'Police Pursuit Comet Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33681,100,'Gecko','The Gecko was one of the results of the explosion in new technology deriving from the covert and highly illegal research labs known as Ghost Sites. It is a superdrone whose structure bears some similarity to Heavy Drones, but whose function is far deadlier.\r\r\n\r\r\nThe Gecko uses up twice the bandwidth of a regular drone, and in turn comes with twice the combat capabilities at much less the skill cost. It accomplishes this in part through an enigmatic new advancement in the theory of remote operations, which allows clone pilots much greater control of detached high-velocity equipment than had hereto been possible.',10000,50,0,1,1,74430.0000,1,839,0),(33682,176,'Gecko Blueprint',' ',0,0.01,0,1,NULL,5000000.0000,1,NULL,0),(33683,543,'Mackinaw ORE Development Edition','The exhumer is the second generation of mining vessels created by <a href=showinfo:30//500014>ORE</a>. Exhumers, like their mining barge cousins, were each created to excel at a specific function, the Mackinaw\'s being storage. A massive ore hold allows the Mackinaw to operate for extended periods without requiring as much support as other exhumers.\r\r\nExhumers are equipped with electronic subsystems specifically designed to accommodate Strip Mining and Ice Harvesting modules.',20000000,150000,450,1,128,70158750.0000,0,NULL,0),(33684,477,'Mackinaw ORE Development Edition Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33685,941,'Orca ORE Development Edition','The Orca was developed as a joint venture between Outer Ring Excavations and Deep Core Mining Inc as a vessel to help meet the demands of New Eden\'s industry and provide a flexible platform from which mining operations can be more easily managed.\r\r\n\r\r\nThe Orca uses much of the technology developed by ORE for the Rorqual and integrated with the latest advancements from Deep Core Mining research division has developed a vessel which offers a diverse role to all sizes of operations and needs. ',250000000,10250000,30000,1,8,610774740.0000,0,NULL,0),(33686,945,'Orca ORE Development Edition Blueprint',' ',0,0.01,0,1,NULL,900000000.0000,1,NULL,0),(33687,883,'Rorqual ORE Development Edition','The Rorqual was conceived and designed by Outer Ring Excavations in response to a growing need for capital industry platforms with the ability to support and sustain large-scale mining operations in uninhabited areas of space.\r\r\n\r\r\nTo that end, the Rorqual\'s primary strength lies in its ability to grind raw ores into particles of smaller size than possible before, while still maintaining their distinctive molecular structure. This means the vessel is able to carry vast amounts of ore in compressed form.\r\r\n\r\r\nAdditionally, the Rorqual is able to fit a capital tractor beam unit, capable of pulling in cargo containers from far greater distances and at far greater speeds than smaller beams can. It also possesses a sizeable drone bay, jump drive capability and the capacity to fit a clone vat bay. This combination of elements makes the Rorqual the ideal nexus to build deep space mining operations around.\r\r\n\r\r\nDue to its specialization towards industrial operations, its ship maintenance bay is able to accommodate only industrial ships, mining barges and their tech 2 variants',1180000000,14500000,40000,1,8,2386833996.0000,0,NULL,0),(33688,944,'Rorqual ORE Development Edition Blueprint',' ',0,0.01,0,1,NULL,3000000000.0000,1,NULL,0),(33689,28,'Iteron Inner Zone Shipping Edition','This lumbering giant is the latest and last iteration in a chain of haulers. It is the only one to retain the original \"Iteron\"-class callsign, but while all the others eventually evolved into specialized versions, the Iteron Mk. V still does what haulers do best: Transporting enormous amounts of goods and commodities between the stars.',13500000,275000,5800,1,8,1241352.0000,0,NULL,0),(33690,108,'Iteron Inner Zone Shipping Edition Blueprint',' ',0,0.01,0,1,NULL,11250000.0000,1,NULL,0),(33691,28,'Tayra Wiyrkomi Edition','The Tayra, an evolution of the now-defunct Badger Mark II, focuses entirely on reaching the highest potential capacity that Caldari engineers can manage.',13000000,270000,7300,1,1,1043248.0000,0,NULL,0),(33692,108,'Tayra Wiyrkomi Edition Blueprint',' ',0,0.01,0,1,NULL,7425000.0000,1,NULL,0),(33693,28,'Mammoth Nefantar Edition','The Mammoth is the largest industrial ship of the Minmatar Republic. It was designed with aid from the Gallente Federation, making the Mammoth both large and powerful yet also nimble and technologically advanced. A very good buy.',11500000,255000,5500,1,2,1243218.0000,0,NULL,0),(33694,108,'Mammoth Nefantar Edition Blueprint',' ',0,0.01,0,1,NULL,9375000.0000,1,NULL,0),(33695,28,'Bestower Tash-Murkon Edition','The Bestower has for decades been used by the Empire as a slave transport, shipping human labor between cultivated planets in Imperial space. As a proof to how reliable this class has been through the years, the Emperor has used an upgraded version of this very same class as transports for the Imperial Treasury. The Bestower has very thick armor and large cargo space.\r\r\n',13500000,260000,4800,1,4,996272.0000,0,NULL,0),(33696,108,'Bestower Tash-Murkon Edition Blueprint',' ',0,0.01,0,1,NULL,4977500.0000,1,NULL,0),(33697,1283,'Prospect','After the runaway success of the Venture mining frigate, ORE spun their growing frontier exploration and exploitation division, Outer Ring Prospecting, into a new subsidiary. The corporation s first project was the development of a new line of Expedition frigates, designed to meet the needs of the riskiest and most lucrative harvesting operations.\r\r\n\r\r\nThe Prospect combines improved asteroid mining systems with the Venture frame whose speed and agility made its predecessor famous. It is also the first ORE ship to take advantage of Covert Ops Cloaking Devices, allowing the Prospect to warp while cloaked for movement to and from asteroid fields in even the most hostile territories.',1400000,50000,150,1,128,4395440.0000,1,1924,0),(33698,105,'Prospect Blueprint',' ',0,0.01,0,1,NULL,2825000.0000,1,NULL,0),(33699,273,'Medium Drone Operation','Skill at controlling medium combat drones. 5% bonus to damage of medium drones per level.',0,0.01,0,1,NULL,100000.0000,1,366,0),(33700,1250,'\'Packrat\' Mobile Tractor Unit','The mobile tractoring unit takes some of the work out of looting the scorched ruins left by capsuleers, be it pulverized asteroids, wrecked ships, or obliterated inhabitation modules of various kinds. Once it has been deployed and completed its automatic activation process, it will lock on to any containers or wrecks within range, reel them in one by one, and empty their contents into its own cargo bay. All the capsuleer needs to do is keep up the pace of destruction.\r\r\n\r\r\n125km effective range.\r\r\n10 second activation time.\r\r\n\r\r\nMay not be deployed within 5km of another Mobile Tractor Unit, within 50km of Stargates or Stations, or within 40km of a Starbase.\r\r\nAutomatically decays if abandoned for two days.',10000,125,27000,1,NULL,4036356.0000,1,1833,0),(33701,1270,'\'Packrat\' Mobile Tractor Unit Blueprint',' ',0,0.01,0,1,NULL,30000000.0000,1,NULL,0),(33702,1250,'\'Magpie\' Mobile Tractor Unit','The mobile tractoring unit takes some of the work out of looting the scorched ruins left by capsuleers, be it pulverized asteroids, wrecked ships, or obliterated inhabitation modules of various kinds. Once it has been deployed and completed its automatic activation process, it will lock on to any containers or wrecks within range, reel them in one by one, and empty their contents into its own cargo bay. All the capsuleer needs to do is keep up the pace of destruction.\r\r\n\r\r\n175km effective range.\r\r\n10 second activation time.\r\r\n\r\r\nMay not be deployed within 5km of another Mobile Tractor Unit, within 50km of Stargates or Stations, or within 40km of a Starbase.\r\r\nAutomatically decays if abandoned for two days.',10000,100,27000,1,NULL,4036356.0000,1,1833,0),(33703,1270,'\'Magpie\' Mobile Tractor Unit Blueprint',' ',0,0.01,0,1,NULL,30000000.0000,1,NULL,0),(33704,640,'Medium Hull Maintenance Bot I','Hull Maintenance Drone',3000,10,0,1,NULL,28022.0000,1,842,0),(33705,1144,'Medium Hull Maintenance Bot I Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,1030,0),(33706,640,'Light Hull Maintenance Bot I','Hull Maintenance Drone',3000,5,0,1,NULL,5444.0000,1,842,0),(33707,1144,'Light Hull Maintenance Bot I Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,1030,0),(33708,640,'Heavy Hull Maintenance Bot II','Hull Maintenance Drone',3000,25,0,1,NULL,361832.0000,1,842,0),(33709,1144,'Heavy Hull Maintenance Bot II Blueprint',' ',0,0.01,0,1,NULL,10000000.0000,1,NULL,0),(33710,640,'Medium Hull Maintenance Bot II','Hull Maintenance Drone',3000,10,0,1,NULL,239092.0000,1,842,0),(33711,1144,'Medium Hull Maintenance Bot II Blueprint',' ',0,0.01,0,1,NULL,2500000.0000,1,NULL,0),(33712,640,'Light Hull Maintenance Bot II','Hull Maintenance Drone',3000,5,0,1,NULL,57922.0000,1,842,0),(33713,1144,'Light Hull Maintenance Bot II Blueprint',' ',0,0.01,0,1,NULL,500000.0000,1,NULL,0),(33714,1091,'Women\'s \'Mitral\' Boots (black)','Bringing to mind the tall arches in a holy cathedral, this regal pair of black boots has a voluminous shape that grants plenty of space to the capsuleer\'s powerful legs, along with patented thermal protection for any manner of environment.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33715,1088,'Women\'s \'Sanctity\' Dress (cream/gold)','Dress like a goddess in the \'Sanctity\' dress, a tight fit that accentuates your divine features. A sharp V-neck cut is framed in a detailed golden tattoo, providing a delicate tone to your appearance, while a golden upper front on a cream background is extended to metallic lines over the shoulder, waist and trim, giving the impression that the wearer is armored with righteousness, beauty, and power.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33716,1091,'Women\'s \'Mitral\' Boots (bronze)','Bringing to mind the tall arches in a holy cathedral, this regal pair of bronze boots has a voluminous shape that grants plenty of space to the capsuleer\'s powerful legs, along with patented thermal protection for any manner of environment.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33717,1091,'Women\'s \'Mitral\' Boots (cream)','Bringing to mind the tall arches in a holy cathedral, this regal pair of cream boots has a voluminous shape that grants plenty of space to the capsuleer\'s powerful legs, along with patented thermal protection for any manner of environment.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33718,1091,'Women\'s \'Mitral\' Boots (dark blue)','Bringing to mind the tall arches in a holy cathedral, this regal pair of dark blue boots has a voluminous shape that grants plenty of space to the capsuleer\'s powerful legs, along with patented thermal protection for any manner of environment.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33719,1091,'Women\'s \'Mitral\' Boots (dark red)','Bringing to mind the tall arches in a holy cathedral, this regal pair of dark red boots has a voluminous shape that grants plenty of space to the capsuleer\'s powerful legs, along with patented thermal protection for any manner of environment.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33720,1091,'Women\'s \'Corsair\' Heels (black)','For the combination of rough-and-tumble flavor with the sleek, sexy lines of patent leather, nothing beats the \'Corsair\' heels. High laces give it a tight, yet extremely comfortable fit, while the leather straps crisscrossing its form, complete with bold, elegant clasps, give it that slight air of piracy which everyone knows tends to adhere - thoroughly undeserved and unfairly, of course - to high-flying capsuleers.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33721,1091,'Women\'s \'Corsair\' Heels (blue)','For the combination of rough-and-tumble flavor with the sleek, sexy lines of patent leather, nothing beats the \'Corsair\' heels. High laces give it a tight, yet extremely comfortable fit, while the leather straps crisscrossing its form, complete with bold, elegant clasps, give it that slight air of piracy which everyone knows tends to adhere - thoroughly undeserved and unfairly, of course - to high-flying capsuleers.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33722,1091,'Women\'s \'Corsair\' Heels (brown)','For the combination of rough-and-tumble flavor with the sleek, sexy lines of patent leather, nothing beats the \'Corsair\' heels. High laces give it a tight, yet extremely comfortable fit, while the leather straps crisscrossing its form, complete with bold, elegant clasps, give it that slight air of piracy which everyone knows tends to adhere - thoroughly undeserved and unfairly, of course - to high-flying capsuleers.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33723,1091,'Women\'s \'Corsair\' Heels (beige)','For the combination of rough-and-tumble flavor with the sleek, sexy lines of patent leather, nothing beats the \'Corsair\' heels. High laces give it a tight, yet extremely comfortable fit, while the leather straps crisscrossing its form, complete with bold, elegant clasps, give it that slight air of piracy which everyone knows tends to adhere - thoroughly undeserved and unfairly, of course - to high-flying capsuleers.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33724,1091,'Women\'s \'Corsair\' Heels (gray)','For the combination of rough-and-tumble flavor with the sleek, sexy lines of patent leather, nothing beats the \'Corsair\' heels. High laces give it a tight, yet extremely comfortable fit, while the leather straps crisscrossing its form, complete with bold, elegant clasps, give it that slight air of piracy which everyone knows tends to adhere - thoroughly undeserved and unfairly, of course - to high-flying capsuleers.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33725,1091,'Women\'s \'Corsair\' Heels (red)','For the combination of rough-and-tumble flavor with the sleek, sexy lines of patent leather, nothing beats the \'Corsair\' heels. High laces give it a tight, yet extremely comfortable fit, while the leather straps crisscrossing its form, complete with bold, elegant clasps, give it that slight air of piracy which everyone knows tends to adhere - thoroughly undeserved and unfairly, of course - to high-flying capsuleers.',0.5,0.1,0,1,NULL,0.0000,1,1404,0),(33726,1088,'Women\'s \'Sanctity\' Dress (black/gold)','Dress like a goddess in the \'Sanctity\' dress, a tight fit that accentuates your divine features. A sharp V-neck cut is framed in a detailed golden tattoo, providing a delicate tone to your appearance, while a matte upper front on a shiny black background is extended to metallic lines over the shoulder, waist and trim, giving the impression that the wearer is armored with righteousness, beauty, and power.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33727,1088,'Women\'s \'Sanctity\' Dress (brown/gold)','Dress like a goddess in the \'Sanctity\' dress, a tight fit that accentuates your divine features. A sharp V-neck cut is framed in a detailed faded gold tattoo, providing a delicate tone to your appearance, while a solid black upper front on a dark brown background is extended to metallic lines over the shoulder, waist and trim, giving the impression that the wearer is armored with righteousness, beauty, and power.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33728,1088,'Women\'s \'Sanctity\' Dress (blue/silver)','Dress like a goddess in the \'Sanctity\' dress, a tight fit that accentuates your divine features. A sharp V-neck cut is framed in a detailed silvery tattoo, providing a delicate tone to your appearance, while a solid black upper front on a dark blue background is extended to metallic lines over the shoulder, waist and trim, giving the impression that the wearer is armored with righteousness, beauty, and power.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33729,1088,'Women\'s \'Sanctity\' Dress (dark green/gold)','Dress like a goddess in the \'Sanctity\' dress, a tight fit that accentuates your divine features. A sharp V-neck cut is framed in a detailed golden tattoo, providing a delicate tone to your appearance, while a solid upper front on a dark green background is extended to metallic lines over the shoulder, waist and trim, giving the impression that the wearer is armored with righteousness, beauty, and power.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33730,1088,'Women\'s \'Sanctity\' Dress (dark red/gold)','Dress like a goddess in the \'Sanctity\' dress, a tight fit that accentuates your divine features. A sharp V-neck cut is framed in a detailed faded golden tattoo, providing a delicate tone to your appearance, while a solid gold upper front on a maroon background is extended to metallic lines over the shoulder, waist and trim, giving the impression that the wearer is armored with righteousness, beauty, and power.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33731,1088,'Women\'s \'Sanctity\' Dress (green/gold)','Dress like a goddess in the \'Sanctity\' dress, a tight fit that accentuates your divine features. A sharp V-neck cut is framed in a detailed golden tattoo, providing a delicate tone to your appearance, while a bronze upper front on a green background is extended to metallic lines over the shoulder, waist and trim, giving the impression that the wearer is armored with righteousness, beauty, and power.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33732,1088,'Women\'s \'Sanctity\' Dress (red/silver)','Dress like a goddess in the \'Sanctity\' dress, a tight fit that accentuates your divine features. A sharp V-neck cut is framed in a detailed silvery tattoo, providing a delicate tone to your appearance, while a solid black upper front on a blood-red background is extended to metallic lines over the shoulder, waist and trim, giving the impression that the wearer is armored with righteousness, beauty, and power.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33733,1088,'Women\'s \'Rocket\' Dress (glossy black)','With its curved, sinuous lines and high black collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through the pitch-black front, overlaid with a fine shoulder brooch, and terminating in a short V-shaped edge, while the hands are covered in silver clasps overlaying a fine pair of black gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33734,1088,'Women\'s \'Rocket\' Dress (black)','With its curved, sinuous lines and high black collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through a front that resembles a cracked desert floor at night, overlaid with a fine shoulder brooch and terminating in a short V-shaped edge, while the hands are covered in silver clasps overlaying a fine pair of black gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33735,1088,'Women\'s \'Rocket\' Dress (blue)','With its curved, sinuous lines and high black collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through a front the color of an early night sky, overlaid with a fine shoulder brooch, and terminating in a short V-shaped edge, while the hands are covered in silver clasps overlaying a fine pair of black gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33736,1088,'Women\'s \'Rocket\' Dress (copper)','With its curved, sinuous lines and high collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through a front showing a murky sky full of stars, overlaid with a fine shoulder brooch and terminating in a short V-shaped edge, while the hands are covered in bronze clasps overlaying a fine pair of brown gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33737,1088,'Women\'s \'Rocket\' Dress (dark grey)','With its curved, sinuous lines and high white collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through the dark grey front, overlaid with a fine shoulder brooch, and terminating in a short V-shaped edge, while the hands are covered in golden clasps overlaying a fine pair of white gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33738,1088,'Women\'s \'Rocket\' Dress (metal) ','With its curved, sinuous lines and high black collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through a front that resembles a cracked desert floor under the light of a dead moon, overlaid with a fine shoulder brooch, and terminating in a short V-shaped edge, while the hands are covered in silver clasps overlaying a fine pair of dark gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33739,1088,'Women\'s \'Rocket\' Dress (green)','With its curved, sinuous lines and high black collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through a front of poison green, overlaid with a fine shoulder brooch, and terminating in a short V-shaped edge, while the hands are covered in silver clasps overlaying a fine pair of black gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33740,1088,'Women\'s \'Rocket\' Dress (purple)','With its curved, sinuous lines and high collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through the shimmering purple front, overlaid with a fine shoulder brooch, and terminating in a short V-shaped edge, while the hands are covered in golden clasps overlaying a fine pair of purple gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33741,1088,'Women\'s \'Rocket\' Dress (red)','With its curved, sinuous lines and high collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through a front that resembles a cracked desert floor under a blood red sky, overlaid with a fine shoulder brooch, and terminating in a short V-shaped edge, while the hands are covered in silver clasps overlaying a fine pair of gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33742,1088,'Women\'s \'Rocket\' Dress (white)','With its curved, sinuous lines and high collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through the bone-white front, overlaid with a fine shoulder brooch, and terminating in a short V-shaped edge, while the hands are covered in golden clasps overlaying a fine pair of white gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33743,1088,'Women\'s \'Rocket\' Dress (dark teal)','With its curved, sinuous lines and high white collar, the \'Rocket\' dress is equally reminiscent of a rocket breaking through the atmosphere and a dagger piercing through skin. A single join snakes through a front the color of deep night sky, overlaid with a fine shoulder brooch, and terminating in a short V-shaped edge, while the hands are covered in golden clasps overlaying a fine pair of white gloves.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(33744,1090,'Women\'s \'Poise\' Pants (glossy black)','A brisk design aimed at attracting attention through elegance, the \'Poise\' pants have a glossy, night-black surface that looks stylish, and yet is able to withstand any and all rigors of capsuleer life. \r\r\n\r\r\nEnjoy the comfort of their casual and outgoing style while knowing that nothing can stand in your way.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33745,1090,'Women\'s \'Poise\' Pants (black)','A brisk design aimed at attracting attention through elegance, the \'Poise\' pants have a matte surface of deep black that looks stylish, and yet is able to withstand any and all rigors of capsuleer life. \r\r\n\r\r\nEnjoy the comfort of their casual and outgoing style while knowing that nothing can stand in your way.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33746,1090,'Women\'s \'Poise\' Pants (beige swirl)','A brisk design aimed at attracting attention through elegance, the \'Poise\' pants have a shiny and intricately decorated surface that looks stylish, and yet is able to withstand any and all rigors of capsuleer life. \r\r\n\r\r\nEnjoy the comfort of their casual and outgoing style while knowing that nothing can stand in your way.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33747,1090,'Women\'s \'Poise\' Pants (cream)','A brisk design aimed at attracting attention through elegance, the \'Poise\' pants have a stylish matte surface the color of a rich, cloudy sky, that yet is able to withstand any and all rigors of capsuleer life. \r\r\n\r\r\nEnjoy the comfort of their casual and outgoing style while knowing that nothing can stand in your way.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33748,1090,'Women\'s \'Poise\' Pants (dark green)','A brisk design aimed at attracting attention through elegance, the \'Poise\' pants have a stylish matte surface that blends in with any surroundings, and yet is able to withstand any and all rigors of capsuleer life. \r\r\n\r\r\nEnjoy the comfort of their casual and outgoing style while knowing that nothing can stand in your way.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33749,1090,'Women\'s \'Poise\' Pants (dark swirl)','A brisk design aimed at attracting attention through elegance, the \'Poise\' pants have a shiny and intricately decorated surface that looks stylish, and yet is able to withstand any and all rigors of capsuleer life. \r\r\n\r\r\nEnjoy the comfort of their casual and outgoing style while knowing that nothing can stand in your way.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33750,1090,'Women\'s \'Poise\' Pants (glossy bronze)','A brisk design aimed at attracting attention through elegance, the \'Poise\' pants have a shiny surface of regal bronze that looks stylish, and yet is able to withstand any and all rigors of capsuleer life. \r\r\n\r\r\nEnjoy the comfort of their casual and outgoing style while knowing that nothing can stand in your way.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33751,1090,'Women\'s \'Poise\' Pants (blue)','A brisk design aimed at attracting attention through elegance, the \'Poise\' pants have a matte surface of a late night cloudless sky that looks stylish, and yet is able to withstand any and all rigors of capsuleer life. \r\r\n\r\r\nEnjoy the comfort of their casual and outgoing style while knowing that nothing can stand in your way.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33752,1090,'Women\'s \'Poise\' Pants (red)','A brisk design aimed at attracting attention through elegance, the \'Poise\' pants have a stylish matte surface the color of fresh blood, that yet is able to withstand any and all rigors of capsuleer life. \r\r\n\r\r\nEnjoy the comfort of their casual and outgoing style while knowing that nothing can stand in your way.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33753,1090,'Women\'s \'Poise\' Pants (glossy red)','A brisk design aimed at attracting attention through elegance, the \'Poise\' pants have a shiny surface of stark red that looks stylish, and yet is able to withstand any and all rigors of capsuleer life. \r\r\n\r\r\nEnjoy the comfort of their casual and outgoing style while knowing that nothing can stand in your way.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33754,1090,'Women\'s \'Strut\' Pants (black)','A stylish yet daring outfit, the \'Strut\' pants are laced from hip to ankle with exclusive hand-tanned leather laces that keep the perfect tight fit, while providing plenty of give for any and all activities you might engage in while wearing this part of your outfit. \r\r\n\r\r\nThe black layer, meanwhile, adjusts easily to your particular form, and its breathing capabilities keep your skin at a comfortable temperature throughout.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33755,1090,'Women\'s \'Strut\' Pants (blue)','A stylish yet daring outfit, the \'Strut\' pants are laced from hip to ankle with exclusive hand-tanned leather laces that keep the perfect tight fit, while providing plenty of give for any and all activities you might engage in while wearing this part of your outfit. \r\r\n\r\r\nThe blue layer, meanwhile, adjusts easily to your particular form, and its breathing capabilities keep your skin at a comfortable temperature throughout.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33756,1090,'Women\'s \'Strut\' Pants (camo)','A stylish yet daring outfit, the \'Strut\' pants are laced from hip to ankle with exclusive hand-tanned leather laces that keep the perfect tight fit, while providing plenty of give for any and all activities you might engage in while wearing this part of your outfit. \r\r\n\r\r\nThe camouflaged layer, meanwhile, adjusts easily to your particular form, and its breathing capabilities keep your skin at a comfortable temperature throughout.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33757,1090,'Women\'s \'Strut\' Pants (matte gray)','A stylish yet daring outfit, the \'Strut\' pants are laced from hip to ankle with exclusive hand-tanned leather laces that keep the perfect tight fit, while providing plenty of give for any and all activities you might engage in while wearing this part of your outfit. \r\r\n\r\r\nThe gray layer, meanwhile, adjusts easily to your particular form, and its breathing capabilities keep your skin at a comfortable temperature throughout.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33758,1090,'Women\'s \'Strut\' Pants (orange)','A stylish yet daring outfit, the \'Strut\' pants are laced from hip to ankle with exclusive hand-tanned leather laces that keep the perfect tight fit, while providing plenty of give for any and all activities you might engage in while wearing this part of your outfit. \r\r\n\r\r\nThe orange layer, meanwhile, adjusts easily to your particular form, and its breathing capabilities keep your skin at a comfortable temperature throughout.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33759,1090,'Women\'s \'Strut\' Pants (red)','A stylish yet daring outfit, the \'Strut\' pants are laced from hip to ankle with exclusive hand-tanned leather laces that keep the perfect tight fit, while providing plenty of give for any and all activities you might engage in while wearing this part of your outfit. \r\r\n\r\r\nThe red layer, meanwhile, adjusts easily to your particular form, and its breathing capabilities keep your skin at a comfortable temperature throughout.',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33760,1090,'Women\'s \'Strut\' Pants (red gloss)','A stylish yet daring outfit, the \'Strut\' pants are laced from hip to ankle with exclusive hand-tanned leather laces that keep the perfect tight fit, while providing plenty of give for any and all activities you might engage in while wearing this part of your outfit.\r\r\n\r\r\nThe shiny red layer, meanwhile, adjusts easily to your particular form, and its breathing capabilities keep your skin at a comfortable temperature throughout.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33761,1090,'Women\'s \'Strut\' Pants (yellow gloss)','A stylish yet daring outfit, the \'Strut\' pants are laced from hip to ankle with exclusive hand-tanned leather laces that keep the perfect tight fit, while providing plenty of give for any and all activities you might engage in while wearing this part of your outfit. \r\r\n\r\r\nThe shiny yellow layer, meanwhile, adjusts easily to your particular form, and its breathing capabilities keep your skin at a comfortable temperature throughout.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1403,0),(33762,353,'QA Mining Laser Upgrade','This module does not exist',1,1,0,1,NULL,123264.0000,0,NULL,0),(33765,186,'Rorqual ORE Development Edition Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(33766,186,'Orca ORE Development Edition Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(33767,1089,'Women\'s \'New Eden Open I\' T-shirt YC 114','This comfortable but eye-catching piece of clothing commemorates the first New Eden Open, a fiery clash of immortals where teams of death-dealing capsuleers were pitted against one another in a test to see who were the best fighter pilots of New Eden.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(33768,1089,'Women\'s \'New Eden Open II\' T-shirt YC 116','Carrying on the proud tradition of murderous battles engaged in for personal renown, this comfortable piece of clothing commemorates the second New Eden Open: a tournament of immortals vying for glory amidst burning carnage, in a test to see who are the best fighter pilots of New Eden.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(33769,1089,'Men\'s \'New Eden Open I\' T-shirt YC 114','This comfortable but eye-catching piece of clothing commemorates the first New Eden Open, a fiery clash of immortals where teams of death-dealing capsuleers were pitted against one another in a test to see who were the best fighter pilots of New Eden.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(33770,1089,'Men\'s \'New Eden Open II\' T-shirt YC 116','Carrying on the proud tradition of murderous battles engaged in for personal renown, this comfortable piece of clothing commemorates the second New Eden Open: a tournament of immortals vying for glory amidst burning carnage, in a test to see who are the best fighter pilots of New Eden.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(33771,1091,'Men\'s \'March\' Boots (White)','These white shoes were made for walking, and will easily carry the wearer through the most rugged of terrain anywhere in the cluster. Metal alloy clasps on the side ensure a firm, tight fit with plenty of support for the ankle without restricting movement, while laces at the top help the boots grip onto the shin and keep the shoes dry in case of adverse weather raining from above. \r\r\n\r\r\nThe front center and the sides are made of a rainproof, breathable material that make these boots a comfort to walk in. The front layer covering the instep, meanwhile, is made of nanoalloy composites that will keep the wearer from harm while making it eminently possible, through the medium of a well-aimed kick, for them to cause grievous damage to others, should the occasion demand it.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(33772,1091,'Men\'s \'March\' Boots (Graphite)','These dark shoes were made for walking, and will easily carry the wearer through the most rugged of terrain anywhere in the cluster. Metal alloy clasps on the side ensure a firm, tight fit with plenty of support for the ankle without restricting movement, while laces at the top help the boots grip onto the shin and keep the shoes dry in case of adverse weather raining from above.\r\r\n\r\r\nThe front center and the sides are made of a rainproof, breathable material that make these boots a comfort to walk in. The front layer covering the instep, meanwhile, is made of nanoalloy composites that will keep the wearer from harm while making it eminently possible, through the medium of a well-aimed kick, for them to cause grievous damage to others, should the occasion demand it.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(33773,1091,'Men\'s \'March\' Boots (Brown)','These rugged, brown shoes were made for walking, and will easily carry the wearer through the most rugged of terrain anywhere in the cluster. Metal alloy clasps on the side ensure a firm, tight fit with plenty of support for the ankle without restricting movement, while laces at the top help the boots grip onto the shin and keep the shoes dry in case of adverse weather raining from above. \r\r\n\r\r\nThe front center and the sides are made of a rainproof, breathable material that make these boots a comfort to walk in. The front layer covering the instep, meanwhile, is made of nanoalloy composites that will keep the wearer from harm while making it eminently possible, through the medium of a well-aimed kick, for them to cause grievous damage to others, should the occasion demand it.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(33774,1091,'Men\'s \'March\' Boots (Blue)','These shimmering blue shoes were made for walking, and will easily carry the wearer through the most rugged of terrain anywhere in the cluster. Metal alloy clasps on the side ensure a firm, tight fit with plenty of support for the ankle without restricting movement, while laces at the top help the boots grip onto the shin and keep the shoes dry in case of adverse weather raining from above. \r\r\n\r\r\nThe front center and the sides are made of a rainproof, breathable material that make these boots a comfort to walk in. The front layer covering the instep, meanwhile, is made of nanoalloy composites that will keep the wearer from harm while making it eminently possible, through the medium of a well-aimed kick, for them to cause grievous damage to others, should the occasion demand it.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(33775,1091,'Men\'s \'March\' Boots (Black)','These pitch black shoes were made for walking, and will easily carry the wearer through the most rugged of terrain anywhere in the cluster. Metal alloy clasps on the side ensure a firm, tight fit with plenty of support for the ankle without restricting movement, while laces at the top help the boots grip onto the shin and keep the shoes dry in case of adverse weather raining from above. \r\r\n\r\r\nThe front center and the sides are made of a rainproof, breathable material that make these boots a comfort to walk in. The front layer covering the instep, meanwhile, is made of nanoalloy composites that will keep the wearer from harm while making it eminently possible, through the medium of a well-aimed kick, for them to cause grievous damage to others, should the occasion demand it.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(33776,1091,'Men\'s \'Ascend\' Boots (white/gold)','Stand firm and proud with this imposing, regal footwear. The primary layer is composed of soft leather of bone-white color that has been tanned with patented Fedo emissions to give it that supple yet tender feel. \r\r\n\r\r\nThe outer layer, meanwhile, is a bolted shin-guard overlaid with interlacing clips of golden metal, and offers both style and substance under even the harshest conditions, giving the clear impression the wearer is someone who should not be taken lightly.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(33777,1091,'Men\'s \'Ascend\' Boots (royal)','Stand firm and proud with this imposing, regal footwear. The primary layer is composed of dark, soft leather that has been tanned with patented Fedo emissions to give it that supple yet tender feel. \r\r\n\r\r\nThe outer layer, meanwhile, is a bolted shin-guard overlaid with interlacing clips of golden metal, and offers both style and substance under even the harshest conditions, giving the clear impression the wearer is someone who should not be taken lightly.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(33778,1091,'Men\'s \'Ascend\' Boots (grey/silver)','Stand firm and proud with this imposing, regal footwear. The primary layer is composed of soft, calmly grey leather that has been tanned with patented Fedo emissions to give it that supple yet tender feel. \r\r\n\r\r\nThe outer layer, meanwhile, is a bolted shin-guard overlaid with interlacing silver-colored clips, and offers both style and substance under even the harshest conditions, giving the clear impression the wearer is someone who should not be taken lightly.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(33779,1091,'Men\'s \'Ascend\' Boots (maroon/black)','Stand firm and proud with this imposing, regal footwear. The primary layer is composed of soft, blood-red leather that has been tanned with patented Fedo emissions to give it that supple yet tender feel. \r\r\n\r\r\nThe outer layer, meanwhile, is a black bolted shin-guard overlaid with interlacing metal clips, and offers both style and substance under even the harshest conditions, giving the clear impression the wearer is someone who should not be taken lightly.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(33780,1091,'Men\'s \'Ascend\' Boots (brown/gold)','Stand firm and proud with this imposing, regal footwear. The primary layer in quiet brown is composed of soft leather that has been tanned with patented Fedo emissions to give it that supple yet tender feel. \r\r\n\r\r\nThe outer layer, meanwhile, is a bolted shin-guard overlaid with interlacing metal clips in shining gold, and offers both style and substance under even the harshest conditions, giving the clear impression the wearer is someone who should not be taken lightly.',0.5,0.1,0,1,NULL,0.0000,1,1400,0),(33781,1090,'Men\'s \'Strider\' Pants (monochrome)','Be ready for battle in our military-grade patented \'Strider\' pants. The material is light and comfortable while at the same time able to withstand the rigors of any number of hazardous environments, and the design has been proven to protect all major arteries and vital organs in the case of skirmish, assault or friendly fire. \r\r\n\r\r\nThis black-and-white look comes complete with a blastproof belt that\'s been battletested among private mercenaries, so even if this item of clothing happens to meet the same untimely end as the flesh of its unfortunately out-of-pod owner, you can rest assured that everyone who handles what\'s left of your corpse will know that you went out in style.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(33782,1090,'Men\'s \'Strider\' Pants (green camo)','Be ready for battle in our military-grade patented \'Strider\' pants. The material is light and comfortable while at the same time able to withstand the rigors of any number of hazardous environments, and the design has been proven to protect all major arteries and vital organs in the case of skirmish, assault or friendly fire. \r\r\n\r\r\nThis green camouflage look comes complete with a blastproof belt that\'s been battletested among private mercenaries, so even if this item of clothing happens to meet the same untimely end as the flesh of its unfortunately out-of-pod owner, you can rest assured that everyone who handles what\'s left of your corpse will know that you went out in style.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(33783,1090,'Men\'s \'Strider\' Pants (graphite)','Be ready for battle in our military-grade patented \'Strider\' pants. The material is light and comfortable while at the same time able to withstand the rigors of any number of hazardous environments, and the design has been proven to protect all major arteries and vital organs in the case of skirmish, assault or friendly fire. \r\r\n\r\r\nThis graphite-black look comes complete with a blastproof belt that\'s been battletested among private mercenaries, so even if this item of clothing happens to meet the same untimely end as the flesh of its unfortunately out-of-pod owner, you can rest assured that everyone who handles what\'s left of your corpse will know that you went out in style.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(33784,1090,'Men\'s \'Strider\' Pants (dark red)','Be ready for battle in our military-grade patented \'Strider\' pants. The material is light and comfortable while at the same time able to withstand the rigors of any number of hazardous environments, and the design has been proven to protect all major arteries and vital organs in the case of skirmish, assault or friendly fire. \r\r\n\r\r\nThis blood red look comes complete with a blastproof belt that\'s been battletested among private mercenaries, so even if this item of clothing happens to meet the same untimely end as the flesh of its unfortunately out-of-pod owner, you can rest assured that everyone who handles what\'s left of your corpse will know that you went out in style.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(33785,1090,'Men\'s \'Strider\' Pants (black)','Be ready for battle in our military-grade patented \'Strider\' pants. The material is light and comfortable while at the same time able to withstand the rigors of any number of hazardous environments, and the design has been proven to protect all major arteries and vital organs in the case of skirmish, assault or friendly fire. \r\r\n\r\r\nThis patented black-leather look comes complete with a blastproof belt that\'s been battletested among private mercenaries, so even if this item of clothing happens to meet the same untimely end as the flesh of its unfortunately out-of-pod owner, you can rest assured that everyone who handles what\'s left of your corpse will know that you went out in style.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(33786,1090,'Men\'s \'Rider\' Pants (white gold)','The overall design of these \'Rider\' pants - including the pleated fold at the front of the slim legs, the reflective edges that contrast precious gold with pure white, and the thin belt lacing at the top - clearly indicates that the wearer is of a high class indeed. \r\r\n\r\r\nAt the same time they are a perfect fit for a body that is never less than fresh out of the darkness of its pod, or the cleansing waters of its clone vats, and that is unhesitant to put its own life on the line whenever needed. Death, however often it visits, should not be any reason to allow oneself a slip in the high standards of style.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(33787,1090,'Men\'s \'Rider\' Pants (royal gold)','The overall design of these \'Rider\' pants - including the pleated fold at the front of the slim legs, the reflective edges that contrast classy gold with a practical dark beige, and the thin belt lacing at the top - clearly indicates that the wearer is of a high class indeed. \r\r\n\r\r\nAt the same time they are a perfect fit for a body that is never less than fresh out of the darkness of its pod, or the cleansing waters of its clone vats, and that is unhesitant to put its own life on the line whenever needed. Death, however often it visits, should not be any reason to allow oneself a slip in the high standards of style.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(33788,1090,'Men\'s \'Rider\' Pants (red gold)','The overall design of these \'Rider\' pants - including the pleated fold at the front of the slim legs, the reflective edges that contrast gold with a regal maroon, and the thin belt lacing at the top - clearly indicates that the wearer is of a high class indeed. \r\r\n\r\r\nAt the same time they are a perfect fit for a body that is never less than fresh out of the darkness of its pod, or the cleansing waters of its clone vats, and that is unhesitant to put its own life on the line whenever needed. Death, however often it visits, should not be any reason to allow oneself a slip in the high standards of style.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(33789,1090,'Men\'s \'Rider\' Pants (reflective blue)','The overall design of these \'Rider\' pants - including the pleated fold at the front of the slim legs, the reflective edges that contrast gold with a shimmering blue, and the thin belt lacing at the top - clearly indicates that the wearer is of a high class indeed. \r\r\n\r\r\nAt the same time they are a perfect fit for a body that is never less than fresh out of the darkness of its pod, or the cleansing waters of its clone vats, and that is unhesitant to put its own life on the line whenever needed. Death, however often it visits, should not be any reason to allow oneself a slip in the high standards of style.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(33790,1090,'Men\'s \'Rider\' Pants (black silver)','The overall design of these \'Rider\' pants - including the pleated fold at the front of the slim legs, the reflective edges that contrast starry silver with darkest black, and the thin belt lacing at the top - clearly indicates that the wearer is of a high class indeed.\r\r\n\r\r\nAt the same time they are a perfect fit for a body that is never less than fresh out of the darkness of its pod, or the cleansing waters of its clone vats, and that is unhesitant to put its own life on the line whenever needed. Death, however often it visits, should not be any reason to allow oneself a slip in the high standards of style.',0.5,0.1,0,1,NULL,0.0000,1,1401,0),(33791,1088,'Men\'s \'Impact\' Jacket (monochrome)','Harkening back to the days where even the most experienced spacefarers needed protection from the bruising of the elements, this elegant, yet rough-and-tumble design shows that the wearer has seen their own share of action and is unquestionably ready for more. \r\r\n\r\r\nA bone-white nanofiber-laced harness locks in seamlessly on the front, while the starkly white sides are composed of thin but untearable material that\'s framed in pitch black and leads to pads covering major joints in the upper body. A capsuleer wearing this jacket is ready for a fight, both in and out of the pod.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(33792,1088,'Men\'s \'Impact\' Jacket (green camo)','Harkening back to the days where even the most experienced spacefarers needed protection from the bruising of the elements, this elegant, yet rough-and-tumble design shows that the wearer has seen their own share of action and is unquestionably ready for more.\r\r\n\r\r\nA pitch black nanofiber-laced harness locks in seamlessly on the front, while the sides are composed of thin but untearable material in the camouflage colors of ground warriors, leading all the way to pads that cover major joints in the upper body. A capsuleer wearing this jacket is ready for a fight, both in and out of the pod.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(33793,1088,'Men\'s \'Impact\' Jacket (graphite)','Harkening back to the days where even the most experienced spacefarers needed protection from the bruising of the elements, this elegant, yet rough-and-tumble design shows that the wearer has seen their own share of action and is unquestionably ready for more.\r\r\n\r\r\nClad in the utter darkness of deep and dangerous space, a nanofiber-laced harness locks in seamlessly on the front, while the sides are composed of thin but untearable material that leads to pads covering major joints in the upper body. A capsuleer wearing this jacket is ready for a fight, both in and out of the pod.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(33794,1088,'Men\'s \'Impact\' Jacket (dark red)','Harkening back to the days where even the most experienced spacefarers needed protection from the bruising of the elements, this elegant, yet rough-and-tumble design shows that the wearer has seen their own share of action and is unquestionably ready for more.\r\r\n\r\r\nA maroon nanofiber-laced harness locks in seamlessly on the front, while the dark red sides are composed of thin but untearable material that leads to pads covering major joints in the upper body, the ensemble giving the all-over impression that the wearer has been immersed in blood that is more than likely to be someone else\'s. A capsuleer wearing this jacket is ready for a fight, both in and out of the pod.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(33795,1088,'Men\'s \'Impact\' Jacket (reflective blue)','Harkening back to the days where even the most experienced spacefarers needed protection from the bruising of the elements, this elegant, yet rough-and-tumble design shows that the wearer has seen their own share of action and is unquestionably ready for more.\r\r\n\r\r\nA burnished nanofiber-laced harness the color of a clean blue sky locks in seamlessly on the front, while the sides are composed of thin but untearable material that leads to pads covering major joints in the upper body. A capsuleer wearing this jacket is ready for a fight, both in and out of the pod.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(33796,1088,'Men\'s \'Curate\' Coat (white gold)','This outerwear signifies the wearer\'s regal nature and (some claim) near-divine immortality.\r\r\nWith a tattoo of golden decorations on a background that bears the flawless white of a capsuleer\'s soul, it befits a person who is charged with the caretaking of innumerable souls, on their crew and elsewhere - along with, occasionally, ushering them to their maker - and is an undeniable statement of purpose in this dark and dangerous world. \r\r\n\r\r\nThe wearer, it says, is not afraid to attract the attention of others, be they admiring or antagonistic; for he follows a mandate greater than that of any mortal man, and he will not, ever, under any circumstances, be stopped.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(33797,1088,'Men\'s \'Curate\' Coat (royal gold)','This outerwear signifies the wearer\'s regal nature and (some claim) near-divine immortality.\r\r\nWith a tattoo of golden decorations on a sandy beige background, as befits a person who is charged with the caretaking of innumerable souls, on their crew and elsewhere - along with, occasionally, ushering them to their maker - it is an undeniable statement of purpose in this dark and dangerous world. \r\r\n\r\r\nThe wearer, it says, is not afraid to attract the attention of others, be they admiring or antagonistic; for he follows a mandate greater than that of any mortal man, and he will not, ever, under any circumstances, be stopped.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(33798,1088,'Men\'s \'Curate\' Coat (red/gold)','This outerwear signifies the wearer\'s regal nature and (some claim) near-divine immortality.\r\r\nWith a tattoo of golden decorations on a blood red background, as befits a person who is charged with the caretaking of innumerable souls, on their crew and elsewhere - along with, occasionally, ushering them to their maker - it is an undeniable statement of purpose in this dark and dangerous world. \r\r\n\r\r\nThe wearer, it says, is not afraid to attract the attention of others, be they admiring or antagonistic; for he follows a mandate greater than that of any mortal man, and he will not, ever, under any circumstances, be stopped.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(33799,1088,'Men\'s \'Curate\' Coat (dark bronze)','This outerwear signifies the wearer\'s regal nature and (some claim) near-divine immortality.\r\r\nWith a tattoo of bronzed decorations, on a background that ranges from musky brown to the darkest black, it befits a person who is charged with the caretaking of innumerable souls, on their crew and elsewhere - along with, occasionally, ushering them to their maker - and is an undeniable statement of purpose in this dark and dangerous world. \r\r\n\r\r\nThe wearer, it says, is not afraid to attract the attention of others, be they admiring or antagonistic; for he follows a mandate greater than that of any mortal man, and he will not, ever, under any circumstances, be stopped.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(33800,1088,'Men\'s \'Curate\' Coat (black/silver)','This outerwear signifies the wearer\'s regal nature and (some claim) near-divine immortality.\r\r\nWith a tattoo of steely silver decorations on a pitch black background that brings to mind a starry sky, it befits a person who is charged with the caretaking of innumerable souls, on their crew and elsewhere - along with, occasionally, ushering them to their maker - and is an undeniable statement of purpose in this dark and dangerous world. \r\r\n\r\r\nThe wearer, it says, is not afraid to attract the attention of others, be they admiring or antagonistic; for he follows a mandate greater than that of any mortal man, and he will not, ever, under any circumstances, be stopped.\r\r\n',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(33803,1088,'Men\'s \'Source\' Coat (black)','Hewing back to an established capsuleer tradition that power is best wielded in terrifyingly good style, this \"Source\" coat has a sleek, lithe look that befits the person who knows far more than they let on. It was released alongside an exclusive compendium that granted access to secret information on the world of New Eden - although it must be admitted that anyone confronted with a capsuleer, particularly one dressed in this fashion, won\'t find it too hard to be convinced that no information should be kept secret from these angry, immortal gods of the skies.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(33804,1088,'Women\'s \'Source\' Coat (silver)','Hewing back to an established capsuleer tradition that power is best wielded in terrifyingly good style, this \"Source\" coat has a sleek, lithe look that befits the person who knows far more than they let on. It was released alongside an exclusive compendium that granted access to secret information on the world of New Eden - although it must be admitted that anyone confronted with a capsuleer, particularly one dressed in this fashion, won\'t find it too hard to be convinced that no information should be kept secret from these angry, immortal gods of the skies.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(33805,695,'DED Officer 1st Class Vessel','This is a fighter-ship belonging to DED, a division in the CONCORD organization responsible for tracking down and eliminating criminals.  Consider it a threat to anyone that has commited a criminal offense within CONCORD patrolled space.',12155000,101000,900,1,NULL,0.0000,0,NULL,0),(33806,697,'CONCORD Starship Vessel','The CONCORD Starship is solely used for transporting or escorting people of extreme importance within CONCORD patrolled space.  It is built for defense with very light offensive capability.',20500000,1080000,665,1,NULL,0.0000,0,NULL,0),(33807,300,'Cybernetic \'Source\' Subprocessor','This grafted subprocessor, based on technology similar to that which powers the New Eden Source compendium, is particularly good for understanding a great deal of information at once. It is implanted in the frontal lobe and grants a bonus to a character\'s Intelligence.\r\r\n\r\r\nEffect: +4 Bonus to Intelligence',0,1,0,1,NULL,400000.0000,1,621,0),(33808,300,'Neural \'Source\' Boost','This grafted subprocessor, based on technology similar to that which powers the New Eden Source compendium, is particularly good for amassing a great deal of information at once. It is implanted in the frontal lobe and grants a bonus to a character\'s Willpower.\r\r\n\r\r\nEffect: +4 Bonus to Willpower',0,1,0,1,NULL,400000.0000,1,620,0),(33809,1194,'New Eden Source','This compendium of reports, data and historical documents - some of which are highly classified - details the landscape of New Eden and the lives of its various citizens. It is a blend of man-on-the-street tales, high-level political reportage, and behind-the-scenes information that casts a new light on the cluster.\r\r\n \r\r\nThe compendium itself is unique in its production: It serves as a repository of facts like any other book, digital or otherwise; but it has certain additional output functions that permit select readers to interface directly with its contents and grasp them at a level that is quite literally cerebral. This is a security measure more than anything, and an expensive one, but it means that parts of the book cannot even be read; instead, they must be imprinted directly on the brain\'s pathways. The only potential recipients of this kind of knowledge - at least, the only ones who can handle it without having their cranial nerves fried to a crisp - are capsuleers.\r\r\n \r\r\nThus, like the fabled Book of Emptiness in Amarr myth, this book is not only a book, but a vessel for a changed outlook on the world, and like that same mythological book, it has the ability to change those readers who are receptive to its dark wonders.',0,0.01,0,1,NULL,0.0000,1,1661,0),(33812,1089,'Men\'s \'Quafe\' T-shirt YC 116','Stalk the halls in your elegant new Quafe Commemorative Casual wear, designed exclusively for attendees of the YC 116 Inner Zone Shipping Conference.\r\r\n\r\r\nNote: While IZS is renowned for its safe shipping methods and extensive reach, the wearer of this shirt is unfortunately not entitled to free interstellar transport on an IZS flight for them and their accompanying family members or friends. They will, however, automatically and without question be seated as far from any Fedos in cargo as is humanly possible.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(33813,1089,'Women\'s \'Quafe\' T-shirt YC 116','Stalk the halls in your elegant new Quafe Commemorative Casual wear, designed exclusively for attendees of the YC 116 Inner Zone Shipping Conference.\r\r\n\r\r\nNote: While IZS is renowned for its safe shipping methods and extensive reach, the wearer of this shirt is unfortunately not entitled to free interstellar transport on an IZS flight for them and their accompanying family members or friends. They will, however, automatically and without question be seated as far from any Fedos in cargo as is humanly possible.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(33816,25,'Garmur','In YC 116, Mordu s Legion intelligence reported to command that the Guristas pirates were developing new and advanced strike craft capabilities using unknown technologies. In response to these reports, Mordu s Legion accelerated a program of ship development that was itself a response to trends in capsuleer tactics and warfare. The crash development and manufacturing effort resulted in a new family of fast strike ships integrated with one another to provide tactical flexibility and firepower across ship class lines.\r\r\n\r\r\nThe Garmur takes up the small craft spot in the Legion s new strike formations and represents a fast-moving attack frigate with superior missile delivery capabilities.',987000,27289,130,1,1,346080.0000,1,1365,0),(33817,105,'Garmur Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33818,26,'Orthrus','In YC 116, Mordu s Legion intelligence reported to command that the Guristas pirates were developing new and advanced strike craft capabilities using unknown technologies. In response to these reports, Mordu s Legion accelerated a program of ship development that was itself a response to trends in capsuleer tactics and warfare. The crash development and manufacturing effort resulted in a new family of fast strike ships integrated with one another to provide tactical flexibility and firepower across ship class lines.\r\r\n\r\r\nThe Orthrus is at the core of the Legion s new strike formations and provides the mercenary pilots with superior projection of high damage missiles while executing rapid attack maneuvers.',9362000,101000,380,1,1,11579728.0000,1,1371,0),(33819,106,'Orthrus Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33820,27,'Barghest','In YC 116, Mordu s Legion intelligence reported to command that the Guristas pirates were developing new and advanced strike craft capabilities using unknown technologies. In response to these reports, Mordu s Legion accelerated a program of ship development that was itself a response to trends in capsuleer tactics and warfare. The crash development and manufacturing effort resulted in a new family of fast strike ships integrated with one another to provide tactical flexibility and firepower across ship class lines.\r\r\n\r\r\nThe Barghest represents the pinnacle of the Legion s ambitions for its new strike craft doctrine: a fast battleship with high-speed missile delivery systems, fully capable of contesting the field with more traditional heavy skirmishers.',98467000,595000,665,1,1,157405934.0000,1,1380,0),(33821,107,'Barghest Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33822,1292,'Omnidirectional Tracking Enhancer I','Enhances the range and improves the tracking speed of all drones.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,15764.0000,1,938,0),(33823,408,'Omnidirectional Tracking Enhancer I Blueprint',' ',0,0.01,0,1,NULL,144000.0000,1,939,0),(33824,1292,'Omnidirectional Tracking Enhancer II','Enhances the range and improves the tracking speed of all drones.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,282964.0000,1,938,0),(33825,408,'Omnidirectional Tracking Enhancer II Blueprint',' ',0,0.01,0,1,NULL,144000.0000,1,NULL,0),(33826,646,'Sentient Omnidirectional Tracking Link','Improves the optimal range and tracking of all drones. \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',0,5,1,1,NULL,9792.0000,1,938,0),(33828,1292,'Sentient Omnidirectional Tracking Enhancer','Enhances the range and improves the tracking speed of all drones.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,938,0),(33830,1292,'Dread Guristas Omnidirectional Tracking Enhancer','Enhances the range and improves the tracking speed of all drones.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,938,0),(33832,1292,'Imperial Navy Omnidirectional Tracking Enhancer','Enhances the range and improves the tracking speed of all drones.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,938,0),(33834,1292,'Unit D-34343\'s Modified Omnidirectional Tracking Enhancer','Enhances the range and improves the tracking speed of all drones.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,938,0),(33836,1292,'Unit F-435454\'s Modified Omnidirectional Tracking Enhancer','Enhances the range and improves the tracking speed of all drones.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,938,0),(33838,1292,'Unit P-343554\'s Modified Omnidirectional Tracking Enhancer','Enhances the range and improves the tracking speed of all drones.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,938,0),(33840,1292,'Unit W-634\'s Modified Omnidirectional Tracking Enhancer','Enhances the range and improves the tracking speed of all drones.    \r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',20,5,0,1,NULL,14400.0000,1,938,0),(33842,645,'Federation Navy Drone Damage Amplifier','The Drone Damage Amplifier projects a multi-node quantum entanglement onto the ship\'s drone communications net, creating a bridged processor between ship and drones that allows for better real-time trajectory projections.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized. \r\r\n',1,5,0,1,NULL,41982.0000,1,938,0),(33844,645,'Imperial Navy Drone Damage Amplifier','The Drone Damage Amplifier projects a multi-node quantum entanglement onto the ship\'s drone communications net, creating a bridged processor between ship and drones that allows for better real-time trajectory projections.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',1,5,0,1,NULL,41982.0000,1,938,0),(33846,645,'Dread Guristas Drone Damage Amplifier','The Drone Damage Amplifier projects a multi-node quantum entanglement onto the ship\'s drone communications net, creating a bridged processor between ship and drones that allows for better real-time trajectory projections.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',1,5,0,1,NULL,41982.0000,1,938,0),(33848,645,'Sentient Drone Damage Amplifier','The Drone Damage Amplifier projects a multi-node quantum entanglement onto the ship\'s drone communications net, creating a bridged processor between ship and drones that allows for better real-time trajectory projections.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.\r\r\n',1,5,0,1,NULL,41982.0000,1,938,0),(33850,644,'Federation Navy Drone Navigation Computer','Increases microwarpdrive speed of drones.',200,25,0,1,NULL,139232.0000,1,938,0),(33852,644,'Sentient Drone Navigation Computer','Increases microwarpdrive speed of drones.',200,25,0,1,NULL,139232.0000,1,938,0),(33856,257,'Expedition Frigates','Skill for operation of Expedition Frigates. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,NULL,4000000.0000,1,377,0),(33857,310,' ',' YC116 3 25-26  \r\r\n\r\r\n ',1,1,0,1,NULL,0.0000,0,NULL,0),(33858,226,' ',' 49-U6U 84 \r\r\n\r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\nSin Glory\r\r\n de \r\r\n \r\r\n \r\r\nkiko \r\r\n \r\r\n \r\r\n \r\r\n \r\r\nDAKE\r\r\n \r\r\n \r\r\n \r\r\nTsukino Usagi\r\r\n \r\r\nAArena\r\r\n \r\r\n0o o0\r\r\n \r\r\n \r\r\nLord Vici\r\r\n \r\r\nSoltueurs \r\r\n \r\r\n8 \r\r\nplayboyNO1\r\r\n \r\r\n \r\r\ndadfafa\r\r\no o\r\r\n De \r\r\n \r\r\nY Y\r\r\n \r\r\n \r\r\nSneezess\r\r\n \r\r\n \r\r\n \r\r\n De \r\r\nK7TanCheng\r\r\n V \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\nHeinz \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n   \r\r\n \r\r\nRAYTHONE\r\r\nBeautiful\r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\nTitusZ\r\r\nJY KOK\r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n \r\r\n 03\r\r\n \r\r\n   ',0,0,0,1,NULL,0.0000,0,NULL,0),(33864,1285,'Mordu s Special Warfare Unit Operative','This Garmur-class frigate is a commander in the elite Special Warfare Unit of Mordu s Legion. \r\r\nLegion Command has never officially confirmed the existence of the Special Warfare Unit, and declines to comment on any questions concerning the appearance of these units throughout low security space. They do however warn that detachments of Legionnaires throughout the cluster will not hesitate to use all necessary force against anyone found to be interfering with their operations.\r\r\n\r\r\nThis vessel should be considered extremely dangerous.\r\r\n',1970000,19700,235,1,1,0.0000,0,NULL,0),(33865,1286,'Mordu s Special Warfare Unit Specialist','This Orthrus-class cruiser is a commander in the elite Special Warfare Unit of Mordu s Legion. \r\r\nLegion Command has never officially confirmed the existence of the Special Warfare Unit, and declines to comment on any questions concerning the appearance of these units throughout low security space. They do however warn that detachments of Legionnaires throughout the cluster will not hesitate to use all necessary force against anyone found to be interfering with their operations.\r\r\n\r\r\nThis vessel should be considered extremely dangerous.\r\r\n',11910000,92000,450,1,1,0.0000,0,NULL,0),(33866,1287,'Mordu s Special Warfare Unit Commander','This Barghest-class battleship is a commander in the elite Special Warfare Unit of Mordu s Legion. \r\r\nLegion Command has never officially confirmed the existence of the Special Warfare Unit, and declines to comment on any questions concerning the appearance of these units throughout low security space. They do however warn that detachments of Legionnaires throughout the cluster will not hesitate to use all necessary force against anyone found to be interfering with their operations.\r\r\n\r\r\nThis vessel should be considered extremely dangerous.\r\r\n',99300000,486000,450,1,1,0.0000,0,NULL,0),(33867,397,'Thukker Component Assembly Array','An assembly facility where Standard and Advanced Capital Ship Components can be manufactured.\r\r\n\r\r\nThis facility is engineered by Thukker specialists to utilize certain unregulated opportunities for expediting construction in low security space\r\r\n\r\r\nActivity bonuses:\r\r\n25% reduction in manufacturing required time\r\r\n15% reduction in manufacturing required materials',100000000,12500,1000000,1,2,10000000.0000,1,932,0),(33868,1048,'Thukker Component Assembly Array Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1340,0),(33869,419,'Brutix Serpentis Edition','One of the most ferocious war vessels to ever spring from Gallente starship design, the Brutix is a behemoth in every sense of the word.  When this hard-hitting monster appears, the battlefield takes notice.',12500000,270000,475,1,8,59855886.0000,0,NULL,0),(33870,489,'Brutix Serpentis Edition Blueprint',' ',0,0.01,0,1,NULL,570000000.0000,1,NULL,0),(33871,419,'Cyclone Thukker Tribe Edition','The Cyclone was created in order to meet the increasing demand for a vessel capable of providing muscle for frigate detachments while remaining more mobile than a battleship.  To this end, the Cyclone\'s seven high-power slots and powerful thrusters have proved ideal.',12500000,216000,450,1,2,66214804.0000,0,NULL,0),(33872,489,'Cyclone Thukker Tribe Edition Blueprint',' ',0,0.01,0,1,NULL,525000000.0000,1,NULL,0),(33873,419,'Ferox Guristas Edition','Designed as much to look like a killing machine as to be one, the Ferox will strike fear into the heart of anyone unlucky enough to get caught in its crosshairs.  With the potential for sizable armament as well as tremendous electronic warfare capability, this versatile gunboat is at home in a great number of scenarios.',13250000,252000,475,1,1,60187424.0000,0,NULL,0),(33874,489,'Ferox Guristas Edition Blueprint',' ',0,0.01,0,1,NULL,540000000.0000,1,NULL,0),(33875,419,'Prophecy Blood Raiders Edition','The Prophecy is built on an ancient Amarrian warship design dating back to the earliest days of starship combat.  Originally intended as a full-fledged battleship, it was determined after mixed fleet engagements with early prototypes that the Prophecy would be more effective as a slightly smaller, more mobile form of artillery support.',12900000,234000,400,1,4,56099454.0000,0,NULL,0),(33876,489,'Prophecy Blood Raiders Edition Blueprint',' ',0,0.01,0,1,NULL,555000000.0000,1,NULL,0),(33877,420,'Catalyst Serpentis Edition','Ideally suited for both skirmish warfare and fleet support, the Catalyst is touted as one of the best anti-frigate platforms out there. Faced with its top-of-the-line tracking equipment, not many can argue.',1550000,55000,450,1,8,1195526.0000,0,NULL,0),(33878,487,'Catalyst Serpentis Edition Blueprint',' ',0,0.01,0,1,NULL,7887800.0000,1,NULL,0),(33879,420,'Coercer Blood Raiders Edition','Noticing the alarming increase in Minmatar frigate fleets, the Imperial Navy made its plans for the Coercer, a vessel designed specifically to seek and destroy the droves of fast-moving frigate rebels. ',1650000,47000,375,1,4,1326320.0000,0,NULL,0),(33880,487,'Coercer Blood Raiders Edition Blueprint',' ',0,0.01,0,1,NULL,8635240.0000,1,NULL,0),(33881,420,'Cormorant Guristas Edition','The Cormorant is the only State-produced space vessel whose design has come from a third party.  Rumors abound, of course, but the designer\'s identity has remained a tightly-kept secret in the State\'s inner circle.',1700000,52000,425,1,1,1229506.0000,0,NULL,0),(33882,487,'Cormorant Guristas Edition Blueprint',' ',0,0.01,0,1,NULL,8416400.0000,1,NULL,0),(33883,420,'Thrasher Thukker Tribe Edition','Engineered as a supplement to its big brother the Cyclone, the Thrasher\'s tremendous turret capabilities and advanced tracking computers allow it to protect its larger counterpart from smaller, faster menaces.',1600000,43000,400,1,2,1121470.0000,0,NULL,0),(33884,487,'Thrasher Thukker Tribe Edition Blueprint',' ',0,0.01,0,1,NULL,7500000.0000,1,NULL,0),(33886,1288,'Mordu\'s Legion Battleship','A Battleship of the Mordu\'s Legion',99300000,486000,450,1,1,0.0000,0,NULL,0),(33887,1288,'Mordu\'s Legion Cruiser','A Cruiser of the Mordu\'s Legion',11910000,92000,450,1,1,0.0000,0,NULL,0),(33888,1288,'Mordu\'s Legion Commander','A Commander of the Mordu\'s Legion',19000000,22000000,235,1,1,0.0000,0,NULL,0),(33889,306,'Guristas Research and Trade Hub','The highest ranking personnel within this deadspace pocket reside here.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(33890,773,'Small Transverse Bulkhead I','This ship modification is designed to increase a ship\'s total hull hit points at the expense of cargo capacity.',200,5,0,1,NULL,0.0000,1,1206,0),(33891,787,'Small Transverse Bulkhead I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1203,0),(33892,773,'Small Transverse Bulkhead II','This ship modification is designed to increase a ship\'s total hull hit points at the expense of cargo capacity.',200,5,0,1,NULL,0.0000,1,1206,0),(33893,787,'Small Transverse Bulkhead II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(33894,773,'Medium Transverse Bulkhead I','This ship modification is designed to increase a ship\'s total hull hit points at the expense of cargo capacity.',200,10,0,1,NULL,0.0000,1,1207,0),(33895,787,'Medium Transverse Bulkhead I Blueprint',' ',0,0.01,0,1,NULL,750000.0000,1,1204,0),(33896,773,'Medium Transverse Bulkhead II','This ship modification is designed to increase a ship\'s total hull hit points at the expense of cargo capacity.',200,10,0,1,NULL,0.0000,1,1207,0),(33897,787,'Medium Transverse Bulkhead II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(33898,773,'Large Transverse Bulkhead I','This ship modification is designed to increase a ship\'s total hull hit points at the expense of cargo capacity.',200,20,0,1,NULL,0.0000,1,1208,0),(33899,787,'Large Transverse Bulkhead I Blueprint',' ',0,0.01,0,1,NULL,1250000.0000,1,1202,0),(33900,773,'Large Transverse Bulkhead II','This ship modification is designed to increase a ship\'s total hull hit points at the expense of cargo capacity.',200,20,0,1,NULL,0.0000,1,1208,0),(33901,787,'Large Transverse Bulkhead II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(33902,773,'Capital Transverse Bulkhead I','This ship modification is designed to increase a ship\'s total hull hit points at the expense of cargo capacity.',200,40,0,1,NULL,0.0000,1,1730,0),(33903,787,'Capital Transverse Bulkhead I Blueprint',' ',0,0.01,0,1,NULL,50000000.0000,1,1719,0),(33904,773,'Capital Transverse Bulkhead II','This ship modification is designed to increase a ship\'s total hull hit points at the expense of cargo capacity.',200,40,0,1,NULL,0.0000,1,1730,0),(33905,787,'Capital Transverse Bulkhead II Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,NULL,0),(33907,186,'Mordus Large Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(33908,186,'Mordus Medium Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(33909,186,'Mordus Small Commander Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(33910,494,'Thukker Component Assembly Facility','This facility may look to outsiders like a standard component factory adorned with Thukker markings, but there are numerous subtle alterations in the outer shell. Heavy armoring makes it impossible to tell what\'s inside without forcibly disassembling it.',1000000,4000,20000,1,NULL,0.0000,0,NULL,0),(33915,1189,'Medium Micro Jump Drive','The Micro Jump Drive is a module that spools up, then jumps the ship forward 100km in the direction it is facing. Upon arrival, the ship maintains its direction and velocity. Warp scramblers can be used to disrupt the module. Spool up time is reduced by the skill <a href=showinfo:4385>Micro Jump Drive Operation</a>.\r\r\n\r\r\nThe Micro Jump Drive was developed by Duvolle Laboratories Advanced Manifold Theory Unit. The drive was conceived by the late Avagher Xarasier, the genius behind several ground-breaking innovations of that era.\r\r\n',0,10,0,1,NULL,340852.0000,1,1650,0),(33916,1191,'Medium Micro Jump Drive Blueprint',' ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(33917,300,'Low-grade Centurion Alpha','This ocular filter has been modified by Mordus scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors and Target Painters\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Centurion implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33918,300,'Low-grade Centurion Beta','This memory augmentation has been modified by Mordus scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors and Target Painters\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Centurion implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(33919,300,'Low-grade Centurion Delta','This cybernetic subprocessor has been modified by Mordus scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors and Target Painters\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Centurion implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(33920,300,'Low-grade Centurion Epsilon','This social adaptation chip has been modified by Mordus scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors and Target Painters\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Centurion implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(33921,300,'Low-grade Centurion Gamma','This neural boost has been modified by Mordus scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to optimal range of ECM, Remote Sensor Dampers, Tracking Disruptors and Target Painters\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Centurion implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(33922,300,'Low-grade Centurion Omega','This implant does nothing in and of itself, but when used in conjunction with other Centurion implants it will boost their effect. \r\r\n\r\r\n10% bonus to the strength of all Centurion implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(33923,300,'Low-grade Crystal Alpha','This ocular filter has been modified by Guristas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,618,0),(33924,300,'Low-grade Crystal Beta','This memory augmentation has been modified by Guristas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,619,0),(33925,300,'Low-grade Crystal Delta','This cybernetic subprocessor has been modified by Guristas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,621,0),(33926,300,'Low-grade Crystal Epsilon','This social adaptation chip has been modified by Guristas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,622,0),(33927,300,'Low-grade Crystal Gamma','This neural boost has been modified by Guristas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to shield boost amount\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Crystal implant secondary effects\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,620,0),(33928,300,'Low-grade Crystal Omega','This implant does nothing in and of itself, but when used in conjunction with other Crystal implants it will boost their effect. \r\r\n\r\r\n10% bonus to the strength of all Crystal implant secondary effects.\r\r\n\r\r\nNote: Has no effect on capital sized modules.',0,1,0,1,NULL,0.0000,1,1506,0),(33929,300,'Low-grade Edge Alpha','This ocular filter has been modified by Syndicate scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% reduction to booster side effects\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Edge implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33930,300,'Low-grade Edge Beta','This memory augmentation has been modified by Syndicate scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% reduction to booster side effects\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Edge implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(33931,300,'Low-grade Edge Delta','This cybernetic subprocessor has been modified by Syndicate scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% reduction to booster side effects\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Edge implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(33932,300,'Low-grade Edge Epsilon','This social adaptation chip has been modified by Syndicate scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% reduction to booster side effects\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Edge implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(33933,300,'Low-grade Edge Gamma','This neural boost has been modified by Syndicate scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% reduction to booster side effects\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Edge implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(33934,300,'Low-grade Edge Omega','This implant does nothing in and of itself, but when used in conjunction with other Edge implants it will boost their effect. \r\r\n\r\r\n10% bonus to the strength of all Edge implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(33935,300,'Low-grade Halo Alpha','This ocular filter has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 Bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33936,300,'Low-grade Halo Beta','This memory augmentation has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 Bonus to Memory\r\r\n\r\r\nSecondary Effect: 1.25% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(33937,300,'Low-grade Halo Delta','This cybernetic subprocessor has been modified by Angel scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 Bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 1.5% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(33938,300,'Low-grade Halo Epsilon','This social adaptation chip has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 Bonus to Charisma\r\r\n\r\r\nSecondary Effect: 2% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(33939,300,'Low-grade Halo Gamma','This neural boost has been modified by Angel scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 Bonus to Willpower\r\r\n\r\r\nSecondary Effect: 1.75% reduction in ship\'s signature radius\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Halo implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(33940,300,'Low-grade Halo Omega','This implant does nothing in and of itself, but when used in conjunction with other Halo implants it will boost their effect.\r\r\n\r\r\n10% bonus to the strength of all Halo implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(33941,300,'Low-grade Harvest Alpha','This ocular filter has been modified by ORE scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% bonus to the range to all mining lasers\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Harvest implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33942,300,'Low-grade Harvest Beta','This memory augmentation has been modified by ORE scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% bonus to the range to all mining lasers\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Harvest implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(33943,300,'Low-grade Harvest Delta','This cybernetic subprocessor has been modified by ORE scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% bonus to the range to all mining lasers\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Harvest implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(33944,300,'Low-grade Harvest Epsilon','This social adaptation chip has been modified by ORE scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to the range to all mining lasers\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Harvest implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(33945,300,'Low-grade Harvest Gamma','This neural boost has been modified by ORE scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to the range to all mining lasers\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Harvest implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(33946,300,'Low-grade Harvest Omega','This implant does nothing in and of itself, but when used in conjunction with other Harvest implants it will boost their effect. \r\r\n\r\r\n10% bonus to the strength of all Harvest implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(33947,300,'Low-grade Nomad Alpha','This ocular filter has been modified by Thukker scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% bonus to agility\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Nomad implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33948,300,'Low-grade Nomad Beta','This memory augmentation has been modified by Thukker scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% bonus to agility\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Nomad implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(33949,300,'Low-grade Nomad Delta','This cybernetic subprocessor has been modified by Thukker scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% bonus to agility\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Nomad implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(33950,300,'Low-grade Nomad Epsilon','This social adaptation chip has been modified by Thukker scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to agility\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Nomad implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(33951,300,'Low-grade Nomad Gamma','This neural boost has been modified by Thukker scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to agility\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Nomad implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(33952,300,'Low-grade Nomad Omega','This implant does nothing in and of itself, but when used in conjunction with other Nomad implants it will boost their effect. \r\r\n\r\r\n10% bonus to the strength of all Nomad implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(33953,300,'Low-grade Slave Alpha','This ocular filter has been modified by Sanshas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% bonus to armor HP\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33954,300,'Low-grade Slave Beta','This memory augmentation has been modified by Sansha scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Memory\r\r\n\r\r\nSecondary Effect: 2% bonus to armor HP\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(33955,300,'Low-grade Slave Delta','This cybernetic subprocessor has been modified by Sanshas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 4% bonus to armor HP\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(33956,300,'Low-grade Slave Epsilon','This social adaption chip has been modified by Sanshas scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to armor HP\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(33957,300,'Low-grade Slave Gamma','This neural boost  has been modified by Sanshas scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to armor HP\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Slave implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(33958,300,'Low-grade Slave Omega','This implant does nothing in and of itself, but when used in conjunction with other Slave implants it will boost their effect. \r\r\n\r\r\n10% bonus to the strength of all Slave implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(33959,300,'Low-grade Snake Alpha','This ocular filter has been modified by Serpentis scientists for use by their elite smugglers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Perception\r\r\n\r\r\nSecondary Effect: 0.5% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 5% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33960,300,'Low-grade Snake Beta','This memory augmentation has been modified by Serpentis scientists for use by their elite smugglers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Memory\r\r\n\r\r\nSecondary Effect: 0.625% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 5% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(33961,300,'Low-grade Snake Delta','This cybernetic subprocessor has been modified by Serpentis scientists for use by their elite smugglers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 0.875% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 5% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(33962,300,'Low-grade Snake Epsilon','This social adaption chip has been modified by Serpentis scientists for use by their elite smugglers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 1% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 5% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(33963,300,'Low-grade Snake Gamma','This neural boost  has been modified by Serpentis scientists for use by their elite smugglers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 0.75% bonus to maximum velocity\r\r\n\r\r\nSet Effect: 5% bonus to the strength of all Snake implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(33964,300,'Low-grade Snake Omega','This implant does nothing in and of itself, but when used in conjunction with other Snake implants it will boost their effect. \r\r\n\r\r\n110% bonus to the strength of all Snake implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(33965,300,'Low-grade Talisman Alpha','This ocular filter has been modified by Blood Raider scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Perception\r\r\n\r\r\nSecondary Effect: 1% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33966,300,'Low-grade Talisman Beta','This memory augmentation has been modified by Blood Raider scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Memory\r\r\n\r\r\nSecondary Effect: 2% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(33967,300,'Low-grade Talisman Delta','This cybernetic subprocessor has been modified by Blood Raider scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Intelligence\r\r\n\r\r\nSecondary Effect: 4% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(33968,300,'Low-grade Talisman Epsilon','This social adaption chip has been modified by Blood Raider scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(33969,300,'Low-grade Talisman Gamma','This neural boost has been modified by Blood Raider scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% reduction in the duration of modules requiring the Capacitor Emission Systems skill\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Talisman implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(33970,300,'Low-grade Talisman Omega','This implant does nothing in and of itself, but when used in conjunction with other Talisman implants it will boost their effect. \r\r\n\r\r\n10% bonus to the strength of all Talisman implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(33971,300,'Low-grade Virtue Alpha','This ocular filter has been modified by Sisters of Eve scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Perception \r\r\n\r\r\nSecondary Effect: 1% bonus to scan strength of probes\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Virtue implant secondary effects',0,1,0,1,NULL,0.0000,1,618,0),(33972,300,'Low-grade Virtue Beta','This memory augmentation has been modified by Sisters of Eve scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Memory \r\r\n\r\r\nSecondary Effect: 2% bonus to scan strength of probes\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Virtue implant secondary effects',0,1,0,1,NULL,0.0000,1,619,0),(33973,300,'Low-grade Virtue Delta','This cybernetic subprocessor has been modified by Sisters of Eve scientists for use by their elite officers. \r\r\n\r\r\nPrimary Effect: +2 bonus to Intelligence \r\r\n\r\r\nSecondary Effect: 4% bonus to scan strength of probes\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Virtue implant secondary effects',0,1,0,1,NULL,0.0000,1,621,0),(33974,300,'Low-grade Virtue Epsilon','This social adaptation chip has been modified by Sisters of Eve scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Charisma\r\r\n\r\r\nSecondary Effect: 5% bonus to scan strength of probes\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Virtue implant secondary effects',0,1,0,1,NULL,0.0000,1,622,0),(33975,300,'Low-grade Virtue Gamma','This neural boost has been modified by Sisters of Eve scientists for use by their elite officers.\r\r\n\r\r\nPrimary Effect: +2 bonus to Willpower\r\r\n\r\r\nSecondary Effect: 3% bonus to scan strength of probes\r\r\n\r\r\nSet Effect: 2.5% bonus to the strength of all Virtue implant secondary effects',0,1,0,1,NULL,0.0000,1,620,0),(33976,300,'Low-grade Virtue Omega','This implant does nothing in and of itself, but when used in conjunction with other Virtue implants it will boost their effect. \r\r\n\r\r\n10% bonus to the strength of all Virtue implant secondary effects.',0,1,0,1,NULL,0.0000,1,1506,0),(33981,1289,'Limited Hyperspatial Accelerator','This unit increases warp speed and acceleration.\r\r\n\r\r\nNo more than three Hyperspatial Accelerators can be fit to one ship.',50,5,0,1,NULL,3699250.0000,1,1931,0),(33982,158,'Limited Hyperspatial Accelerator Blueprint',' ',0,0.01,0,1,NULL,249980.0000,1,NULL,0),(33983,1289,'Experimental Hyperspatial Accelerator','This unit increases warp speed and acceleration.\r\r\n\r\r\nNo more than three Hyperspatial Accelerators can be fit to one ship.',50,5,0,1,NULL,3699250.0000,1,1931,0),(33984,158,'Experimental Hyperspatial Accelerator Blueprint',' ',0,0.01,0,1,NULL,249980.0000,1,NULL,0),(33985,1289,'Prototype Hyperspatial Accelerator','This unit increases warp speed and acceleration.\r\r\n\r\r\nNo more than three Hyperspatial Accelerators can be fit to one ship.',50,5,0,1,NULL,3699250.0000,1,1931,0),(33986,158,'Prototype Hyperspatial Accelerator Blueprint',' ',0,0.01,0,1,NULL,249980.0000,1,NULL,0),(33987,306,'Guristas Transponder Tower','The highest ranking personnel within this deadspace pocket reside here.',100000,100000000,10000,1,NULL,0.0000,0,NULL,0),(33988,526,'Guristas Data Sequence','This data salvaged from a Guristas Transponder Tower could be used to decrypt the locations of hidden pirate research sites. Unfortunately the data is in fragmentary form and hundreds, if not thousands, of sequences would be required to break the code. While individually it may be worthless, Mordu s Legion has been offering plenty to get their hands on them.',1,0.1,0,1,NULL,3328.0000,1,1840,0),(33989,1090,'Women\'s \'Hover\' Tights (black)','These black seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(33990,1276,'Tournament Micro Jump Unit',' ',10000,1,27000,1,NULL,2.0000,1,NULL,0),(33992,1083,'Accessories/Glasses/Monocle_01/Types/MonocleM01_RightBlack.type','Accessories/Glasses/Monocle_01/Types/MonocleM01_RightBlack.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(33993,1083,'Accessories/Glasses/Monocle_F_T02/Types/Monocle_F_T02_black_left.type','Accessories/Glasses/Monocle_F_T02/Types/Monocle_F_T02_black_left.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(33995,1084,'Tattoo/ArmLeft/Sleeve01/Types/Sleeve01_F_Left.type','Tattoo/ArmLeft/Sleeve01/Types/Sleeve01_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(33996,1084,'Tattoo/ArmLeft/Sleeve02/Types/Sleeve02_F_Left.type','Tattoo/ArmLeft/Sleeve02/Types/Sleeve02_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(33997,1084,'Tattoo/ArmLeft/Sleeve03/Types/Sleeve03_F_Left.type','Tattoo/ArmLeft/Sleeve03/Types/Sleeve03_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(33998,1084,'Tattoo/ArmLeft/Sleeve06/Types/Sleeve06_F_Left.type','Tattoo/ArmLeft/Sleeve06/Types/Sleeve06_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(33999,1084,'Tattoo/ArmLeft/Sleeve07/Types/Sleeve07_F_Left.type','Tattoo/ArmLeft/Sleeve07/Types/Sleeve07_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34000,1084,'Tattoo/ArmLeft/Sleeve09/Types/Sleeve09_F_Left.type','Tattoo/ArmLeft/Sleeve09/Types/Sleeve09_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34001,1084,'Tattoo/ArmLeft/Sleeve10/Types/Sleeve10_F_Left.type','Tattoo/ArmLeft/Sleeve10/Types/Sleeve10_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34002,1084,'Tattoo/ArmLeft/Sleeve11/Types/Sleeve11_F_Left.type','Tattoo/ArmLeft/Sleeve11/Types/Sleeve11_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34003,1084,'Tattoo/ArmLeft/Sleeve12/Types/Sleeve12_F_Left.type','Tattoo/ArmLeft/Sleeve12/Types/Sleeve12_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34004,1084,'Tattoo/ArmLeft/Sleeve13/Types/Sleeve13_F_Left.type','Tattoo/ArmLeft/Sleeve13/Types/Sleeve13_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34005,1084,'Tattoo/ArmLeft/Sleeve15/Types/Sleeve15_F_Left.type','Tattoo/ArmLeft/Sleeve15/Types/Sleeve15_F_Left.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34006,1084,'Tattoo/ArmRight/Sleeve01/Type/Sleeve01_F_Right.type','Tattoo/ArmRight/Sleeve01/Type/Sleeve01_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34007,1084,'Tattoo/ArmRight/Sleeve02/Type/Sleeve02_F_Right.type','Tattoo/ArmRight/Sleeve02/Type/Sleeve02_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34008,1084,'Tattoo/ArmRight/Sleeve03/Type/Sleeve03_F_Right.type','Tattoo/ArmRight/Sleeve03/Type/Sleeve03_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34009,1084,'Tattoo/ArmRight/Sleeve06/Type/Sleeve06_F_Right.type','Tattoo/ArmRight/Sleeve06/Type/Sleeve06_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34010,1084,'Tattoo/ArmRight/Sleeve07/Type/Sleeve07_F_Right.type','Tattoo/ArmRight/Sleeve07/Type/Sleeve07_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34011,1084,'Tattoo/ArmRight/Sleeve09/Type/Sleeve09_F_Right.type','Tattoo/ArmRight/Sleeve09/Type/Sleeve09_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34012,1084,'Tattoo/ArmRight/Sleeve10/Type/Sleeve10_F_Right.type','Tattoo/ArmRight/Sleeve10/Type/Sleeve10_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34013,1084,'Tattoo/ArmRight/Sleeve11/Type/Sleeve11_F_Right.type','Tattoo/ArmRight/Sleeve11/Type/Sleeve11_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34014,1084,'Tattoo/ArmRight/Sleeve12/Type/Sleeve12_F_Right.type','Tattoo/ArmRight/Sleeve12/Type/Sleeve12_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34015,1084,'Tattoo/ArmRight/Sleeve13/Type/Sleeve13_F_Right.type','Tattoo/ArmRight/Sleeve13/Type/Sleeve13_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34016,1084,'Tattoo/ArmRight/Sleeve15/Type/Sleeve15_F_Right.type','Tattoo/ArmRight/Sleeve15/Type/Sleeve15_F_Right.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34017,1271,'Women\'s \'Vise\' Cybernetic Arm (matte black left)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in colors of deepest night. Moreover, some of the traditionally larger muscles have replaced by full metal covers, as if they were turrets waiting to be awakened.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in pure black are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34018,1271,'Women\'s \'Vise\' Cybernetic Arm (black and orange ringed left)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in colors of deepest night. Moreover, some of the traditionally larger muscles have replaced by socketed metal pumps that are nested inside one another in concentric fashion, giving a slim and tight, yet powerful impression.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in sunset orange are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34019,1271,'Women\'s \'Vise\' Cybernetic Arm (black ringed left)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in colors of deepest night. Moreover, some of the traditionally larger muscles have replaced by socketed metal pumps that are nested inside one another in concentric fashion, giving a slim and tight, yet powerful impression.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34020,1271,'Women\'s \'Vise\' Cybernetic Arm (black and yellow left)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in blackest night. Moreover, some of the traditionally larger muscles have replaced by full metal covers, as if they were turrets waiting to be awakened.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in sunrise yellow are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34021,1271,'Women\'s \'Vise\' Cybernetic Arm (blue and black ringed left)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in colors of summer night. Moreover, some of the traditionally larger muscles have replaced by socketed metal pumps that are nested inside one another in concentric fashion, giving a slim and tight, yet powerful impression.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in deep black are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34022,1271,'Women\'s \'Vise\' Cybernetic Arm (blue and white left)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in celestial blue. Moreover, some of the traditionally larger muscles have replaced by full metal covers, as if they were turrets waiting to be awakened.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in purest white are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34023,1271,'Women\'s \'Vise\' Cybernetic Arm (white and gray ringed left)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in colors of unblemished white. Moreover, some of the traditionally larger muscles have replaced by socketed metal pumps that are nested inside one another in concentric fashion, giving a slim and tight, yet powerful impression.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in practical gray are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34024,1271,'Men\'s \'Crusher\' Cybernetic Arm (black and orange left)','The F-916.083 model \'Crusher\' Cybernetic Arm, in night black and sunset orange, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.1,0.5,0,1,NULL,0.0000,1,1836,0),(34025,1271,'Men\'s \'Crusher\' Cybernetic Arm (black and red left)','The F-916.083 model \'Crusher\' Cybernetic Arm, in night black and blood red, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34026,1271,'Men\'s \'Crusher\' Cybernetic Arm (black and yellow left)','The F-916.083 model \'Crusher\' Cybernetic Arm, in night black and sunrise yellow, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34027,1271,'Men\'s \'Crusher\' Cybernetic Arm (blue and white left)','The F-916.083 model \'Crusher\' Cybernetic Arm, in celestial blue and silvery white, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34028,1271,'Men\'s \'Crusher\' Cybernetic Arm (green camo left)','The F-916.083 model \'Crusher\' Cybernetic Arm, in militaristic green camo, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34029,1271,'Men\'s \'Crusher\' Cybernetic Arm (green and yellow left)','The F-916.083 model \'Crusher\' Cybernetic Arm, in marine green and golden yellow, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34030,1271,'Men\'s \'Crusher\' Cybernetic Arm (gunmetal left)','The F-916.083 model \'Crusher\' Cybernetic Arm, in the red brass of gunmetal, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34031,1271,'Women\'s \'Vise\' Cybernetic Arm (matte black right)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in colors of deepest night. Moreover, some of the traditionally larger muscles have replaced by full metal covers, as if they were turrets waiting to be awakened.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in pure black are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34032,1271,'Women\'s \'Vise\' Cybernetic Arm (black and orange ringed right)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in colors of deepest night. Moreover, some of the traditionally larger muscles have replaced by socketed metal pumps that are nested inside one another in concentric fashion, giving a slim and tight, yet powerful impression.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in sunset orange are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34033,1271,'Women\'s \'Vise\' Cybernetic Arm (black ringed right)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in colors of deepest night. Moreover, some of the traditionally larger muscles have replaced by socketed metal pumps that are nested inside one another in concentric fashion, giving a slim and tight, yet powerful impression.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34034,1271,'Women\'s \'Vise\' Cybernetic Arm (black and yellow right)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in blackest night. Moreover, some of the traditionally larger muscles have replaced by full metal covers, as if they were turrets waiting to be awakened.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in sunrise yellow are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34035,1271,'Women\'s \'Vise\' Cybernetic Arm (blue and black ringed right)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in colors of summer night. Moreover, some of the traditionally larger muscles have replaced by socketed metal pumps that are nested inside one another in concentric fashion, giving a slim and tight, yet powerful impression.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in deep black are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34036,1271,'Women\'s \'Vise\' Cybernetic Arm (blue and white right)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in celestial blue. Moreover, some of the traditionally larger muscles have replaced by full metal covers, as if they were turrets waiting to be awakened.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in purest white are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34037,1271,'Women\'s \'Vise\' Cybernetic Arm (white and gray ringed right)','The F-512.185 model \'Vise\' Cybernetic Arm is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure that they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nFor instance, there are no unwieldy mechanical joints visible anywhere on the device. The shoulder is instead covered with a number of tiny clamps whose design conveys the sinuous curved lines of capsuleer beauty while simultaneously ensuring the shoulder has more than its full range of mobility. The elbow, likewise, appears more human than machine, thanks in good part to the superstrong stretchable material that covers it entirely in colors of unblemished white. Moreover, some of the traditionally larger muscles have replaced by socketed metal pumps that are nested inside one another in concentric fashion, giving a slim and tight, yet powerful impression.\r\r\n\r\r\nThe hand on the Arm resembles a glove, and its delineated fingers in practical gray are delicate enough to feel even the slightest change of pressure in the air. The hand\'s internal sensors render it so nimble that it can hold on to almost anything, even the slightest wisp of material, without leaving a mark; yet so strong that the only time its grip can be forced against the owner\'s will to open, the rest of its owner will long since have been separated from the Arm.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34038,1271,'Men\'s \'Crusher\' Cybernetic Arm (black and orange right)','The F-916.083 model \'Crusher\' Cybernetic Arm, in night black and sunset orange, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34039,1271,'Men\'s \'Crusher\' Cybernetic Arm (black and red right)','The F-916.083 model \'Crusher\' Cybernetic Arm, in night black and blood red, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34040,1271,'Men\'s \'Crusher\' Cybernetic Arm (black and yellow right)','The F-916.083 model \'Crusher\' Cybernetic Arm, in night black and sunrise yellow, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34041,1271,'Men\'s \'Crusher\' Cybernetic Arm (blue and white right)','The F-916.083 model \'Crusher\' Cybernetic Arm, in celestial blue and silvery white, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34042,1271,'Men\'s \'Crusher\' Cybernetic Arm (green camo right)','The F-916.083 model \'Crusher\' Cybernetic Arm, in militaristic green camo, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34043,1271,'Men\'s \'Crusher\' Cybernetic Arm (green and yellow right)','The F-916.083 model \'Crusher\' Cybernetic Arm, in marine green and golden yellow, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34044,1271,'Men\'s \'Crusher\' Cybernetic Arm (gunmetal right)','The F-916.083 model \'Crusher\' Cybernetic Arm, in the red brass of gunmetal, is the latest in naturalistic technologies that aim to enhance the human experience rather than cause - or worsen - a disconnect from reality. As such, its components have been carefully designed to ensure they operate at a level of efficiency that is pleasing and empowering to the human mind, while not going too far beyond that level.\r\r\n\r\r\nThe purpose of its shoulder pad, for instance, is not just to absorb any number of shocks that a capsuleer might suffer inside and out of the capsule, but also function as a clamp - because this model, quite honestly, is so strong that if its internal push/pull sensors were to malfunction and it were to grip something with the full extent of its capabilities, it might very well tear the wearer\'s entire shoulder out of its socket.\r\r\n\r\r\nLikewise, scanners in the fingers can detect details unavailable to normal humans - particulars in heat, texture and light reflection - but are set on a timer whereby they limit the details after a while, because even a capsuleer\'s mind, which can multitask at near-superhuman levels, is not set up to handle a constant influx of unnecessary data. \r\r\n\r\r\nFinally, the upper arms have exposed and slanted machinery that resembles the striations of raw muscle. It could of course have been covered over, but was kept open to indicate the unfettered strength of the capsuleer in all that he does.',0.5,0.1,0,1,NULL,0.0000,1,1836,0),(34045,1090,'Women\'s \'Hover\' Tights (light)','These light, nearly nude seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34046,1090,'Women\'s \'Hover\' Tights (orange)','These orange seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34047,1090,'Women\'s \'Hover\' Tights (pink)','These pink seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34048,1090,'Women\'s \'Hover\' Tights (red)','These red seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34049,1090,'Women\'s \'Hover\' Tights (opaque black)','These opaque black seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34050,1090,'Women\'s \'Hover\' Tights (opaque blue)','These opaque blue seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34051,1090,'Women\'s \'Hover\' Tights (opaque gray)','These opaque gray seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34052,1090,'Women\'s \'Hover\' Tights (matte black)','These matte black seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34053,1090,'Women\'s \'Hover\' Tights (opaque purple)','These opaque purple seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34054,1090,'Women\'s \'Hover\' Tights (white)','These white seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34055,1090,'Women\'s \'Hover\' Tights (yellow)','These yellow seamed tights, casual and comfortable as they are, were in fact created from a material previously used by Sisters of EVE rescue squads when doing excavations in highly unstable areas. For the Sisters, the material was interwoven into an complex rope mechanism deployed whenever something (or someone inside something) needed to be pulled out with such immense force that every single supporting structure in the area might collapse. In all their rescue operations, the rope itself has never broken.\r\r\n\r\r\nIn short, the material is light, porous, and damn near unbreakable, retaining its shape without strangling the legs or being overstretched after removal, and it may be used for even the most vigorous physical activities with no ill effect.',0.1,0.1,0,1,NULL,0.0000,1,1944,0),(34056,1092,'Men\'s \'Nova\' Headwear (black)','This regal and complex piece of headwear is, as the perspicuous viewer may have suspected, of Amarr origin. It derives in part from a type of cap that certain Amarr missionaries would routinely wear during excursions into unknown territories; part for protection against the elements, part to identify themselves with a type of clothing they felt certain would not be found in heathen places, and part, the myth goes, to help frighten the locals into submission.\r\r\n\r\r\nThe intricate and highly decorated headwear, black as the darkness that awaits all of us who fail to find the glory of God, is emblematic of the infinite machineries of our god and the vast expanses it represents. Moreover, it\'s complete with the powerful arms reaching from the origin of thought, consciousness and the waking world, spreading out to remind the wearer that the Lord\'s grasp on our world is absolute.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34057,1092,'Men\'s \'Tectonic\' Headwear (matte black)','This imposing, interlocked piece of headwear comes from hardworking Caldari scientists, all of whom are of course fiercely loyal to the State\'s core cause of teamwork, cooperation and personal sacrifice for the greater good. \r\r\n\r\r\nIt is composed of sliding plates - matte black, so as to better fit in with the crowd - that adjust fully to the wearer\'s head. It is a complex assemblage of parts that shift in union, none of them out of place, and none of them failing to do its duty as supporter and protector of the whole.\r\r\n\r\r\nEach plate is, in and of itself, immensely resilient to all manner of wear and tear, but it\'s only when fitted into the complicated mesh that their resilience rises by an order of magnitude, each part linking to the next to form a layer of pure strength.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34058,1092,'Men\'s \'Tectonic\' Headwear (white)','This imposing, interlocked piece of headwear comes from hardworking Caldari scientists, all of whom are of course fiercely loyal to the State\'s core cause of teamwork, cooperation and personal sacrifice for the greater good. \r\r\n\r\r\nIt is composed of sliding plates - white and unblemished, all the better to subtly indicate the purity of the Caldari working spirit - that adjust fully to the wearer\'s head. It is a complex assemblage of parts that shift in union, none of them out of place, and none of them failing to do its duty as supporter and protector of the whole.\r\r\n\r\r\nEach [white] plate is, in and of itself, immensely resilient to all manner of wear and tear, but it\'s only when fitted into the complicated mesh that their resilience rises by an order of magnitude, each part linking to the next to form a layer of pure strength.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34059,1092,'Men\'s \'Nova\' Headwear (silver)','This regal and complex piece of headwear is, as the perspicuous viewer may have suspected, of Amarr origin. It derives in part from a type of cap that certain Amarr missionaries would routinely wear during excursions into unknown territories; part for protection against the elements, part to identify themselves with a type of clothing they felt certain would not be found in heathen places, and part, the myth goes, to help frighten the locals into submission.\r\r\n\r\r\nThe intricate and highly decorated headwear, silver as the twin moons over Athra, is emblematic of the infinite machineries of our god and the vast expanses it represents. Moreover, it\'s complete with the powerful arms reaching from the origin of thought, consciousness and the waking world, spreading out to remind the wearer that the Lord\'s grasp on our world is absolute.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34060,1092,'Men\'s \'Nova\' Headwear (gold)','This regal and complex piece of headwear is, as the perspicuous viewer may have suspected, of Amarr origin. It derives in part from a type of cap that certain Amarr missionaries would routinely wear during excursions into unknown territories; part for protection against the elements, part to identify themselves with a type of clothing they felt certain would not be found in heathen places, and part, the myth goes, to help frighten the locals into submission.\r\r\n\r\r\nThe intricate and highly decorated headwear, golden as the sun rising on the magnificent Amarr empire, is emblematic of the infinite machineries of our god and the vast expanses it represents. Moreover, it\'s complete with the powerful arms reaching from the origin of thought, consciousness and the waking world, spreading out to remind the wearer that the Lord\'s grasp on our world is absolute.',0.1,0.1,0,1,NULL,0.0000,1,1943,0);
INSERT INTO `invTypes` VALUES (34061,1092,'Men\'s \'Nova\' Headwear (bronze)','This regal and complex piece of headwear is, as the perspicuous viewer may have suspected, of Amarr origin. It derives in part from a type of cap that certain Amarr missionaries would routinely wear during excursions into unknown territories; part for protection against the elements, part to identify themselves with a type of clothing they felt certain would not be found in heathen places, and part, the myth goes, to help frighten the locals into submission.\r\r\n\r\r\nThe intricate and highly decorated headwear, bronze as the blood that flows from heathens, is emblematic of the infinite machineries of our god and the vast expanses it represents. Moreover, it\'s complete with the powerful arms reaching from the origin of thought, consciousness and the waking world, spreading out to remind the wearer that the Lord\'s grasp on our world is absolute.\r\r\n',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34062,1092,'Men\'s \'Tectonic\' Headwear (metal)','This imposing, interlocked piece of headwear comes from hardworking Caldari scientists, all of whom are of course fiercely loyal to the State\'s core cause of teamwork, cooperation and personal sacrifice for the greater good. \r\r\n\r\r\nIt is composed of sliding plates - with a metal sheen, all the better to subtly indicate Caldari strength - that adjust fully to the wearer\'s head. It is a complex assemblage of parts that shift in union, none of them out of place, and none of them failing to do its duty as supporter and protector of the whole.\r\r\n\r\r\nEach plate is, in and of itself, immensely resilient to all manner of wear and tear, but it\'s only when fitted into the complicated mesh that their resilience rises by an order of magnitude, each part linking to the next to form a layer of pure strength.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34063,1092,'Men\'s \'Tectonic\' Headwear (shiny black)','This imposing, interlocked piece of headwear comes from hardworking Caldari scientists, all of whom are of course fiercely loyal to the State\'s core cause of teamwork, cooperation and personal sacrifice for the greater good. \r\r\n\r\r\nIt is composed of sliding plates - with a shiny metal sheen, all the better to subtly indicate the limitless depths of Caldari strength and unity - that adjust fully to the wearer\'s head. It is a complex assemblage of parts that shift in union, none of them out of place, and none of them failing to do its duty as supporter and protector of the whole.\r\r\n\r\r\nEach plate is, in and of itself, immensely resilient to all manner of wear and tear, but it\'s only when fitted into the complicated mesh that their resilience rises by an order of magnitude, each part linking to the next to form a layer of pure strength.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34064,1092,'Women\'s \'Aeriform\' Headwear (cyan)','This translucent cyan decoration was created for lightweight comfort. As part of its design it covers only part of the head, all the better to indicate a debonair look for the most fashionable (and, truth be told, richest and most powerful) individuals in the cluster. It is the kind of headgear that might be taken into sports, into high-speed traffic, or simply into a meeting of high-powered executives, where its casual style makes it very apparent who\'s boss.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34065,1092,'Women\'s \'Blades\' Headwear (gunmetal)','This sharp-looking decoration in gunmetal hue draws its inspiration from ancient Amarr tradition, and has received greater attention in recent years due to the tendency of people of royal blood to wear it at official functions.\r\r\n\r\r\nIt is regal and imposing, with an otherworldly - and some say devilish - appearance, and in its clean design it is said to offer several different interpretations depending on whether the onlooker is standing at attention or supplicating on their knees. It  might be a halo around the wearer\'s head, gently implying her sanctified nature. it might be a set of wings that indicate the eventual heavenly flight of her soul. Or it might be the spikes on which those who displease her will be impaled.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34066,1092,'Women\'s \'Aeriform\' Headwear (blue)','This translucent blue decoration was created for lightweight comfort. As part of its design it covers only part of the head, all the better to indicate a debonair look for the most fashionable (and, truth be told, richest and most powerful) individuals in the cluster. It is the kind of headgear that might be taken into sports, into high-speed traffic, or simply into a meeting of high-powered executives, where its casual style makes it very apparent who\'s boss.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34067,1092,'Women\'s \'Blades\' Headwear (platinum)','This sharp-looking decoration in platinum hue draws its inspiration from ancient Amarr tradition, and has received greater attention in recent years due to the tendency of people of royal blood to wear it at official functions.\r\r\n\r\r\nIt is regal and imposing, with an otherworldly - and some say devilish - appearance, and in its clean design it is said to offer several different interpretations depending on whether the onlooker is standing at attention or supplicating on their knees. It  might be a halo around the wearer\'s head, gently implying her sanctified nature. it might be a set of wings that indicate the eventual heavenly flight of her soul. Or it might be the spikes on which those who displease her will be impaled.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34068,1092,'Women\'s \'Spiderweb\' Headwear (black)','This elegant, intricately decorated black lacework is a perfect match for the pilot who wants her bodily decorations to have a nice undertone of her time in the capsule, while simultaneously reminding the lucky onlookers that she is, just like the decoration, elegant, cryptic, and not quite of this world.\r\r\n\r\r\nThe material is a delicate mesh of rare metals intermixed with sheets of superthin, stretchable atomic structures. It\'s strong enough to withstand any rigors and to help the head\'s skin breathe easy, while being supple enough to follow along with even the most minute shifts in expression; all the more for a lady of immense power, diplomacy, class and - for a select few - immeasurable deviousness, to slyly express her thoughts to the world.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34069,1092,'Women\'s \'Blades\' Headwear (gold)','This sharp-looking decoration in golden hue draws its inspiration from ancient Amarr tradition, and has received greater attention in recent years due to the tendency of people of royal blood to wear it at official functions.\r\r\n\r\r\nIt is regal and imposing, with an otherworldly - and some say devilish - appearance, and in its clean design it is said to offer several different interpretations depending on whether the onlooker is standing at attention or supplicating on their knees. It  might be a halo around the wearer\'s head, gently implying her sanctified nature. it might be a set of wings that indicate the eventual heavenly flight of her soul. Or it might be the spikes on which those who displease her will be impaled.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34070,1092,'Women\'s \'Aeriform\' Headwear (orange)','This translucent orange decoration was created for lightweight comfort. As part of its design it covers only part of the head, all the better to indicate a debonair look for the most fashionable (and, truth be told, richest and most powerful) individuals in the cluster. It is the kind of headgear that might be taken into sports, into high-speed traffic, or simply into a meeting of high-powered executives, where its casual style makes it very apparent who\'s boss.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34071,1092,'Women\'s \'Blades\' Headwear (black)','This sharp-looking decoration in pitch-black hue draws its inspiration from ancient Amarr tradition, and has received greater attention in recent years due to the tendency of people of royal blood to wear it at official functions.\r\r\n\r\r\nIt is regal and imposing, with an otherworldly - and some say devilish - appearance, and in its clean design it is said to offer several different interpretations depending on whether the onlooker is standing at attention or supplicating on their knees. It  might be a halo around the wearer\'s head, gently implying her sanctified nature. it might be a set of wings that indicate the eventual heavenly flight of her soul. Or it might be the spikes on which those who displease her will be impaled.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34072,1092,'Women\'s \'Spiderweb\' Headwear (copper)','This elegant, intricately decorated lacework with a copper finish is a perfect match for the pilot who wants her bodily decorations to have a nice undertone of her time in the capsule, while simultaneously reminding the lucky onlookers that she is, just like the decoration, elegant, cryptic, and not quite of this world.\r\r\n\r\r\nThe material is a delicate mesh of rare metals intermixed with sheets of superthin, stretchable atomic structures. It\'s strong enough to withstand any rigors and to help the head\'s skin breathe easy, while being supple enough to follow along with even the most minute shifts in expression; all the more for a lady of immense power, diplomacy, class and - for a select few - immeasurable deviousness, to slyly express her thoughts to the world.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34073,1092,'Women\'s \'Spiderweb\' Headwear (metallic)','This elegant, intricately decorated lacework with a metallic sheen is a perfect match for the pilot who wants her bodily decorations to have a nice undertone of her time in the capsule, while simultaneously reminding the lucky onlookers that she is, just like the decoration, elegant, cryptic, and not quite of this world.\r\r\n\r\r\nThe material is a delicate mesh of rare metals intermixed with sheets of superthin, stretchable atomic structures. It\'s strong enough to withstand any rigors and to help the head\'s skin breathe easy, while being supple enough to follow along with even the most minute shifts in expression; all the more for a lady of immense power, diplomacy, class and - for a select few - immeasurable deviousness, to slyly express her thoughts to the world.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34074,1092,'Women\'s \'Blades\' Headwear (jade)','This sharp-looking decoration in green jade hue draws its inspiration from ancient Amarr tradition, and has received greater attention in recent years due to the tendency of people of royal blood to wear it at official functions.\r\r\n\r\r\nIt is regal and imposing, with an otherworldly - and some say devilish - appearance, and in its clean design it is said to offer several different interpretations depending on whether the onlooker is standing at attention or supplicating on their knees. It  might be a halo around the wearer\'s head, gently implying her sanctified nature. it might be a set of wings that indicate the eventual heavenly flight of her soul. Or it might be the spikes on which those who displease her will be impaled.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34075,1092,'hair/Hair_Medium_Hp_01/Types/Hair_Medium_Hp_01_Simple.type','hair/Hair_Medium_Hp_01/Types/Hair_Medium_Hp_01_Simple.type',0.1,0.1,0,1,NULL,0.0000,0,NULL,0),(34076,1092,'Women\'s \'Aeriform\' Headwear (clear)','This translucent decoration was created for lightweight comfort. As part of its design it covers only part of the head, all the better to indicate a debonair look for the most fashionable (and, truth be told, richest and most powerful) individuals in the cluster. It is the kind of headgear that might be taken into sports, into high-speed traffic, or simply into a meeting of high-powered executives, where its casual style makes it very apparent who\'s boss.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34077,1092,'Women\'s \'Spiderweb\' Headwear (golden)','This elegant, intricately decorated golden lacework is a perfect match for the pilot who wants her bodily decorations to have a nice undertone of her time in the capsule, while simultaneously reminding the lucky onlookers that she is, just like the decoration, elegant, cryptic, and not quite of this world.\r\r\n\r\r\nThe material is a delicate mesh of rare metals intermixed with sheets of superthin, stretchable atomic structures. It\'s strong enough to withstand any rigors and to help the head\'s skin breathe easy, while being supple enough to follow along with even the most minute shifts in expression; all the more for a lady of immense power, diplomacy, class and - for a select few - immeasurable deviousness, to slyly express her thoughts to the world.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34078,1092,'Women\'s \'Aeriform\' Headwear (black)','This opaque black decoration was created for lightweight comfort. As part of its design it covers only part of the head, all the better to indicate a debonair look for the most fashionable (and, truth be told, richest and most powerful) individuals in the cluster. It is the kind of headgear that might be taken into sports, into high-speed traffic, or simply into a meeting of high-powered executives, where its casual style makes it very apparent who\'s boss.',0.1,0.1,0,1,NULL,0.0000,1,1943,0),(34079,1091,'Feet/SpaceBoots01F/Types/spaceboots01f_black.type','Feet/SpaceBoots01F/Types/spaceboots01f_black.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34080,1091,'Women\'s \'Eternity\' Boots (Black/Gold)','Designer: Sennda of Emrayur\r\r\n\r\r\nWith every stunning outfit there is a pair of boots to tie the look together. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious black with golden detailing, and embedded with specialized nanofibers to give it a unique brilliant finish. Paired with the \'Eternity\' suit and top, these striking boots are the culmination of a look designed to turn heads.',0.5,0.1,0,1,4,0.0000,1,1404,0),(34081,1091,'Feet/SpaceBoots01F/Types/spaceboots01f_blue.type','Feet/SpaceBoots01F/Types/spaceboots01f_blue.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34082,1091,'Feet/SpaceBoots01F/Types/spaceboots01f_brown.type','Feet/SpaceBoots01F/Types/spaceboots01f_brown.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34083,1091,'Women\'s \'Eternity\' Boots (Olive)','Designer: Sennda of Emrayur\r\r\n\r\r\nWith every stunning outfit there is a pair of boots to tie the look together. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious olive green with golden detailing, and embedded with specialized nanofibers to give it a unique brilliant finish. Paired with the \'Eternity\' suit and top, these striking boots are the culmination of a look designed to turn heads.',0.5,0.1,0,1,4,0.0000,1,1404,0),(34084,1091,'Feet/SpaceBoots01F/Types/spaceboots01f_orange.type','Feet/SpaceBoots01F/Types/spaceboots01f_orange.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34085,1091,'Feet/SpaceBoots01F/Types/spaceboots01f_red.type','Feet/SpaceBoots01F/Types/spaceboots01f_red.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34086,1091,'Women\'s \'Eternity\' Boots (Black/Red)','Designer: Sennda of Emrayur\r\r\n\r\r\nWith every stunning outfit there is a pair of boots to tie the look together. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious black with red and white detailing, and embedded with specialized nanofibers to give it a unique brilliant finish. Paired with the \'Eternity\' suit and top, these striking boots are the culmination of a look designed to turn heads. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1404,0),(34087,1091,'Feet/SpaceBoots01F/Types/spaceboots01f_stealth.type','Feet/SpaceBoots01F/Types/spaceboots01f_stealth.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34088,1091,'Women\'s \'Eternity\' Boots (White)','Designer: Sennda of Emrayur\r\r\n\r\r\nWith every stunning outfit there is a pair of boots to tie the look together. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious white with black detailing, and embedded with specialized nanofibers to give it a unique brilliant finish. Paired with the \'Eternity\' suit and top, these striking boots are the culmination of a look designed to turn heads.',0.5,0.1,0,1,4,0.0000,1,1404,0),(34089,1091,'Women\'s \'Eternity\' Boots (Yellow)','Designer: Sennda of Emrayur\r\r\n\r\r\nWith every stunning outfit there is a pair of boots to tie the look together. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious yellow with black detailing, and embedded with specialized nanofibers to give it a unique brilliant finish. Paired with the \'Eternity\' suit and top, these striking boots are the culmination of a look designed to turn heads.',0.5,0.1,0,1,4,0.0000,1,1404,0),(34090,1088,'Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_black.type','Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_black.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34091,1088,'Women\'s \'Eternity\' Suit Top (Black/Gold)','Designer: Sennda of Emrayur\r\r\n\r\r\nWith a fashion forward approach to spacewear, the unique sleeve and collar design will turn heads even in the Crystal Boulevard. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious black with golden detailing, and embedded with specialized nanofibers to give it a unique brilliant finish. Paired with the \'Eternity\' suit, the top is the perfect complement to an already bold look.\r\r\n',0.5,0.1,0,1,4,0.0000,1,1405,0),(34092,1088,'Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_blue.type','Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_blue.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34093,1088,'Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_brown.type','Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_brown.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34094,1088,'Women\'s \'Eternity\' Suit Top (Olive)','Designer: Sennda of Emrayur\r\r\n\r\r\nWith a fashion forward approach to spacewear, the unique sleeve and collar design will turn heads even in the Crystal Boulevard. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious olive green with golden detailing, and embedded with specialized nanofibers to give it a unique brilliant finish. Paired with the \'Eternity\' suit, the top is the perfect complement to an already bold look.\r\r\n',0.5,0.1,0,1,4,0.0000,1,1405,0),(34095,1088,'Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_orange.type','Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_orange.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34096,1088,'Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_red.type','Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_red.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34097,1088,'Women\'s \'Eternity\' Suit Top (Black/Red)','Designer: Sennda of Emrayur\r\r\n\r\r\nWith a fashion forward approach to spacewear, the unique sleeve and collar design will turn heads even in the Crystal Boulevard. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious black with red and white detailing, and embedded with specialized nanofibers to give it a unique brilliant finish. Paired with the \'Eternity\' suit, the top is the perfect complement to an already bold look.\r\r\n',0.5,0.1,0,1,4,0.0000,1,1405,0),(34098,1088,'Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_stealth.type','Outer/SpaceSuit_Top_01/Types/spacesuit_01_top_f_stealth.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34099,1088,'Women\'s \'Eternity\' Suit Top (White)','Designer: Sennda of Emrayur\r\r\n\r\r\nWith a fashion forward approach to spacewear, the unique sleeve and collar design will turn heads even in the Crystal Boulevard. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious white with black detailing, and embedded with specialized nanofibers to give it a unique brilliant finish. Paired with the \'Eternity\' suit, the top is the perfect complement to an already bold look.\r\r\n',0.5,0.1,0,1,4,0.0000,1,1405,0),(34100,1088,'Women\'s \'Eternity\' Suit Top (Yellow)','Designer: Sennda of Emrayur\r\r\n\r\r\nWith a fashion forward approach to spacewear, the unique sleeve and collar design will turn heads even in the Crystal Boulevard. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious yellow with black detailing, and embedded with specialized nanofibers to give it a unique brilliant finish. Paired with the \'Eternity\' suit, the top is the perfect complement to an already bold look.\r\r\n',0.5,0.1,0,1,4,0.0000,1,1405,0),(34101,1090,'bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_black.type','bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_black.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34102,1090,'Women\'s \'Eternity\' Suit (Black/Gold)','Designer: Sennda of Emrayur\r\r\n\r\r\nThe  Eternity  suit is a bold statement of fashion forward thinking, only worn by those brave enough to don this form fitting attire. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious metallic black, and embedded with specialized nanofibers to give it a unique brilliant finish. Golden detailing and deep black accents complete the look, which can be worn on its own, or with the matching sleeve and collar suit top.',0.5,0.1,0,1,4,0.0000,1,1403,0),(34103,1090,'bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_blue.type','bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_blue.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34104,1090,'bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_brown.type','bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_brown.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34105,1090,'Women\'s \'Eternity\' Suit (Olive)','Designer: Sennda of Emrayur\r\r\n\r\r\nThe  Eternity  suit is a bold statement of fashion forward thinking, only worn by those brave enough to don this form fitting attire. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious olive green, and embedded with specialized nanofibers to give it a unique brilliant finish. Golden detailing and fine green patterning complete the look, which can be worn on its own, or with the matching sleeve and collar suit top. \r\r\n\r\r\n',0.5,0.1,0,1,4,0.0000,1,1403,0),(34106,1090,'bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_orange.type','bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_orange.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34107,1090,'bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_red.type','bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_red.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34108,1090,'Women\'s \'Eternity\' Suit (Black/Red)','Designer: Sennda of Emrayur\r\r\n\r\r\nThe  Eternity  suit is a bold statement of fashion forward thinking, only worn by those brave enough to don this form fitting attire. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious black, and embedded with specialized nanofibers to give it a unique brilliant finish. White detailing and deep red accents complete the look, which can be worn on its own or with the matching sleeve and collar suit top. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1403,0),(34109,1090,'bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_stealth.type','bottomOuter/SpaceSuit_01/Types/spacesuit_01_f_stealth.type',0.5,0.1,0,1,NULL,0.0000,0,NULL,0),(34110,1090,'Women\'s \'Eternity\' Suit (White)','Designer: Sennda of Emrayur\r\r\n\r\r\nThe  Eternity  suit is a bold statement of fashion forward thinking, only worn by those brave enough to don this form fitting attire. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious white, and embedded with specialized nanofibers to give it a unique brilliant finish. Black detailing and white camouflaged patterning complete the look, which can be worn on its own or with the matching sleeve and collar suit top. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1403,0),(34111,1090,'Women\'s \'Eternity\' Suit (Yellow)','Designer: Sennda of Emrayur\r\r\n\r\r\nThe  Eternity  suit is a bold statement of fashion forward thinking, only worn by those brave enough to don this form fitting attire. Each piece is handcrafted from the softest genetically enhanced livestock leather, dyed a luxurious yellow, and embedded with specialized nanofibers to give it a unique brilliant finish. Black detailing and yellow accents complete the look, which can be worn on its own, or with the matching sleeve and collar suit top. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1403,0),(34112,310,'Abandoned CRC Monitoring Station','This relay station was used by the Communications Relay Committee until July YC116, when it was abandoned after an assault by Dominations forces.\r\r\n\r\r\nContaining equipment used by the CRC to monitor and intercept radio, wireless and fluid router transmissions, the DED believe that the site was attacked after intercepting encrypted data broadcasted to Angel Cartel headquarters from a scouting party in Evati.\r\r\n\r\r\nThe CRC operator of this site, codenamed  Eshtir , has vanished without trace and is now reportedly on the run from Dominations forces, whom have placed a sizeable bounty on his head. \r\r\n',1,1,0,1,NULL,0.0000,0,NULL,0),(34118,27,'Megathron Quafe Edition','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.',98400000,486000,675,1,8,190932898.0000,0,NULL,0),(34119,107,'Megathron Quafe Edition Blueprint',' ',0,0.01,0,1,NULL,1250000000.0000,1,NULL,0),(34120,1297,'Mobile Competitive Vault','..',10000,300,0,1,NULL,33230852.0000,0,NULL,0),(34121,1268,'Mobile Competitive Vault Blueprint',' ',0,0.01,0,1,NULL,150000000.0000,1,NULL,0),(34122,1299,'Limited Jump Drive Economizer','This unit decreases the isotope fuel requirements of starship jump drives.\r\r\n\r\r\nCan only be fitted to Jump Freighters and Rorquals.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,3500,0,1,NULL,6319600.0000,1,1941,0),(34123,158,'Limited Jump Drive Economizer Blueprint',' ',0,0.01,0,1,NULL,249980.0000,1,NULL,0),(34124,1299,'Experimental Jump Drive Economizer','This unit decreases the isotope fuel requirements of starship jump drives.\r\r\n\r\r\nCan only be fitted to Jump Freighters and Rorquals.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,3500,0,1,NULL,6319600.0000,1,1941,0),(34125,158,'Experimental Jump Drive Economizer Blueprint',' ',0,0.01,0,1,NULL,249980.0000,1,NULL,0),(34126,1299,'Prototype Jump Drive Economizer','This unit decreases the isotope fuel requirements of starship jump drives.\r\r\n\r\r\nCan only be fitted to Jump Freighters and Rorquals.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',50,3500,0,1,NULL,6319600.0000,1,1941,0),(34127,158,'Prototype Jump Drive Economizer Blueprint',' ',0,0.01,0,1,NULL,249980.0000,1,NULL,0),(34132,1301,'Pilot\'s Body Resculpt Certificate','This certificate allows you a single resculpt of your pilot\'s facial features and body shape. Once you activate the certificate it will be consumed immediately, and the next time you enter pilot customization you can make use of the full resculpt.',0,0.01,0,1,NULL,0.0000,1,1942,0),(34133,1301,'Multiple Pilot Training Certificate','This certificate allows you to train multiple pilots on the same account at the same time. Once used, it will allow you to either activate an additional training queue (up to a maximum of two) or extend the duration of an already active additional queue. The certificate is consumed immediately upon activation, and its training queue lasts thirty (30) days.\r\r\n\r\r\nPlease note that under no circumstances can you train two skills simultaneously on the <b>same</b> pilot.',0,0.01,0,1,NULL,0.0000,1,1942,0),(34134,988,'Wormhole E004','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34135,988,'Wormhole L005','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34136,988,'Wormhole Z006','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34137,988,'Wormhole M001','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34138,988,'Wormhole C008','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34139,988,'Wormhole G008','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34140,988,'Wormhole Q003','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34141,818,'Burner Dramiel','This individual is a rogue element of the Angel Cartel and should be considered highly dangerous.\r\r\n\r\r\nThe motivation for their activities are unknown - it could be to test-run experimental technology, to try secret new battle tactics on the local colonists, or just to splinter off their faction in time-honored fashion.',750000,19700,235,1,32,0.0000,0,NULL,0),(34142,818,'Burner Worm','This individual is a rogue element of the Guristas Pirates and should be considered highly dangerous.\r\r\n\r\r\nThe motivation for their activities are unknown - it could be to test-run experimental technology, to try secret new battle tactics on the local colonists, or just to splinter off their faction in time-honored fashion.',1480000,19700,235,1,1,0.0000,0,NULL,0),(34143,818,'Burner Daredevil','This individual is a rogue element of the Serpentis Corporation and should be considered highly dangerous.\r\r\n\r\r\nThe motivation for their activities are unknown - it could be to test-run experimental technology, to try secret new battle tactics on the local colonists, or just to splinter off their faction in time-honored fashion.',823000,19700,235,1,8,0.0000,0,NULL,0),(34144,818,'Burner Cruor','This individual is a rogue element of the Blood Raiders and should be considered highly dangerous.\r\r\n\r\r\nThe motivation for their activities are unknown - it could be to test-run experimental technology, to try secret new battle tactics on the local colonists, or just to splinter off their faction in time-honored fashion.',1203000,19700,235,1,4,0.0000,0,NULL,0),(34145,818,'Burner Succubus','This individual is a rogue element of Sansha\'s Nation and should be considered highly dangerous.\r\r\n\r\r\nThe motivation for their activities are unknown - it could be to test-run experimental technology, to try secret new battle tactics on the local colonists, or just to splinter off their faction in time-honored fashion.',965000,19700,235,1,4,0.0000,0,NULL,0),(34151,27,'Rattlesnake Victory Edition','In the time-honored tradition of pirates everywhere, Korako  Rabbit\' Kosakami shamelessly stole the idea of the Scorpion-class battleship and put his own spin on it.  The result: the fearsome Rattlesnake, flagship of any large Gurista attack force.  There are, of course, also those who claim things were the other way around; that the notorious silence surrounding the Scorpion\'s own origins is, in fact, an indication of its having been designed by Kosakami all along.',99300000,486000,665,1,1,157405934.0000,1,1380,0),(34153,107,'Rattlesnake Victory Edition Blueprint',' ',0,0.01,0,1,NULL,1800000000.0000,1,NULL,0),(34154,818,'Burner Burst','This Burst is flown by an elite support pilot that recently went rogue from the Republic Fleet and should be considered highly dangerous.\r\r\n\r\r\nFormerly part of a crack commando unit that was sent to prison by a military court, this individual promptly escaped and has been operating as a soldier of fortune ever since.',1420000,17100,225,1,2,0.0000,0,NULL,0),(34155,818,'Burner Jaguar','This Jaguar is flown by an elite assault pilot that recently went rogue from the Republic Fleet and should be considered highly dangerous.\r\r\n\r\r\nFormerly part of a crack commando unit that was sent to prison by a military court, this individual promptly escaped and has been operating as a soldier of fortune ever since.',1366000,27289,130,1,2,0.0000,0,NULL,0),(34156,1088,'Men\'s \'Marshal\' Jacket (Caldari)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of the Caldari State. Its slanted lines in dark blue over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the blue hues on a black background running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34157,1088,'Men\'s \'Marshal\' Jacket (Amarr)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of the Amarr Empire. Its slanted lines in black on brown over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the golden  hues running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34158,1088,'Men\'s \'Marshal\' Jacket (Minmatar)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of the Minmatar Republic. Its slanted lines in copper brown over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the darker hues running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34159,1088,'Men\'s \'Marshal\' Jacket (Gallente)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of the Gallente Federation. Its slanted lines in shining turquoise over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the black hues running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34160,1088,'Men\'s \'Marshal\' Jacket (ORE)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of ORE. Its slanted lines in matte gold over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the black hues running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34161,1088,'Men\'s \'Marshal\' Jacket (Sisters of EVE)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of the Sisters of EVE. Its slanted lines in purest white over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the pitch black running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34162,1088,'Men\'s \'Marshal\' Jacket (Mordu\'s Legion)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of Mordu\'s Legion. Its slanted lines in matte black over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the outlines running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34163,1088,'Men\'s \'Marshal\' Jacket (InterBus)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of InterBus. Its slanted lines in sunset orange over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the darker outlines running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,4,0.0000,1,1399,0),(34164,1088,'Men\'s \'Marshal\' Jacket (Angel Cartel)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of the Angel Cartel. Its slanted lines in light blue over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the black hues running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34165,1088,'Men\'s \'Marshal\' Jacket (Sansha\'s Nation)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of Sansha\'s Nation. Its slanted lines in dark brown over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the olive hues running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34166,1088,'Men\'s \'Marshal\' Jacket (Blood Raiders)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of the Blood Raiders. Its slanted lines in pitch black over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the crimson hues running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34167,1088,'Men\'s \'Marshal\' Jacket (Guristas)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of the Guristas. Its slanted lines in light brown over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the black hues running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34168,1088,'Men\'s \'Marshal\' Jacket (Serpentis)','This jacket indicates, with a casual but deadly certainty, that the wearer is a proud supporter of the Serpentis. Its slanted lines in shiny gold over the shoulder and forearms give the impression of a potential for unimaginable speed. Meanwhile, the darker outlines running up front and back - in a column rising through the spine and chest and eventually fountaining up through the shoulders - remind any onlookers that they\'re looking at a man of immense power.',0.5,0.1,0,1,NULL,0.0000,1,1399,0),(34169,1088,'Women\'s \'Gunner\' Jacket (Caldari)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A solid blue front with outlines of a rising pillar serve to underline your undeniable and unyielding presence, while pitch black sleeves give you the commanding appearance you deserve. Finally, the logo of the Caldari State advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34170,1088,'Women\'s \'Gunner\' Jacket (Amarr)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A solid bronze pillar rises in front and back on a dark brown background to underline your undeniable and unyielding presence, while armbands and epaulettes give you the commanding appearance you deserve. Finally, the logo of the Amarr Empire advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34171,1088,'Women\'s \'Gunner\' Jacket (Minmatar)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A solid dark pillar rises in front and back to underline your undeniable and unyielding presence, while light brown armbands and epaulettes give you the commanding appearance you deserve. Finally, the logo of the Minmatar Republic advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34172,1088,'Women\'s \'Gunner\' Jacket (Gallente)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A solid turquoise pillar rises in front and back to underline your undeniable and unyielding presence, while black armbands and epaulettes give you the commanding appearance you deserve. Finally, the logo of the Gallente Federation advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34173,1088,'Women\'s \'Gunner\' Jacket (ORE)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A dark pillar rises in front and back to underline your undeniable and unyielding presence, while armbands and epaulettes in matte gold give you the commanding appearance you deserve. Finally, the logo of ORE advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34174,1088,'Women\'s \'Gunner\' Jacket (Sisters of EVE)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A solid black pillar rises in front and back to underline your undeniable and unyielding presence, while armbands and epaulettes of purest white on red give you the commanding appearance you deserve. Finally, the logo of the Sisters of EVE advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34175,1088,'Women\'s \'Gunner\' Jacket (Mordu\'s Legion)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. An outlined pillar rises in front and back to underline your undeniable and unyielding presence, while pitch black matte sleeves give you the commanding appearance you deserve. Finally, the logo of Mordu\'s Legion advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34176,1088,'Women\'s \'Gunner\' Jacket (InterBus)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A solid black pillar rises in front and back to underline your undeniable and unyielding presence, while armbands and epaulettes in sunset orange give you the commanding appearance you deserve. Finally, the logo of InterBus advertises your proud support for the only faction that matters.',0.5,0.1,0,1,4,0.0000,1,1405,0),(34177,1088,'Women\'s \'Gunner\' Jacket (Angel Cartel)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A solid pillar of black rises in front and back to underline your undeniable and unyielding presence, while sky-blue armbands and epaulettes give you the commanding appearance you deserve. Finally, the logo of the Angel Cartel advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34178,1088,'Women\'s \'Gunner\' Jacket (Sansha\'s Nation)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A solid olive pillar rises in front and back to underline your undeniable and unyielding presence, while armbands and epaulettes in the same color on a dark green background give you the commanding appearance you deserve. Finally, the logo of Sansha\'s Nation advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34179,1088,'Women\'s \'Gunner\' Jacket (Blood Raiders)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A solid crimson pillar rises in front and back to underline your undeniable and unyielding presence, while an extended length of shiny black from wrist to wrist gives you the commanding appearance you deserve. Finally, the logo of the Blood Raiders advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34180,1088,'Women\'s \'Gunner\' Jacket (Guristas)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. A dark pillar rises in front and back to underline your undeniable and unyielding presence, while light brown armbands and epaulettes give you the commanding appearance you deserve. Finally, the logo of the Guristas advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34181,1088,'Women\'s \'Gunner\' Jacket (Serpentis)','Advertise your stature as the terror of the celestial skies in this sleek, comfortable jacket. An outlined pillar rises in front and back to underline your undeniable and unyielding presence, while armbands and epaulettes in glinting gold give you the commanding appearance you deserve. Finally, the logo of the Serpentis advertises your proud support for the only faction that matters.',0.5,0.1,0,1,NULL,0.0000,1,1405,0),(34182,818,'Burner Bantam','This Bantam is flown by an elite support pilot that recently went rogue from the Caldari Navy and should be considered highly dangerous.\r\r\n\r\r\nFormerly part of a crack commando unit that was sent to prison by a military court, this individual promptly escaped and has been operating as a soldier of fortune ever since.',1480000,17100,225,1,1,0.0000,0,NULL,0),(34183,818,'Burner Hawk','This Hawk is flown by an elite assault pilot that recently went rogue from the Caldari Navy and should be considered highly dangerous.\r\r\n\r\r\nFormerly part of a crack commando unit that was sent to prison by a military court, this individual promptly escaped and has been operating as a soldier of fortune ever since.',1217000,27289,130,1,1,0.0000,0,NULL,0),(34184,818,'Burner Inquisitor','This Inquisitor is flown by an elite support pilot that recently went rogue from the Imperial Navy and should be considered highly dangerous.\r\r\n\r\r\nFormerly part of a crack commando unit that was sent to prison by a military court, this individual promptly escaped and has been operating as a soldier of fortune ever since.',1630000,28600,235,1,4,0.0000,0,NULL,0),(34185,818,'Burner Vengeance','This Enyo is flown by an elite assault pilot that recently went rogue from the Imperial Navy and should be considered highly dangerous.\r\r\n\r\r\nFormerly part of a crack commando unit that was sent to prison by a military court, this individual promptly escaped and has been operating as a soldier of fortune ever since.',1163000,27289,130,1,4,0.0000,0,NULL,0),(34186,818,'Burner Navitas','This Navitas is flown by an elite support pilot that recently went rogue from the Federation Navy and should be considered highly dangerous.\r\r\n\r\r\nFormerly part of a crack commando unit that was sent to prison by a military court, this individual promptly escaped and has been operating as a soldier of fortune ever since.',1450000,28600,235,1,8,0.0000,0,NULL,0),(34187,818,'Burner Enyo','This Enyo is flown by an elite assault pilot that recently went rogue from the Federation Navy and should be considered highly dangerous.\r\r\n\r\r\nFormerly part of a crack commando unit that was sent to prison by a military court, this individual promptly escaped and has been operating as a soldier of fortune ever since.',1171000,27289,130,1,8,0.0000,0,NULL,0),(34190,226,'Amarr Battleship Wreck 1','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(34191,226,'Amarr Battleship Wreck 2','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(34192,226,'Caldari Battleship Wreck 1','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(34193,226,'Caldari Battleship Wreck 2','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(34194,226,'Gallente Battleship Wreck 1','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(34195,226,'Gallente Battleship Wreck 2','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(34196,226,'Minmatar Battleship Wreck 1','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(34197,226,'Minmatar Battleship Wreck 2','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(34201,1304,'Accelerant Decryptor','Unexceptional texts mostly aimed at rookie researchers wishing to increase the production efficiency of invention jobs.<br><br>Probability Multiplier: +20% <br>Max. Run Modifier: +1 <br>Material Efficiency Modifier: +2 <br>Time Efficiency Modifier: +10',1,0.1,0,1,4,0.0000,1,1873,0),(34202,1304,'Attainment Decryptor','Dynamic guidelines for invention jobs, increasing the chance of success and number of runs greatly at a slight cost to material efficiency.<br><br>Probability Multiplier: +80% <br>Max. Run Modifier: +4 <br>Material Efficiency Modifier: -1 <br>Time Efficiency Modifier: +4',1,0.1,0,1,4,0.0000,1,1873,0),(34203,1304,'Augmentation Decryptor','Clever research technique that allows for refolding of blueprint materials in invention jobs. While the number of runs is greatly increased the probability of invention is adversely affected. <br><br>Probability Multiplier: -40% <br>Max. Run Modifier: +9 <br>Material Efficiency Modifier: -2 <br>Time Efficiency Modifier: +2',1,0.1,0,1,4,0.0000,1,1873,0),(34204,1304,'Parity Decryptor','Balanced decryptor that increases the likelihood of successful invention considerably, while still providing nice supplementary benefits with just a slight increase in production time.<br><br>Probability Multiplier: +50% <br> Max. Run Modifier: +3 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: -2',1,0.1,0,1,4,0.0000,1,1873,0),(34205,1304,'Process Decryptor','Optimizes invention procedures, increasing time efficiency with a slight boost to material efficiency and success chance.<br><br>Probability Multiplier: +10% <br>Max. Run Modifier: N/A <br>Material Efficiency Modifier: +3 <br>Time Efficiency Modifier: +6',1,0.1,0,1,4,0.0000,1,1873,0),(34206,1304,'Symmetry Decryptor','This decryptor contains true and tested research methods regarding invention jobs with decent stats across the board.<br><br>Probability Multiplier: N/A  <br>Max. Run Modifier: +2 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: +8',1,0.1,0,1,4,0.0000,1,1873,0),(34207,1304,'Optimized Attainment Decryptor','A rare and valuable decryptor that dramatically increases your chance for success at invention. Gives minor benefit to mineral efficiency at the expense of slight increase in production time.<br><br>Probability Multiplier: +90% <br>Max. Run Modifier: +2 <br>Material Efficiency Modifier: +1 <br>Time Efficiency Modifier: -2',1,0.1,0,1,4,0.0000,1,1873,0),(34208,1304,'Optimized Augmentation Decryptor','A rare and valuable decryptor that gives solid boost to number of runs an invented BPC will have, plus improved mineral efficiency, with just a slight decrease in invention success.<br><br>Probability Multiplier: -10% <br>Max. Run Modifier: +7 <br>Material Efficiency Modifier: +2 <br>Time Efficiency Modifier: 0',1,0.1,0,1,4,0.0000,1,1873,0),(34210,1089,'Men\'s \'Quafethron\' T-shirt','Stand astride the two worlds of earth and space as a towering, immortal colossus, and celebrate it in the most casual of ways.\r\r\n\r\r\nNot only does this item indicate that the wearer - whose clothing is as stylish, sleek and nonchalant as they themselves are - does, in fact, hold immeasurable power and is capable of piloting celestial behemoths that would blot out the sun; it also shows that they are in tune with life\'s little pleasures, and may well enjoy a can or two of Quafe when they\'re outside the capsule.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(34211,1089,'Women\'s \'Quafethron\' T-shirt','Stand astride the two worlds of earth and space as a towering, immortal colossus, and celebrate it in the most casual of ways.\r\r\n\r\r\nNot only does this item indicate that the wearer - whose clothing is as stylish, sleek and nonchalant as they themselves are - does, in fact, hold immeasurable power and is capable of piloting celestial behemoths that would blot out the sun; it also shows that they are in tune with life\'s little pleasures, and may well enjoy a can or two of Quafe when they\'re outside the capsule.',0.5,0.1,0,1,NULL,0.0000,1,1662,0),(34213,27,'Apocalypse Blood Raider Edition','In days past, only those in high favor with the Emperor could hope to earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. In latter years, even though now in full market circulation, these golden, metallic monstrosities are still feared and respected as enduring symbols of Amarrian might.',97100000,495000,675,1,4,199648910.0000,0,NULL,0),(34214,107,'Apocalypse Blood Raider Edition Blueprint',' ',0,0.01,0,1,NULL,1265000000.0000,1,NULL,0),(34215,27,'Apocalypse Kador Edition','In days past, only those in high favor with the Emperor could hope to earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. In latter years, even though now in full market circulation, these golden, metallic monstrosities are still feared and respected as enduring symbols of Amarrian might.',97100000,495000,675,1,4,199648910.0000,0,NULL,0),(34216,107,'Apocalypse Kador Edition Blueprint',' ',0,0.01,0,1,NULL,1265000000.0000,1,NULL,0),(34217,27,'Apocalypse Tash-Murkon Edition','In days past, only those in high favor with the Emperor could hope to earn the reward of commanding one of the majestic and powerful Apocalypse class battleships. In latter years, even though now in full market circulation, these golden, metallic monstrosities are still feared and respected as enduring symbols of Amarrian might.',97100000,495000,675,1,4,199648910.0000,0,NULL,0),(34218,107,'Apocalypse Tash-Murkon Edition Blueprint',' ',0,0.01,0,1,NULL,1265000000.0000,1,NULL,0),(34219,900,'Paladin Blood Raider Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Carthum Conglomerate \r\r\n\r\r\nCarthum ships are the very embodiment of the Amarrian warfare philosophy. Possessing sturdy armor and advanced weapon systems, they provide a nice mix of offense and defense.\r\r\n\r\r\n',92245000,495000,1125,1,4,396902230.0000,0,NULL,0),(34220,107,'Paladin Blood Raider Edition Blueprint',' ',0,0.01,0,1,NULL,1800000000.0000,1,NULL,0),(34221,900,'Paladin Kador Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Carthum Conglomerate \r\r\n\r\r\nCarthum ships are the very embodiment of the Amarrian warfare philosophy. Possessing sturdy armor and advanced weapon systems, they provide a nice mix of offense and defense.\r\r\n\r\r\n',92245000,495000,1125,1,4,396902230.0000,0,NULL,0),(34222,107,'Paladin Kador Edition Blueprint',' ',0,0.01,0,1,NULL,1800000000.0000,1,NULL,0),(34223,900,'Paladin Tash-Murkon Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Carthum Conglomerate \r\r\n\r\r\nCarthum ships are the very embodiment of the Amarrian warfare philosophy. Possessing sturdy armor and advanced weapon systems, they provide a nice mix of offense and defense.\r\r\n\r\r\n',92245000,495000,1125,1,4,396902230.0000,0,NULL,0),(34224,107,'Paladin Tash-Murkon Edition Blueprint',' ',0,0.01,0,1,NULL,1800000000.0000,1,NULL,0),(34225,27,'Raven Guristas Edition','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.',99300000,486000,665,1,1,198117134.0000,0,NULL,0),(34226,107,'Raven Guristas Edition Blueprint',' ',0,0.01,0,1,NULL,1135000000.0000,1,NULL,0),(34227,27,'Raven Kaalakiota Edition','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.',99300000,486000,665,1,1,198117134.0000,0,NULL,0),(34228,107,'Raven Kaalakiota Edition Blueprint',' ',0,0.01,0,1,NULL,1135000000.0000,1,NULL,0),(34229,27,'Raven Nugoeihuvi Edition','The Raven is the powerhouse of the Caldari Navy. With its myriad launcher slots and powerful shields, few ships can rival it in strength or majesty.',99300000,486000,665,1,1,198117134.0000,0,NULL,0),(34230,107,'Raven Nugoeihuvi Edition Blueprint',' ',0,0.01,0,1,NULL,1135000000.0000,1,NULL,0),(34231,900,'Golem Guristas Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Lai Dai \r\r\n\r\r\nLai Dai have always favored a balanced approach to their mix of on-board systems, leading to a line-up of versatile ships but providing very little in terms of tactical specialization.\r\r\n\r\r\n',94335000,486000,1225,1,1,395370454.0000,0,NULL,0),(34232,107,'Golem Guristas Edition Blueprint',' ',0,0.01,0,1,NULL,1650000000.0000,1,NULL,0),(34233,900,'Golem Kaalakiota Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Lai Dai \r\r\n\r\r\nLai Dai have always favored a balanced approach to their mix of on-board systems, leading to a line-up of versatile ships but providing very little in terms of tactical specialization.\r\r\n\r\r\n',94335000,486000,1225,1,1,395370454.0000,0,NULL,0),(34234,107,'Golem Kaalakiota Edition Blueprint',' ',0,0.01,0,1,NULL,1650000000.0000,1,NULL,0),(34235,900,'Golem Nugoeihuvi Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Lai Dai \r\r\n\r\r\nLai Dai have always favored a balanced approach to their mix of on-board systems, leading to a line-up of versatile ships but providing very little in terms of tactical specialization.\r\r\n\r\r\n',94335000,486000,1225,1,1,395370454.0000,0,NULL,0),(34236,107,'Golem Nugoeihuvi Edition Blueprint',' ',0,0.01,0,1,NULL,1650000000.0000,1,NULL,0),(34237,27,'Megathron Police Edition','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.',98400000,486000,675,1,8,190932898.0000,0,NULL,0),(34238,107,'Megathron Police Edition Blueprint',' ',0,0.01,0,1,NULL,1250000000.0000,1,NULL,0),(34239,27,'Megathron Inner Zone Shipping Edition','The Megathron has established itself as one of the most feared and respected battleships around. Since its first appearance almost two decades ago it has seen considerable service in the troublesome regions on the outskirts of the Federation, helping to expand and defend Gallentean influence there.',98400000,486000,675,1,8,190932898.0000,0,NULL,0),(34240,107,'Megathron Inner Zone Shipping Edition Blueprint',' ',0,0.01,0,1,NULL,1250000000.0000,1,NULL,0),(34241,900,'Kronos Police Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Duvolle Labs\r\r\n\r\r\nDuvolle Labs manufactures sturdy ships with a good mix of offensive and defensive capabilities. Since the company is one of New Eden\'s foremost manufacturers of particle blasters, its ships tend to favor turrets and thus have somewhat higher power output than normal.\r\r\n\r\r\n',93480000,486000,1275,1,8,388186218.0000,0,NULL,0),(34242,107,'Kronos Police Edition Blueprint',' ',0,0.01,0,1,NULL,1760000000.0000,1,NULL,0),(34243,900,'Kronos Quafe Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Duvolle Labs\r\r\n\r\r\nDuvolle Labs manufactures sturdy ships with a good mix of offensive and defensive capabilities. Since the company is one of New Eden\'s foremost manufacturers of particle blasters, its ships tend to favor turrets and thus have somewhat higher power output than normal.\r\r\n\r\r\n',93480000,486000,1275,1,8,388186218.0000,0,NULL,0),(34244,107,'Kronos Quafe Edition Blueprint',' ',0,0.01,0,1,NULL,1760000000.0000,1,NULL,0),(34245,900,'Kronos Inner Zone Shipping Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Duvolle Labs\r\r\n\r\r\nDuvolle Labs manufactures sturdy ships with a good mix of offensive and defensive capabilities. Since the company is one of New Eden\'s foremost manufacturers of particle blasters, its ships tend to favor turrets and thus have somewhat higher power output than normal.\r\r\n\r\r\n',93480000,486000,1275,1,8,388186218.0000,0,NULL,0),(34246,107,'Kronos Inner Zone Shipping Edition Blueprint',' ',0,0.01,0,1,NULL,1760000000.0000,1,NULL,0),(34247,27,'Tempest Justice Edition','The Tempest is one of the Republic Fleet\'s key vessels; a versatile gunship proficient at long-range bombardment and capable of dishing out specialized types of damage with great effectiveness. A well-rounded squadron of Tempests has been proven time and time again to be an invaluable wild card in a fleet battle, one which opponents should ignore at their own peril.',99500000,450000,600,1,2,187005890.0000,0,NULL,0),(34248,107,'Tempest Justice Edition Blueprint',' ',0,0.01,0,1,NULL,1055000000.0000,1,NULL,0),(34249,27,'Tempest Krusual Edition','The Tempest is one of the Republic Fleet\'s key vessels; a versatile gunship proficient at long-range bombardment and capable of dishing out specialized types of damage with great effectiveness. A well-rounded squadron of Tempests has been proven time and time again to be an invaluable wild card in a fleet battle, one which opponents should ignore at their own peril.',99500000,450000,600,1,2,187005890.0000,0,NULL,0),(34250,107,'Tempest Krusual Edition Blueprint',' ',0,0.01,0,1,NULL,1055000000.0000,1,NULL,0),(34251,27,'Tempest Nefantar Edition','The Tempest is one of the Republic Fleet\'s key vessels; a versatile gunship proficient at long-range bombardment and capable of dishing out specialized types of damage with great effectiveness. A well-rounded squadron of Tempests has been proven time and time again to be an invaluable wild card in a fleet battle, one which opponents should ignore at their own peril.',99500000,450000,600,1,2,187005890.0000,0,NULL,0),(34252,107,'Tempest Nefantar Edition Blueprint',' ',0,0.01,0,1,NULL,1055000000.0000,1,NULL,0),(34253,900,'Vargur Justice Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Boundless Creation\r\r\n\r\r\nBoundless Creation\'s ships are based on the Brutor Tribe\'s philosophy of warfare: simply fit as much firepower onto your ship as possible. Defense systems and electronics arrays therefore take a back seat to sheer annihilative potential.\r\r\n\r\r\n',96520000,450000,1150,1,2,384259210.0000,0,NULL,0),(34254,107,'Vargur Justice Edition Blueprint',' ',0,0.01,0,1,NULL,1450000000.0000,1,NULL,0),(34255,900,'Vargur Krusual Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Boundless Creation\r\r\n\r\r\nBoundless Creation\'s ships are based on the Brutor Tribe\'s philosophy of warfare: simply fit as much firepower onto your ship as possible. Defense systems and electronics arrays therefore take a back seat to sheer annihilative potential.\r\r\n\r\r\n',96520000,450000,1150,1,2,384259210.0000,0,NULL,0),(34256,107,'Vargur Krusual Edition Blueprint',' ',0,0.01,0,1,NULL,1450000000.0000,1,NULL,0),(34257,900,'Vargur Nefantar Edition','Geared toward versatility and prolonged deployment in hostile environments, Marauders represent the cutting edge in today\'s warship technology. While especially effective at support suppression and wreckage salvaging, they possess comparatively weak sensor strength and may find themselves at increased risk of sensor jamming. Nevertheless, these thick-skinned, hard-hitting monsters are the perfect ships to take on long trips behind enemy lines.\r\r\n\r\r\nDeveloper: Boundless Creation\r\r\n\r\r\nBoundless Creation\'s ships are based on the Brutor Tribe\'s philosophy of warfare: simply fit as much firepower onto your ship as possible. Defense systems and electronics arrays therefore take a back seat to sheer annihilative potential.\r\r\n\r\r\n',96520000,450000,1150,1,2,384259210.0000,0,NULL,0),(34258,107,'Vargur Nefantar Edition Blueprint',' ',0,0.01,0,1,NULL,1450000000.0000,1,NULL,0),(34260,548,'Surgical Warp Disrupt Probe','Deployed from an Interdiction Sphere Launcher fitted to an Interdictor this probe prevents warping from within its area of effect.',1,5,0,2,NULL,65684.0000,1,1201,0),(34264,864,'Focused Void Bomb','Radiates an omnidirectional pulse upon detonation that neutralizes a portion of the energy in the surrounding vessels.\r\r\n\r\r\nThis variant of the standard Void Bomb neutralizes an incredible amount of capacitor within a tiny area, and is unsuitable for use against sub-capital vessels.',1000,75,0,20,NULL,16224848.0000,1,1015,0),(34266,1308,'Small Higgs Anchor I','This unique rig generates drag against the energy field of space itself, causing the fitted ship to increase in mass and agility while greatly reducing maximum velocity.\r\r\nThis effect also reduces a ship\'s maximum warp speed, although the impact on warp velocity can be mitigated through skilled use.\r\r\n\r\r\nOnly one Higgs Anchor can be fitted at a time.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,NULL,0.0000,1,1210,0),(34267,787,'Small Higgs Anchor I Blueprint',' ',0,0.01,0,1,NULL,125000.0000,1,1240,0),(34268,1308,'Medium Higgs Anchor I','This unique rig generates drag against the energy field of space itself, causing the fitted ship to increase in mass and agility while greatly reducing maximum velocity.\r\r\nThis effect also reduces a ship\'s maximum warp speed, although the impact on warp velocity can be mitigated through skilled use.\r\r\n\r\r\nOnly one Higgs Anchor can be fitted at a time.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,10,0,1,NULL,0.0000,1,1211,0),(34269,787,'Medium Higgs Anchor I Blueprint',' ',0,0.01,0,1,4,750000.0000,1,1241,0),(34271,53,'Test Resistance Small Laser 2','A high-powered pulse laser. Good for short to medium range encounters. \r\r\n\r\r\nRequires frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray.',500,5,1,1,4,5984.0000,0,NULL,0),(34272,53,'Polarized Small Focused Pulse Laser','A high-powered pulse laser. Good for short to medium range encounters.\r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted. \r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Conflagration, Scorch.',500,5,1,1,4,265076.0000,1,570,0),(34273,133,'Polarized Small Pulse Laser Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(34274,53,'Polarized Heavy Pulse Laser','A heavy laser designed for short to medium range engagements. Delivers powerful damage. \r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted.\r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Conflagration, Scorch.',1000,10,1,1,4,819990.0000,1,572,0),(34275,133,'Polarized Heavy Pulse Laser Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(34276,53,'Polarized Mega Pulse Laser','A super-heavy pulse laser designed for medium range engagements. \r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted.\r\r\n\r\r\nRequires either regular or advanced frequency crystal ammo types: Gamma, Infrared, Microwave, Multifrequency, Radio, Standard, Ultraviolet, Xray, Conflagration, Scorch.',2000,20,1,1,4,2414030.0000,1,573,0),(34277,133,'Polarized Mega Pulse Laser Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(34278,74,'Polarized Light Neutron Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted.\r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',500,5,0.6,1,4,265028.0000,1,561,0),(34279,154,'Polarized Light Neutron Blaster Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(34280,74,'Polarized Heavy Neutron Blaster','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets. \r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted.\r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',1000,10,3,1,4,852758.0000,1,562,0),(34281,154,'Polarized Heavy Neutron Blaster Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(34282,74,'Polarized Neutron Blaster Cannon','Particle blasters operate on a similar principle as the railgun except they fire a magnetically contained ball of subatomic particles. No other turret class can match the sheer destructive power of particle blasters, but due to the rapid dispersion of the containment field, it also has the worst range of all turrets.\r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted. \r\r\n\r\r\nRequires either regular or advanced hybrid charge types: Antimatter, Iridium, Iron, Lead, Plutonium, Thorium, Tungsten, Uranium, Null, Void.',2000,20,6,1,4,2108430.0000,1,563,0),(34283,154,'Polarized Neutron Blaster Cannon Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(34284,55,'Polarized 200mm AutoCannon','The 200mm is a powerful autocannon that can smash apart most lightly armored frigates with ease. \r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted.\r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',500,5,0.9,1,4,223498.0000,1,574,0),(34285,135,'Polarized 200mm AutoCannon Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(34286,55,'Polarized 425mm AutoCannon','The 425mm is a behemoth that will inflict severe damage on most cruisers and frigates in short-range battles. \r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted.\r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',1000,10,4.5,1,4,781286.0000,1,575,0),(34287,135,'Polarized 425mm AutoCannon Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(34288,55,'Polarized 800mm Repeating Cannon','A two-barreled, intermediate-range, powerful cannon capable of causing tremendous damage. \r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted.\r\r\n\r\r\nMust be loaded with any of the following regular and advanced projectile ammo types: Carbonized Lead, Depleted Uranium, EMP, Fusion, Nuclear, Phased Plasma, Proton, Titanium Sabot, Barrage, Hail.',75,20,9,1,4,2355530.0000,1,576,0),(34289,135,'Polarized 800mm Repeating Cannon Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34290,507,'Polarized Rocket Launcher','A tiny launcher that can carry a very limited supply of rockets. Not really intended as a primary weapon but rather as a cheap supplementary weapon system.\r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted.',0,5,0.75,1,4,54774.0000,1,639,0),(34291,136,'Polarized Rocket Launcher Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(34292,771,'Polarized Heavy Assault Missile Launcher','A launcher intended for use on cruiser-class spacecraft. While assault launchers do not possess the sheer damage-dealing capability of regular heavy missile launchers, their blend of speed and attack power lends them application across a good range of tactical situations.\r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted. ',0,10,2.97,1,4,309722.0000,1,974,0),(34293,136,'Polarized Heavy Assault Missile Launcher Blueprint',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34294,508,'Polarized Torpedo Launcher','A massive launcher designed for extended bombardments of hard targets like battleships and stations. Contains a huge missile capacity, but has a slow firing rate and trouble targeting small, fast ships.\r\r\n\r\r\nPolarized weapons offer extremely good primary stats, but come with the cost of completely negating all resistances on a ship if fitted.',0,20,6,1,4,1344308.0000,1,644,0),(34295,136,'Polarized Torpedo Launcher Blueprint',' ',0,0.01,0,1,4,9999999.0000,1,NULL,0),(34299,306,'Mangled Storage Depot','This storage depot is badly banged up and most of its contents probably destroyed, but a detailed analysis might still reveal something of value.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34300,306,'Dented Storage Depot','This storage depot has seen some rough treatment, but you should still find something of value intact, if you employ your analyzer with skill.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34301,306,'Remote Pressure Control Unit','This unit can remotely override the controls of the nearby pressure station. Perhaps it can be used to temporarily decrease the flow of overheated plasma from the badly damaged station, though you surmise a failure could result in something backfiring. ',10000,27500,2700,1,4,0.0000,0,NULL,0),(34302,226,'Plasma Chamber Debris','These are the remains of a plasma chamber, used to store large quantities of volatile materials. The destruction of the chamber has released the hazardous materials into the surrounding space.',0,0,0,1,4,0.0000,0,NULL,0),(34303,319,'Plasma Chamber','This storage unit is filled with volatile materials. Handle with care.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(34304,226,'Wrecked Storage Depot','This storage depot has been completely wrecked, with nothing of value remaining. It is hard to tell whether the depot was destroyed by nearby explosions or through savage scavenging. Probably a bit of both.',0,0,0,1,4,0.0000,0,NULL,0),(34305,306,'Remote Defense Grid Unit','This unit can remotely shut down the defense mechanisms still active in the area. Skillful hacking should do the trick. ',10000,27500,2700,1,4,0.0000,0,NULL,0),(34306,1308,'Large Higgs Anchor I','This unique rig generates drag against the energy field of space itself, causing the fitted ship to increase in mass and agility while greatly reducing maximum velocity.\r\r\nThis effect also reduces a ship\'s maximum warp speed, although the impact on warp velocity can be mitigated through skilled use.\r\r\n\r\r\nOnly one Higgs Anchor can be fitted at a time.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,20,0,1,4,0.0000,1,1212,0),(34307,787,'Large Higgs Anchor I Blueprint',' ',0,0.01,0,1,4,1250000.0000,1,1242,0),(34308,1308,'Capital Higgs Anchor I','This unique rig generates drag against the energy field of space itself, causing the fitted ship to increase in mass and agility while greatly reducing maximum velocity.\r\r\nThis effect also reduces a ship\'s maximum warp speed, although the impact on warp velocity can be mitigated through skilled use.\r\r\n\r\r\nOnly one Higgs Anchor can be fitted at a time.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,40,0,1,4,0.0000,1,1740,0),(34309,787,'Capital Higgs Anchor I Blueprint',' ',0,0.01,0,1,4,50000000.0000,1,1720,0),(34310,226,'Unidentified Structure','There\'s nothing in our databanks that matches this structure.',0,0,0,1,1,0.0000,0,NULL,0),(34311,314,'Honorary Fabricator-General Baton','This baton of command is inscribed with the name of the capsuleer <url=showinfo:1377//1319007453>Ascentior</url> and signifies his honorary rank as a Fabricator-General of the Imperial Navy. This award was given in recognition of exemplary service as the top supplier of Sleeper components for the Imperial Navy s research program in late YC 116.\r\r\n ',1,0.1,0,1,4,0.0000,1,NULL,0),(34312,314,'Honorary Brigadier of Engineers Insignia','This service insignia is inscribed on the reverse with the name of the capsuleer <url=showinfo:1377//332275222>TorDog</url> and indicates his honorary rank as a Caldari Brigadier of Engineers. This award was given in recognition of exemplary service as the top supplier of Sleeper components for the Caldari Navy s research program in late YC 116.\r\r\n ',1,0.1,0,1,1,0.0000,1,NULL,0),(34313,314,'Honorary Federal Harbormaster Pennon','This naval pennon has the name of the capsuleer <url=showinfo:1377//101054534>Shipstorm</url> woven into its fabric and displays his honorary rank as a Federal Harbormaster. This award was given in recognition of exemplary service as the top supplier of Sleeper components for the Federation Navy s research program in late YC 116.',1,0.1,0,1,8,0.0000,1,NULL,0),(34314,314,'Honorary Fleet Architect Badge','This military badge carries the name of the capsuleer <url=showinfo:1377//90771225>Lotrec Emetin</url> and is a mark of his honorary rank as a Republic Fleet Architect. This award was given in recognition of exemplary service as the top supplier of Sleeper components for the Republic Fleet s research program in late YC 116.\r\r\n ',1,0.1,0,1,2,0.0000,1,NULL,0),(34315,306,'Hyperfluct Generator','This enigmatic unit hums with power, but to what purpose it is difficult to tell. It has a complex set of technical gadgets and perhaps delving into it with a Data Analyzer will reveal its true purpose. It seems though that it is well setup to protect its secrets, so caution is advised.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34316,226,'Damaged Spatial Concealment Chamber','The purpose of this large structure seems to have been to cloak a section of space - section big enough to conceal a sizable site. There are indications that this structure was damaged recently, to the point where it could no longer serve its purpose. Who damaged the structure or why is impossible to tell.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(34317,1305,'Confessor','Your first duty is to purge yourself in the flames of your confession before God. You must become ash in God\'s hands, for only then may you rise anew to strike the adversary down.\r\r\n\r\r\n-<i>Apostle-Martial Zhar Pashay\'s dawn address to the Paladins at the Battle of Rahdo, Amarr Prime AD 20538</i>',2000000,47000,400,1,4,9200000.0000,1,1952,0),(34318,1309,'Confessor Blueprint','The Confessor-class Tactical Destroyer was developed for the glory of the Amarr Empire in YC116 with the invaluable aid of ninety-four loyal capsuleers. The most dedicated of these pilots were:\r\r\n<url=showinfo:1373//1319007453>Ascentior</url>\r\r\n<url=showinfo:1373//94237537>SALVATIONCOME4TRUBELIVER TYGODAMEN</url>\r\r\n<url=showinfo:1373//93337897>Blaze Tiberius</url>\r\r\n<url=showinfo:1373//422609556>Makoto Priano</url>\r\r\n<url=showinfo:1373//92813750>Ibrahim Tash-Murkon</url>\r\r\n<url=showinfo:1373//92355763>Lunarisse Aspenstar</url>\r\r\n<url=showinfo:1373//166109376>Methos Horseman</url>\r\r\n<url=showinfo:1373//150389477>Chiralos</url>\r\r\n<url=showinfo:1373//93396569>Soren Tyrhanos</url>\r\r\n<url=showinfo:1373//90500669>Dreadnaught X</url>',0,0.01,0,1,4,40000000.0000,1,NULL,0),(34319,1306,'Confessor Defense Mode','33.3% bonus to all armor resistances\r\r\n33.3% reduction in ship signature radius',100,5,0,1,4,0.0000,0,NULL,0),(34321,1306,'Confessor Sharpshooter Mode','66.6% bonus to Small Energy Turret optimal range\r\r\n100% bonus to sensor strength, targeting range and scan resolution',100,5,0,1,4,0.0000,0,NULL,0),(34323,1306,'Confessor Propulsion Mode','66.6% bonus to maximum velocity\r\r\n33.3% bonus to ship inertia modifier',100,5,0,1,4,0.0000,0,NULL,0),(34325,15,'Sisters of EVE Logistics Station',' ',0,1,0,1,8,0.0000,0,NULL,0),(34326,15,'Sisters of EVE Industrial Station',' ',0,1,0,1,8,0.0000,0,NULL,0),(34327,257,'ORE Freighter','Skill at operating ORE freighters. \r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,128,35000000.0000,1,377,0),(34328,513,'Bowhead','As part of its ongoing program of developing new products for the capsuleer market, ORE has created the Bowhead freighter as a specialized ship transporter. Experience with the ship-handling technology used in the Orca and Rorqual vessels enabled the Outer Ring Development division to build a ship dedicated to moving multiple assembled hulls at once.\r\r\n\r\r\nOuter Ring Excavations are aggressively marketing the Bowhead as a flexible transport platform for organizing fleet logistics across New Eden, available from authorized ORE outlets.',640000000,17550000,4000,1,128,1303616848.0000,1,1950,0),(34329,525,'Bowhead Blueprint',' ',0,0.01,0,1,128,1550000000.0000,1,1949,0),(34330,306,'Resource Container','The bolted container drifts silently amongst the stars, giving no hint to what treasures it may hide.',10000,2750,2700,1,4,0.0000,1,NULL,0),(34331,6,'Sun A0IV (Turbulent Blue Subgiant)','This bright blue star emits unusually high neutrino levels and experiences frequent coronal mass ejections at unpredictable intervals.\r\r\n\r\r\nExperts have been unable to determine the cause of this violent instability.',1e35,1,0,1,4,0.0000,0,NULL,0),(34332,226,'Expedition Command Outpost Wreck','Scarred and scorched by devastating forces, this wrecked station apparently served as the command post for the Sanctuary expedition to Thera. Wreathed in clouds of plasma, gas and dust, the station\'s destruction, while not absolute, is profound and the interior has been gutted by fire and explosions.',0,0,0,1,8,0.0000,0,NULL,0),(34333,227,'Cloud Rings',' ',0,0,0,1,4,0.0000,0,NULL,0),(34334,226,'Planetary Colonization Office Wreck','Perhaps the saddest testament to the shattered dreams of the expedition to Thera, this wrecked station seems to have been established as a coordinating center for the colonization of the planet it orbits. As Thera VIII is shattered and wracked by titanic quakes, such an effort would seem improbable unless the shattering happened relatively recently.  \r\r\n\r\r\nWhile the damage to this station is extensive and very little survives, there are large storage areas containing bins of rock samples that apparently originated from a geologically stable barren or temperate planet.\r\r\n',0,0,0,1,8,0.0000,0,NULL,0),(34335,226,'Testing Facilities Wreck','Apparently set up to study nearby Talocan technology, this station has been buckled and broken by numerous impacts, possibly from material thrown up from the devastated planet below. The array of Talocan static gates nearby is eerily intact and seems to be functional to some degree.',0,0,0,1,8,0.0000,0,NULL,0),(34336,226,'Exotic Specimen Warehouse Wreck','Wrecked and battered, though largely intact, this station and its neighbor must originally have been sheltered in the lee of the planet to some extent. Disruption of orbital mechanics in this system make it difficult to be sure but the proximity of Thera III to the central star and the survival of recognizable station ruins requires an explanation of this kind. Some have suggested wilder theories concerning the nearby Talocan technology.\r\r\n\r\r\nThe station itself seems to have functioned as a vast storehouse of materials and specimens gathered from the core of the system. Not much remains and large quantities of radioactive fullerene gas seem to have bled from the ruptured storage vessels.\r\r\n',0,0,0,1,8,0.0000,0,NULL,0),(34337,1307,'Circadian Seeker','The design of this Sleeper drone is unlike anything that has been seen to date. The drone explores with a mechanical indifference to the monotony of its task, executing each new maneuver with a flawless, unthinking precision.',2000000,0,0,1,64,0.0000,0,NULL,0),(34338,988,'Wormhole T458','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34339,485,'Moros Interbus Edition','Of all the dreadnoughts currently in existence, the imposing Moros possesses a tremendous capacity to fend off garguantuan hostiles while still posing a valid threat to any and all larger-scale threats on the battlefield. By virtue of its protean array of point defense capabilities, and its terrifying ability to unleash rapid and thoroughly devastating amounts of destruction on the battlefield, the Moros is single-handedly capable of turning the tide in a fleet battle.',1292500000,17550000,2550,1,8,2515543002.0000,0,NULL,0),(34340,537,'Moros Interbus Edition Blueprint',' ',0,0.01,0,1,4,1900000000.0000,1,NULL,0),(34341,485,'Naglfar Justice Edition','The Naglfar is based on a Matari design believed to date back to the earliest annals of antiquity.  While the exact evolution of memes informing its figure is unclear, the same distinctive vertical monolith form has shown up time and time again in the wind-scattered remnants of Matari legend.\r\r\n\r\r\nBoasting an impressive versatility in firepower options, the Naglfar is capable of holding its own against opponents of all sizes and shapes.  While its defenses don\'t go to extremes as herculean as those of its counterparts, the uniformity of resilience - coupled with the sheer amount of devastation it can dish out - make this beast an invaluable addition to any fleet.\r\r\n\r\r\n',1127500000,15500000,2900,1,2,2465892518.0000,0,NULL,0),(34342,537,'Naglfar Justice Edition Blueprint',' ',0,0.01,0,1,4,1850000000.0000,1,NULL,0),(34343,485,'Phoenix Wiyrkomi Edition','In terms of Caldari design philosophy, the Phoenix is a chip off the old block.  With a heavily tweaked missile interface, targeting arrays of surpassing quality and the most advanced shield systems to be found anywhere, it is considered the strongest long-range installation attacker out there.\r\r\n\r\r\nWhile its shield boosting actuators allow the Phoenix, when properly equipped, to withstand tremendous punishment over a short duration, its defenses are not likely to hold up against sustained attack over longer periods.  With a strong supplementary force, however, few things in existence rival this vessel\'s pure annihilative force.',1320000000,16250000,2750,1,1,2451853460.0000,0,NULL,0),(34344,537,'Phoenix Wiyrkomi Edition Blueprint',' ',0,0.01,0,1,4,1950000000.0000,1,NULL,0),(34345,485,'Revelation Sarum Edition','The Revelation represents the pinnacle of Amarrian military technology.  Maintaining their proud tradition of producing the strongest armor plating to be found anywhere, the Empire\'s engineers outdid themselves in creating what is arguably the most resilient dreadnought in existence.\r\r\n\r\r\nAdded to that, the Revelation\'s ability to fire capital beams makes its position on the battlefield a unique one.  When extended sieges are the order of the day, this is the ship you call in.',1237500000,18500000,2175,1,4,2479301962.0000,0,NULL,0),(34346,537,'Revelation Sarum Edition Blueprint',' ',0,0.01,0,1,4,2000000000.0000,1,NULL,0),(34347,1088,'Men\'s \'Outlaw\' Jacket (Blood Raiders)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, this jacket indicates that the wearer is a true supporter of the Blood Raiders. Each jacket is crafted from the finest leather, dyed carbon black, and accented with studded crimson passants and crimson trim. Finally, the jacket is emblazoned with the Blood Raiders logo, located directly over the heart of the wearer. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1399,0),(34348,1088,'Men\'s \'Outlaw\' Jacket (Sansha\'s Nation)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, this jacket indicates that the wearer is a true supporter of the Sansha cause. Each jacket is crafted from the finest leather, dyed a dark green, and accented with spiked white passants and olive trim. Finally, the jacket is emblazoned with the Sansha\'s Nation logo, located directly over the heart of the wearer.',0.5,0.1,0,1,4,0.0000,1,1399,0),(34349,1088,'Men\'s \'Outlaw\' Jacket (Guristas)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, this jacket indicates that the wearer is a true supporter of the Guristas. Each jacket is crafted from the finest leather, dyed charcoal gray, and accented with studded white passants and umber trim. Finally, the jacket is emblazoned with the Guristas logo, located directly over the heart of the wearer\r\r\n',0.5,0.1,0,1,4,0.0000,1,1399,0),(34350,1088,'Women\'s \'Outlaw\' Coat (Sansha\'s Nation)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, this jacket indicates that the wearer is a true supporter of the Sansha cause. Each jacket is crafted from the finest leather, dyed a dark green, and accented with spiked white passants and olive trim. Finally, the jacket is emblazoned with the Sansha\'s Nation logo, located directly over the heart of the wearer. ',0.5,0.1,0,1,4,0.0000,1,1405,0),(34351,1088,'Women\'s \'Outlaw\' Coat (Guristas)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, this jacket indicates that the wearer is a true supporter of the Guristas. Each jacket is crafted from the finest leather, dyed charcoal gray, and accented with studded white passants and umber trim. Finally, the jacket is emblazoned with the Guristas logo, located directly over the heart of the wearer.',0.5,0.1,0,1,4,0.0000,1,1405,0),(34352,226,'Revenant Wreckage','This hollowed out husk is all that remains of one of New Eden\'s most impressive capital ships.  What was once a battlefield juggernaut has been reduced to nothing but a silent, slowly deteriorating tomb.',0,0,0,1,NULL,0.0000,0,NULL,0),(34353,1088,'Women\'s \'Outlaw\' Coat (Blood Raiders)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, this jacket indicates that the wearer is a true supporter of the Blood Raiders. Each jacket is crafted from the finest leather, dyed carbon black, and accented with studded crimson passants and crimson trim. Finally, the jacket is emblazoned with the Blood Raiders logo, located directly over the heart of the wearer. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1405,0),(34354,1090,'Men\'s \'Outlaw\' Pants (Blood Raiders)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these pants indicate that the wearer is a true supporter of the Blood Raiders. Each pair of pants is richly detailed, with charcoal gray fabric and carbon black accents. When paired with the matching Blood Raiders Jacket these pants present a stunning visual motif. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1401,0),(34355,1090,'Men\'s \'Outlaw\' Pants (Sansha\'s Nation)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these pants indicate that the wearer is a true supporter of the Sansha cause. Each pair of pants is richly detailed, with olive camouflage fabric and dark green accents. When paired with the matching Sansha\'s Nation Jacket these pants present a stunning visual motif.',0.5,0.1,0,1,4,0.0000,1,1401,0),(34356,1090,'Men\'s \'Outlaw\' Pants (Guristas)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these pants indicate that the wearer is a true supporter of the Guristas. Each pair of pants is richly detailed, with basalt gray fabric and charcoal gray accents. When paired with the matching Guristas Jacket these pants present a stunning visual motif. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1401,0),(34357,1090,'Women\'s \'Outlaw\' Pants (Blood Raiders)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these pants indicate that the wearer is a true supporter of the Blood Raiders. Each pair of pants is richly detailed, with crimson fabric and carbon black accents. When paired with the matching Blood Raiders Coat these pants present a stunning visual motif. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1403,0),(34358,1090,'Women\'s \'Outlaw\' Pants (Sansha\'s Nation)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these pants indicate that the wearer is a true supporter of the Sansha cause. Each pair of pants is richly detailed, with olive camouflage fabric and dark green accents. When paired with the matching Sansha\'s Nation Coat these pants present a stunning visual motif.',0.5,0.1,0,1,4,0.0000,1,1403,0),(34359,1090,'Women\'s \'Outlaw\' Pants (Guristas)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these pants indicate that the wearer is a true supporter of the Guristas. Each pair of pants is richly detailed, with basalt gray fabric and charcoal gray accents. When paired with the matching Guristas Coat these pants present a stunning visual motif. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1403,0),(34360,1091,'Men\'s \'Outlaw\' Boots (Blood Raiders)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these boots indicate that the wearer is a true supporter of the Blood Raiders. These tall lace-up boots make a statement of power and dominance in crimson and carbon black. When paired with the matching jacket and pants, these boots represent the ultimate homage to the Blood Raiders. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1400,0),(34361,1091,'Men\'s \'Outlaw\' Boots (Sansha\'s Nation)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these boots indicate that the wearer is a true supporter of the Sansha cause. These tall lace-up boots make a statement of power and dominance in olive and charcoal gray. When paired with the matching jacket and pants, these boots represent the ultimate homage to Sansha\'s Nation.',0.5,0.1,0,1,4,0.0000,1,1400,0),(34362,1091,'Men\'s \'Outlaw\' Boots (Guristas)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these boots indicate that the wearer is a true supporter of the Guristas. These tall lace-up boots make a statement of power and dominance in basalt and charcoal gray. When paired with the matching jacket and pants, these boots represent the ultimate homage to the Guristas.\r\r\n',0.5,0.1,0,1,4,0.0000,1,1400,0),(34363,1091,'Women\'s \'Outlaw\' Boots (Blood Raiders)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these boots indicate that the wearer is a true supporter of the Blood Raiders. These tall lace-up boots make a statement of power and dominance in crimson and carbon black. When paired with the matching coat and pants, these boots represent the ultimate homage to the Blood Raiders. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1404,0),(34364,1091,'Women\'s \'Outlaw\' Boots (Sansha\'s Nation)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these boots indicate that the wearer is a true supporter of the Sansha cause. These tall lace-up boots make a statement of power and dominance in olive and charcoal gray. When paired with the matching coat and pants, these boots represent the ultimate homage to Sansha\'s Nation.',0.5,0.1,0,1,4,0.0000,1,1404,0),(34365,1091,'Women\'s \'Outlaw\' Boots (Guristas)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, these boots indicate that the wearer is a true supporter of the Guristas. These tall lace-up boots make a statement of power and dominance in basalt and charcoal gray. When paired with the matching coat and pants, these boots represent the ultimate homage to the Guristas.\r\r\n',0.5,0.1,0,1,4,0.0000,1,1404,0),(34366,988,'Wormhole M164','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34367,988,'Wormhole L031','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34368,988,'Wormhole Q063','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34369,988,'Wormhole V898','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34370,988,'Wormhole E587','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34371,988,'Wormhole F353','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34372,988,'Wormhole F135','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34373,952,'Remote Calibration Device - Low Power','The calibration device can be fed coordinates to calibrate the nearby rift to become functional. This device slot is for low power setting, resulting in shorter distance covered when using the rift.\r\r\n\r\r\nTo activate this slot, you need to insert X-Axis Coordinate, Y-Axis Coordinate and a Z-Axis Coordinate into it.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34374,952,'Remote Calibration Device - High Power','The calibration device can be fed coordinates to calibrate the nearby rift to become functional. This device slot is for high power setting, resulting in longer distance covered when using the rift.\r\r\n\r\r\nTo activate this slot, you need to insert X-Axis Coordinate, Y-Axis Coordinate and a Z-Axis Coordinate into it.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34375,306,'Coordinate Plotting Device','Accessing this device will give you a plot for a coordinate. It needs to be entered into a Remote Calibration Device to calibrate the unusable rift in the vicinity. You need three plots to complete the coordinate. ',10000,27500,2700,1,4,0.0000,0,NULL,0),(34378,306,'Intact Storage Depot','This storage depot seems relatively intact, meaning there is a good chance of something lucrative lurking inside, waiting to be unlocked with a relic analyzer.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34379,226,'Inactive Sentry Gun','A sentry gun of Sleeper design. Currently dormant.',0,0,0,1,1,0.0000,0,NULL,0),(34381,314,'X-Axis Calibration Coordinate','This is one of three coordinate plots required to correctly align the nearby rift to make it functional.\r\r\n\r\r\nAll three coordinate plots need to be placed into either the low power or the high power Remote Calibration Device.\r\r\n',1,0.1,0,1,4,0.0000,1,NULL,0),(34382,314,'Y-Axis Calibration Coordinate','This is one of three coordinate plots required to correctly align the nearby rift to make it functional.\r\r\n\r\r\nAll three coordinate plots need to be placed into either the low power or the high power Remote Calibration Device.',1,0.1,0,1,4,0.0000,1,NULL,0),(34383,314,'Z-Axis Calibration Coordinate','This is one of three coordinate plots required to correctly align the nearby rift to make it functional.\r\r\n\r\r\nAll three coordinate plots need to be placed into either the low power or the high power Remote Calibration Device.',1,0.1,0,1,4,0.0000,1,NULL,0),(34384,226,'Immobile Tractor Beam','Heavy duty, fast working tractor beam. It can be aligned to pull storage depots surrounding the distant Sleeper enclave close to itself, if you manage to activate it.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34385,306,'Pristine Storage Depot','This storage depot seems to be in pristine condition. Whatever is stored inside should be completely unscathed and is only a relic analyzing away from being available.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34386,226,'Impenetrable Storage Depot','This storage depot has thick walls, making it hard to gauge its contents from afar. You need to get close to get a read on what is hidden inside.',0,0,0,1,4,0.0000,0,NULL,0),(34387,226,'Spatial Rift','Superficially similar to natural phenomena observed throughout space, this spatial rift appears to be artificially generated by a Talocan static gate array. Observations have shown that large quantities of dangerous gamma radiation and x-rays are pouring out of the rift. If this tear in space-time leads anywhere it is likely to be very inhospitable.',1,0,0,1,4,0.0000,0,NULL,0),(34388,226,'Communication Relay','Apparently a hastily converted radiation monitoring satellite, this device seems to have briefly functioned as an emergency communications relay. It shows relatively few signs of damage but seems to have been knocked out of commission by several precise energy weapon strikes to its processing cores.',0,0,0,1,4,0.0000,0,NULL,0),(34389,226,'Matyrhan Lakat-Hro','Surviving markings on the wreck of this Hel-class supercarrier identify it as the Matyrhan Lakat-Hro. In many places symbols of the Thukker Tribe are present along with numerous caravan markings that appear to confirm a link to the lost Lakat-Hro Great Caravan. \r\r\n\r\r\nThe presence of such a vessel in the Thera system has drawn attention to the Thukker contingent working with the Sanctuary here but no comment on the matter has been forthcoming from either party. Early delvers into the wreck\'s scorched interior soon discovered that all data storage devices had been carefully purged and destructively irradiated.\r\r\n',0,0,0,1,4,0.0000,0,NULL,0),(34390,257,'Amarr Tactical Destroyer','Skill at operating Amarr Tactical Destroyers.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,4,1000000.0000,1,377,0),(34391,952,'Solray Gamma Alignment Unit','This unit catches gamma rays from the sun, amplifies them and redirects elsewhere based on how the unit is aligned. It may require a Gamma Ray Modulate Disc to align correctly.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34392,226,'Bioinformatics Processing Cells','Such scans as can penetrate this structure suggest it is primarily made up of a series of interconnected cells, run through with monitoring systems and data processing networks. There is significant damage to the shielding of this facility and some conduits are sufficiently exposed to reveal that complex processing routines are still operating on vast quantities of bioinformatic data.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(34393,1088,'Men\'s \'Outlaw\' Jacket (Burnt Orange)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, this jacket was given as a gift to signify the coming of the New Year. Each jacket is crafted from the finest leather, dyed charcoal gray, and accented with studded white passants and burnt orange trim. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1399,0),(34394,1088,'Women\'s \'Outlaw\' Coat (Burnt Orange)','Designer: Unknown\r\r\n\r\r\nStraight from the discreet consignments of Intaki Commerce, this jacket was given as a gift to signify the coming of the New Year. Each jacket is crafted from the finest leather, dyed charcoal gray, and accented with studded white passants and burnt orange trim. \r\r\n',0.5,0.1,0,1,4,0.0000,1,1405,0),(34395,186,'Amarr Advanced Destroyer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(34396,964,'Self-Assembling Nanolattice','Self-Assembling Nanolattices are the result of a breakthrough in applied fullerene technology achieved by a joint Carthum-Viziam research team formed at the request of the Imperial Navy in late YC116. The development of this technology was made possible by the contributions of numerous capsuleers, most notably members of the venerable loyalist alliance <url=showinfo:16159//1186465684>Praetoria Imperialis Excubitoris</url>.\r\r\n\r\r\nAlthough these carbon-based structures are exceptional in their high strength and low mass, it is their ability to reconfigure rapidly when exposed to electromagnetic fields that makes Self-Assembling Nanolattices one of the most significant advancements in starship engineering in decades.',1,5,0,1,4,400000.0000,1,1147,0),(34397,965,'Self-Assembling Nanolattice Blueprint',' ',0,0.01,0,1,4,10000000.0000,1,1191,0),(34398,952,'Solray Infrared Alignment Unit','This unit catches infrared rays from the sun, amplifies them and redirects elsewhere based on how the unit is aligned. It may require an Infrared Ray Modulate Disc to align correctly.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34399,952,'Solray Radio Alignment Unit','This unit catches radio rays from the sun, amplifies them and redirects elsewhere based on how the unit is aligned. It may require a Radio Ray Modulate Disc to align correctly.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34400,314,'Gamma Ray Modulate Disc','This disc of crystals is specially constructed to modulate gamma rays in a Solray Gamma Alignment Unit.',1,0.1,0,1,4,2000000.0000,1,NULL,0),(34401,314,'Infrared Ray Modulate Disc','This disc of crystals is specially constructed to modulate infrared rays in a Solray Infrared Alignment Unit.',1,0.1,0,1,4,2000000.0000,1,NULL,0),(34402,314,'Radio Ray Modulate Disc','This disc of crystals is specially constructed to modulate radio rays in a Solray Radio Alignment Unit.',1,0.1,0,1,4,2000000.0000,1,NULL,0),(34403,306,'Solray Observational Unit','The Solray Observational Unit monitors the nearby Solray structure. Hacking into its mainframe gives the data needed to correct the alignment error of the Solray alignment units, in the form of a crystal discs.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34404,226,'Solray Unaligned Power Terminal','The Solray Power Terminal is intended to use solar power to generate energy, by gathering solar power from nearby Solray Alignment Units. However, it seems the alignment units are not working properly, causing the Solray Power Terminal to flare its energy erratically into space around it. This makes it extremely hazardous to move close to.',0,0,0,1,4,0.0000,0,NULL,0),(34405,226,'Solray Aligned Power Terminal','The Solray Power Terminal now seems to be in working order. The erratic outlet of energy seems to be lessening. You should be able to move close to this structure now, but use extreme care.',0,0,0,1,4,0.0000,0,NULL,0),(34406,306,'Remote Reroute Unit','This unit can be used to change settings of nearby structures, such as changing destination beacon for a spatial rift. Skillful use of hacking is required, but note that it might not be possible to adjust the settings a second time.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34412,997,'Small Intact Hull Section','Found drifting amongst the ruins of a Sleeper compound, these small sections of a Sleeper vessel represent a significant archaeological discovery. Not only is the hull itself an incredibly rare find, but the excellent condition it is in makes this a particularly useful case study for the Sleeper\'s ship construction methods.\r\r\n\r\r\nPristine, working examples of Sleeper technology such as this are extremely rare and even more valuable. With the right skills and equipment, they can offer great insights into the scientific pursuits of the ancient race that designed them. ',0,30,0,1,4,0.0000,1,1909,0),(34414,997,'Small Malfunctioning Hull Section','Found drifting amongst the ruins of a Sleeper compound, these small sections of a Sleeper vessel represent a significant archaeological discovery. The hull itself is an incredibly rare find, tainted only by the condition it is in. Although it was clearly built to survive the stress of space, the countless years of environmental exposure have still taken a heavy toll, stripping from it a great deal of the original functionality. \r\r\n\r\r\nEven despite the damage, it would still make a respectable case study for the Sleeper\'s vessel construction methods. A skilled scientist could still possibly extract enough information to try and reverse engineer it. ',0,30,0,1,4,0.0000,1,1909,0),(34416,997,'Small Wrecked Hull Section','Mistakenly identified by the analyzers as a derelict structure, these ancient Sleeper hull fragments are almost entirely destroyed. Whether slow erosion or some more rapid and violent event devastated the technology remains unclear. It is simply too badly damaged to make an educated guess. \r\r\n\r\r\nThere isn\'t much of a chance that anything useful could be reverse engineered from such badly ruined fragments, but there is little doubt that those few lucky researchers who successfully managed it would uncover the secrets to Sleeper hull designs. For many, that opportunity alone would be worth the gamble. ',0,30,0,1,4,0.0000,1,1909,0),(34417,1194,'Manufacturing Union s Placard','A solid morphite placard produced in celebration of the Secure Commerce Commission s official recognition of the Manufacturing Workers Union on July 22nd, YC115.',10,3,0,1,4,0.0000,1,1661,0),(34418,1194,'The Galactic Party Planning Guide','A compilation of guidelines for hosting your own capsuleer focused social gatherings, with chapters written by <url=showinfo:1384//647201759>Zapawork</url>, <url=showinfo:1377//101032679>nGR RDNx</url>, <url=showinfo:1375//806529354>Demetri Slavic</url>, <url=showinfo:1383//109000795>Dierdra Vaal</url> and <url=showinfo:1376//1239463613>Bam Stroker</url>.\r\r\n\r\r\nNote: Due to a formatting error, chapters by <url=showinfo:1377//101032679>nGR RDNx</url> and <url=showinfo:1376//1239463613>Bam Stroker</url> may be displayed upside down.\r\r\n',10,3,0,1,4,0.0000,1,1661,0),(34419,1194,'Jump Fatigue Recovery Agent','Poteque Pharmaceuticals were unable to trace the origins of this strange white powder, and were similarly baffled when trying to explain its miraculous ability to cure jump fatigue and allow the user to speak at a rate of roughly 300 words per minute.',10,3,0,1,4,0.0000,1,1661,0),(34420,1194,'Cooking With Veldspar','A family friendly holoreel compilation filled with the finest culinary tips New Eden has to offer.',10,3,0,1,4,0.0000,1,1661,0),(34421,1194,'Chribba s Modified Strip Miner','Jury rigged with duct tape and a laser pointer, even Outer Ring Excavations are bewildered by this module s ability to chew through so much ore per hour.',10,3,0,1,4,0.0000,1,1661,0),(34422,1194,'Rooks & Kings   The Clarion Call Compilation','Presented in all its glory on high resolution holoreel, you can now enjoy the glorious smooth tones of <url=showinfo:1373//822363613>Lord Maldoror s</url> narration in the comfort of your own captain s quarters.\r\r\n\r\r\n',10,3,0,1,4,0.0000,1,1661,0),(34423,1194,'Pre-Completed CSM 10 Ballot Paper','It would appear that a certain alliance has already decided whom its pilots will be voting for!',10,3,0,1,4,0.0000,1,1661,0),(34424,1194,'Titanium Plated Cranial Shielding','Those amidst the capsuleer \"information elite\" often utilize this homemade armor-piece to protect them from the dangers inherent in meta-space communication and theory-crafting.',10,3,0,1,4,0.0000,1,1661,0),(34425,1194,'SCC Guidelines   Lotteries For Dummies','The Secure Commerce Commission presents this comprehensive guide on how to host your gambling establishment within the law, in order to prevent seizure of assets by CONCORD.',10,3,0,1,4,0.0000,1,1661,0),(34426,1194,'Sort Dragon s Guide To Diplomacy','Famed for his leadership of Here Be Dragons, <url=showinfo:1384//1272172192>Sort Dragon</url> shares his top ten tips for Coalition self-destruction.',10,3,0,1,4,0.0000,1,1661,0),(34427,1194,'Polaris Eviction Notice','Oops.',10,3,0,1,4,0.0000,1,1661,0),(34428,1194,'Jump Portal Generation Instruction Holoreel','The finer points of bridging your fleet, rather than jumping. Narrated by <url=showinfo:1383//942377007>Oleena Natiras</url>, veteran of the Battle of Asakai.',10,3,0,1,4,0.0000,1,1661,0),(34429,1194,'Vincent Pryce s Warp Disruption Field Generator','A scale replica of the actual Warp Disruption Field Generator that caused the Battle of Asakai, one of the most expensive engagements in the history of Capsuleer warfare.',10,3,0,1,4,0.0000,1,1661,0),(34430,1194,'My God, It s Full Of Holes!','The Capsuleer s guide to all things wormhole. Navigation, mass calculation and lifestyle tips for wormhole dwellers included!',10,3,0,1,4,0.0000,1,1661,0),(34431,1194,'Guillome Renard s Sleeper Loot Stash','Crate after crate, packed with Neural Network Analyzers and Sleeper Data Libraries which were collected by <url=showinfo:1378//1643090141>Guillome Renard</url> during the research race of YC116.',10,3,0,1,4,0.0000,1,1661,0),(34432,1194,'Sisters Of EVE Charity Statue','A commemorative golden statue from a Sisters Of EVE Fundraiser which raised 7,634,000,000,000 Kredits in YC115.',10,3,0,1,4,0.0000,1,1661,0),(34433,1194,'The Damsel s Drunk Bodyguard','This guy really should probably be working ',10,3,0,1,4,0.0000,1,1661,0),(34434,1194,'Alice Saki s Good Posting Guide','Straight from the woman with the most positive Intergalactic Summit profile in the cluster, 101 tips for public relations superiority.',10,3,0,1,4,0.0000,1,1661,0),(34435,1194,'Soxfour s Spaceboots','Found in the airlock of a Leisure Group pleasure node on board the station orbiting Arifsdald III - Moon 14, these boots contain a note that reads as follows  Dear Nullarbor. Stop stealing my shoes. It s not funny anymore.   FF ',10,3,0,1,4,0.0000,1,1661,0),(34436,1194,'The Friend Ship','The best ship in New Eden.',10,3,0,1,4,0.0000,1,1661,0),(34437,383,'Rewired Sentry Gun','A sentry gun of Sleeper design. Has been rewired to view hostile targets as friendly and vice versa.',0,0,0,1,1,0.0000,0,NULL,0),(34438,306,'Sentry Repair Station','This is a maintenance facility for the Sleeper sentry guns in the vicinity. It can be hacked to change what sentry guns it is repairing.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34439,988,'Wormhole A009','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,NULL,0.0000,0,NULL,0),(34440,186,'Sleeper Medium Wreck ','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,NULL,0.0000,0,NULL,0),(34441,27,'Dominix Quafe Edition','The Dominix is one of the old warhorses dating back to the Gallente-Caldari War. While no longer regarded as the king of the hill, it is by no means obsolete. Its formidable hulk and powerful drone arsenal means that anyone not in the largest and latest battleships will regret ever locking horns with it.',100250000,454500,600,1,8,220059424.0000,0,NULL,0),(34442,107,'Dominix Quafe Edition Blueprint',' ',0,0.01,0,1,NULL,1660000000.0000,1,NULL,0),(34443,25,'Tristan Quafe Edition','Often nicknamed The Fat Man this nimble little frigate is mainly used by the Federation in escort duties or on short-range patrols. The Tristan has been very popular throughout Gallente space for years because of its versatility. It is rather expensive, but buyers will definitely get their money\'s worth, as the Tristan is one of the more powerful frigates available on the market.',956000,26500,140,1,8,337330.0000,0,NULL,0),(34444,105,'Tristan Quafe Edition Blueprint',' ',0,0.01,0,1,NULL,2825000.0000,1,NULL,0),(34445,26,'Vexor Quafe Edition','The Vexor is a strong combat ship that is also geared to operate in a variety of other roles. The Vexor is especially useful for surveying in potentially hostile sectors as it can stay on duty for a very long time before having to return to base. Furthermore, it is well capable of defending itself against even concentrated attacks.',11100000,115000,480,1,8,12003364.0000,0,NULL,0),(34446,106,'Vexor Quafe Edition Blueprint',' ',0,0.01,0,1,NULL,83250000.0000,1,NULL,0),(34447,306,'Cerebrum Maintenance Chamber','This large structure contains various materials used to maintain and repair the important Central Archive Cerebrum structure. Note that it is possible this structure is linked into the archive defense system, so hack with caution. ',10000,27500,2700,1,4,0.0000,0,NULL,0),(34448,226,'Smoldering Archive Ruins','These are the remains of a majestic Archive structure, containing untold riches and knowledge. It now lies in ruins, emitting dangerous materials into space around it. It is impossible to determine from the outside if anything of value remains, though the dormant Archive worker machines inside might be able to eject whatever is left. They will have to be activated first, though.',0,0,0,1,4,0.0000,0,NULL,0),(34449,952,'Central Archive Cerebrum','This is the central part of the Archive Cerebrum, the unit supervising the archives area. It has received damage, a fractured membrane leaking vital fluid for it to function properly. To make it functional again, it needs to reach equilibrium in its fluid system. Once functional, it can direct the Archive worker machines stationed around the area.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34450,314,'Intravenous Oscillation Fluid','This thick liquid is used by the Central Archive Cerebrum to operate its intricate machinery.\r\r\n',1,0.1,0,1,4,0.0000,1,NULL,0),(34451,314,'Nanoplastic Membrane Patch','This length of super-thin nanoplastic is used by the Central Archive Cerebrum to operate its intricate machinery.\r\r\n',1,0.1,0,1,4,0.0000,1,NULL,0),(34452,314,'Self-regulating Machine Gears','These complex set of gears are used by the Central Archive Cerebrum to operate its intricate machinery.',1,0.1,0,1,4,0.0000,1,NULL,0),(34453,306,'Vessel Rejuvenation Battery','This enigmatic, but highly advanced structure has massive repairing and protection capabilities for ships in its vicinity, but will only last for a very short time. It can be activated by successfully hacking it. This should be done only when in a dire situation.',10000,27500,2700,1,4,0.0000,0,NULL,0),(34454,383,'Archive Sentry Tower','These fearsome sentry towers have remained the faithful and dangerous guardians of their sleeping masters, even after countless years of constant duty. As unpredictable as they are powerful, the towers have been expertly designed to provide lasting vigilance with an unquestioning, mechanical loyalty. The weapons systems on board are frighteningly precise and devastating upon impact.',1000,1000,1000,1,64,0.0000,0,NULL,0),(34455,383,'Impaired Archive Sentry Tower','These fearsome sentry towers have remained the faithful and dangerous guardians of their sleeping masters, even after countless years of constant duty. As unpredictable as they are powerful, the towers have been expertly designed to provide lasting vigilance with an unquestioning, mechanical loyalty. The weapons systems on board are frighteningly precise and devastating upon impact.',1000,1000,1000,1,64,0.0000,0,NULL,0),(34456,226,'Angel Fence','A fence.',0,0,0,1,NULL,0.0000,0,NULL,0),(34457,27,' YC117 ','This is a special Armageddon variant developed by a mysterious faction of New Eden.',105200000,486000,600,1,4,251111582.0000,0,NULL,0),(34458,107,' YC117 ',' ',0,0.01,0,1,4,1565000000.0000,1,NULL,0),(34459,27,' YC117 ','This is a special Abaddon variant developed by a mysterious faction of New Eden.',103200000,495000,525,1,4,232044778.0000,0,NULL,0),(34460,107,' YC117 ',' ',0,0.01,0,1,4,1800000000.0000,1,NULL,0),(34461,27,' YC117 ','This is a special Machariel variant developed by a mysterious faction of New Eden.',94680000,595000,665,1,2,157405934.0000,0,NULL,0),(34462,107,' YC117 ',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34463,27,' YC117 ','This is a special Rattlesnake variant developed by a mysterious faction of New Eden.',99300000,486000,665,1,1,157405934.0000,0,NULL,0),(34464,107,' YC117 ',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34465,27,' YC117 ','This is a special Dominix variant developed by a mysterious faction of New Eden.',100250000,454500,600,1,8,220059424.0000,0,NULL,0),(34466,107,' YC117 ',' ',0,0.01,0,1,4,1660000000.0000,1,NULL,0),(34467,27,' YC117 ','This is a special Megathron variant developed by a mysterious faction of New Eden.',98400000,486000,675,1,8,190932898.0000,0,NULL,0),(34468,107,' YC117 ',' ',0,0.01,0,1,4,1250000000.0000,1,NULL,0),(34469,27,' YC117 ','This is a special Raven variant developed by a mysterious faction of New Eden.',99300000,486000,665,1,1,198117134.0000,0,NULL,0),(34470,107,' YC117 ',' ',0,0.01,0,1,4,1135000000.0000,1,NULL,0),(34471,27,' YC117 ','This is a special Apocalypse variant developed by a mysterious faction of New Eden.',97100000,495000,675,1,4,199648910.0000,0,NULL,0),(34472,107,' YC117 ',' ',0,0.01,0,1,4,1265000000.0000,1,NULL,0),(34473,419,' YC117 ','This is a special Drake variant developed by a mysterious faction of New Eden.',14810000,252000,450,1,1,59996916.0000,0,NULL,0),(34474,489,' YC117 ',' ',0,0.01,0,1,4,580000000.0000,1,NULL,0),(34475,26,' YC117 ','This is a special Gila variant developed by a mysterious faction of New Eden.',9600000,101000,440,1,1,11579728.0000,0,NULL,0),(34476,106,' YC117 ',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34477,358,' YC117 ','This is a special Eagle variant developed by a mysterious faction of New Eden.',11720000,101000,550,1,1,48893330.0000,0,NULL,0),(34478,106,' YC117 ',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34479,358,' YC117 ','This is a special Ishtar variant developed by a mysterious faction of New Eden.',11100000,115000,560,1,8,48392154.0000,0,NULL,0),(34480,106,' YC117 ',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34481,762,'Domination Inertial Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,4,6036.0000,1,1086,0),(34483,762,'Shadow Serpentis Inertial Stabilizers','Improves ship handling and maneuverability.\r\r\n\r\r\nPenalty: Using more than one type of this module or similar modules that affect the same attribute on the ship will be penalized.',200,5,0,1,4,6036.0000,1,1086,0),(34485,78,'ORE Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,4,13888.0000,1,1195,0),(34487,78,'Syndicate Reinforced Bulkheads','Increases structural hit points while reducing agility and cargo capacity.',200,5,0,1,4,13888.0000,1,1195,0),(34489,765,'ORE Expanded Cargohold','Increases cargo hold capacity.',50,5,0,1,4,1792.0000,1,1197,0),(34494,226,'Unidentified Wormhole','There\'s nothing in our databanks that matches this wormhole.',0,0,0,1,64,0.0000,0,NULL,0),(34495,1310,'Drifter Battleship','CONCORD\'s analysis of this battleship has been hampered by its advanced hull and shielding. The propulsion system is unfamiliar but tentative theories have suggested that the vessel somehow directly interacts with the fabric of space-time while moving. The standard weapon systems of this ship appear to be semi-autonomous and effective against a range of targets.\r\r\nDED contact briefings suggest the free floating turrets are a secondary weapon, with an extremely dangerous primary weapon held in reserve against those this ship\'s commander considers a significant threat.\r\r\nThreat level: Critical\r\r\n ',10900000,109000,120,1,64,0.0000,0,NULL,0),(34496,31,'Council Diplomatic Shuttle','Based on a decommissioned Pacifier-class CONCORD frigate, this swift armored transport is typically used by the Directive Enforcement Department to ensure secure transportation of VIPs and high profile political figures.\r\r\n\r\r\nMost recently it has been utilized to carry members of the <url=http://community.eveonline.com/community/csm/>Council of Stellar Management</url> to and from their bi-annual summit with the CONCORD Assembly in Yulai.',1600000,5000,10,1,8,5556.0000,1,1618,0),(34497,111,'Council Diplomatic Shuttle Blueprint',' ',0,0.01,0,1,NULL,50000.0000,1,NULL,0),(34498,952,'Sentinel Vault','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34499,952,'Barbican Vault','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34500,952,'Vidette Vault','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34501,952,'Conflux Vault','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34502,952,'Redoubt Vault','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34503,306,'Sentinel Beta Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34504,306,'Sentinel Delta Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34505,306,'Sentinel Alpha Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34506,306,'Sentinel Gamma Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34507,306,'Barbican Beta Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34508,306,'Barbican Delta Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34509,306,'Barbican Alpha Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34510,306,'Barbican Gamma Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34511,306,'Vidette Beta Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34512,306,'Vidette Delta Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34513,306,'Vidette Alpha Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34514,306,'Vidette Gamma Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34515,306,'Conflux Beta Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34516,306,'Conflux Delta Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34517,306,'Conflux Alpha Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34518,306,'Conflux Gamma Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34519,306,'Redoubt Beta Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34520,306,'Redoubt Delta Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34521,306,'Redoubt Alpha Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34522,306,'Redoubt Gamma Access Unit','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34523,1207,'Sentinel Alignment Unit 0','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34524,1207,'Sentinel Alignment Unit 1','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34525,1207,'Barbican Alignment Unit 0','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34526,1207,'Barbican Alignment Unit 1','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34527,1207,'Vidette Alignment Unit 0','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34528,1207,'Vidette Alignment Unit 1','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34529,1207,'Conflux Alignment Unit 0','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34530,1207,'Conflux Alignment Unit 1','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34531,1207,'Redoubt Alignment Unit 0','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34532,1207,'Redoubt Alignment Unit 1','This look like a storage device of unknown origin. Detailed analysis might reveal more.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34533,257,'Minmatar Tactical Destroyer','Skill at operating Minmatar Tactical Destroyers.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,2,1000000.0000,1,377,0),(34534,226,'Sentinel Hive','Dwarfing the majestic enclave in size, the scale of this Hive sends shivers of awe into all those who bear witness to its grandeur.\r\r\nIts walls stand defiant against the harsh black vacuum. Its structure, testament to the unfathomable technological prowess of the Sleeper race. \r\r\n\r\r\nCold, sharp edges seem to tear at the very fabric of space, distorting reality around it.\r\r\nOne can only cower in fear at the thought of what a construction of this magnitudes purpose could be.\r\r\n',100000,100000000,10000,1,64,0.0000,0,NULL,0),(34535,226,'Barbican Hive','Dwarfing the majestic enclave in size, the scale of this Hive sends shivers of awe into all those who bear witness to its grandeur.\r\r\nIts walls stand defiant against the harsh black vacuum. Its structure, testament to the unfathomable technological prowess of the Sleeper race. \r\r\n\r\r\nCold, sharp edges seem to tear at the very fabric of space, distorting reality around it.\r\r\nOne can only cower in fear at the thought of what a construction of this magnitudes purpose could be.',100000,100000000,10000,1,64,0.0000,0,NULL,0),(34536,226,'Vidette Hive','Dwarfing the majestic enclave in size, the scale of this Hive sends shivers of awe into all those who bear witness to its grandeur.\r\r\nIts walls stand defiant against the harsh black vacuum. Its structure, testament to the unfathomable technological prowess of the Sleeper race. \r\r\n\r\r\nCold, sharp edges seem to tear at the very fabric of space, distorting reality around it.\r\r\nOne can only cower in fear at the thought of what a construction of this magnitudes purpose could be.',100000,100000000,10000,1,64,0.0000,0,NULL,0),(34537,226,'Conflux Hive','Dwarfing the majestic enclave in size, the scale of this Hive sends shivers of awe into all those who bear witness to its grandeur.\r\r\nIts walls stand defiant against the harsh black vacuum. Its structure, testament to the unfathomable technological prowess of the Sleeper race. \r\r\n\r\r\nCold, sharp edges seem to tear at the very fabric of space, distorting reality around it.\r\r\nOne can only cower in fear at the thought of what a construction of this magnitudes purpose could be.',100000,100000000,10000,1,64,0.0000,0,NULL,0),(34538,226,'Redoubt Hive','Dwarfing the majestic enclave in size, the scale of this Hive sends shivers of awe into all those who bear witness to its grandeur.\r\r\nIts walls stand defiant against the harsh black vacuum. Its structure, testament to the unfathomable technological prowess of the Sleeper race. \r\r\n\r\r\nCold, sharp edges seem to tear at the very fabric of space, distorting reality around it.\r\r\nOne can only cower in fear at the thought of what a construction of this magnitudes purpose could be.',100000,100000000,10000,1,64,0.0000,0,NULL,0),(34539,226,'Unidentified Sleeper Device',' ',100000000000,10000000000,0,1,64,0.0000,0,NULL,0),(34540,1314,'Sentinel Sequence 0','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,0,NULL,0),(34541,1314,'Sentinel Sequence 1','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,0,NULL,0),(34542,1314,'Barbican Sequence 0','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,0,NULL,0),(34543,1314,'Barbican Sequence 1','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,0,NULL,0),(34544,1314,'Vidette Sequence 0','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,0,NULL,0),(34545,1314,'Vidette Sequence 1','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,0,NULL,0),(34546,1314,'Conflux Sequence 0','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,0,NULL,0),(34547,1314,'Conflux Sequence 1','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,0,NULL,0),(34548,1314,'Redoubt Sequence 0','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,0,NULL,0),(34549,1314,'Redoubt Sequence 1','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to activate a certain acceleration gate. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,0,NULL,0),(34551,1314,'Sentinel Index','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to unlock a container of some sorts. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,1,2013,0),(34552,1314,'Barbican Index','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to unlock a container of some sorts. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,1,2013,0),(34553,1314,'Vidette Index','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to unlock a container of some sorts. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,1,2013,0),(34554,1314,'Conflux Index','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to unlock a container of some sorts. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,1,2013,0),(34555,1314,'Redoubt Index','This intriguing code is filled with unfamiliar mathematical algorithms. What little can be discerned is that it can be used to unlock a container of some sorts. It has a built-in recalibration code that makes it a one-use only passkey.',1,0.1,0,1,64,0.0000,1,2013,0),(34556,1314,'Sentinel Element','The strange, unreal aspect of this object plays havoc with your mind.\r\r\nThe distortion is interfering with signal reception and hindering decryption.\r\r\nDespite this, one strong repetitive motif is breaking through the chaos. \r\r\nA single repeating concept.\r\r\n\r\r\nSentinel.\r\r\n',1,0.1,0,1,64,0.0000,1,2013,0),(34557,1314,'Barbican Element','The strange, unreal aspect of this object plays havoc with your mind.\r\r\nThe distortion is interfering with signal reception and hindering decryption.\r\r\nDespite this, one strong repetitive motif is breaking through the chaos. \r\r\nA single repeating concept.\r\r\n\r\r\nBarbican.',1,0.1,0,1,64,0.0000,1,2013,0),(34558,1314,'Vidette Element','The strange, unreal aspect of this object plays havoc with your mind.\r\r\nThe distortion is interfering with signal reception and hindering decryption.\r\r\nDespite this, one strong repetitive motif is breaking through the chaos. \r\r\nA single repeating concept.\r\r\n\r\r\nVidette.',1,0.1,0,1,64,0.0000,1,2013,0),(34559,1314,'Conflux Element','The strange, unreal aspect of this object plays havoc with your mind.\r\r\nThe distortion is interfering with signal reception and hindering decryption.\r\r\nDespite this, one strong repetitive motif is breaking through the chaos. \r\r\nA single repeating concept.\r\r\n\r\r\nConflux.',1,0.1,0,1,64,0.0000,1,2013,0),(34560,1314,'Redoubt Element','The strange, unreal aspect of this object plays havoc with your mind.\r\r\nThe distortion is interfering with signal reception and hindering decryption.\r\r\nDespite this, one strong repetitive motif is breaking through the chaos. \r\r\nA single repeating concept.\r\r\n\r\r\nRedoubt.',1,0.1,0,1,64,0.0000,1,2013,0),(34561,1310,'Drifter Battleship','CONCORD\'s analysis of this battleship has been hampered by its advanced hull and shielding. The propulsion system is unfamiliar but tentative theories have suggested that the vessel somehow directly interacts with the fabric of space-time while moving. The standard weapon systems of this ship appear to be semi-autonomous and effective against a range of targets.\r\r\nDED contact briefings suggest the free floating turrets are a secondary weapon, with an extremely dangerous primary weapon held in reserve against those this ship\'s commander considers a significant threat.\r\r\nThreat level: Critical',10900000,109000,120,1,64,0.0000,0,NULL,0),(34562,1305,'Svipul','Released in YC 117 as the result of the first Republic Fleet joint research project to include engineers from all seven Minmatar tribes, the Svipul is a powerful symbol of inter-tribal unity for many Republic citizens.\r\r\n\r\r\nAlthough the contributions of engineers from the Nefantar and Starkmanir tribes were fairly minor, a large delegation from the Vo-Lakat Thukker caravan and donations from Republic loyalist capsuleers across the cluster were invaluable to the development of this incredibly adaptable warship.',1500000,47000,430,1,2,9200000.0000,1,1953,0),(34563,1309,'Svipul Blueprint','The Svipul-class Tactical Destroyer was developed on behalf of the Minmatar people in YC117 with the invaluable aid of eighty-seven dedicated capsuleers. Of these pilots, the greatest contributors were:\r\r\n<url=showinfo:1373//90771225>Lotrec Emetin</url>\r\r\n<url=showinfo:1373//334330150>Robert Warner</url>\r\r\n<url=showinfo:1373//230923199>Dr Scott</url>\r\r\n<url=showinfo:1373//1097436858>Esrevid Nekkeg</url>\r\r\n<url=showinfo:1373//257707569>SambaSol</url>\r\r\n<url=showinfo:1373//90792984>Nrone3 Agalder</url>\r\r\n<url=showinfo:1373//1540818861>Myronik</url>\r\r\n<url=showinfo:1373//644454761>Lynnu</url>\r\r\n<url=showinfo:1373//986524995>Maataak</url>\r\r\n<url=showinfo:1373//577820985>Shalmon Aliatus</url>',0,0.01,0,1,2,40000000.0000,1,NULL,0),(34564,1306,'Svipul Defense Mode','33.3% bonus to all shield and armor resistances\r\r\n66.6% reduction in MicroWarpdrive signature radius penalty',100,5,0,1,2,0.0000,0,NULL,0),(34566,1306,'Svipul Propulsion Mode','66.6% bonus to maximum velocity\r\r\n33.3% bonus to ship inertia modifier',100,5,0,1,2,0.0000,0,NULL,0),(34570,1306,'Svipul Sharpshooter Mode','33.3% bonus to Small Projectile Turret tracking speed\r\r\n100% bonus to sensor strength, targeting range and scan resolution',100,5,0,1,2,0.0000,0,NULL,0),(34572,1207,'Sleeper Databank','This hull plate still has an unobstructed access point for the databank it holds. You may be able to extract something with your Data Analyzer.',10000,27500,2700,1,64,0.0000,0,NULL,0),(34573,226,'Unidentified Structure','There\'s nothing in our databanks that matches this structure.',0,0,0,1,1,0.0000,0,NULL,0),(34574,1,'CharacterDrifter',' ',0,0,0,1,16,0.0000,1,NULL,0),(34575,1314,'Antikythera Element','Limited information is available on this object.\r\r\n\r\r\nA direct analysis reveals some vague and distorted results.\r\r\nSlight external damage signals that it was detached from something else, but despite its removal, the core structure continues to thrum with a deep, surging power.\r\r\n\r\r\nEven without proof or solid knowledge of the function of this component, it is quite clear that it forms a vital part of something much larger.\r\r\n',1,0.1,0,1,64,5000000.0000,1,2013,0),(34579,286,'Clonejacker Punk','This young pirate is looking to make a name as a clonejacker, raiding illegal clone labs for biomass to be sold on the black market. Such an inexperienced criminal is unlikely to pick a fight with a capsuleer unless provoked.',1970000,19700,125,1,1,0.0000,0,NULL,0),(34580,53,'Lux Kontos','This strange weapon system appears to be semi-autonomous, floating freely from the vessel deploying it. Analysis of the weapon\'s firing signature indicates a broad spectrum of disruptive energies are used against its targets.\r\r\n',0,0,0,1,16,0.0000,1,NULL,0),(34584,186,'Minmatar Advanced Destroyer Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,2,0.0000,0,NULL,0),(34588,286,'Belter Hoodlum','This low level criminal is likely a former asteroid miner turned to preying on his former colleagues. Many crime gangs recruit from the lowest paid among those who work in space as a means of gaining new pilots. Such an inexperienced criminal is unlikely to pick a fight with a capsuleer unless provoked.',1970000,19700,125,1,1,0.0000,0,NULL,0),(34589,286,'Narco Pusher','This criminal is a low level pusher for narcotics gangs operating in the area. These drug pushers sell their illegal wares to miners and others working in dangerous space industries. These criminals avoid trouble unless provoked.',1970000,19700,125,1,1,0.0000,0,NULL,0),(34590,26,'Victorieux Luxury Yacht','Developed for use by station governors and other well-connected members of the Intaki Syndicate, Victorieux-class Luxury Yachts combine opulent accommodations with state of the art cloaking and propulsion systems. The Victorieux enables comfortable and discreet travel for business or pleasure, from Poitot to Intaki and beyond.\r\r\n\r\r\nThe Syndicate has steadfastly refused to answer inquiries on how they obtained the technology necessary to enable simultaneous cloak and warp drive activation on this yacht.\r\r\n\r\r\nIn early YC117, Silphy en Diabel announced that the Syndicate would be sponsoring an invitational tournament and making limited run blueprints for the Victorieux available to all capsuleer supporters of the winning team.',10000000,115000,30,1,8,15508800.0000,1,1699,0),(34591,106,'Victorieux Luxury Yacht Blueprint',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34592,817,'Serpentis Burner Cruiser','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations.\r\r\n\r\r\nThis Serpentis pirate is a negotiator, a fixer who establishes contracts between pirate-trained clone soldiers and those who, like the Serpentis, are playing the long game of strategy and counter-strategy, and whose tactical needs are served best by shadowy associations with a small but unstoppable force of death.',11200000,112000,480,1,8,0.0000,0,NULL,0),(34593,1313,'Entosis Link I','This mysterious device is the result of reverse-engineering salvaged Drifter technology. It appears to use ancient Jovian techniques and materials to allow more efficient mind-machine links than were thought possible in the past. The practical applications of this technology are still unclear.\r\r\n\r\r\nThis module requires a full warm-up cycle before beginning to influence targeted structures.\r\r\nOnce activated, this module cannot be deactivated until it completes its current cycle.\r\r\nWhile an Entosis Link is active, the fitted ship cannot cloak, warp, jump, dock or receive any form of remote assistance.\r\r\n\r\r\nDisclaimer: The Carthum Conglomerate, as well as its registered subsidiaries and partners, accepts absolutely no legal or ethical liability for any unforeseen consequences of connecting untested Drifter-derived technology directly to the user\'s mind.',0,20,0,1,16,56492000.0000,1,2018,0),(34594,1318,'Entosis Link I Blueprint',' ',0,0.01,0,1,16,200000000.0000,1,2020,0),(34595,1313,'Entosis Link II','This mysterious device is the result of reverse-engineering salvaged Drifter technology. It appears to use ancient Jovian techniques and materials to allow more efficient mind-machine links than were thought possible in the past. The practical applications of this technology are still unclear.\r\r\n\r\r\nThis module requires a full warm-up cycle before beginning to influence targeted structures.\r\r\nOnce activated, this module cannot be deactivated until it completes its current cycle.\r\r\nWhile an Entosis Link is active, the fitted ship cannot cloak, warp, jump, dock or receive any form of remote assistance.\r\r\n\r\r\nDisclaimer: The Carthum Conglomerate, as well as its registered subsidiaries and partners, accepts absolutely no legal or ethical liability for any unforeseen consequences of connecting untested Drifter-derived technology directly to the user\'s mind.',0,20,0,1,16,166467220.0000,1,2018,0),(34596,1318,'Entosis Link II Blueprint',' ',0,0.01,0,1,16,9999999.0000,1,NULL,0),(34599,1311,'Apocalypse Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1964,0),(34600,1311,'Apocalypse Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1964,0),(34601,1311,'Harbinger Kador SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1956,0),(34602,1311,'Harbinger Khanid SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1956,0),(34603,1311,'Oracle Khanid SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1956,0),(34604,1311,'Oracle Sarum SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1956,0),(34605,1311,'Prophecy Blood Raiders SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34606,1311,'Prophecy Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1956,0),(34607,1311,'Prophecy Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1956,0),(34608,1311,'Ferox Guristas SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34609,1311,'Ferox Lai Dai SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1957,0),(34610,1311,'Naga Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1957,0),(34611,1311,'Brutix Roden SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1958,0),(34612,1311,'Brutix Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1958,0),(34613,1311,'Brutix Serpentis SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34614,1311,'Myrmidon Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1958,0),(34615,1311,'Myrmidon InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1958,0),(34616,1311,'Talos Duvolle SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1958,0),(34617,1311,'Talos InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1958,0),(34618,1311,'Cyclone Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1959,0),(34619,1311,'Cyclone Thukker Tribe SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(34620,1311,'Hurricane Sebiestor SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1959,0),(34621,1311,'Tornado Nefantar SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1959,0),(34623,1311,'Abaddon Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1964,0),(34624,1311,'Abaddon Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1964,0),(34625,1311,'Armageddon Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1964,0),(34626,1311,'Armageddon Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1964,0),(34627,1311,'Apocalypse Ardishapur SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1964,0),(34628,1311,'Apocalypse Khanid SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1964,0),(34629,1311,'Raven Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1965,0),(34630,1311,'Rokh Nugoeihuvi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1965,0),(34631,1311,'Rokh Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1965,0),(34632,1311,'Scorpion Ishukone Watch SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1965,0),(34633,1311,'Dominix Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1966,0),(34634,1311,'Dominix Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1966,0),(34635,1311,'Dominix Quafe SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1966,0),(34636,1311,'Hyperion Aliastra SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1966,0),(34637,1311,'Hyperion Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1966,0),(34638,1311,'Megathron Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1966,0),(34639,1311,'Megathron Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1966,0),(34640,1311,'Megathron Quafe SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1966,0),(34641,1311,'Maelstrom Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1967,0),(34642,1311,'Maelstrom Nefantar SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1967,0),(34643,1311,'Typhoon Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1967,0),(34645,1311,'Orca ORE Development SKIN (Permanent)',' ',0,0.01,0,1,128,0.0000,1,1969,0),(34646,1311,'Rorqual ORE Development SKIN (Permanent)',' ',0,0.01,0,1,128,0.0000,1,1969,0),(34647,1311,'Archon Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1974,0),(34648,1311,'Archon Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1974,0),(34649,1311,'Aeon Khanid SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1974,0),(34650,1311,'Aeon Sarum SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1974,0),(34651,1311,'Chimera Lai Dai SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1975,0),(34652,1311,'Wyvern Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1975,0),(34653,1311,'Thanatos Quafe SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1976,0),(34654,1311,'Thanatos Roden SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1976,0),(34655,1311,'Nyx InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1976,0),(34656,1311,'Nyx Quafe SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1976,0),(34657,1311,'Nidhoggur Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1977,0),(34658,1311,'Hel Sebiestor SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1977,0),(34659,1311,'Revelation Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1980,0),(34660,1311,'Revelation Sarum SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1980,0),(34661,1311,'Phoenix Lai Dai SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1981,0),(34662,1311,'Phoenix Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1981,0),(34663,1311,'Moros InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1982,0),(34664,1311,'Moros Roden SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1982,0),(34665,1311,'Naglfar Justice SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1983,0),(34666,1311,'Providence Ardishapur SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1984,0),(34667,1311,'Providence Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1984,0),(34668,1311,'Charon Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1985,0),(34669,1311,'Obelisk Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1986,0),(34670,1311,'Obelisk Quafe SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1986,0),(34671,1311,'Fenrir Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1987,0),(34672,1311,'Avatar Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1978,0),(34673,1311,'Avatar Khanid SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1978,0),(34674,1311,'Erebus Duvolle SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1979,0),(34675,1311,'Erebus InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1979,0),(34676,1311,'Arbitrator Ardishapur SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1990,0),(34677,1311,'Arbitrator Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1990,0),(34678,1311,'Augoror Ardishapur SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1990,0),(34679,1311,'Augoror Khanid SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1990,0),(34680,1311,'Maller Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1990,0),(34681,1311,'Maller Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1990,0),(34682,1311,'Omen Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1990,0),(34683,1311,'Omen Sarum SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1990,0),(34684,1311,'Omen Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1990,0),(34685,1311,'Caracal Nugoeihuvi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1991,0),(34686,1311,'Caracal Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1991,0),(34687,1311,'Moa Lai Dai SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1991,0),(34688,1311,'Osprey Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,1991,0),(34689,1311,'Celestis Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1992,0),(34690,1311,'Celestis InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1992,0),(34691,1311,'Exequror Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1992,0),(34692,1311,'Thorax Aliastra SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1992,0),(34693,1311,'Thorax Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1992,0),(34694,1311,'Vexor Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1992,0),(34695,1311,'Vexor InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1992,0),(34696,1311,'Vexor Quafe SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1992,0),(34697,1311,'Bellicose Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1993,0),(34698,1311,'Stabber Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1993,0),(34699,1311,'Stabber Nefantar SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1993,0),(34700,1311,'Coercer Ardishapur SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1994,0),(34701,1311,'Coercer Blood Raiders SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34702,1311,'Coercer Sarum SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1994,0),(34703,1311,'Dragoon Khanid SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1994,0),(34704,1311,'Dragoon Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,1994,0),(34705,1311,'Cormorant Guristas SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34706,1311,'Algos Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1996,0),(34707,1311,'Algos InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1996,0),(34708,1311,'Catalyst Aliastra SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1996,0),(34709,1311,'Catalyst Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1996,0),(34710,1311,'Catalyst Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1996,0),(34711,1311,'Catalyst InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1996,0),(34712,1311,'Catalyst Quafe SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,1996,0),(34713,1311,'Catalyst Serpentis SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34714,1311,'Talwar Sebiestor SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1997,0),(34715,1311,'Thrasher Nefantar SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1997,0),(34716,1311,'Thrasher Thukker Tribe SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(34717,226,'Jove Observatory','CONCORD\'s analysis has revealed only scant and confusing information about this structure. Surveys of the damaged areas of the structure reveal a series of clearly powerful but functionally mysterious elements. The structure is undoubtedly Jove in origin but it is hard to determine its exact age given the advanced nature of the materials and construction. Regardless of its age, it is safe to say the structure surpasses anything we have previously seen.',0,0,0,1,16,0.0000,0,NULL,0),(34718,1311,'Comet Police Pursuit SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2000,0),(34719,1311,'Crucifier Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34720,1311,'Crucifier Sarum SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34721,1311,'Executioner Ardishapur SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34722,1311,'Executioner Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34723,1311,'Inquisitor Khanid SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34724,1311,'Inquisitor Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34725,1311,'Magnate Ardishapur SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34726,1311,'Magnate Sarum SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34727,1311,'Magnate Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34728,1311,'Punisher Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34729,1311,'Punisher Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34730,1311,'Tormentor Ardishapur SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34731,1311,'Tormentor Sarum SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2002,0),(34732,1311,'Heron Sukuuvestaa SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,2003,0),(34733,1311,'Kestrel Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,2003,0),(34734,1311,'Merlin Nugoeihuvi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,2003,0),(34735,1311,'Merlin Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,2003,0),(34736,1311,'Atron Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34737,1311,'Atron InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34738,1311,'Imicus Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34739,1311,'Imicus Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34740,1311,'Incursus Aliastra SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34741,1311,'Incursus Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34742,1311,'Maulus Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34743,1311,'Maulus Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34744,1311,'Navitas Intaki Syndicate SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34745,1311,'Tristan Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34746,1311,'Tristan Quafe SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2004,0),(34747,1311,'Probe Vherokior SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,2005,0),(34748,1311,'Rifter Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,2005,0),(34749,1311,'Rifter Nefantar SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,2005,0),(34750,1311,'Slasher Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,2005,0),(34751,1311,'Vigil Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,2005,0),(34752,1311,'Bestower Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2007,0),(34753,1311,'Sigil Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2007,0),(34754,1311,'Tayra Wiyrkomi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,2008,0),(34755,1311,'Iteron Mark V Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2009,0),(34756,1311,'Iteron Mark V InterBus SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2009,0),(34757,1311,'Mammoth Nefantar SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,2010,0),(34758,1311,'Hulk ORE Development SKIN (Permanent)',' ',0,0.01,0,1,128,0.0000,1,2012,0),(34759,1311,'Mackinaw ORE Development SKIN (Permanent)',' ',0,0.01,0,1,128,0.0000,1,2012,0),(34760,1311,'Skiff ORE Development SKIN (Permanent)',' ',0,0.01,0,1,128,0.0000,1,2012,0),(34761,226,'Jove Observatory','CONCORD\'s analysis has revealed only scant and confusing information about this structure. Surveys of the damaged areas of the structure reveal a series of clearly powerful but functionally mysterious elements. The structure is undoubtedly Jove in origin but it is hard to determine its exact age given the advanced nature of the materials and construction. Regardless of its age, it is safe to say the structure surpasses anything we have previously seen.',0,0,0,1,64,0.0000,0,NULL,0),(34762,226,'Jove Observatory','CONCORD\'s analysis has revealed only scant and confusing information about this structure. Surveys of the damaged areas of the structure reveal a series of clearly powerful but functionally mysterious elements. The structure is undoubtedly Jove in origin but it is hard to determine its exact age given the advanced nature of the materials and construction. Regardless of its age, it is safe to say the structure surpasses anything we have previously seen.',0,0,0,1,64,0.0000,0,NULL,0),(34763,226,'Jove Observatory','CONCORD\'s analysis has revealed only scant and confusing information about this structure. Surveys of the damaged areas of the structure reveal a series of clearly powerful but functionally mysterious elements. The structure is undoubtedly Jove in origin but it is hard to determine its exact age given the advanced nature of the materials and construction. Regardless of its age, it is safe to say the structure surpasses anything we have previously seen.',0,0,0,1,64,0.0000,0,NULL,0),(34764,226,'Jove Observatory','CONCORD\'s analysis has revealed only scant and confusing information about this structure. Surveys of the damaged areas of the structure reveal a series of clearly powerful but functionally mysterious elements. The structure is undoubtedly Jove in origin but it is hard to determine its exact age given the advanced nature of the materials and construction. Regardless of its age, it is safe to say the structure surpasses anything we have previously seen.',0,0,0,1,64,0.0000,0,NULL,0),(34765,226,'Jove Observatory','CONCORD\'s analysis has revealed only scant and confusing information about this structure. Surveys of the damaged areas of the structure reveal a series of clearly powerful but functionally mysterious elements. The structure is undoubtedly Jove in origin but it is hard to determine its exact age given the advanced nature of the materials and construction. Regardless of its age, it is safe to say the structure surpasses anything we have previously seen.',0,0,0,1,64,0.0000,0,NULL,0),(34766,226,'Jove Corpse','A Jovian corpse.',200,2,0,1,4,0.0000,0,NULL,0),(34767,226,'Jove Corpse','A Jovian corpse.',200,2,0,1,4,0.0000,0,NULL,0),(34768,186,'Drifter Battleship Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,27500,27500,1,64,0.0000,0,NULL,0),(34769,1194,'CSM 1 Electee Archive Script ','A secure holographic datapad, used to access the CONCORD public information database.\r\r\n \r\r\n \r\r\n//archive_yulai8_ict -search\r\r\n>SEARCH INITIATED\r\r\n>SEARCH SEQUENCE... COMPLETE\r\r\n//archive_csm -search\r\r\n>ARCHIVE SEARCH... COMPLETE\r\r\n>LOADING... COMPLETE \r\r\n \r\r\nCouncil of Stellar Management 1 electees:\r\r\n \r\r\n<url=showinfo:1378//161929388>Ankhesentapemkah</url>\r\r\n<url=showinfo:1385//138453917>Bane Glorious</url>\r\r\n<url=showinfo:1373//902506853>Darius JOHNSON</url>\r\r\n<url=showinfo:1383//109000795>Dierdra Vaal</url>\r\r\n<url=showinfo:1374//144583249>Hardin</url>\r\r\n<url=showinfo:1379//780632175>Inanna Zuni</url>\r\r\n<url=showinfo:1377//158634209>Jade Constantine</url>\r\r\n<url=showinfo:1378//699886074>LaVista Vista</url>\r\r\n<url=showinfo:1377//156565803>Omber Zombie</url>\r\r\n<url=showinfo:1376//1761171880>Serenity Steele</url>\r\r\n<url=showinfo:1375//154392629>Tusko Hopkins</url>',0,0.01,0,1,4,0.0000,1,1661,0),(34770,1194,'CSM 2 Electee Archive Script','A secure holographic datapad, used to access the CONCORD public information database.\r\r\n \r\r\n \r\r\n//archive_yulai8_ict -search\r\r\n>SEARCH INITIATED\r\r\n>SEARCH SEQUENCE... COMPLETE\r\r\n//archive_csm -search\r\r\n>ARCHIVE SEARCH... COMPLETE\r\r\n>LOADING... COMPLETE \r\r\n \r\r\nCouncil of Stellar Management 2 electees:\r\r\n \r\r\n<url=showinfo:1378//161929388>Ankhesentapemkah</url>\r\r\n<url=showinfo:1377//845702584>Bunyip</url>\r\r\n<url=showinfo:1373//902506853>Darius JOHNSON</url>\r\r\n<url=showinfo:1379//146431304>Extreme</url>\r\r\n<url=showinfo:1386//179116309>Issler Dainze</url>\r\r\n<url=showinfo:1378//699886074>LaVista Vista</url>\r\r\n<url=showinfo:1386//1271256719>Meissa Anunthiel</url>\r\r\n<url=showinfo:1377//156565803>Omber Zombie</url>\r\r\n<url=showinfo:1380//734776565>Pattern Clarc</url>\r\r\n<url=showinfo:1375//154392629>Tusko Hopkins</url>\r\r\n<url=showinfo:1377//1611864709>Vuk Lau</url>',0,0.01,0,1,4,0.0000,1,1661,0),(34771,1194,'CSM 3 Electee Archive Script','A secure holographic datapad, used to access the CONCORD public information database.\r\r\n \r\r\n \r\r\n//archive_yulai8_ict -search\r\r\n>SEARCH INITIATED\r\r\n>SEARCH SEQUENCE... COMPLETE\r\r\n//archive_csm -search\r\r\n>ARCHIVE SEARCH... COMPLETE\r\r\n>LOADING... COMPLETE \r\r\n \r\r\nCouncil of Stellar Management 3 electees:\r\r\n \r\r\n<url=showinfo:1376//1282041313>Avalloc</url>\r\r\n<url=showinfo:1376//1828158994>Chip Mintago</url>\r\r\n<url=showinfo:1383//109000795>Dierdra Vaal</url>\r\r\n<url=showinfo:1377//254956725>Erik Finnegan</url>\r\r\n<url=showinfo:1386//179116309>Issler Dainze</url>\r\r\n<url=showinfo:1383//765935202>mazzilliu</url>\r\r\n<url=showinfo:1386//1271256719>Meissa Anunthiel</url>\r\r\n<url=showinfo:1377//156565803>Omber Zombie</url>\r\r\n<url=showinfo:1376//1761171880>Serenity Steele</url>\r\r\n<url=showinfo:1378//938930965>Shatana Fulfairas</url>\r\r\n<url=showinfo:1377//1611864709>Vuk Lau</url>\r\r\n<url=showinfo:1383//1012990282>Weazy Z</url>\r\r\n<url=showinfo:1375//932924156>Zastrow J</url>',0,0.01,0,1,4,0.0000,1,1661,0),(34772,1194,'CSM 4 Electee Archive Script','A secure holographic datapad, used to access the CONCORD public information database.\r\r\n \r\r\n \r\r\n//archive_yulai8_ict -search\r\r\n>SEARCH INITIATED\r\r\n>SEARCH SEQUENCE... COMPLETE\r\r\n//archive_csm -search\r\r\n>ARCHIVE SEARCH... COMPLETE\r\r\n>LOADING... COMPLETE \r\r\n \r\r\nCouncil of Stellar Management 4 electees:\r\r\n \r\r\n<url=showinfo:1377//725386886>Alekseyev Karrde</url>\r\r\n<url=showinfo:1377//817355844>ElvenLord</url>\r\r\n<url=showinfo:1376//741641765>Farscape Hw</url>\r\r\n<url=showinfo:1377//1170412163>Helen Highwater</url>\r\r\n<url=showinfo:1378//1059081514>Korvin</url>\r\r\n<url=showinfo:1386//1271256719>Meissa Anunthiel</url>\r\r\n<url=showinfo:1383//197776836>Mrs Trzzbk</url>\r\r\n<url=showinfo:1376//1761171880>Serenity Steele</url>\r\r\n<url=showinfo:1375//617542418>Sokratesz</url>\r\r\n<url=showinfo:1386//243938166>Song Li</url>\r\r\n<url=showinfo:1384//887054826>T\'Amber</url>\r\r\n<url=showinfo:1379//899490472>TeaDaze</url>\r\r\n<url=showinfo:1380//528904696>Z0D</url>\r\r\n<url=showinfo:1375//932924156>Zastrow J</url>',0,0.01,0,1,4,0.0000,1,1661,0),(34773,1194,'CSM 5 Electee Archive Script','A secure holographic datapad, used to access the CONCORD public information database.\r\r\n \r\r\n \r\r\n//archive_yulai8_ict -search\r\r\n>SEARCH INITIATED\r\r\n>SEARCH SEQUENCE... COMPLETE\r\r\n//archive_csm -search\r\r\n>ARCHIVE SEARCH... COMPLETE\r\r\n>LOADING... COMPLETE \r\r\n \r\r\nCouncil of Stellar Management 5 electees:\r\r\n \r\r\n<url=showinfo:1383//109000795>Dierdra Vaal</url>\r\r\n<url=showinfo:1378//1059081514>Korvin</url>\r\r\n<url=showinfo:1383//765935202>mazzilliu</url>\r\r\n<url=showinfo:1386//1271256719>Meissa Anunthiel</url>\r\r\n<url=showinfo:1380//1252841503>Mynxee</url>\r\r\n<url=showinfo:1375//617542418>Sokratesz</url>\r\r\n<url=showinfo:1379//899490472>TeaDaze</url>\r\r\n<url=showinfo:1377//1036406382>Trebor Daehdoow</url>\r\r\n<url=showinfo:1377//1611864709>Vuk Lau</url>',0,0.01,0,1,4,0.0000,1,1661,0),(34774,1194,'CSM 6 Electee Archive Script','A secure holographic datapad, used to access the CONCORD public information database.\r\r\n \r\r\n \r\r\n//archive_yulai8_ict -search\r\r\n>SEARCH INITIATED\r\r\n>SEARCH SEQUENCE... COMPLETE\r\r\n//archive_csm -search\r\r\n>ARCHIVE SEARCH... COMPLETE\r\r\n>LOADING... COMPLETE \r\r\n \r\r\nCouncil of Stellar Management 6 electees:\r\r\n \r\r\n<url=showinfo:1376//874265450>Darius III</url>\r\r\n<url=showinfo:1377//824281015>Draco Llasa</url>\r\r\n<url=showinfo:1383//820303498>Elise Randolph</url>\r\r\n<url=showinfo:1373//516538429>Killer2</url>\r\r\n<url=showinfo:1383//1789860477>Krutoj</url>\r\r\n<url=showinfo:1386//1271256719>Meissa Anunthiel</url>\r\r\n<url=showinfo:1378//566954154>Prometheus Exenthal</url>\r\r\n<url=showinfo:1379//465739014>Seleene</url>\r\r\n<url=showinfo:1376//443630591>The Mittani</url>\r\r\n<url=showinfo:1377//1036406382>Trebor Daehdoow</url>\r\r\n<url=showinfo:1373//960494793>Two step</url>\r\r\n<url=showinfo:1378//121154444>UAxDEATH</url>\r\r\n<url=showinfo:1373//922355212>Vile Rat</url>\r\r\n<url=showinfo:1377//1397864946>White Tree</url>',0,0.01,0,1,4,0.0000,1,1661,0),(34775,1194,'CSM 7 Electee Archive Script','A secure holographic datapad, used to access the CONCORD public information database.\r\r\n \r\r\n \r\r\n//archive_yulai8_ict -search\r\r\n>SEARCH INITIATED\r\r\n>SEARCH SEQUENCE... COMPLETE\r\r\n//archive_csm -search\r\r\n>ARCHIVE SEARCH... COMPLETE\r\r\n>LOADING... COMPLETE \r\r\n \r\r\nCouncil of Stellar Management 7 electees:\r\r\n \r\r\n<url=showinfo:1377//725386886>Alekseyev Karrde</url>\r\r\n<url=showinfo:1376//874265450>Darius III</url>\r\r\n<url=showinfo:1377//907617205>Dovinian</url>\r\r\n<url=showinfo:1383//820303498>Elise Randolph</url>\r\r\n<url=showinfo:1383//546647940>Greene Lee</url>\r\r\n<url=showinfo:1379//310590714>Hans Jagerblitzen</url>\r\r\n<url=showinfo:1386//179116309>Issler Dainze</url>\r\r\n<url=showinfo:1375//728763157>Kelduum Revaan</url>\r\r\n<url=showinfo:1386//1271256719>Meissa Anunthiel</url>\r\r\n<url=showinfo:1379//465739014>Seleene</url>\r\r\n<url=showinfo:1377//1036406382>Trebor Daehdoow</url>\r\r\n<url=showinfo:1373//960494793>Two step</url>\r\r\n<url=showinfo:1378//121154444>UAxDEATH</url>',0,0.01,0,1,4,0.0000,1,1661,0),(34776,1194,'CSM 8 Electee Archive Script','A secure holographic datapad, used to access the CONCORD public information database.\r\r\n \r\r\n \r\r\n//archive_yulai8_ict -search\r\r\n>SEARCH INITIATED\r\r\n>SEARCH SEQUENCE... COMPLETE\r\r\n//archive_csm -search\r\r\n>ARCHIVE SEARCH... COMPLETE\r\r\n>LOADING... COMPLETE \r\r\n \r\r\nCouncil of Stellar Management 8 electees:\r\r\n \r\r\n<url=showinfo:1378//1869635534>Ali Aras</url>\r\r\n<url=showinfo:1376//772205373>Chitsa Jason</url>\r\r\n<url=showinfo:1383//318491604>James Arget</url>\r\r\n<url=showinfo:1376//1234938555>Kesper North</url>\r\r\n<url=showinfo:1378//1059081514>Korvin</url>\r\r\n<url=showinfo:1376//301445721>Malcanis</url>\r\r\n<url=showinfo:1383//425176718>Mangala Solaris</url>\r\r\n<url=showinfo:1377//1946611318>Mike Azariah</url>\r\r\n<url=showinfo:1375//406944591>mynnna</url>\r\r\n<url=showinfo:1385//317012339>progodlegend</url>\r\r\n<url=showinfo:1373//626711141>Ripard Teg</url>\r\r\n<url=showinfo:1385//445750677>Sala Cameron</url>\r\r\n<url=showinfo:1384//1272172192>Sort Dragon</url>\r\r\n<url=showinfo:1376//1036406382>Trebor Daehdoow</url>',0,0.01,0,1,4,0.0000,1,1661,0),(34777,1194,'CSM 9 Electee Archive Script','A secure holographic datapad, used to access the CONCORD public information database.\r\r\n \r\r\n \r\r\n//archive_yulai8_ict -search\r\r\n>SEARCH INITIATED\r\r\n>SEARCH SEQUENCE... COMPLETE\r\r\n//archive_csm -search\r\r\n>ARCHIVE SEARCH... COMPLETE\r\r\n>LOADING... COMPLETE \r\r\n \r\r\nCouncil of Stellar Management 9 electees:\r\r\n \r\r\n<url=showinfo:1378//1869635534>Ali Aras</url>\r\r\n<url=showinfo:1385//1961135874>Asayanami Dei</url>\r\r\n<url=showinfo:1379//1189792277>corbexx</url>\r\r\n<url=showinfo:1376//1260698623>corebloodbrothers</url>\r\r\n<url=showinfo:1378//216879785>DJ FunkyBacon</url>\r\r\n<url=showinfo:1379//2053796889>Gorski Car</url>\r\r\n<url=showinfo:1375//957563959>Major Jsilva</url>\r\r\n<url=showinfo:1383//425176718>Mangala Solaris</url>\r\r\n<url=showinfo:1377//1946611318>Mike Azariah</url>\r\r\n<url=showinfo:1375//406944591>mynnna</url>\r\r\n<url=showinfo:1385//317012339>progodlegend</url>\r\r\n<url=showinfo:1384//720191856>Sion Kumitomo</url>\r\r\n<url=showinfo:1379//90926985>Steve Ronuken</url>\r\r\n<url=showinfo:1379//91512622>Sugar Kyle</url>\r\r\n<url=showinfo:1380//127629559>Xander Phoena</url>',0,0.01,0,1,4,0.0000,1,1661,0),(34778,1194,'CSM 10 Electee Archive Script ','A secure holographic datapad, used to access the CONCORD public information database.\r\r\n \r\r\n \r\r\n//archive_yulai8_ict -search\r\r\n>SEARCH INITIATED\r\r\n>SEARCH SEQUENCE... COMPLETE\r\r\n//archive_csm -search\r\r\n>ARCHIVE SEARCH... COMPLETE\r\r\n>LOADING... COMPLETE\r\r\n \r\r\nCouncil of Stellar Management 10 electees:\r\r\n \r\r\n<url=showinfo:1375//92888420>Cagali Cagali</url>\r\r\n<url=showinfo:1377//94447432>Chance Ravinne</url>\r\r\n<url=showinfo:1379//1189792277>corbexx</url>\r\r\n<url=showinfo:1376//1260698623>corebloodbrothers</url>\r\r\n<url=showinfo:1386//95190469>Endie</url>\r\r\n<url=showinfo:1380//736229961>Gorga</url>\r\r\n<url=showinfo:1375//91688663>Jayne Fillon</url>\r\r\n<url=showinfo:1373//814076069>Manfred Sideous</url>\r\r\n<url=showinfo:1377//1946611318>Mike Azariah</url>\r\r\n<url=showinfo:1384//720191856>Sion Kumitomo</url>\r\r\n<url=showinfo:1384//1272172192>Sort Dragon</url>\r\r\n<url=showinfo:1379//90926985>Steve Ronuken</url>\r\r\n<url=showinfo:1379//91512622>Sugar Kyle</url>\r\r\n<url=showinfo:1378//142180392>Thoric Frosthammer</url>',0,0.01,0,1,4,0.0000,1,1661,0),(34779,1311,'Megathron Quafe SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34780,1311,'Megathron Quafe SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34781,1311,'Megathron Quafe SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34782,1311,'Megathron Quafe SKIN (365 days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34783,817,'Burner Talos','This prototype battlecruiser is based on the common Talos hull structure, but has been heavily modified by the Serpentis Corporation for sensitive smuggling operations.\r\r\n\r\r\nIt is piloted by a rogue former test pilot who broke from the Serpentis and went into business for himself.',11200000,112000,480,1,8,0.0000,0,NULL,0),(34784,226,'Sleeper Vessel',' ',0,0,0,1,64,0.0000,0,NULL,0),(34785,817,'Burner Ashimmu','This individual is a rogue element adherent to the Sani Sabik blood cult. She recently broke away from the Blood Raider Covenant when Covenant leadership expressed disapproval towards her obsession with Drifters.\r\r\n\r\r\nThis pirate should be considered extremely dangerous.',11800000,118000,235,1,4,0.0000,0,NULL,0),(34786,1311,'Eagle Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34787,1311,'Ishtar Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34788,1311,'Gila Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34789,1311,'Drake Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34790,1311,'Abaddon Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34791,1311,'Apocalypse Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34792,1311,'Apocalypse Blood Raider SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34795,1311,'Armageddon Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34796,1311,'Raven Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34797,1311,'Raven Guristas SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34798,1311,'Raven Kaalakiota SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34799,1311,'Raven Nugoeihuvi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34800,1311,'Dominix Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34801,1311,'Megathron Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34802,1311,'Megathron Police SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34805,1311,'Tempest Justice SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(34808,1311,'Tempest Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1967,0),(34809,1311,'Tempest Nefantar SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,1967,0),(34810,1311,'Paladin Blood Raider SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,2024,0),(34811,1311,'Paladin Kador SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34812,1311,'Paladin Tash-Murkon SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34813,1311,'Golem Guristas SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34814,1311,'Golem Kaalakiota SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,2025,0),(34815,1311,'Golem Nugoeihuvi SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34816,1311,'Kronos Inner Zone Shipping SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34817,1311,'Kronos Police SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,2026,0),(34818,1311,'Kronos Quafe SKIN (Permanent)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34819,1311,'Vargur Justice SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(34820,1311,'Vargur Krusual SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(34821,1311,'Vargur Nefantar SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(34822,1311,'Machariel Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,32,0.0000,1,NULL,0),(34823,1311,'Rattlesnake Serenity YC117 SKIN (Permanent)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(34824,1089,'Men\'s \'Emergent Threats\' T-shirt YC 117','Step out in style in your exquisite new Quafe Commemorative Casual Wear, designed exclusively for attendees of the YC 117 SOCT Symposium on Emergent Threats.\r\r\n\r\r\nNote: While this shirt features a stylish representation of a Jove Observatory, it does not guarantee the wearer safe access to the Observatory locations.\r\r\n',0.5,0.1,0,1,4,0.0000,1,1398,0),(34825,1089,'Women\'s \'Emergent Threats\' T-shirt YC 117','Step out in style in your exquisite new Quafe Commemorative Casual Wear, designed exclusively for attendees of the YC 117 SOCT Symposium on Emergent Threats.\r\r\n\r\r\nNote: While this shirt features a stylish representation of a Jove Observatory, it does not guarantee the wearer safe access to the Observatory locations.\r\r\n',0.5,0.1,0,1,4,0.0000,1,1406,0),(34826,1313,'QA Entosis Link','Entosis Link.',0,20,0,1,16,56492000.0000,0,NULL,0),(34827,1318,'QA Entosis Link Blueprint',' ',0,0.01,0,1,16,19840.0000,0,NULL,0),(34828,1305,'Jackdaw','Despite widespread disappointment within the State that Caldari researchers fell behind their counterparts in the Empire and Republic during the second wave of sleeper-derived weapons development in late YC116 and early YC117, the quality of their end result cannot be denied.\r\r\n\r\r\nThe Jackdaw is a versatile and powerful combat vessel, combining cutting edge advancements in missile and shield technology with the incredible breakthrough of the Self-Assembling Nanolattice to produce a ship that any Caldari pilot can be proud to fly.',1000000,47000,450,1,1,853584.0000,1,2021,0),(34829,1309,'Jackdaw Blueprint','The Jackdaw-class Tactical Destroyer was developed in YC117 for use by the Caldari State, its constituent megacorporations, and its allies. One hundred and thirty four capsuleers contributed invaluable assistance towards the development of this warship. The greatest of these pilots were:\r\r\n<url=showinfo:1373//332275222>TorDog</url>\r\r\n<url=showinfo:1373//422609556>Makoto Priano</url>\r\r\n<url=showinfo:1373//94509643>Solecist Project</url>\r\r\n<url=showinfo:1373//93395846>Asuna Crossbreed</url>\r\r\n<url=showinfo:1373//94090758>IAm NumberSix</url>\r\r\n<url=showinfo:1373//92668441>Iv d\'Este</url>\r\r\n<url=showinfo:1373//93320153>Alvarez Akachi</url>\r\r\n<url=showinfo:1373//196895851>Sany Saccante</url>\r\r\n<url=showinfo:1373//490128470>darkezero</url>\r\r\n<url=showinfo:1373//93332086>Kara Korbrey</url>',0,0.01,0,1,1,40000000.0000,1,NULL,0),(34832,1316,'Entosis Command Node','This structure can captured by targeting it with an Entosis Link module.',1,1,0,1,4,0.0000,0,NULL,0),(34833,226,'Jove Corpse','A Jovian corpse.',200,2,0,1,4,0.0000,0,NULL,0),(34834,226,'Jove Corpse','A Jovian corpse.',200,2,0,1,4,0.0000,0,NULL,0),(34835,226,'Jove Corpse','A Jovian corpse.',200,2,0,1,4,0.0000,0,NULL,0),(34836,226,'Jove Corpse','A Jovian corpse.',200,2,0,1,4,0.0000,0,NULL,0),(34837,226,'Sleeper Canopic','The structure of this device suggests that it is designed to preserve a singular occupant for an undefined period of time.',200,2,0,1,4,0.0000,0,NULL,0),(34838,226,'Sleeper Canopic','The structure of this device suggests that it is designed to preserve a singular occupant for an undefined period of time.',200,2,0,1,4,0.0000,0,NULL,0),(34839,226,'Sleeper Canopic','The structure of this device suggests that it is designed to preserve a singular occupant for an undefined period of time.',200,2,0,1,4,0.0000,0,NULL,0),(34840,226,'Enclave Debris','The remnants of this Sleeper Enclave are a stark reminder of the harshness of space.',100000,100000000,10000,1,4,0.0000,0,NULL,0),(34841,1317,'Entrapment Array 2 Blueprint',' ',0,0.01,0,1,4,1000000000.0000,1,2016,0),(34842,1317,'Entrapment Array 3 Blueprint',' ',0,0.01,0,1,4,1500000000.0000,1,2016,0),(34843,1317,'Entrapment Array 4 Blueprint',' ',0,0.01,0,1,4,2000000000.0000,1,2016,0),(34844,1317,'Entrapment Array 5 Blueprint',' ',0,0.01,0,1,4,2500000000.0000,1,2016,0),(34845,1317,'Pirate Detection Array 1 Blueprint',' ',0,0.01,0,1,4,250000000.0000,1,2016,0),(34846,1317,'Pirate Detection Array 2 Blueprint',' ',0,0.01,0,1,4,500000000.0000,1,2016,0),(34847,1317,'Pirate Detection Array 3 Blueprint',' ',0,0.01,0,1,4,1000000000.0000,1,2016,0),(34848,1317,'Pirate Detection Array 4 Blueprint',' ',0,0.01,0,1,4,1250000000.0000,1,2016,0),(34849,1317,'Pirate Detection Array 5 Blueprint',' ',0,0.01,0,1,4,1500000000.0000,1,2016,0),(34850,1317,'Quantum Flux Generator 1 Blueprint',' ',0,0.01,0,1,4,250000000.0000,1,2016,0),(34851,1317,'Quantum Flux Generator 2 Blueprint',' ',0,0.01,0,1,4,500000000.0000,1,2016,0),(34852,1317,'Quantum Flux Generator 3 Blueprint',' ',0,0.01,0,1,4,750000000.0000,1,2016,0),(34853,1317,'Quantum Flux Generator 4 Blueprint',' ',0,0.01,0,1,4,1000000000.0000,1,2016,0),(34854,1317,'Quantum Flux Generator 5 Blueprint',' ',0,0.01,0,1,4,1250000000.0000,1,2016,0),(34855,1317,'Ore Prospecting Array 1 Blueprint',' ',0,0.01,0,1,4,250000000.0000,1,2014,0),(34856,1317,'Ore Prospecting Array 2 Blueprint',' ',0,0.01,0,1,4,375000000.0000,1,2014,0),(34857,1317,'Ore Prospecting Array 3 Blueprint',' ',0,0.01,0,1,4,500000000.0000,1,2014,0),(34858,1317,'Ore Prospecting Array 4 Blueprint',' ',0,0.01,0,1,4,625000000.0000,1,2014,0),(34859,1317,'Ore Prospecting Array 5 Blueprint',' ',0,0.01,0,1,4,1250000000.0000,1,2014,0),(34860,1317,'Survey Networks 1 Blueprint',' ',0,0.01,0,1,4,250000000.0000,1,2014,0),(34861,1317,'Survey Networks 2 Blueprint',' ',0,0.01,0,1,4,500000000.0000,1,2014,0),(34862,1317,'Survey Networks 3 Blueprint',' ',0,0.01,0,1,4,750000000.0000,1,2014,0),(34863,1317,'Survey Networks 4 Blueprint',' ',0,0.01,0,1,4,1000000000.0000,1,2014,0),(34864,1317,'Survey Networks 5 Blueprint',' ',0,0.01,0,1,4,1250000000.0000,1,2014,0),(34865,1317,'Advanced Logistics Network Blueprint',' ',0,0.01,0,1,4,1000000000.0000,1,2017,0),(34866,1317,'Cynosural Navigation Blueprint',' ',0,0.01,0,1,4,500000000.0000,1,2017,0),(34867,1317,'Cynosural Suppression Blueprint',' ',0,0.01,0,1,4,1000000000.0000,1,2017,0),(34868,1317,'Supercapital Construction Facilities Blueprint',' ',0,0.01,0,1,4,375000000.0000,1,2017,0),(34869,1317,'Entrapment Array 1 Blueprint',' ',0,0.01,0,1,4,500000000.0000,1,2016,0),(34870,1319,'SKIN',' ',0,0,0,1,4,0.0000,0,NULL,0),(34873,383,'Proximity-activated Autoturret','Proximity based sentry gun.\r\r\n\r\r\nEntering within 10km of this turret will cause it to engage with your ship.',1000,1000,1000,1,4,0.0000,0,NULL,0),(34874,280,'Gleaned Information','YC116-01-27: Multiple ultra high energy fluctuations developing. Recording numerous S.O.S. transponders.\r\r\n\r\r\nYC115-05-07: \"..you are encroaching on sovereign Federation space, return to Republic space or you will be fired upon.\"\r\r\n\r\r\nYC112-05-12: Multiple artificial gravitational anomalies detected cluster wide.\r\r\n\r\r\nYC110-05-15: ... summit between the Federation and Caldari State, where a general evacuation order was issued mom ...\r\r\n\r\r\nYC110-10-31: ... in the Gallente Federation, is known primarily for harboring a particular kind of plant life known as the Isirus poppy.',1,0.1,0,1,16,30.0000,0,NULL,0),(34875,280,'Gleaned Information','YC108-12-17 -   lockdown in effect. Sosala local defences reacting. Amarr Fleet mobilisation hindered by multiple attacks. Indicating complete destruction of Battlestation facility by Minmatar loyalist capsuleer cohorts. Flagged for close monitoring...\r\r\n\r\r\nYC107-06-09 -   planet-wide emergency declared by Amarr Empire. Blood Raider fleet breaking orbital blockade. Chemical compound residue still circulating in high atmosphere, predicated near-total consumption rate among local slave population. Additional trace chem .\r\r\n\r\r\nYC108-06-07 - Multiple jump drive spikes detected in Pator, Heimatar, Minmatar Republic\r\r\nOrigin: Republic Fleet anchorage 12\r\r\nCommand key override: Muritor, Karishal 1st Class Captain\r\r\nCONCORD authorisation key: Not accounted, unauthorised deployment. CONCORD control warning flag issued to Republic Fleet\r\r\nShip designations: Alfhild, Magni, Modi, Verkana, Gordd, Hjalin, Svertan, Torshvern ..\r\r\n\r\r\nYC107-05-30 -   of Caldari loyalist capsuleer cohorts, Caldari Independent Navy Reserve, [CAIN] verified termination of Dr Ullia Hnolku in the Magiko system, Minmatar Republic. Insorum prototype retr...',1,0.1,0,1,16,30.0000,0,NULL,0),(34876,280,'Gleaned Information','YC109-02-02 - Critical Termination Notice - Capsuleer: Karishal Muritor. Defiants faction. Capsule breach indicated in Auga, orbital track of tenth planet. Unable to locate clone activation --- working --- Unable to locate clone activation --- extending network search --- Unable to loc .\r\r\n\r\r\nYC109-02-12 -   mass rally in Pator. Republic fleet task force warping in --- identified, command ships, fleet capsuleer --- monitoring --- designation change Admiral Kanth Filmir resignation conf .\r\r\n\r\r\nYC110-06-10 - Massive internal fires detected. Alfhild supercarrier drifting out of [system] system. Unknown souls remaining on board. Tracking until out of monitoring range...\r\r\n\r\r\nYC109-02-09 - ...hra\'Khan, a group with long-standing yet historically shaky ties to the Republic, declared Prime Minister Midular their \"number one enemy,\" calling for a 1 ISK bounty on her head, the \"value representing her worth to the Minmat \r\r\n\r\r\nYC108-04-10 - Captain 1st Class Karishal Muritor of the Republic Fleet was today awarded Drupar s Sun, one of the most prestigious medals given by the Republic, at a Fleet awar...',1,0.1,0,1,16,30.0000,0,NULL,0),(34877,280,'Gleaned Information','23121-09-11 - Updated Gallente status provides a model for social cohesion. Suggest further observations are shared with Modifier enclaves. \r\r\n\r\r\n23146-05-20 - Azbel-Wuthrich experiment has been a success. Planetary communications reveal the message as  :-)  \r\r\n\r\r\n23154-12-12 - Randomized sweeps of recently seceded Caldari communications indicate that alternative source for model of social cohesion will be increasingly defined by opposition to Gallente model. Schism becoming pronounced. Threshold for constructive comparison of existing conditions approaching. \r\r\n\r\r\n23194-02-01 - Gallente have created an agency known as The Scope for the dissemination of information across Empires. Suggest that this network be monitored. Potential to extrapolate prototype for impartial communication between disparate enclaves. \r\r\n\r\r\n23216-06-06 - In position at Diemnon Planetesimal. Collating system scans. Source of burst unidentified. Team dispatched. Alert still in effect. \r\r\n\r\r\nYC11-03-11 - Life sign detected aboard the ship. Contrary to intelligence gather by Villore observatory, vessel not destroyed. Remaining in Ouperia to monitor.',1,0.1,0,1,16,30.0000,0,NULL,0),(34878,280,'Gleaned Information','YC109-10-20 - New fleet elements moving into the Great Wildlands.  Comm scan confirms that all Elders are once again currently located on the Ragnarok now under construction.\r\r\n\r\r\nYC110-05-11 -  How have we survived, we of New Eden, when the definition of humanity remains so elusive, so transparent, to so many? \r\r\n\r\r\nYC110-05-28 -  ...we, the Archangels, are more capable of providing for the welfare of this Republic than your government. \r\r\n\r\r\nYC110-05-30 -  ...I m issuing a warning directly to you, and every uniformed serviceman and women of the DED and CONCORD. Either you heed it, or some of you will end up paying with your lives. \r\r\n\r\r\nYC111-03-10 -  We stand at a hopeful crossroad in human history. Stretching out before us for the first time in millenia are the paths of our ancestors \r\r\n\r\r\nYC111-06-10 - Meta-analysis of Huola confirms data obtained from Lulm. Correlation with trends from observatories in the Gallente-Caldari warzone. Indications capsuleer elements are operating systematically, and/or strategically, in regions governed by the CONCORD Emergency Militia Warpowers Act.\r\r\n\r\r\nYC114-03-03 - Priority alert. Amarr vessel detected emerging from Anoikis amongst armored expeditionary fleet. Cargo contains a large quantity of implants meeting revised conditions. ',1,0.1,0,1,4,30.0000,0,NULL,0),(34879,280,'Gleaned Information','YC9-11-03 - \"Now if you look to section eight of the report, you will see that the new system provides an unprecedented level of harmony. The new electrochemical system eliminates undesirable reactions and emotions in 34% of testers. With further development, I am certain we can truly make everyone happy.\"\r\r\n\r\r\nYC37-08-23 - Gamma Enclave recently available personnel: 44 cybernetics experts, 32 geneticists, 9 materials scientists, 6 sociologists. Awaiting kitz assignment.\r\r\n\r\r\nYC110-10-03 -  rbinger of hope. I am the sword of the righteous, and to all who hear my words I say this: What you give to thi \"\r\r\n\r\r\nYC106-11-17 - Capsuleer cohort tracking system implemented. Receiving data.\"\r\r\n',1,0.1,0,1,16,30.0000,0,NULL,0),(34880,280,'Gleaned Information','YC37-09-01 - CONCORD Resolution D/912/37 passes with unilateral support from all five empires.\r\r\n\r\r\nYC44-06-03 - Preliminary forecast: Cohort \'EOM\' casualty causation: est 78,944,293,285. Action advisory: Continued observation, Non-interference.\r\r\n\r\r\nYC104-12-09 - Preliminary forecast: Cohort \'SN\' resurgence likelihood: 96.44% Action advisory: Continued observation, Non-interference.\r\r\n\r\r\nYC106-03-22 - Advanced materials technology saturation at threshold. Implement stage two technology surveillance.\r\r\n\r\r\nYC106-11-17 - Capsuleer cohort tracking system implemented. Receiving data.\r\r\n\r\r\nYC111-02-06 - Catastrophic collapse of Cohort 632866070. Cascade effect tracking algorithm active. Capsuleer Cohort vulnerability documented for further analysis.\r\r\n\r\r\nYC111-03-11 - RT HIGH ALERT HIGH ALERT HIGH ALERT HIGH ALERT HIGH ALERT HIGH ALERT HIGH ALERT HIGH ALERT HIGH ALERT HIGH ALERT HIGH ALERT HIGH ALERT HIGH ALE\r\r\n\r\r\nYC111-03-27 - Fullerene technology saturation at threshold. Implement stage three technology surveillance.\r\r\n\r\r\nYC113-03-18 - Alert: Intercept of encrypted traffic [source Imperial-Internal] reference keywords \'analysis, implant, recovered, subject, body\'. Inferred keywords: autopsy, Anoikis, sleeper, breakthrough, disease\r\r\n\r\r\nYC114-03-20 - New research data collated. Source: Eram spider. Create new index.\r\r\n\r\r\nYC117-02-09 - Cloaking system failure. Proximity alert. Initiate system shutdown.\r\r\n',1,0.1,0,1,16,30.0000,0,NULL,0),(34881,280,'Gleaned Information','YC105-09-09 - Kindness never goes unpunished.\r\r\n\r\r\nYC110-09-08 - Meme Sample: Conforming Rebellion.\r\r\n\r\r\nYC111-03-10 - \'Elusive\' does not match \'contacted government\' or \'alerted media\'.\r\r\n\r\r\nYC112-01-05 - Meme Sample: Conscripted Compassion.\r\r\n\r\r\nYC112-03-25 - Meme Sample: Circumscribed Rage.\r\r\n\r\r\nYC112-10-05 - Dead end.\r\r\n\r\r\nYC115-04-17 - Meme Sample: Collective Individuality.\r\r\n',1,0.1,0,1,16,30.0000,0,NULL,0),(34882,280,'Gleaned Information','YC105-12-22 - Give them tools and they may evolve.\r\r\n\r\r\nYC106-03-11 - Give them symbols and they may stagnate.\r\r\n\r\r\nYC107-07-05 - ...recommend discarding current primary node for that model.\r\r\n\r\r\nYC108-05-16 - They only notice small tragedies.\r\r\n\r\r\nYC109-01-12 - They let names define their perceptions.\r\r\n\r\r\nYC110-12-25 - Give them what they want and it may destroy them.\r\r\n\r\r\nYC111-03-10 - Self-interest continues to outweigh self-sacrifice.\r\r\n\r\r\nYC112-03-04 - Does this duplicate portions of the Skarkon model?',1,0.1,0,1,16,30.0000,0,NULL,0),(34883,280,'Gleaned Information','YC105-5-29 - So fragile, these minds. So fleeting, their crimes.\r\r\n\r\r\nYC106-12-20 - Step One: Build a Better Ant.\r\r\n\r\r\nYC107-09-15 - Step Two: Kick over The Ant Hill.\r\r\n\r\r\nYC108-09-26 - Step Three: Assess.\r\r\n\r\r\nYC109-06-23 - Models indicate that virions have spread beyond those five systems. \r\r\n\r\r\nYC110-06-10 - Step Four: Reiterate.\r\r\n\r\r\nYC111-03-10 - \'Defect-mediated turbulence\'?\r\r\n\r\r\nYC112-12-13 - Disruption Event Identified. Type: Infiltration Disclosure.  Subtype: Wedge Mirror.  Actor: True Power.  Targeted Interstice: CONCORD - Capsuleer Cohort.  Motivation:...\r\r\n\r\r\nYC113-07-07 - Disruption Event Identified. Type: Resource Shift. Subtype: Need Further Data. Actor: Need Further Data. Targeted Interstice: 4 Potentials. 1)... \r\r\n\r\r\nYC114-05-14 - They are not yet acknowledging the pattern.\r\r\n\r\r\nYC115-03-22 - Disruption Event Identified.  Type: Apoptosis...\r\r\n\r\r\nYC116-01-01 - Disruption Event Identified.  Type: Cathexis...\r\r\n\r\r\nYC117-01-12 - They could not predict this?\r\r\n\r\r\nYC111 - Capsuleer espionage detected. \r\r\n\r\r\nYC108 - \'Titan\' class vessel detected. Receiving data.\r\r\n\r\r\nYC112 - Sansha activity registered.\r\r\n\r\r\nYC107 - Destination: Vak\'Atioth.\r\r\n\r\r\nYC110 - \"Thanks sweetie, but that\'s all right. I\'ll only be a few minutes.\" \r\r\n\r\r\nYC105 - Location: Rethan. Class: Yacht. Maker: Viziam.\r\r\n',1,0.1,0,1,16,30.0000,0,NULL,0),(34884,186,'ORE Freighter Wreck','The remains of a destroyed ship. Perhaps with the proper equipment something of value could be salvaged from it. ',10000,750000,750000,1,128,0.0000,0,NULL,0),(34885,1311,'Abaddon Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34886,1311,'Abaddon Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34887,1311,'Abaddon Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34888,1311,'Abaddon Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34889,1311,'Abaddon Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34890,1311,'Abaddon Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34891,1311,'Abaddon Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34892,1311,'Abaddon Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34893,1311,'Abaddon Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34894,1311,'Abaddon Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34895,1311,'Abaddon Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34896,1311,'Abaddon Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34897,1311,'Aeon Khanid SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34898,1311,'Aeon Khanid SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34899,1311,'Aeon Khanid SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34900,1311,'Aeon Khanid SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34901,1311,'Aeon Sarum SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34902,1311,'Aeon Sarum SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34903,1311,'Aeon Sarum SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34904,1311,'Aeon Sarum SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34905,1311,'Algos Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34906,1311,'Algos Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34907,1311,'Algos Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34908,1311,'Algos Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34909,1311,'Algos InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34910,1311,'Algos InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34911,1311,'Algos InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34912,1311,'Algos InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34913,1311,'Apocalypse Ardishapur SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34914,1311,'Apocalypse Ardishapur SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34915,1311,'Apocalypse Ardishapur SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34916,1311,'Apocalypse Ardishapur SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34917,1311,'Apocalypse Blood Raider SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34918,1311,'Apocalypse Blood Raider SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34919,1311,'Apocalypse Blood Raider SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34920,1311,'Apocalypse Blood Raider SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34921,1311,'Apocalypse Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34922,1311,'Apocalypse Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34923,1311,'Apocalypse Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34924,1311,'Apocalypse Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34925,1311,'Apocalypse Khanid SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34926,1311,'Apocalypse Khanid SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34927,1311,'Apocalypse Khanid SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34928,1311,'Apocalypse Khanid SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34929,1311,'Apocalypse Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34930,1311,'Apocalypse Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34931,1311,'Apocalypse Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34932,1311,'Apocalypse Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34933,1311,'Apocalypse Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34934,1311,'Apocalypse Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34935,1311,'Apocalypse Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34936,1311,'Apocalypse Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34937,1311,'Arbitrator Ardishapur SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34938,1311,'Arbitrator Ardishapur SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34939,1311,'Arbitrator Ardishapur SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34940,1311,'Arbitrator Ardishapur SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34941,1311,'Arbitrator Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34942,1311,'Arbitrator Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34943,1311,'Arbitrator Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34944,1311,'Arbitrator Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34945,1311,'Archon Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34946,1311,'Archon Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34947,1311,'Archon Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34948,1311,'Archon Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34949,1311,'Archon Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34950,1311,'Archon Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34951,1311,'Archon Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34952,1311,'Archon Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34953,1311,'Armageddon Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34954,1311,'Armageddon Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34955,1311,'Armageddon Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34956,1311,'Armageddon Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34957,1311,'Armageddon Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34958,1311,'Armageddon Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34959,1311,'Armageddon Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34960,1311,'Armageddon Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34961,1311,'Armageddon Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34962,1311,'Armageddon Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34963,1311,'Armageddon Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34964,1311,'Armageddon Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34965,1311,'Atron Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34966,1311,'Atron Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34967,1311,'Atron Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34968,1311,'Atron Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34969,1311,'Atron InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34970,1311,'Atron InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34971,1311,'Atron InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34972,1311,'Atron InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34973,1311,'Augoror Ardishapur SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34974,1311,'Augoror Ardishapur SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34975,1311,'Augoror Ardishapur SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34976,1311,'Augoror Ardishapur SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34977,1311,'Augoror Khanid SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34978,1311,'Augoror Khanid SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34979,1311,'Augoror Khanid SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34980,1311,'Augoror Khanid SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34981,1311,'Avatar Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34982,1311,'Avatar Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34983,1311,'Avatar Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34984,1311,'Avatar Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34985,1311,'Avatar Khanid SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34986,1311,'Avatar Khanid SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34987,1311,'Avatar Khanid SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34988,1311,'Avatar Khanid SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34989,1311,'Bellicose Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(34990,1311,'Bellicose Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(34991,1311,'Bellicose Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(34992,1311,'Bellicose Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(34993,1311,'Bestower Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34994,1311,'Bestower Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34995,1311,'Bestower Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34996,1311,'Bestower Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(34997,1311,'Brutix Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34998,1311,'Brutix Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(34999,1311,'Brutix Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35000,1311,'Brutix Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35001,1311,'Brutix Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35002,1311,'Brutix Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35003,1311,'Brutix Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35004,1311,'Brutix Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35005,1311,'Brutix Serpentis SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35006,1311,'Brutix Serpentis SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,1958,0),(35007,1311,'Brutix Serpentis SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35008,1311,'Brutix Serpentis SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35009,1311,'Caracal Nugoeihuvi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35010,1311,'Caracal Nugoeihuvi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35011,1311,'Caracal Nugoeihuvi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35012,1311,'Caracal Nugoeihuvi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35013,1311,'Caracal Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35014,1311,'Caracal Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35015,1311,'Caracal Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35016,1311,'Caracal Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35017,1311,'Catalyst Aliastra SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35018,1311,'Catalyst Aliastra SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35019,1311,'Catalyst Aliastra SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35020,1311,'Catalyst Aliastra SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35021,1311,'Catalyst Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35022,1311,'Catalyst Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35023,1311,'Catalyst Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35024,1311,'Catalyst Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35025,1311,'Catalyst Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35026,1311,'Catalyst Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35027,1311,'Catalyst Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35028,1311,'Catalyst Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35029,1311,'Catalyst InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35030,1311,'Catalyst InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35031,1311,'Catalyst InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35032,1311,'Catalyst InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35033,1311,'Catalyst Quafe SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35034,1311,'Catalyst Quafe SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35035,1311,'Catalyst Quafe SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35036,1311,'Catalyst Quafe SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35037,1311,'Catalyst Serpentis SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35038,1311,'Catalyst Serpentis SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,1996,0),(35039,1311,'Catalyst Serpentis SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35040,1311,'Catalyst Serpentis SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35041,1311,'Celestis Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35042,1311,'Celestis Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35043,1311,'Celestis Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35044,1311,'Celestis Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35045,1311,'Celestis InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35046,1311,'Celestis InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35047,1311,'Celestis InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35048,1311,'Celestis InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35049,1311,'Charon Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35050,1311,'Charon Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35051,1311,'Charon Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35052,1311,'Charon Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35053,1311,'Chimera Lai Dai SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35054,1311,'Chimera Lai Dai SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35055,1311,'Chimera Lai Dai SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35056,1311,'Chimera Lai Dai SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35057,1311,'Coercer Ardishapur SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35058,1311,'Coercer Ardishapur SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35059,1311,'Coercer Ardishapur SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35060,1311,'Coercer Ardishapur SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35061,1311,'Coercer Blood Raiders SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35062,1311,'Coercer Blood Raiders SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,1994,0),(35063,1311,'Coercer Blood Raiders SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35064,1311,'Coercer Blood Raiders SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35065,1311,'Coercer Sarum SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35066,1311,'Coercer Sarum SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35067,1311,'Coercer Sarum SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35068,1311,'Coercer Sarum SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35069,1311,'Comet Police Pursuit SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35070,1311,'Comet Police Pursuit SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35071,1311,'Comet Police Pursuit SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35072,1311,'Comet Police Pursuit SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35073,1311,'Cormorant Guristas SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35074,1311,'Cormorant Guristas SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,1995,0),(35075,1311,'Cormorant Guristas SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35076,1311,'Cormorant Guristas SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35077,1311,'Crucifier Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35078,1311,'Crucifier Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35079,1311,'Crucifier Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35080,1311,'Crucifier Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35081,1311,'Crucifier Sarum SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35082,1311,'Crucifier Sarum SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35083,1311,'Crucifier Sarum SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35084,1311,'Crucifier Sarum SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35085,1311,'Cyclone Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35086,1311,'Cyclone Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35087,1311,'Cyclone Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35088,1311,'Cyclone Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35089,1311,'Cyclone Thukker Tribe SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35090,1311,'Cyclone Thukker Tribe SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,1959,0),(35091,1311,'Cyclone Thukker Tribe SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35092,1311,'Cyclone Thukker Tribe SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35093,1311,'Dominix Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35094,1311,'Dominix Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35095,1311,'Dominix Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35096,1311,'Dominix Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35097,1311,'Dominix Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35098,1311,'Dominix Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35099,1311,'Dominix Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35100,1311,'Dominix Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35101,1311,'Dominix Quafe SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35102,1311,'Dominix Quafe SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35103,1311,'Dominix Quafe SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35104,1311,'Dominix Quafe SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35105,1311,'Dominix Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35106,1311,'Dominix Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35107,1311,'Dominix Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35108,1311,'Dominix Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35109,1311,'Dragoon Khanid SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35110,1311,'Dragoon Khanid SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35111,1311,'Dragoon Khanid SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35112,1311,'Dragoon Khanid SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35113,1311,'Dragoon Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35114,1311,'Dragoon Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35115,1311,'Dragoon Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35116,1311,'Dragoon Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35117,1311,'Drake Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35118,1311,'Drake Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35119,1311,'Drake Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35120,1311,'Drake Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35121,1311,'Eagle Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35122,1311,'Eagle Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35123,1311,'Eagle Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35124,1311,'Eagle Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35125,1311,'Erebus Duvolle SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35126,1311,'Erebus Duvolle SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35127,1311,'Erebus Duvolle SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35128,1311,'Erebus Duvolle SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35129,1311,'Erebus InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35130,1311,'Erebus InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35131,1311,'Erebus InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35132,1311,'Erebus InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35133,1311,'Executioner Ardishapur SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35134,1311,'Executioner Ardishapur SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35135,1311,'Executioner Ardishapur SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35136,1311,'Executioner Ardishapur SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35137,1311,'Executioner Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35138,1311,'Executioner Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35139,1311,'Executioner Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35140,1311,'Executioner Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35141,1311,'Exequror Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35142,1311,'Exequror Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35143,1311,'Exequror Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35144,1311,'Exequror Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35145,1311,'Fenrir Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35146,1311,'Fenrir Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35147,1311,'Fenrir Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35148,1311,'Fenrir Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35149,1311,'Ferox Guristas SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35150,1311,'Ferox Guristas SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,1957,0),(35151,1311,'Ferox Guristas SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35152,1311,'Ferox Guristas SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35153,1311,'Ferox Lai Dai SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35154,1311,'Ferox Lai Dai SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35155,1311,'Ferox Lai Dai SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35156,1311,'Ferox Lai Dai SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35157,1311,'Gila Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35158,1311,'Gila Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35159,1311,'Gila Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35160,1311,'Gila Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35161,1311,'Golem Guristas SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35162,1311,'Golem Guristas SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35163,1311,'Golem Guristas SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35164,1311,'Golem Guristas SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35165,1311,'Golem Kaalakiota SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35166,1311,'Golem Kaalakiota SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35167,1311,'Golem Kaalakiota SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35168,1311,'Golem Kaalakiota SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35169,1311,'Golem Nugoeihuvi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35170,1311,'Golem Nugoeihuvi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35171,1311,'Golem Nugoeihuvi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35172,1311,'Golem Nugoeihuvi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35173,1311,'Harbinger Kador SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35174,1311,'Harbinger Kador SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35175,1311,'Harbinger Kador SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35176,1311,'Harbinger Kador SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35177,1311,'Harbinger Khanid SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35178,1311,'Harbinger Khanid SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35179,1311,'Harbinger Khanid SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35180,1311,'Harbinger Khanid SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35181,1311,'Hel Sebiestor SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35182,1311,'Hel Sebiestor SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35183,1311,'Hel Sebiestor SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35184,1311,'Hel Sebiestor SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35185,1311,'Heron Sukuuvestaa SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35186,1311,'Heron Sukuuvestaa SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35187,1311,'Heron Sukuuvestaa SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35188,1311,'Heron Sukuuvestaa SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35189,1311,'Hulk ORE Development SKIN (7 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35190,1311,'Hulk ORE Development SKIN (30 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35191,1311,'Hulk ORE Development SKIN (90 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35192,1311,'Hulk ORE Development SKIN (365 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35193,1311,'Hurricane Sebiestor SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35194,1311,'Hurricane Sebiestor SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35195,1311,'Hurricane Sebiestor SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35196,1311,'Hurricane Sebiestor SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35197,1311,'Hyperion Aliastra SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35198,1311,'Hyperion Aliastra SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35199,1311,'Hyperion Aliastra SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35200,1311,'Hyperion Aliastra SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35201,1311,'Hyperion Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35202,1311,'Hyperion Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35203,1311,'Hyperion Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35204,1311,'Hyperion Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35205,1311,'Imicus Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35206,1311,'Imicus Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35207,1311,'Imicus Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35208,1311,'Imicus Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35209,1311,'Imicus Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35210,1311,'Imicus Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35211,1311,'Imicus Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35212,1311,'Imicus Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35213,1311,'Incursus Aliastra SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35214,1311,'Incursus Aliastra SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35215,1311,'Incursus Aliastra SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35216,1311,'Incursus Aliastra SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35217,1311,'Incursus Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35218,1311,'Incursus Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35219,1311,'Incursus Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35220,1311,'Incursus Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35221,1311,'Inquisitor Khanid SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35222,1311,'Inquisitor Khanid SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35223,1311,'Inquisitor Khanid SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35224,1311,'Inquisitor Khanid SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35225,1311,'Inquisitor Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35226,1311,'Inquisitor Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35227,1311,'Inquisitor Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35228,1311,'Inquisitor Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35229,1311,'Ishtar Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35230,1311,'Ishtar Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35231,1311,'Ishtar Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35232,1311,'Ishtar Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35233,1311,'Iteron Mark V Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35234,1311,'Iteron Mark V Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35235,1311,'Iteron Mark V Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35236,1311,'Iteron Mark V Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35237,1311,'Iteron Mark V InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35238,1311,'Iteron Mark V InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35239,1311,'Iteron Mark V InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35240,1311,'Iteron Mark V InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35241,1311,'Kestrel Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35242,1311,'Kestrel Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35243,1311,'Kestrel Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35244,1311,'Kestrel Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35245,1311,'Kronos Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35246,1311,'Kronos Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35247,1311,'Kronos Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35248,1311,'Kronos Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35249,1311,'Kronos Police SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35250,1311,'Kronos Police SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35251,1311,'Kronos Police SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35252,1311,'Kronos Police SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35253,1311,'Kronos Quafe SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35254,1311,'Kronos Quafe SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35255,1311,'Kronos Quafe SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35256,1311,'Kronos Quafe SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35257,1311,'Machariel Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,32,0.0000,1,NULL,0),(35258,1311,'Machariel Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,32,0.0000,1,NULL,0),(35259,1311,'Machariel Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,32,0.0000,1,NULL,0),(35260,1311,'Machariel Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,32,0.0000,1,NULL,0),(35261,1311,'Mackinaw ORE Development SKIN (7 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35262,1311,'Mackinaw ORE Development SKIN (30 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35263,1311,'Mackinaw ORE Development SKIN (90 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35264,1311,'Mackinaw ORE Development SKIN (365 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35265,1311,'Maelstrom Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35266,1311,'Maelstrom Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35267,1311,'Maelstrom Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35268,1311,'Maelstrom Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35269,1311,'Maelstrom Nefantar SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35270,1311,'Maelstrom Nefantar SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35271,1311,'Maelstrom Nefantar SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35272,1311,'Maelstrom Nefantar SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35273,1311,'Magnate Ardishapur SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35274,1311,'Magnate Ardishapur SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35275,1311,'Magnate Ardishapur SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35276,1311,'Magnate Ardishapur SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35277,1311,'Magnate Sarum SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35278,1311,'Magnate Sarum SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35279,1311,'Magnate Sarum SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35280,1311,'Magnate Sarum SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35281,1311,'Magnate Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35282,1311,'Magnate Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35283,1311,'Magnate Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35284,1311,'Magnate Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35285,1311,'Maller Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35286,1311,'Maller Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35287,1311,'Maller Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35288,1311,'Maller Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35289,1311,'Maller Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35290,1311,'Maller Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35291,1311,'Maller Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35292,1311,'Maller Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35293,1311,'Mammoth Nefantar SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35294,1311,'Mammoth Nefantar SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35295,1311,'Mammoth Nefantar SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35296,1311,'Mammoth Nefantar SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35297,1311,'Maulus Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35298,1311,'Maulus Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35299,1311,'Maulus Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35300,1311,'Maulus Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35301,1311,'Maulus Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35302,1311,'Maulus Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35303,1311,'Maulus Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35304,1311,'Maulus Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35305,1311,'Megathron Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35306,1311,'Megathron Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35307,1311,'Megathron Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35308,1311,'Megathron Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35309,1311,'Megathron Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35310,1311,'Megathron Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35311,1311,'Megathron Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35312,1311,'Megathron Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35313,1311,'Megathron Police SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35314,1311,'Megathron Police SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35315,1311,'Megathron Police SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35316,1311,'Megathron Police SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35317,1311,'Megathron Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35318,1311,'Megathron Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35319,1311,'Megathron Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35320,1311,'Megathron Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35321,1311,'Merlin Nugoeihuvi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35322,1311,'Merlin Nugoeihuvi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35323,1311,'Merlin Nugoeihuvi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35324,1311,'Merlin Nugoeihuvi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35325,1311,'Merlin Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35326,1311,'Merlin Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35327,1311,'Merlin Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35328,1311,'Merlin Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35329,1311,'Moa Lai Dai SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35330,1311,'Moa Lai Dai SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35331,1311,'Moa Lai Dai SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35332,1311,'Moa Lai Dai SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35333,1311,'Moros InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35334,1311,'Moros InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35335,1311,'Moros InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35336,1311,'Moros InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35337,1311,'Moros Roden SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35338,1311,'Moros Roden SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35339,1311,'Moros Roden SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35340,1311,'Moros Roden SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35341,1311,'Myrmidon Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35342,1311,'Myrmidon Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35343,1311,'Myrmidon Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35344,1311,'Myrmidon Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35345,1311,'Myrmidon InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35346,1311,'Myrmidon InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35347,1311,'Myrmidon InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35348,1311,'Myrmidon InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35349,1311,'Naga Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35350,1311,'Naga Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35351,1311,'Naga Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35352,1311,'Naga Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35353,1311,'Naglfar Justice SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35354,1311,'Naglfar Justice SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35355,1311,'Naglfar Justice SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35356,1311,'Naglfar Justice SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35357,1311,'Navitas Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35358,1311,'Navitas Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35359,1311,'Navitas Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35360,1311,'Navitas Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35361,1311,'Nidhoggur Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35362,1311,'Nidhoggur Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35363,1311,'Nidhoggur Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35364,1311,'Nidhoggur Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35365,1311,'Nyx InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35366,1311,'Nyx InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35367,1311,'Nyx InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35368,1311,'Nyx InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35369,1311,'Nyx Quafe SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35370,1311,'Nyx Quafe SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35371,1311,'Nyx Quafe SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35372,1311,'Nyx Quafe SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35373,1311,'Obelisk Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35374,1311,'Obelisk Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35375,1311,'Obelisk Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35376,1311,'Obelisk Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35377,1311,'Obelisk Quafe SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35378,1311,'Obelisk Quafe SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35379,1311,'Obelisk Quafe SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35380,1311,'Obelisk Quafe SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35381,1311,'Omen Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35382,1311,'Omen Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35383,1311,'Omen Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35384,1311,'Omen Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35385,1311,'Omen Sarum SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35386,1311,'Omen Sarum SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35387,1311,'Omen Sarum SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35388,1311,'Omen Sarum SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35389,1311,'Omen Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35390,1311,'Omen Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35391,1311,'Omen Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35392,1311,'Omen Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35393,1311,'Oracle Khanid SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35394,1311,'Oracle Khanid SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35395,1311,'Oracle Khanid SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35396,1311,'Oracle Khanid SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35397,1311,'Oracle Sarum SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35398,1311,'Oracle Sarum SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35399,1311,'Oracle Sarum SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35400,1311,'Oracle Sarum SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35401,1311,'Orca ORE Development SKIN (7 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35402,1311,'Orca ORE Development SKIN (30 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35403,1311,'Orca ORE Development SKIN (90 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35404,1311,'Orca ORE Development SKIN (365 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35405,1311,'Osprey Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35406,1311,'Osprey Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35407,1311,'Osprey Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35408,1311,'Osprey Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35409,1311,'Paladin Blood Raider SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35410,1311,'Paladin Blood Raider SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35411,1311,'Paladin Blood Raider SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35412,1311,'Paladin Blood Raider SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35413,1311,'Paladin Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35414,1311,'Paladin Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35415,1311,'Paladin Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35416,1311,'Paladin Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35417,1311,'Paladin Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35418,1311,'Paladin Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35419,1311,'Paladin Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35420,1311,'Paladin Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35421,1311,'Phoenix Lai Dai SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35422,1311,'Phoenix Lai Dai SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35423,1311,'Phoenix Lai Dai SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35424,1311,'Phoenix Lai Dai SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35425,1311,'Phoenix Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35426,1311,'Phoenix Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35427,1311,'Phoenix Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35428,1311,'Phoenix Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35429,1311,'Probe Vherokior SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35430,1311,'Probe Vherokior SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35431,1311,'Probe Vherokior SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35432,1311,'Probe Vherokior SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35433,1311,'Prophecy Blood Raiders SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35434,1311,'Prophecy Blood Raiders SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,1956,0),(35435,1311,'Prophecy Blood Raiders SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35436,1311,'Prophecy Blood Raiders SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35437,1311,'Prophecy Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35438,1311,'Prophecy Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35439,1311,'Prophecy Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35440,1311,'Prophecy Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35441,1311,'Prophecy Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35442,1311,'Prophecy Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35443,1311,'Prophecy Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35444,1311,'Prophecy Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35445,1311,'Providence Ardishapur SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35446,1311,'Providence Ardishapur SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35447,1311,'Providence Ardishapur SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35448,1311,'Providence Ardishapur SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35449,1311,'Providence Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35450,1311,'Providence Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35451,1311,'Providence Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35452,1311,'Providence Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35453,1311,'Punisher Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35454,1311,'Punisher Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35455,1311,'Punisher Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35456,1311,'Punisher Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35457,1311,'Punisher Tash-Murkon SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35458,1311,'Punisher Tash-Murkon SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35459,1311,'Punisher Tash-Murkon SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35460,1311,'Punisher Tash-Murkon SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35461,1311,'Rattlesnake Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35462,1311,'Rattlesnake Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35463,1311,'Rattlesnake Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35464,1311,'Rattlesnake Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35465,1311,'Raven Guristas SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35466,1311,'Raven Guristas SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35467,1311,'Raven Guristas SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35468,1311,'Raven Guristas SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35469,1311,'Raven Kaalakiota SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35470,1311,'Raven Kaalakiota SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35471,1311,'Raven Kaalakiota SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35472,1311,'Raven Kaalakiota SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35473,1311,'Raven Nugoeihuvi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35474,1311,'Raven Nugoeihuvi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35475,1311,'Raven Nugoeihuvi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35476,1311,'Raven Nugoeihuvi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35477,1311,'Raven Serenity YC117 SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35478,1311,'Raven Serenity YC117 SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35479,1311,'Raven Serenity YC117 SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35480,1311,'Raven Serenity YC117 SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35481,1311,'Raven Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35482,1311,'Raven Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35483,1311,'Raven Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35484,1311,'Raven Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35485,1311,'Revelation Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35486,1311,'Revelation Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35487,1311,'Revelation Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35488,1311,'Revelation Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35489,1311,'Revelation Sarum SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35490,1311,'Revelation Sarum SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35491,1311,'Revelation Sarum SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35492,1311,'Revelation Sarum SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35493,1311,'Rifter Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35494,1311,'Rifter Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35495,1311,'Rifter Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35496,1311,'Rifter Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35497,1311,'Rifter Nefantar SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35498,1311,'Rifter Nefantar SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35499,1311,'Rifter Nefantar SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35500,1311,'Rifter Nefantar SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35501,1311,'Rokh Nugoeihuvi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35502,1311,'Rokh Nugoeihuvi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35503,1311,'Rokh Nugoeihuvi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35504,1311,'Rokh Nugoeihuvi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35505,1311,'Rokh Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35506,1311,'Rokh Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35507,1311,'Rokh Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35508,1311,'Rokh Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35509,1311,'Rorqual ORE Development SKIN (7 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35510,1311,'Rorqual ORE Development SKIN (30 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35511,1311,'Rorqual ORE Development SKIN (90 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35512,1311,'Rorqual ORE Development SKIN (365 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35513,1311,'Scorpion Ishukone Watch SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35514,1311,'Scorpion Ishukone Watch SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35515,1311,'Scorpion Ishukone Watch SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35516,1311,'Scorpion Ishukone Watch SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35517,1311,'Sigil Kador SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35518,1311,'Sigil Kador SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35519,1311,'Sigil Kador SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35520,1311,'Sigil Kador SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35521,1311,'Skiff ORE Development SKIN (7 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35522,1311,'Skiff ORE Development SKIN (30 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35523,1311,'Skiff ORE Development SKIN (90 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35524,1311,'Skiff ORE Development SKIN (365 Days)',' ',0,0.01,0,1,128,0.0000,1,NULL,0),(35525,1311,'Slasher Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35526,1311,'Slasher Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35527,1311,'Slasher Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35528,1311,'Slasher Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35529,1311,'Stabber Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35530,1311,'Stabber Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35531,1311,'Stabber Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35532,1311,'Stabber Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35533,1311,'Stabber Nefantar SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35534,1311,'Stabber Nefantar SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35535,1311,'Stabber Nefantar SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35536,1311,'Stabber Nefantar SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35537,1311,'Talos Duvolle SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35538,1311,'Talos Duvolle SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35539,1311,'Talos Duvolle SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35540,1311,'Talos Duvolle SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35541,1311,'Talos InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35542,1311,'Talos InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35543,1311,'Talos InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35544,1311,'Talos InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35545,1311,'Talwar Sebiestor SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35546,1311,'Talwar Sebiestor SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35547,1311,'Talwar Sebiestor SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35548,1311,'Talwar Sebiestor SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35549,1311,'Tayra Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35550,1311,'Tayra Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35551,1311,'Tayra Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35552,1311,'Tayra Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35553,1311,'Tempest Justice SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35554,1311,'Tempest Justice SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35555,1311,'Tempest Justice SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35556,1311,'Tempest Justice SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35557,1311,'Tempest Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35558,1311,'Tempest Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35559,1311,'Tempest Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35560,1311,'Tempest Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35561,1311,'Tempest Nefantar SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35562,1311,'Tempest Nefantar SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35563,1311,'Tempest Nefantar SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35564,1311,'Tempest Nefantar SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35565,1311,'Thanatos Quafe SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35566,1311,'Thanatos Quafe SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35567,1311,'Thanatos Quafe SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35568,1311,'Thanatos Quafe SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35569,1311,'Thanatos Roden SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35570,1311,'Thanatos Roden SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35571,1311,'Thanatos Roden SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35572,1311,'Thanatos Roden SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35573,1311,'Thorax Aliastra SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35574,1311,'Thorax Aliastra SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35575,1311,'Thorax Aliastra SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35576,1311,'Thorax Aliastra SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35577,1311,'Thorax Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35578,1311,'Thorax Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35579,1311,'Thorax Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35580,1311,'Thorax Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35581,1311,'Thrasher Nefantar SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35582,1311,'Thrasher Nefantar SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35583,1311,'Thrasher Nefantar SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35584,1311,'Thrasher Nefantar SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35585,1311,'Thrasher Thukker Tribe SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35586,1311,'Thrasher Thukker Tribe SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,1997,0),(35587,1311,'Thrasher Thukker Tribe SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35588,1311,'Thrasher Thukker Tribe SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35589,1311,'Tormentor Ardishapur SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35590,1311,'Tormentor Ardishapur SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35591,1311,'Tormentor Ardishapur SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35592,1311,'Tormentor Ardishapur SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35593,1311,'Tormentor Sarum SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35594,1311,'Tormentor Sarum SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35595,1311,'Tormentor Sarum SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35596,1311,'Tormentor Sarum SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35597,1311,'Tornado Nefantar SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35598,1311,'Tornado Nefantar SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35599,1311,'Tornado Nefantar SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35600,1311,'Tornado Nefantar SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35601,1311,'Tristan Inner Zone Shipping SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35602,1311,'Tristan Inner Zone Shipping SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35603,1311,'Tristan Inner Zone Shipping SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35604,1311,'Tristan Inner Zone Shipping SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35605,1311,'Tristan Quafe SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35606,1311,'Tristan Quafe SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35607,1311,'Tristan Quafe SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35608,1311,'Tristan Quafe SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35609,1311,'Typhoon Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35610,1311,'Typhoon Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35611,1311,'Typhoon Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35612,1311,'Typhoon Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35613,1311,'Vargur Justice SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35614,1311,'Vargur Justice SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35615,1311,'Vargur Justice SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35616,1311,'Vargur Justice SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35617,1311,'Vargur Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35618,1311,'Vargur Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35619,1311,'Vargur Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35620,1311,'Vargur Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35621,1311,'Vargur Nefantar SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35622,1311,'Vargur Nefantar SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35623,1311,'Vargur Nefantar SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35624,1311,'Vargur Nefantar SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35625,1311,'Vexor Intaki Syndicate SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35626,1311,'Vexor Intaki Syndicate SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35627,1311,'Vexor Intaki Syndicate SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35628,1311,'Vexor Intaki Syndicate SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35629,1311,'Vexor InterBus SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35630,1311,'Vexor InterBus SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35631,1311,'Vexor InterBus SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35632,1311,'Vexor InterBus SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35633,1311,'Vexor Quafe SKIN (7 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35634,1311,'Vexor Quafe SKIN (30 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35635,1311,'Vexor Quafe SKIN (90 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35636,1311,'Vexor Quafe SKIN (365 Days)',' ',0,0.01,0,1,8,0.0000,1,NULL,0),(35637,1311,'Vigil Krusual SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35638,1311,'Vigil Krusual SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35639,1311,'Vigil Krusual SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35640,1311,'Vigil Krusual SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35641,1311,'Wyvern Wiyrkomi SKIN (7 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35642,1311,'Wyvern Wiyrkomi SKIN (30 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35643,1311,'Wyvern Wiyrkomi SKIN (90 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35644,1311,'Wyvern Wiyrkomi SKIN (365 Days)',' ',0,0.01,0,1,1,0.0000,1,NULL,0),(35645,227,'Strange Beacon',' ',0,0,0,1,4,0.0000,0,NULL,0),(35646,818,'Burner Sentinel','This pilot is a fanatical follower of a newly independent Blood Raider captain. It will do anything to protect its master, and should be considered extremely dangerous.',2860000,28600,235,1,4,0.0000,0,NULL,0),(35650,988,'Wormhole S877','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,4,0.0000,0,NULL,0),(35651,988,'Wormhole B735','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,4,0.0000,0,NULL,0),(35652,988,'Wormhole V928','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,4,0.0000,0,NULL,0),(35653,988,'Wormhole C414','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,4,0.0000,0,NULL,0),(35654,988,'Wormhole R259','An unstable wormhole, deep in space. Wormholes of this kind usually collapse after a few days, and can lead to anywhere.',0,0,0,1,4,0.0000,0,NULL,0),(35656,46,'10MN Y-S8 Compact Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,5,0,1,1,3952.0000,1,542,0),(35657,46,'100MN Y-S8 Compact Afterburner','Gives a boost to the maximum velocity of the ship when activated. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module.\r\r\n\r\r\nNote: Usually fit on Battleships',0,5,0,1,2,161280.0000,1,542,0),(35658,46,'5MN Quad LiF Restrained Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Frigates and Destroyers',0,10,0,1,8,37748.0000,1,131,0),(35659,46,'50MN Y-T8 Compact Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,1,37748.0000,1,131,0),(35660,46,'50MN Quad LiF Restrained Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Usually fit on Cruisers and Battlecruisers',0,10,0,1,1,37748.0000,1,131,0),(35661,46,'500MN Y-T8 Compact Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,2,790940.0000,1,131,0),(35662,46,'500MN Quad LiF Restrained Microwarpdrive','Massive boost to speed for a very short time. The thrust that boosts the ship, and the corresponding maximum velocity bonus, are limited by the mass of the ship that uses this module. The sheer amount of energy needed to power this system means that it must permanently reserve a fraction of the capacitor output just to maintain the integrity of its warp containment field, and when activated it substantially increases the ship\'s EM footprint.\r\r\n\r\r\nPenalty: Max capacitor reduced.\r\r\n\r\r\nNote: Battleship class module',0,10,0,1,2,790940.0000,1,131,0),(35663,383,'Inert Proximity-activated Autoturret','Proximity based sentry gun.\r\r\n\r\r\nEntering within 10km of this turret will cause it to engage with your ship.',1000,1000,1000,1,4,0.0000,0,NULL,0),(35676,1306,'Jackdaw Defense Mode','33.3% bonus to all shield resistances\r\r\n33.3% reduction in ship signature radius',100,5,0,1,4,0.0000,0,NULL,0),(35677,1306,'Jackdaw Propulsion Mode','33.3% bonus to maximum velocity\r\r\n66.6% bonus to ship inertia modifier',100,5,0,1,4,0.0000,0,NULL,0),(35678,1306,'Jackdaw Sharpshooter Mode','66.6% bonus to Rocket and Light Missile velocity\r\r\n100% bonus to sensor strength, targeting range and scan resolution',100,5,0,1,4,0.0000,0,NULL,0),(35679,554,'Burner Clone Soldier Transport','With the advent of clone soldiers, a new breed of pirate has arisen to take advantage of their existence. CONCORD, which had been content to leave the pirates be so long as they remained within their own territories, sees the presence of pirate-affiliated clone soldiers as a major threat to the safety of the cluster, and will go to extraordinary means to disrupt their operations. This former member of the Angel Cartel is a transporter, responsible for the swift conveyance of clone soldiers to their intended destination.\r\r\n\r\r\nIntelligence experts have been unable to determine why this splinter group of former Angel Cartel pirates is recruiting clone soldiers in such large numbers.',89000000,890000,2000,1,2,0.0000,0,NULL,0),(35680,257,'Caldari Tactical Destroyer','Skill at operating Caldari Tactical Destroyers.\r\r\n\r\r\n<font color=\"0xffF67828\"><b>This skill cannot be trained on Trial Accounts.</b></font>',0,0.01,0,1,1,1000000.0000,1,377,0),(35681,1089,'Men\'s \'Humanitarian\' T-shirt YC 117','This highly prestigious item of clothing was created in YC 117 and presented to New Eden\'s charitable societies. The shirt stands as undeniable proof that its purchaser is on the side of good in a world that all too often can be cruel and merciless. Wear it with pride, and know that you have made a difference in the lives of strangers.',0,0.1,0,1,4,0.0000,1,1398,0),(35682,1089,'Women\'s \'Humanitarian\' T-shirt YC 117','This highly prestigious item of clothing was created in YC 117 and presented to New Eden\'s charitable societies. The shirt stands as undeniable proof that its purchaser is on the side of good in a world that all too often can be cruel and merciless. Wear it with pride, and know that you have made a difference in the lives of strangers.',0,0.1,0,1,4,0.0000,1,1406,0),(35689,818,'Burner Escort Dramiel','This individual is a rogue element of the Angel Cartel and should be considered highly dangerous.\r\r\n\r\r\nThe motivation for their activities are unknown - it could be to test-run experimental technology, to try secret new battle tactics on the local colonists, or just to splinter off their faction in time-honored fashion.',750000,19700,235,1,32,0.0000,0,NULL,0),(35690,1311,'Astero Sanctuary SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35691,1311,'Astero Sanctuary SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35692,1311,'Astero Sanctuary SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35693,1311,'Astero Sanctuary SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35694,1311,'Astero Sanctuary SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35695,1311,'Stratios Sanctuary SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35696,1311,'Stratios Sanctuary SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35697,1311,'Stratios Sanctuary SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35698,1311,'Stratios Sanctuary SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35699,1311,'Stratios Sanctuary SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35700,1311,'Nestor Sanctuary SKIN (Permanent)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35701,1311,'Nestor Sanctuary SKIN (7 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35702,1311,'Nestor Sanctuary SKIN (30 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35703,1311,'Nestor Sanctuary SKIN (90 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35704,1311,'Nestor Sanctuary SKIN (365 Days)',' ',0,0.01,0,1,4,0.0000,1,NULL,0),(35705,1311,'Vargur Thukker Tribe SKIN (Permanent)',' ',0,0.01,0,1,2,0.0000,1,2027,0),(35706,1311,'Vargur Thukker Tribe SKIN (7 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35707,1311,'Vargur Thukker Tribe SKIN (30 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35708,1311,'Vargur Thukker Tribe SKIN (90 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35709,1311,'Vargur Thukker Tribe SKIN (365 Days)',' ',0,0.01,0,1,2,0.0000,1,NULL,0),(35764,319,'EVE/Evetypes/Types/Names:505970','EVE/Evetypes/Types/Descriptions:505971',100000,100000000,10000,1,64,0.0000,0,NULL,0),(35770,1395,'EVE/Evetypes/Types/Names:505984','EVE/Evetypes/Types/Descriptions:505985',20,5,0,1,NULL,15764.0000,1,707,0),(35771,1395,'EVE/Evetypes/Types/Names:505986','EVE/Evetypes/Types/Descriptions:505987',30,5,0,1,NULL,0.0000,1,707,0),(35772,1397,'EVE/Evetypes/Types/Names:505989','EVE/Evetypes/Types/Descriptions:505990',0,0.01,0,1,NULL,144000.0000,1,343,0),(35773,1397,'EVE/Evetypes/Types/Names:505991','EVE/Evetypes/Types/Descriptions:505992',0,0.01,0,1,NULL,0.0000,1,NULL,0),(35774,1395,'EVE/Evetypes/Types/Names:505993','EVE/Evetypes/Types/Descriptions:505994',20,5,0,1,NULL,0.0000,1,707,0),(350916,350858,'Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,1500.0000,1,364056,0),(351063,350858,'Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,1500.0000,1,354565,0),(351071,351064,'Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(351252,351210,'Saga','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,353664,0),(351253,351210,'Methana','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,353664,0),(351278,351210,'Gunnlogi C-I','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,4,97500.0000,1,353657,0),(351297,350858,'20GJ Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,6300.0000,1,356968,0),(351310,350858,'ST-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,6300.0000,1,356963,0),(351311,350858,'ST-201 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,24000.0000,1,356960,0),(351317,350858,'80GJ Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,24000.0000,1,356971,0),(351320,350858,'Passenger Position','This is used for passenger positions. Please do not unpublish or delete this.',0,0.01,0,1,NULL,1500.0000,1,NULL,0),(351321,351210,'Colima','Conceived as the  ultimate urban pacifier , in practice the Medium Attack Vehicle is that and more   having inherited the strengths of its forebears, and few of their weaknesses. Its anti-personnel weaponry make it the perfect tool for flushing out insurgents, while the ample armor it carries means that it can withstand multiple direct hits and still keep coming. Though somewhat less effective on an open battlefield, its success rate in urban environments has earned the MAV almost legendary status among the troops it serves.',0,0,0,1,NULL,0.0000,1,NULL,0),(351332,350858,'80GJ Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,105240.0000,1,356977,0),(351336,350858,'80GJ Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,24000.0000,1,356976,0),(351337,350858,'20GJ Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,6300.0000,1,356979,0),(351352,351210,'Bolas','Utilizing cloaking technology to conceal their approach, RDVs are unmanned vehicles designed to ferry supplies to almost any location on the battlefield. The sky above any battlefield teems with these unseen harbingers. Death on the battlefield may be no more than an instant away, but thanks to the RDVs so too are reinforcements!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(351354,351210,'Myron','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,45000.0000,1,353671,0),(351355,351210,'Grimsnes','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,45000.0000,1,353671,0),(351610,351121,'Basic Afterburner','Once activated, this module provides a temporary speed boost to aerial vehicles.\r\r\n\r\r\nNOTE: Only one afterburner can be fitted at a time.\r\r\nStacking penalties apply to this module and other modules of this type; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,4500.0000,1,354460,0),(351611,351121,'Enhanced Afterburner','Once activated, this module provides a temporary speed boost to aerial vehicles.\r\r\n\r\r\nNOTE: Only one afterburner can be fitted at a time.\r\r\nStacking penalties apply to this module and other modules of this type; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,12060.0000,1,354460,0),(351614,351121,'Basic 120mm Armor Plates','Increases maximum strength of vehicle\'s armor but the increased mass affects acceleration and top speed.',0,0.01,0,1,NULL,9000.0000,1,363305,0),(351615,351121,'Basic 60mm Armor Plates','Increases maximum strength of vehicle\'s armor but the increased mass affects acceleration and top speed.',0,0.01,0,1,NULL,5250.0000,1,363306,0),(351620,351121,'Nanofiber Structure I','Increases vehicle speed at the cost of reduced armor strength. Top speed +10%, Armor HP -10%.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,6000.0000,1,NULL,0),(351630,351121,'Basic Overdrive Unit','This propulsion upgrade increases a vehicle powerplant\'s power output for increased speed and torque.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,8000.0000,0,NULL,0),(351631,351121,'Enhanced Overdrive Unit','This propulsion upgrade increases a vehicle powerplant\'s power output for increased speed and torque.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,8050.0000,0,NULL,0),(351632,351121,'Complex Overdrive Unit','This propulsion upgrade increases a vehicle powerplant\'s power output for increased speed and torque.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,9000.0000,0,NULL,0),(351633,351121,'Overdrive','This propulsion upgrade increases a vehicle powerplant\'s power output for increased speed and torque.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(351669,351121,'Basic Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.',0,0.01,0,1,NULL,900.0000,1,365244,0),(351670,351121,'Enhanced Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.',0,0.01,0,1,NULL,2415.0000,1,365244,0),(351671,351121,'Complex Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.',0,0.01,0,1,NULL,3945.0000,1,365244,0),(351673,351121,'Basic Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0.01,0,1,NULL,1275.0000,1,365247,0),(351674,351121,'Enhanced Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0.01,0,1,NULL,3420.0000,1,365247,0),(351675,351121,'Complex Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0.01,0,1,NULL,5595.0000,1,365247,0),(351679,351121,'Basic Light Damage Modifier','Increases damage output of all light handheld weapons.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1275.0000,1,354434,0),(351680,351121,'Enhanced Light Damage Modifier','Increases damage output of all light handheld weapons.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,354434,0),(351681,351121,'Complex Light Damage Modifier','Increases damage output of all light handheld weapons.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5595.0000,1,354434,0),(351684,351121,'Basic Kinetic Catalyzer','Increases sprinting speed of the user.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,675.0000,1,354427,0),(351686,351121,'Basic Cardiac Stimulant','Increases maximum stamina of the user.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,2600.0000,0,NULL,0),(351687,351121,'Enhanced Kinetic Catalyzer','Increases sprinting speed of the user.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,1815.0000,1,354427,0),(351688,351121,'Complex Kinetic Catalyzer','Increases sprinting speed of the user.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,2955.0000,1,354427,0),(351689,351121,'Enhanced Cardiac Stimulant','Increases maximum stamina of the user.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,5440.0000,0,NULL,0),(351690,351121,'Complex Cardiac Stimulant','Increases maximum stamina of the user.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,7920.0000,0,NULL,0),(351696,351121,'Basic CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1200.0000,1,354430,0),(351697,351121,'Enhanced CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3210.0000,1,354430,0),(351698,351121,'Complex CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5265.0000,1,354430,0),(351699,351121,'Basic PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,1200.0000,1,354431,0),(351700,351121,'Enhanced PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,3210.0000,1,354431,0),(351701,351121,'Complex PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,5265.0000,1,354431,0),(351706,350858,'Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,450.0000,1,363464,0),(351709,350858,'AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,750.0000,1,363467,0),(351732,351121,'\'Goliath\' Basic Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.\r\r\n',0,0.01,0,1,NULL,900.0000,1,365244,0),(351824,351210,'Madrugar G-I','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,4,97500.0000,1,353657,0),(351855,350858,'Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,1500.0000,1,354618,0),(351858,351844,'Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,1125.0000,1,354414,0),(351865,351121,'Basic Heavy Armor Repairer','Passively repairs damage done to the vehicle\'s armor.',0,0.01,0,1,NULL,9000.0000,1,363441,0),(351905,351121,'Basic Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0.01,0,1,NULL,975.0000,1,365248,0),(351906,351121,'Enhanced Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0.01,0,1,NULL,2610.0000,1,365248,0),(351907,351121,'Complex Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0.01,0,1,NULL,4275.0000,1,365248,0),(351908,351121,'Basic Shield Recharger','Improves the recharge rate of dropsuit\'s shields.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1350.0000,1,365250,0),(351909,351121,'Enhanced Shield Recharger','Improves the recharge rate of dropsuit\'s shields.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3615.0000,1,365250,0),(351910,351121,'Complex Shield Recharger','Improves the recharge rate of dropsuit\'s shields.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,5925.0000,1,365250,0),(351915,351844,'Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,900.0000,1,354403,0),(351916,351844,'Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,900.0000,1,354410,0),(352017,351121,'\'Scalar\' Basic CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1200.0000,1,354430,0),(352018,351121,'\'Azimuth\' Basic PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,1200.0000,1,354431,0),(352019,351121,'\'Monolith\' Basic Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0.01,0,1,NULL,1275.0000,1,365247,0),(352020,351121,'\'Kinesis\' Basic Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0.01,0,1,NULL,975.0000,1,365248,0),(352021,351121,'\'Synapse\' Basic Shield Recharger','Improves the recharge rate of dropsuit\'s shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1350.0000,1,365250,0),(352022,351121,'\'Icarus\' Basic Kinetic Catalyzer','Increases sprinting speed of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,675.0000,1,354427,0),(352032,351121,'Basic Light Shield Booster','Once activated, this module instantly recharges a portion of the vehicle\'s shield HP.',0,0.01,0,1,NULL,5250.0000,1,363448,0),(352034,351121,'Basic Light Shield Extender','Increases maximum strength of vehicle\'s shields but increases the shield depleted recharge delay.',0,0.01,0,1,NULL,5250.0000,1,363457,0),(352035,351121,'Basic Heavy Shield Extender','Increases maximum strength of vehicle\'s shields but increases the shield depleted recharge delay.',0,0.01,0,1,NULL,9000.0000,1,363456,0),(352041,351121,'\'Helix\' Enhanced PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,3210.0000,1,354431,0),(352042,351121,'\'Dimension\' Enhanced CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3210.0000,1,354430,0),(352043,351121,'\'Vector\' Complex CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3210.0000,1,354430,0),(352044,351121,' ',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(352045,351121,'\'Polaris\' Complex PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,3210.0000,1,354431,0),(352046,351121,'\'Menhir\' Enhanced Armor Repairer','Passively repairs damage done to dropsuit\'s armor.\r\r\n',0,0.01,0,1,NULL,3420.0000,1,365247,0),(352047,351121,'\'Obelisk\' Complex Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0.01,0,1,NULL,3420.0000,1,365247,0),(352048,351121,'\'Samson\' Enhanced Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.\r\r\n',0,0.01,0,1,NULL,2415.0000,1,365244,0),(352049,351121,'\'Hercules\' Complex Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.',0,0.01,0,1,NULL,2415.0000,1,365244,0),(352050,351121,'\'Mercury\' Enhanced Kinetic Catalyzer','Increases sprinting speed of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,1815.0000,1,354427,0),(352051,351121,'\'Spark\' Enhanced Shield Recharger','Improves the recharge rate of dropsuit\'s shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3615.0000,1,365250,0),(352052,351121,'\'Impulse\' Enhanced Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0.01,0,1,NULL,2610.0000,1,365248,0),(352057,351121,'Heavy Shield Transporter I','Once activated this module recharges the targeted vehicle s shields.',0,0.01,0,1,NULL,32000.0000,1,NULL,0),(352067,351121,'Basic CPU Upgrade Unit','Increases a vehicle\'s maximum CPU output in order to support more CPU intensive modules.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3000.0000,1,354453,0),(352068,351121,'Enhanced CPU Upgrade Unit','Increases a vehicle\'s maximum CPU output in order to support more CPU intensive modules.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,8040.0000,1,354453,0),(352069,351121,'Complex CPU Upgrade Unit','Increases a vehicle\'s maximum CPU output in order to support more CPU intensive modules.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,13155.0000,1,354453,0),(352070,351121,'Quantum CPU Enhancer','Increases a vehicle\'s overall CPU output, enabling it to equip more CPU intensive modules. Increases CPU output by 13%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,18200.0000,1,NULL,0),(352071,351121,'Basic Powergrid Upgrade','Increases a vehicles\'s maximum powergrid output in order to support more PG intensive modules.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,3000.0000,1,354458,0),(352072,351121,'Enhanced Powergrid Upgrade','Increases a vehicles\'s maximum powergrid output in order to support more PG intensive modules.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,8040.0000,1,354458,0),(352073,351121,'Complex Powergrid Upgrade','Increases a vehicles\'s maximum powergrid output in order to support more PG intensive modules. \r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,13155.0000,1,354458,0),(352074,351121,'Type-G Powergrid Expansion System','Increases a vehicle\'s overall powergrid output by 14%. \r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,18200.0000,1,NULL,0),(352076,351121,'Power Diagnostic System I ','Increases the overall efficiency of a vehicle\'s engineering subsystems, thereby increasing its powergrid, shields and shield recharge by 5%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters shield recharge rate or powergrid will be reduced. ',0,0.01,0,1,NULL,6000.0000,1,NULL,0),(352077,351121,'Beta Power Diagnostic System','Increases the overall efficiency of a vehicle\'s engineering subsystems, thereby increasing its powergrid, shields and shield recharge by 4%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters shield recharge rate or powergrid will be reduced.',0,0.01,0,1,NULL,8680.0000,1,NULL,0),(352078,351121,'Local Power Diagnostic System','Increases the overall efficiency of a vehicle\'s engineering subsystems, thereby increasing its powergrid, shields and shield recharge by 7%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters shield recharge rate or powergrid will be reduced.',0,0.01,0,1,NULL,12560.0000,1,NULL,0),(352079,351121,'Type-G Power Diagnostic System','Increases the overall efficiency of a vehicle\'s engineering subsystems, thereby increasing its powergrid, shields and shield recharge by 6%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters shield recharge rate or powergrid will be reduced.',0,0.01,0,1,NULL,18200.0000,1,NULL,0),(352083,351121,'Systemic Field Stabilizer I','Increases the damage output of all vehicle mounted railgun and blaster turrets.  Grants 3% bonus to hybrid turret damage, and a 2% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25000.0000,1,NULL,0),(352089,351121,'Basic Light Armor Repairer','Passively repairs damage done to the vehicle\'s armor.',0,0.01,0,1,NULL,5250.0000,1,363440,0),(352101,351121,'Light Remote Armor Repair Unit I','Once activated this module repairs the damage done to the targeted vehicle s armor.',0,0.01,0,1,NULL,16000.0000,1,NULL,0),(352108,351121,'[DEV] High Vehicle PG/CPU','Set PG and CPU to high values',0,0.01,0,1,NULL,5000.0000,0,NULL,0),(352221,351121,'Energized Plating I','Passively reduces damage done to the vehicle\'s armor. -10% damage taken to armor hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,6000.0000,1,NULL,0),(352263,350858,'Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,1500.0000,1,354335,0),(352274,351121,'[DEV] High Infantry PG/CPU','Set PG and CPU to high values',0,0.01,0,1,NULL,500.0000,0,NULL,0),(352277,351121,'Basic Armor Hardener','Once activated, this module temporarily reduces the damage done to armor.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,6000.0000,1,357120,0),(352279,351121,'Basic Auto-Detonator','At the moment of death this unit triggers a small explosive powerful enough to kill any infantry unit nearby.',0,0.01,0,1,NULL,3400.0000,1,NULL,0),(352293,351121,'Basic Shield Hardener','Once activated, this module temporarily reduces the damage done to shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,6000.0000,1,363452,0),(352304,350858,'Militia 20GJ Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,5505.0000,1,355465,0),(352305,350858,'Militia 80GJ Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,14670.0000,1,355465,0),(352313,350858,'Militia 80GJ Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,14670.0000,1,355465,0),(352314,350858,'Militia 20GJ Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,5505.0000,1,355465,0),(352415,351064,'Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,3000.0000,1,354380,0),(352472,350858,'\'Paradox\' Graded Particle Cannon (S)','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,6000.0000,1,NULL,0),(352493,351844,'\'Dawnpyre\' R-9 Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,3945.0000,1,354404,0),(352499,350858,'Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,675.0000,1,354343,0),(352508,350858,'Flux Grenade','The Flux grenade is a hand-thrown wave shaper designed to destroy low-level electronic equipment and disrupt shielding.',0,0.01,0,1,NULL,600.0000,1,363470,0),(352526,350858,'\'Husk\' Phase-synched Railgun (L)','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,24000.0000,1,NULL,0),(352536,351121,'Basic Power Diagnostics Unit','Provides a marginal boost to power grid output and reduces the delay before shield recharge begins.',0,0.01,0,1,NULL,750.0000,1,NULL,0),(352537,351121,'Complex Power Diagnostics Unit','Provides a marginal boost to power grid output and reduces the delay before shield recharge begins.',0,0.01,0,1,NULL,3285.0000,1,NULL,0),(352538,351121,'Enhanced Power Diagnostics Unit','Provides a marginal boost to power grid output and reduces the delay before shield recharge begins.',0,0.01,0,1,NULL,2010.0000,1,NULL,0),(352550,351121,'Basic Scanner','Once activated, this module will reveal the location of enemy units within its active radius provided it\'s precise enough to detect the unit\'s scan profile.',0,0.01,0,1,NULL,6000.0000,1,356916,0),(352556,350858,'Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,1500.0000,1,354347,0),(352587,351064,'Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,354388,0),(352588,351064,'Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,3000.0000,1,354384,0),(352591,351064,'Frontline - CA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer. \r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,610.0000,1,NULL,0),(352592,351064,'Militia Amarr Heavy Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(352593,351064,'Militia Minmatar Medium Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(352594,351064,'Pilot G-I','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Gallente suit instead incorporates a host of structural monitoring nodes, smart I/O channels and energy management controllers into a wearable interface that enhances the performance of the vehicle s shield and armor subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,3000.0000,1,NULL,0),(352595,351064,'Militia Pilot Dropsuit','Pilot armor developed by Gallente scientists.',0,0.01,0,1,NULL,6080.0000,1,NULL,0),(352596,351064,'Militia Gallente Light Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(352602,350858,'Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,1500.0000,1,354331,0),(352604,351121,'Basic Mobile CRU','This module provides a clone reanimation unit inside a manned vehicle for mobile spawning.',0,0.01,0,1,NULL,6750.0000,1,354455,0),(352687,351121,'Basic Myofibril Stimulant','Increases damage done by melee attacks.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,780.0000,1,354429,0),(352887,351648,'Corporations','Basic corporation operation. \r\r\n\r\r\n+10 corporation members allowed per level.',0,0.01,0,1,NULL,20000.0000,1,363476,0),(352888,351648,'Megacorp Control','Advanced corporation operation. \r\r\n\r\r\n+50 members per level.',0,0.01,0,1,NULL,400000.0000,1,363476,0),(352890,351648,'Transstellar Empire Control','Advanced corporation operation. \r\r\n\r\r\n+200 corporation members allowed per level. ',0,0.01,0,1,NULL,8000000.0000,1,363476,0),(352891,350858,'Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,675.0000,1,354352,0),(352928,351064,'[DEV] Offline Dropsuit','Default armor used for offline mode.',0,0.01,0,1,NULL,4680.0000,1,NULL,0),(352929,351121,'Enhanced Myofibril Stimulant','Increases damage done by melee attacks.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,2085.0000,1,354429,0),(352934,351064,'Assault B-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer. \r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,13155.0000,0,NULL,0),(352937,351064,'Assault vk.1','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer. \r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,94425.0000,0,NULL,0),(352938,351064,'Assault Type-II','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer. \r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,4905.0000,0,NULL,0),(352939,351064,'Scout Type-II','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,4905.0000,0,NULL,0),(352940,351064,'Scout B-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,13155.0000,0,NULL,0),(352942,351064,'Scout vk.1','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,94425.0000,0,NULL,0),(352944,351064,'Heavy Type-II','The Heavy dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,4905.0000,0,NULL,0),(353032,350858,'Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,1500.0000,1,354364,0),(353041,351121,'Complex Myofibril Stimulant','Increases damage done by melee attacks.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,3420.0000,1,354429,0),(353042,350858,'[TEST] Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,5200.0000,1,NULL,0),(353089,351210,'Sagaris','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies.\r\r\nThe Marauder class pushes its power plant to the limit, achieving improved damage output and excellent protection from its greatly enhanced armor. \r\r\n\r\r\n+4% bonus to Large Missile launcher damage per level.',0,0.01,0,1,NULL,1227600.0000,1,NULL,0),(353106,350858,'Breach Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,2460.0000,1,354331,0),(353107,350858,'Tactical Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,2460.0000,1,NULL,0),(353108,350858,'\'Blindfire\' Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,4020.0000,1,354331,0),(353109,350858,'GEK-38 Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,10770.0000,1,354332,0),(353110,350858,'GK-13 Burst Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,4,10770.0000,1,354332,0),(353111,350858,'G7-M Compact Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,4,10770.0000,1,NULL,0),(353112,350858,'\'Gorewreck\' GK-13 Burst Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,10770.0000,1,354332,0),(353113,350858,'\'Killswitch\' GEK-38 Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,10770.0000,1,354332,0),(353114,350858,'Duvolle Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class.\r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,47220.0000,1,354333,0),(353115,350858,'CreoDron Breach Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,4,47220.0000,1,354333,0),(353116,350858,'Allotek Burst Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,4,47220.0000,1,354333,0),(353117,350858,'\'Codewish\' Duvolle Tactical Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,28845.0000,1,354333,0),(353118,350858,'\'Stormside\' Roden Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,28845.0000,1,NULL,0),(353119,350858,'\'Hollowsight\' Carthum Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,28845.0000,1,NULL,0),(353120,350858,'Militia Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class.\r\r\n\r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,610.0000,1,355463,0),(353126,350858,'Assault Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets. \r\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,1110.0000,0,NULL,0),(353127,350858,'Breach Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,1110.0000,1,354352,0),(353128,350858,'\'Slashvent\' Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,1815.0000,1,354352,0),(353129,350858,'M512-A Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,4845.0000,1,354353,0),(353130,350858,'M209 Assault Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,7935.0000,1,354353,0),(353131,350858,'SK9M Breach Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,7935.0000,1,354353,0),(353132,350858,'\'Bedlam\' M512-A Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,4845.0000,1,354353,0),(353133,350858,'\'Minddrive\' SK9M Breach Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,4845.0000,1,354353,0),(353134,350858,'Six Kin Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,21240.0000,1,354354,0),(353135,350858,'Ishukone Assault Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,34770.0000,1,354354,0),(353136,350858,'Freedom Burst Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets. \r\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,34770.0000,1,NULL,0),(353137,350858,'\'Gargoyle\' Freedom Burst Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets. \r\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,12975.0000,1,NULL,0),(353138,350858,'\'Mashgrill\' CreoDron Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets. \r\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,12975.0000,1,NULL,0),(353139,350858,'\'Spitfire\' Six Kin Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,12975.0000,1,354354,0),(353140,350858,'Militia Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets. \r\r\n\r\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,270.0000,1,355463,0),(353143,350858,'Assault Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it. \r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,2460.0000,0,NULL,0),(353144,350858,'Breach Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,2460.0000,1,354335,0),(353145,350858,'\'Strumborne\' Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,4020.0000,1,354335,0),(353146,350858,'9K330 Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,6585.0000,1,354336,0),(353147,350858,'DAU-2/A Assault Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,10770.0000,1,354336,0),(353148,350858,'DCMA-5 Breach Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,10770.0000,1,354336,0),(353149,350858,'\'Blastwave\' 9K330 Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,10770.0000,1,354336,0),(353150,350858,'\'Arcflare\' DAU-2/A Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it. \r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,10770.0000,1,NULL,0),(353151,350858,'Kaalakiota Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,28845.0000,1,354337,0),(353152,350858,'Ishukone Assault Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,47220.0000,1,354337,0),(353153,350858,'Imperial Armaments Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it. \r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,28845.0000,1,NULL,0),(353154,350858,'\'Grimlock\' Guristas Assault Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,28845.0000,1,354337,0),(353155,350858,'\'Backscatter\' Freedom Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it. \r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,28845.0000,1,NULL,0),(353156,350858,'\'Torchflare\' Kaalakiota Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it. \r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,28845.0000,1,354337,0),(353161,350858,'Tactical Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,2460.0000,1,354347,0),(353162,350858,'Charge Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,47220.0000,1,354350,0),(353163,350858,'\'Farsight\' Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,4020.0000,1,354347,0),(353164,350858,'NT-511 Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,6585.0000,1,354348,0),(353165,350858,'C27-N Specialist Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,10770.0000,1,354348,0),(353166,350858,'C15-A Tactical Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,10770.0000,1,354348,0),(353167,350858,'\'Genesis\' NT-511 Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,10770.0000,1,354348,0),(353168,350858,'\'Downwind\' C15-A Tactical Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,10770.0000,1,354348,0),(353169,350858,'Ishukone Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,28845.0000,1,354350,0),(353170,350858,'Lai Dai Compact Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,47220.0000,1,NULL,0),(353171,350858,'Roden Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,4,47220.0000,1,354350,0),(353172,350858,'\'Horizon\' Kaalakiota Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,28845.0000,1,354350,0),(353173,350858,'\'Corona\' Ishukone Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,28845.0000,1,NULL,0),(353174,350858,'\'Surgepoint\' Six Kin Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,28845.0000,1,NULL,0),(353175,350858,'Militia Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,610.0000,1,355463,0),(353179,350858,'Assault Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,2460.0000,1,354364,0),(353180,350858,'Specialist Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,2460.0000,0,NULL,0),(353181,350858,'\'Scattermind\' Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,4020.0000,1,354364,0),(353182,350858,'CBR7 Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,6585.0000,1,354366,0),(353183,350858,'CBR-112 Specialist Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,10770.0000,1,354366,0),(353184,350858,'CFG-129 Assault Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,10770.0000,1,354366,0),(353185,350858,'\'Darkside\' CBR7 Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,10770.0000,1,354366,0),(353186,350858,'\'Scramkit\' CBR-112 Breach Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,10770.0000,1,NULL,0),(353187,350858,'Wiyrkomi Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,28845.0000,1,354367,0),(353188,350858,'Wiyrkomi Specialist Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,47220.0000,1,354367,0),(353189,350858,'Ishukone Assault Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,47220.0000,1,354367,0),(353190,350858,'\'Mimicry\' CreoDron Tactical Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,28845.0000,1,NULL,0),(353191,350858,'\'Weavewind\' Roden Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,28845.0000,1,NULL,0),(353192,350858,'\'Haywire\' Wiyrkomi Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,28845.0000,1,354367,0),(353193,350858,'Militia Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,610.0000,1,355463,0),(353196,350858,'Specialist Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target. \r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,1110.0000,1,NULL,0),(353197,350858,'Burst Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target. \r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,1110.0000,0,NULL,0),(353198,350858,'\'Surgewick\' Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,1815.0000,1,354343,0),(353199,350858,'CAR-9 Burst Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,4845.0000,1,354344,0),(353200,350858,'IA5 Tactical Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target. \r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,4845.0000,1,354344,0),(353201,350858,'TT-3 Assault Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,4845.0000,1,354344,0),(353202,350858,'\'Flashbow\' CAR-9 Burst Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,4845.0000,1,354344,0),(353203,350858,'\'Hazemoon\' IA5 Tactical Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target. \r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,4845.0000,1,NULL,0),(353204,350858,'Ishukone Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target. \r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,12975.0000,1,NULL,0),(353205,350858,'Viziam Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,12975.0000,1,354345,0),(353206,350858,'Imperial Burst Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,21240.0000,1,354345,0),(353207,350858,'\'Burnscar\' Khanid Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\r\n\r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,12975.0000,1,354345,0),(353208,350858,'\'Grindfell\' Imperial Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target. \r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,12975.0000,1,NULL,0),(353209,350858,'\'Singetear\' Viziam Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target. \r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,12975.0000,1,354345,0),(353213,351844,'Quantum Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,1470.0000,0,NULL,0),(353214,351844,'Gauged Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,1470.0000,0,NULL,0),(353215,351844,'Stable Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,1470.0000,0,NULL,0),(353216,351844,'K17/D Nanohive (R)','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,6465.0000,1,354411,0),(353217,351844,'R11-4 Flux Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,3945.0000,0,NULL,0),(353218,351844,'X-3 Quantum Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,3945.0000,1,354411,0),(353219,351844,'\'Cistern\' K-17D Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,3945.0000,1,354411,0),(353220,351844,'Ishukone Flux Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,17310.0000,1,354412,0),(353222,351844,'Ishukone Gauged Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,28335.0000,1,354412,0),(353223,351844,'Allotek Nanohive (R)','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,28335.0000,1,354412,0),(353224,351844,'\'Centrifuge\' Ishukone Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,10575.0000,1,354412,0),(353225,351844,'\'Isotope\' Kaalakiota Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,10575.0000,1,354412,0),(353229,351844,'Flux Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,1845.0000,1,354414,0),(353230,351844,'Triage Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,3015.0000,0,NULL,0),(353231,351844,'Inert Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,3015.0000,0,NULL,0),(353232,351844,'Stable Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,1845.0000,0,NULL,0),(353233,351844,'BDR-2 Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,4935.0000,1,354415,0),(353234,351844,'BDR-5 Axis Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,4935.0000,1,354415,0),(353235,351844,'A/7 Inert Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,4935.0000,0,NULL,0),(353236,351844,'Core Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,13215.0000,1,354416,0),(353237,351844,'Six Kin Triage Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,21630.0000,1,354416,0),(353238,351844,'Lai Dai Flux Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,21630.0000,1,354416,0),(353239,351844,'\'Splinter\' Axis Boundless Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,8070.0000,1,354416,0),(353240,351844,'\'Schizm\' Core Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,8070.0000,1,354416,0),(353244,351844,'Flux Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,1470.0000,0,NULL,0),(353245,351844,'Quantum Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,1470.0000,0,NULL,0),(353246,351844,'Gauged Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,1470.0000,0,NULL,0),(353247,351844,'Stable Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,1470.0000,1,354403,0),(353248,351844,'R-9 Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,2415.0000,1,354404,0),(353249,351844,'N-11/A Flux Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,3945.0000,1,354404,0),(353250,351844,'P-13 Quantum Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,3945.0000,1,354404,0),(353251,351844,'Viziam Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,6465.0000,1,354405,0),(353252,351844,'Viziam Gauged Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,10575.0000,1,354405,0),(353253,351844,'Viziam Stable Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,10575.0000,1,354405,0),(353254,351844,'\'Proxy\' Viziam Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,3945.0000,1,354405,0),(353255,351844,'\'Abyss\' Carthum Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,17310.0000,1,354405,0),(353256,351844,'\'Fractal\' A/7 Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,8070.0000,1,354415,0),(353257,351064,'[TEST] QA Dropsuit','This suit is to be used for testing purposes only! It has ridiculously high pg/cpu designed to help devs and QA do fitting-related tasks more easily.',0,0.01,0,1,NULL,4680.0000,1,NULL,0),(353258,350858,'Railgun Installation','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,16560.0000,1,NULL,0),(353263,350858,'Missile Installation','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,16560.0000,1,NULL,0),(353264,350858,'Blaster Installation','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,16560.0000,1,NULL,0),(353281,350858,'Burst Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,2460.0000,0,NULL,0),(353283,351121,'Basic Cardiac Regulator','Increases max stamina and stamina recovery rate of the user.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,720.0000,1,354425,0),(353284,351121,'Enhanced Cardiac Regulator','Increases max stamina and stamina recovery rate of the user.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1935.0000,1,354425,0),(353285,351121,'Complex Cardiac Regulator','Increases max stamina and stamina recovery rate of the user.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,3150.0000,1,354425,0),(353289,350858,'Militia MT-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,5505.0000,1,355465,0),(353317,351648,'Large Blaster Operation','Skill at operating large blaster turrets.\r\r\n\r\r\nUnlocks access to standard large blasters at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,149000.0000,1,353715,0),(353318,351648,'Large Blaster Proficiency','Advanced skill at operating large blaster turrets.\r\r\n\r\r\n+10% to large blaster rotation speed per level.',0,0.01,0,1,NULL,567000.0000,1,353715,0),(353322,351648,'Large Missile Launcher Operation','Skill at operating large missile launcher turrets.\r\r\n\r\r\nUnlocks access to standard large missile launchers at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,149000.0000,1,353715,0),(353323,351648,'Large Missile Launcher Proficiency','Advanced skill at operating large missile launcher turrets.\r\r\n\r\r\n+10% to large missile launcher rotation speed per level.',0,0.01,0,1,NULL,567000.0000,1,353715,0),(353326,351648,'Small Blaster Operation','Skill at operating small blaster turrets.\r\r\n\r\r\nUnlocks access to standard small blasters at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,149000.0000,1,353715,0),(353327,351648,'Small Blaster Proficiency','Advanced skill at operating small blaster turrets.\r\r\n\r\r\n+10% to small blaster rotation speed per level.',0,0.01,0,1,NULL,567000.0000,1,353715,0),(353330,351648,'Small Missile Launcher Operation','Skill at operating small missile launcher turrets.\r\r\n\r\r\nUnlocks access to standard small missile launchers at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,149000.0000,1,353715,0),(353331,351648,'Small Missile Launcher Proficiency','Advanced skill at operating small missile launcher turrets.\r\r\n\r\r\n+10% to small missile launcher rotation speed per level.',0,0.01,0,1,NULL,567000.0000,1,353715,0),(353335,351648,'Turret Operation','Skill at operating vehicle turrets.\r\r\n\r\r\nUnlocks skills that can be trained to operate vehicle turrets.',0,0.01,0,1,NULL,48000.0000,1,353715,0),(353336,351648,'Vehicle Turret Upgrades','Basic understanding of turret upgrades.\r\r\n\r\r\nUnlocks the ability to use modules that alter turret functionality. Basic variants at lvl.1; enhanced at lvl.3; complex at lvl.5.',0,0.01,0,1,NULL,66000.0000,1,353716,0),(353352,351648,'Dropsuit Electronics','Basic understanding of dropsuit electronics.\r\r\n\r\r\nUnlocks the ability to use electronics modules.\r\r\n\r\r\n+5% bonus to dropsuit CPU output per level.',0,0.01,0,1,NULL,567000.0000,1,353708,0),(353353,351648,'Vehicle Electronics','Basic understanding of vehicle electronic systems.\r\r\n\r\r\nUnlocks access to scanner modules. Basic variants at lvl.1; enhanced at lvl.3; complex at lvl.5.\r\r\n',0,0.01,0,1,NULL,66000.0000,1,365001,0),(353357,351648,'Profile Analysis','Basic understanding of scan profiles. \r\n\r\nUnlocks the ability to use precision enhancer modules.\r\n\r\n-5% dropsuit scan precision per level.',0,0.01,0,1,NULL,203000.0000,0,NULL,0),(353363,351648,'Drop Uplink Deployment','Skill at drop uplink deployment.\r\r\n\r\r\nUnlocks access to standard drop uplinks at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,149000.0000,1,353708,0),(353365,351648,'Long Range Scanning','Understanding of operating vehicle scanning systems.\r\r\nUnlocks ability to use range amplifier modules. \r\r\n+2% bonus to vehicle scan radius per level.',0,0.01,0,1,NULL,99000.0000,0,NULL,0),(353366,351648,'Dropsuit Engineering','Basic understanding of dropsuit engineering.\r\r\n\r\r\n+5% to dropsuit maximum powergrid (PG) output per level.',0,0.01,0,1,NULL,567000.0000,1,353708,0),(353368,351648,'Vehicle Engineering','Basic understanding of vehicle engineering.\r\r\n\r\r\nUnlocks access to mobile CRU (Clone Reanimation Unit) modules. Basic variants at lvl.1; enhanced at lvl.3; complex at lvl.5.',0,0.01,0,1,NULL,66000.0000,1,365001,0),(353369,351648,'Active Shield Enhancement','Basic understanding of active shield module management.\r\r\n\r\r\n+5% to active duration of vehicle shield modules per level.',0,0.01,0,1,NULL,99000.0000,0,NULL,0),(353370,351648,'Dropsuit Shield Upgrades','Basic understanding of dropsuit shield enhancement.\r\n\r\nUnlocks the ability to use shield modules.\r\n\r\n+5% to dropsuit maximum shield per level.',0,0.01,0,1,NULL,66000.0000,1,353708,0),(353371,351648,'Shield Boost Systems','Base skill for shield booster operation.\r\r\n\r\r\nUnlocks the ability to use shield booster modules.\r\r\n\r\r\n+3% vehicle shield recharge rate per level.',0,0.01,0,1,NULL,149000.0000,1,NULL,0),(353372,351648,'Remote Shield Modulation','Basic understanding of remote shield boosting systems.\r\r\n\r\r\n+5% to maximum repair distance of vehicle remote shield modules per level.',0,0.01,0,1,NULL,99000.0000,0,NULL,0),(353373,351648,'Shield Recharging','Advanced understanding of dropsuit shield recharging.\r\r\n\r\r\nUnlocks access to shield recharger dropsuit modules.\r\r\n\r\r\n+3% to shield recharger module efficacy per level.',0,0.01,0,1,NULL,149000.0000,1,353708,0),(353375,351648,'Dropsuit Armor Upgrades','Basic understanding of dropsuit armor augmentation.\r\n\r\nUnlocks the ability to use armor modules.\r\n\r\n+5% to dropsuit maximum armor per level.',0,0.01,0,1,NULL,66000.0000,1,353708,0),(353376,351648,'Armor Repair Systems','Advanced understanding of dropsuit armor repair.\r\r\n\r\r\nUnlocks access to armor repairer dropsuit modules.\r\r\n\r\r\n+5% to armor repair module efficacy per level.',0,0.01,0,1,NULL,149000.0000,1,353708,0),(353377,351648,'Remote Armor Repair','Basic understanding of remote armor repair systems.\r\r\n\r\r\n+5% to maximum repair distance of vehicle remote armor modules per level.',0,0.01,0,1,NULL,99000.0000,0,NULL,0),(353378,351648,'Active Armor Enhancement','Basic understanding of active armor module management.\r\r\n\r\r\n+5% to active duration of vehicle armor modules per level.',0,0.01,0,1,NULL,99000.0000,0,NULL,0),(353379,351648,'Armor Plating','Advanced understanding of dropsuit armor augmentation.\r\r\n\r\r\nUnlocks access to armor plate dropsuit modules.\r\r\n\r\r\n+2% to armor plate module efficacy per level.',0,0.01,0,1,NULL,149000.0000,1,353708,0),(353381,351648,'Vehicle Command','Skill at operating vehicle systems.\r\r\n\r\r\nUnlocks skills that can be trained to operate vehicles. ',0,0.01,0,1,NULL,48000.0000,1,353711,0),(353382,351648,'Piloting','Skill at operating aerial vehicle systems.\r\r\nUnlocks skills that can be trained to operate aerial vehicles. ',0,0.01,0,1,NULL,90000.0000,0,NULL,0),(353386,351648,'LAV Operation','Skill at operating Light Attack Vehicles (LAV).\r\r\n\r\r\nUnlocks the ability to use standard LAVs.',0,0.01,0,1,NULL,229000.0000,1,353711,0),(353387,351648,'HAV Operation','Skill at operating Heavy Attack Vehicles (HAV).\r\r\n\r\r\nUnlocks the ability to use standard HAVs.',0,0.01,0,1,NULL,229000.0000,1,353711,0),(353388,351648,'Dropship Operation','Skill at operating dropships.\r\r\n\r\r\nUnlocks the ability to use standard dropships.',0,0.01,0,1,NULL,229000.0000,1,353711,0),(353389,351648,'Gallente HAV','Skill at operating Gallente Heavy Attack Vehicles.\r\r\n\r\r\nUnlocks the ability to use Gallente HAVs.',0,0.01,0,1,NULL,957000.0000,0,NULL,0),(353390,351648,'Gallente Dropship','Skill at operating Gallente dropships.\r\r\n\r\r\nUnlocks the ability to use Gallente dropships.',0,0.01,0,1,NULL,957000.0000,0,NULL,0),(353391,351648,'Gallente LAV','Skill at operating Gallente Light Attack Vehicles.\r\r\n\r\r\nUnlocks the ability to use Gallente LAVs.',0,0.01,0,1,NULL,123000.0000,0,NULL,0),(353393,351648,' ',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(353399,351648,'Caldari Marauder','Skill at operating vehicles specialized in Marauder roles.\r\r\n\r\r\n+4% bonus to turret damage per level.',0,0.01,0,1,NULL,4919000.0000,0,NULL,0),(353405,351648,'Core Grid Management','Basic understanding of vehicle power management.\r\r\n\r\r\n+5% to recharge rate of all active modules per level.',0,0.01,0,1,NULL,567000.0000,1,365001,0),(353408,351648,'Dropsuit Command','Base skill for operating dropsuits. \r\r\n\r\r\nUnlocks Medium suits at lvl.1, Light suits at lvl.2, and Heavy suits at lvl.3.\r\r\n',0,0.01,0,1,NULL,48000.0000,1,353707,0),(353413,351648,'Minmatar Medium Dropsuits','Skill at operating Minmatar Medium dropsuits.\r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,229000.0000,1,353707,0),(353426,351648,'Kinetic Catalyzation','Advanced understanding of dropsuit biotic augmentations.\r\r\n\r\r\nUnlocks the ability to use kinetic catalyzer modules to increase sprinting speed.\r\r\n\r\r\n+1% to kinetic catalyzer module efficacy per level.',0,0.01,0,1,NULL,149000.0000,1,353708,0),(353427,351648,'Cardiac Regulation','Advanced understanding of dropsuit biotic augmentations.\r\r\n\r\r\nUnlocks access to cardiac regulator modules to increase max stamina and stamina recovery rate.\r\r\n\r\r\n+2% to cardiac regulator module efficacy per level.',0,0.01,0,1,NULL,149000.0000,1,353708,0),(353428,351648,'Endurance','Skill at using dropsuit augmentations.\r\r\nUnlocks ability to use cardiac stimulant modules to increase stamina.\r\r\n+5% stamina per level.',0,0.01,0,1,NULL,203000.0000,0,NULL,0),(353435,351648,'Weaponry','Skill at using handheld weapons.\r\r\n\r\r\nUnlocks sidearm weapons at lvl.1, light weapons at lvl.3, and heavy weapons at lvl.5.',0,0.01,0,1,NULL,48000.0000,1,353684,0),(353436,351648,'Sidearm Weapon Upgrade','Skill at sidearm weapon resource management.\r\r\n5% reduction to sidearm CPU usage per level.',0,0.01,0,1,NULL,192000.0000,0,NULL,0),(353437,351648,'Sidearm Weapon Upgrade Proficiency','Advanced skill at sidearm weapon resource management.\r\r\n3% reduction to sidearm CPU usage per level.',0,0.01,0,1,NULL,795000.0000,0,NULL,0),(353438,351648,'Light Weapon Upgrade','Skill at light weapon resource management.\r\r\n5% reduction to light weapon CPU usage per level.',0,0.01,0,1,NULL,270000.0000,0,NULL,0),(353440,351648,'Light Weapon Upgrade Proficiency','Advanced skill at light weapon resource management.\r\r\n3% reduction to light weapon CPU usage per level.',0,0.01,0,1,NULL,1115000.0000,0,NULL,0),(353441,351648,'Heavy Weapon Upgrade','Skill at heavy weapon resource management.\r\r\n5% reduction to heavy weapon CPU usage per level.',0,0.01,0,1,NULL,378000.0000,0,NULL,0),(353443,351648,'Sidearm Weapon Rapid Reload','Skill at rapidly reloading sidearm weapons.\r\r\n+3% bonus to sidearm reload speed per level.',0,0.01,0,1,NULL,72000.0000,0,NULL,0),(353444,351648,'Sidearm Weapon Rapid Reload Proficiency','Advanced skill at rapidly reloading sidearm weapons.\r\r\n+2% bonus to sidearm reload speed per level.',0,0.01,0,1,NULL,417000.0000,0,NULL,0),(353445,351648,'Light Weapon Rapid Reload','Skill at rapidly reloading light weapons.\r\r\n+3% bonus to light weapon reload speed per level.',0,0.01,0,1,NULL,149000.0000,0,NULL,0),(353446,351648,'Light Weapon Rapid Reload Proficiency','Advanced skill at rapidly reloading light weapons.\r\r\n+2% bonus to light weapon reload speed per level.',0,0.01,0,1,NULL,851000.0000,0,NULL,0),(353447,351648,'Heavy Weapon Rapid Reload','Skill at rapidly reloading heavy weapons.\r\r\n+3% bonus to heavy weapon reload speed per level.',0,0.01,0,1,NULL,203000.0000,0,NULL,0),(353448,351648,'Heavy Weapon Rapid Reload Proficiency','Advanced skill at rapidly reloading heavy weapons.\r\r\n+2% bonus to heavy weapon reload speed per level.',0,0.01,0,1,NULL,1161000.0000,0,NULL,0),(353449,351648,'Sidearm Weapon Sharpshooter','Skill at sidearm weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0.01,0,1,NULL,72000.0000,0,NULL,0),(353450,351648,'Sidearm Weapon Sharpshooter Proficiency','Advanced skill at sidearm weapon marksmanship.\r\r\n+3% sidearm maximum effective range per level.',0,0.01,0,1,NULL,417000.0000,0,NULL,0),(353451,351648,'Light Weapon Sharpshooter','Skill at light weapon marksmanship.\r\r\n+5% light weapon maximum effective range per level.',0,0.01,0,1,NULL,149000.0000,0,NULL,0),(353452,351648,'Light Weapon Sharpshooter Proficiency','Advanced skill at light weapon marksmanship.\r\r\n+3% light weapon maximum effective range per level.',0,0.01,0,1,NULL,851000.0000,0,NULL,0),(353453,351648,'Heavy Weapon Sharpshooter','Skill at heavy weapon marksmanship.\r\r\n+5% heavy weapon maximum effective range per level.',0,0.01,0,1,NULL,203000.0000,0,NULL,0),(353454,351648,'Heavy Weapon Sharpshooting Proficiency','Advanced skill at heavy weapon marksmanship.\r\r\n+3% heavy weapons maximum effective range per level.',0,0.01,0,1,NULL,1161000.0000,0,NULL,0),(353455,351648,'Sidearm Weapon Capacity','Skill at sidearm weapon ammunition management.\r\r\n+5% sidearm maximum ammunition capacity per level.',0,0.01,0,1,NULL,72000.0000,0,NULL,0),(353456,351648,'Sidearm Weapon Capacity Proficiency','Advanced skill at sidearm weapon ammunition management.\r\r\n+3% sidearm maximum ammunition capacity per level.',0,0.01,0,1,NULL,417000.0000,0,NULL,0),(353457,351648,'Light Weapon Capacity','Skill at light weapon ammunition management.\r\r\n+5% light weapons maximum ammunition capacity per level.',0,0.01,0,1,NULL,149000.0000,0,NULL,0),(353458,351648,'Light Weapon Capacity Proficiency','Advanced skill at light weapon ammunition management.\r\r\n+3% light weapon maximum ammunition capacity per level.',0,0.01,0,1,NULL,851000.0000,0,NULL,0),(353459,351648,'Heavy Weapon Capacity','Skill at heavy weapon ammunition management.\r\r\n+5% heavy weapons maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,0,NULL,0),(353460,351648,'Heavy Weapon Capacity Proficiency','Advanced skill at heavy weapon ammunition management.\r\r\n+3% maximum ammunition capacity of heavy weapons per level.',0,0.01,0,1,NULL,1161000.0000,0,NULL,0),(353461,351648,'Assault Rifle Operation','Skill at handling assault rifles.\r\n\r\n5% reduction to assault rifle kick per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(353462,351648,'Assault Rifle Proficiency','Skill at handling assault rifles.\r\r\n\r\r\n+3% assault rifle damage against shields per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(353463,351648,'Forge Gun Operation','Skill at handling forge guns.\r\n\r\n5% reduction to forge gun charge time per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(353464,351648,'Forge Gun Proficiency','Skill at handling forge guns.\r\r\n\r\r\n+3% forge gun damage against armor per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(353465,351648,'Laser Rifle Operation','Skill at handling laser rifles.\r\n\r\n5% bonus to laser rifle cooldown speed per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(353466,351648,'Laser Rifle Proficiency','Skill at handling laser rifles.\r\r\n\r\r\n+3% laser rifle damage against shields per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(353467,351648,'Heavy Machine Gun Operation','Skill at handling heavy machine guns.\r\r\n\r\r\n5% bonus to heavy machine gun kick per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(353468,351648,'Heavy Machine Gun Proficiency','Skill at handling heavy machine guns.\r\r\n\r\r\n+3% heavy machine gun damage against armor per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(353469,351648,'Mass Driver Operation','Skill at handling mass drivers.\r\n\r\n+5% mass driver blast radius per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(353470,351648,'Mass Driver Proficiency','Skill at handling mass drivers.\r\r\n\r\r\n+3% mass driver damage against armor per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(353471,351648,'Swarm Launcher Operation','Skill at handling swarm launchers.\r\r\n\r\r\n5% reduction to swarm launcher lock-on time per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(353472,351648,'Swarm Launcher Proficiency','Skill at handling swarm launchers.\r\r\n\r\r\n+3% swarm launcher missile damage against armor per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(353473,351648,'Scrambler Pistol Operation','Skill at handling scrambler pistols.\r\n\r\n+1 scrambler pistol clip size per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(353474,351648,'Scrambler Pistol Proficiency','Skill at handling scrambler pistols.\r\r\n\r\r\n+3% scrambler pistol damage against shields per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(353475,351648,'Sniper Rifle Operation','Skill at handling sniper rifles.\r\r\n\r\r\n5% reduction to sniper rifle scope sway per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(353476,351648,'Sniper Rifle Proficiency','Skill at handling sniper rifles.\r\r\n\r\r\n+3% sniper rifle damage against armor per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(353477,351648,'Submachine Gun Operation','Skill at handling submachine guns.\r\n\r\n5% reduction to submachine gun kick per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(353478,351648,'Submachine Gun Proficiency','Skill at handling submachine guns.\r\r\n\r\r\n+3% submachine gun damage against armor per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(353479,351648,'Hand-to-Hand Combat','Advanced understanding of dropsuit biotic augmentations.\r\r\n\r\r\nUnlocks ability to use myofibril stimulant modules to increase melee damage.\r\r\n\r\r\n+10% to myofibril stimulant module efficacy per level.',0,0.01,0,1,NULL,149000.0000,1,353708,0),(353482,351648,'Demolitions','Skill at handling remote explosives. \r\n\r\nUnlocks access to standard remote explosives at lvl.1; advanced at lvl.3; prototype at lvl.5',0,0.01,0,1,NULL,72000.0000,1,353684,0),(353484,351648,'Grenadier','Skill at handling grenades.\r\n\r\nUnlocks access to standard grenades at lvl.1; advanced at lvl.3; prototype at lvl.5',0,0.01,0,1,NULL,378000.0000,1,353684,0),(353485,351648,'Heavy Weapon Upgrade Proficiency','Advanced skill at heavy weapon resource management.\r\r\n3% reduction to heavy weapon CPU usage per level.',0,0.01,0,1,NULL,1560000.0000,0,NULL,0),(353486,351210,'Onikuma','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,18330.0000,1,355464,0),(353685,351648,'Amarr Heavy Dropsuits','Skill at operating Amarr Heavy dropsuits.\r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,229000.0000,1,353707,0),(353686,351648,'Caldari Medium Dropsuits','Skill at operating Caldari Medium dropsuits.\r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,229000.0000,1,353707,0),(353687,351648,'Gallente Light Dropsuits','Skill at operating Gallente Light dropsuits. \r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,229000.0000,1,353707,0),(353691,350858,'Sleek Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,735.0000,1,363464,0),(353692,350858,'Capped Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,1400.0000,1,NULL,0),(353693,350858,'M1 Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,1200.0000,1,363465,0),(353694,350858,'M8 Packed Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,3225.0000,1,363465,0),(353695,350858,'\'Shroud\' M1 Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,1980.0000,1,363465,0),(353696,350858,'Core Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,14160.0000,1,363466,0),(353697,350858,'Freedom Sleek Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,23190.0000,1,NULL,0),(353698,350858,'\'Cavity\' M2 Contact Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,5280.0000,1,363465,0),(353699,350858,'\'Vapor\' Core Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,5280.0000,1,363466,0),(353701,350858,'Small CA Railgun Installation ','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(353702,350858,'Small Rocket Installation','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(353705,350858,'Small Blaster Installation ','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(353730,350858,'Sleek AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,1230.0000,1,363467,0),(353731,350858,'Packed AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,2010.0000,1,363467,0),(353732,350858,'EX-0 AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,2010.0000,1,363468,0),(353733,350858,'EX-11 Packed AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,8805.0000,1,363468,0),(353734,350858,'\'Hollow\' EX-0 AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,2010.0000,1,363468,0),(353735,350858,'Wiyrkomi AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,8805.0000,1,363469,0),(353736,350858,'Lai Dai Sleek AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,14415.0000,1,363469,0),(353737,350858,'\'Void\' Kaalakiota AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,5385.0000,1,NULL,0),(353738,350858,'\'Sigil\' Wiyrkomi AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,5385.0000,1,363469,0),(353741,350858,'Militia Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor. The Militia variant is standard-issue for all new recruits.',0,0.01,0,1,NULL,180.0000,1,355463,0),(353742,351121,'Militia Shield Extender','Increases maximum strength of dropsuit\'s shields.',0,0.01,0,1,NULL,400.0000,1,355466,0),(353743,351121,'Militia Shield Recharger','Improves the recharge rate of dropsuit\'s shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,550.0000,1,355466,0),(353744,351121,'Militia Cardiac Regulator','Increases max stamina and stamina recovery rate of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,290.0000,1,355466,0),(353748,351844,'Custom Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,1125.0000,1,354414,0),(353749,350858,'Volatile Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,735.0000,1,363464,0),(353759,351064,'Scout G/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(353760,351064,'Scout gk.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,57690.0000,1,354390,0),(353763,351064,'Assault C/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(353764,351064,'Assault ck.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,57690.0000,1,354378,0),(353766,351064,'Sentinel A/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,8040.0000,1,354381,0),(353767,351064,'Sentinel ak.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,57690.0000,1,354382,0),(353768,351064,'Logistics M/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(353769,351064,'Logistics mk.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,57690.0000,1,354386,0),(353772,350858,'80GJ Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,105240.0000,1,356972,0),(353773,350858,'80GJ Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,281955.0000,1,356973,0),(353774,350858,'20GJ Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,16873.5000,1,356969,0),(353775,350858,'20GJ Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,74014.5000,1,356970,0),(353783,350858,'80GJ Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,281955.0000,1,356978,0),(353796,350858,'20GJ Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,16873.5000,1,356980,0),(353797,350858,'20GJ Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,74014.5000,1,356981,0),(353800,350858,'AT-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,16873.5000,1,356964,0),(353801,350858,'XT-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,74014.5000,1,356965,0),(353808,351210,'Baloch','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,18330.0000,1,355464,0),(353817,350858,'XT-201 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,281955.0000,1,356962,0),(353818,350858,'AT-201 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,105240.0000,1,356961,0),(353832,351210,'Surya','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies.\r\r\nThe Marauder class pushes its power plant to the limit, achieving improved damage output and excellent protection from its greatly enhanced armor. \r\r\n\r\r\n+4% bonus to Large Blaster turret damage per level.',0,0.01,0,1,NULL,1227600.0000,1,NULL,0),(353879,351210,'Eryx','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.\r\r\n\r\r\nThe Logistics class is the ultimate troop transport. A vehicle that, thanks to its on-board Clone Reanimation Unit (CRU), redefines the notion of frontline troop insertion.',0,0.01,0,1,NULL,301395.0000,1,NULL,0),(353881,351210,'Prometheus','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.\r\r\n\r\r\nThe Logistics class is the ultimate troop transport. A vehicle that, thanks to its on-board Clone Reanimation Unit (CRU), redefines the notion of frontline troop insertion.',0,0.01,0,1,NULL,301395.0000,1,NULL,0),(353884,351210,'Python','The Dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm s way.\r\r\n\r\r\nThe Assault class is a low-level aerial attack craft. Its light frame makes it highly maneuverable, while the front-mounted pilot-controlled turret gives it a significant advantage in aerial engagements. \r\r\n',0,0,0,1,NULL,200000.0000,1,364768,0),(353886,351210,'Incubus','The Dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm s way.\r\r\n\r\r\nThe Assault class is a low-level aerial attack craft. Its light frame makes it highly maneuverable, while the front-mounted pilot-controlled turret gives it a significant advantage in aerial engagements. \r\r\n',0,0,0,1,NULL,200000.0000,1,364768,0),(353900,351210,'Charybdis','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.\r\r\n\r\r\nThe Logistics class is equipped with superior armor and shield plating allowing it to withstand more punishment. Additionally, each Logistics LAV comes with a built-in special edition infantry repair tool, allowing it to support multiple allies at the same time. This particular model comes with built-in remote shield boosting functionality.',0,0.01,0,1,NULL,84000.0000,1,NULL,0),(353904,351210,'Limbus','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.\r\r\n\r\r\nThe Logistics is equipped with superior armor and shield plating allowing it to withstand more punishment. Additionally, each Logistics LAV comes with a built-in special edition infantry repair tool, allowing it to support multiple allies at the same time. This particular model comes with built-in remote armor repairing functionality.',0,0.01,0,1,NULL,84000.0000,1,NULL,0),(353907,351121,'Logistics LAV Mass Remote Repairer (S)','Repairs armor of targeted entity.\r\r\nModule Type: Active\r\r\nRepaire Rate: 150AP/1s\r\r\nCooldown Time: 0\r\r\nPG Cost: 0\r\r\nCPU Cost: 0',0,0.01,0,1,NULL,24000.0000,1,NULL,0),(353919,351121,'Remote Shield Booster (S)','Boosts shields of targeted entity. (Vehicles only)\r\r\n\r\r\nModule Type: Active\r\r\nBoost Rate: 50SP/s\r\r\nDuration: 10s\r\r\nCooldown Time: 10s\r\r\nPG Cost: 50\r\r\nCPU Cost: 30',0,0.01,0,1,NULL,24000.0000,1,NULL,0),(353929,350858,'Militia Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\r\n \r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,270.0000,1,355463,0),(353931,351121,'Militia Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.',0,0.01,0,1,NULL,370.0000,1,355466,0),(353932,351121,'Militia Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0.01,0,1,NULL,520.0000,1,355466,0),(353933,351121,'Militia Light Damage Modifier','Increases damage output of all light handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,520.0000,1,355466,0),(353934,351121,'Militia Kinetic Catalyzer','Increases sprinting speed of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,270.0000,1,355466,0),(353935,351121,'Militia Cardiac Stimulant','Increases maximum stamina of the user.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced.',0,0.01,0,1,NULL,450.0000,1,354425,0),(353936,351121,'Militia Myofibril Stimulant','Increases damage done by melee attacks.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,320.0000,1,355466,0),(353959,351064,'\'Carbon\' Assault C-I','Aside from its designation as  Project Zero , little is known about the Carbon suit. Rumor has it that the suit is a first-generation failure, progenitor tech designed to adapt to and merge with the user s neural network over time. Usage of the suit is not recommended and prolonged exposure to be avoided pending verification of the claims.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(353960,351064,'\'Carbon\' Assault C/1-Series','Aside from its designation as  Project Zero , little is known about the Carbon suit. Rumor has it that the suit is a first-generation failure, progenitor tech designed to adapt to and merge with the user s neural network over time. Usage of the suit is not recommended and prolonged exposure to be avoided pending verification of the claims.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(353961,351064,'\'Kindred\' Scout G-I','Last seen more than a hundred years ago, the Kindred were believed dead, but the emergence of their colors amongst the ranks of cloned soldiers has caused many to question those assumptions. Is it really them? Why have they returned? And most importantly, to what end?',0,0.01,0,1,NULL,3000.0000,1,354388,0),(353962,351064,'\'Carbon\' Assault ck.0','Aside from its designation as  Project Zero , little is known about the Carbon suit. Rumor has it that the suit is a first-generation failure, progenitor tech designed to adapt to and merge with the user s neural network over time. Usage of the suit is not recommended and prolonged exposure to be avoided pending verification of the claims.',0,0.01,0,1,NULL,21540.0000,1,354378,0),(353963,351064,'\'Firebrand\' Assault C-I','Gold-plated and as bright as a newborn star, the Firebrand is designed for the mercenary who\'s as confident in his skills as he is unconcerned about sacrificing the element of surprise. Traditionalists may scoff at the sheer excess of such a suit, but, well, who really cares what anybody else thinks?',0,0.01,0,1,NULL,3000.0000,1,354376,0),(353964,351064,'\'Firebrand\' Assault C/1-Series','Gold-plated and as bright as a newborn star, the Firebrand is designed for the mercenary who\'s as confident in his skills as he is unconcerned about sacrificing the element of surprise. Traditionalists may scoff at the sheer excess of such a suit, but, well, who really cares what anybody else thinks?',0,0.01,0,1,NULL,8040.0000,1,354377,0),(353965,351064,'\'Firebrand\' Assault ck.0','Gold-plated and as bright as a newborn star, the Firebrand is designed for the mercenary who\'s as confident in his skills as he is unconcerned about sacrificing the element of surprise. Traditionalists may scoff at the sheer excess of such a suit, but, well, who really cares what anybody else thinks?',0,0.01,0,1,NULL,21540.0000,1,354378,0),(353966,351064,'\'Kindred\' Scout G/1-Series','Last seen more than a hundred years ago, the Kindred were believed dead, but the emergence of their colors amongst the ranks of cloned soldiers has caused many to question those assumptions. Is it really them? Why have they returned? And most importantly, to what end?',0,0.01,0,1,NULL,8040.0000,1,354389,0),(353967,351064,'\'Kindred\' Scout gk.0','Last seen more than a hundred years ago, the Kindred were believed dead, but the emergence of their colors amongst the ranks of cloned soldiers has caused many to question those assumptions. Is it really them? Why have they returned? And most importantly, to what end?',0,0.01,0,1,NULL,21540.0000,1,354390,0),(353974,351064,'\'Solstice\' Scout G-I','I do not question. I do not hesitate. I am an agent of change, as immutable as time itself. Fate is my shadow and will, my weapon. And on this day as you stare into my eyes and plead for mercy, you will know my name.\r\r\nThis is my promise.',0,0.01,0,1,NULL,3000.0000,1,354388,0),(353975,351064,'\'Orchid\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient equipment hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier\'s strength, balance, and resistance to impact forces. The suit\'s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. Furthermore, every armor plate on the suit is energized to absorb the force of incoming plasma-based projectiles, neutralizing their ionization and reducing thermal damage.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment\'s notice. Its ability to carry anything from small arms and explosives to heavy anti-vehicle munitions and deployable support gear makes it the most adaptable suit on the battlefield.',0,0.01,0,1,NULL,6800.0000,1,354376,0),(353980,351121,'Enhanced Heavy Armor Repairer','Passively repairs damage done to the vehicle\'s armor.',0,0.01,0,1,NULL,24105.0000,1,363441,0),(353981,351121,'Complex Heavy Armor Repairer','Passively repairs damage done to the vehicle\'s armor.',0,0.01,0,1,NULL,39465.0000,1,363441,0),(353982,351121,'Heavy Automated Armor Repair Unit','Once activated this module repairs the damage done to the vehicle s armor.',0,0.01,0,1,NULL,97160.0000,1,NULL,0),(353983,351121,'Enhanced Light Armor Repairer','Passively repairs damage done to the vehicle\'s armor.',0,0.01,0,1,NULL,14070.0000,1,363440,0),(353984,351121,'Complex Light Armor Repairer','Passively repairs damage done to the vehicle\'s armor.',0,0.01,0,1,NULL,23025.0000,1,363440,0),(353985,351121,'Light Automated Armor Repair Unit','Once activated this module repairs the damage done to the vehicle s armor.',0,0.01,0,1,NULL,48560.0000,1,NULL,0),(353986,351121,'Heavy Remote Armor Repair Unit I','Once activated this module repairs the damage done to the targeted vehicle s armor.',0,0.01,0,1,NULL,32000.0000,1,NULL,0),(353987,351121,'Heavy Remote IG-R Polarized Armor Regenerator','Once activated, repairs damage done to the targeted vehicle\'s armor.',0,0.01,0,1,NULL,46320.0000,1,NULL,0),(353988,351121,'Heavy Remote Efficient Armor Repair Unit','Once activated this module repairs the damage done to the targeted vehicle s armor.',0,0.01,0,1,NULL,67080.0000,1,NULL,0),(353989,351121,'Heavy Remote Automated Armor Repair Unit','Once activated this module repairs the damage done to the targeted vehicle s armor.',0,0.01,0,1,NULL,97160.0000,1,NULL,0),(353990,351121,'Light Remote IG-R Polarized Armor Regenerator','Once activated, repairs damage done to the targeted vehicle\'s armor.',0,0.01,0,1,NULL,23160.0000,1,NULL,0),(353991,351121,'Light Remote Efficient Armor Repair Unit','Once activated this module repairs the damage done to the targeted vehicle s armor.',0,0.01,0,1,NULL,33560.0000,1,NULL,0),(353992,351121,'Light Remote Automated Armor Repair Unit','Once activated this module repairs the damage done to the targeted vehicle s armor.',0,0.01,0,1,NULL,48560.0000,1,NULL,0),(353994,351064,'\'Relic\' Assault C-I','The Siege of Tikraul is a stain on our history. An avoidable tragedy made worse by the apathy of every generation born hence. Rather than honor the fallen, most would rather pretend it never happened. They would have you forget. I will not. I wear their colors in remembrance, in deference and in defiance. Coated in the blood of my enemy, they will enjoy, in death, the victory denied them in life.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(354003,351064,'\'Relic\' Assault C/1-Series','The Siege of Tikraul is a stain on our history. An avoidable tragedy made worse by the apathy of every generation born hence. Rather than honor the fallen, most would rather pretend it never happened. They would have you forget. I will not. I wear their colors in remembrance, in deference and in defiance. Coated in the blood of my enemy, they will enjoy, in death, the victory denied them in life.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(354005,351064,'\'Relic\' Assault ck.0','The Siege of Tikraul is a stain on our history. An avoidable tragedy made worse by the apathy of every generation born hence. Rather than honor the fallen, most would rather pretend it never happened. They would have you forget. I will not. I wear their colors in remembrance, in deference and in defiance. Coated in the blood of my enemy, they will enjoy, in death, the victory denied them in life.',0,0.01,0,1,NULL,21540.0000,1,354378,0),(354007,351064,'\'Hazard\' Logistics M-I','Patterned after the uniform worn by Group-5, a regiment of first responders who lost their lives when the plasma wave struck Seyllin I and destroyed the planet, those who wear this suit pay tribute not just to them, but to all who lost their lives in one of the darkest moments in New Eden\'s history.',0,0.01,0,1,NULL,4905.0000,1,354384,0),(354011,351121,'Militia CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,490.0000,1,355466,0),(354012,351121,'Militia PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,490.0000,1,355466,0),(354106,351844,'Militia Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,370.0000,1,355468,0),(354107,351844,'Militia Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\n\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,370.0000,1,355468,0),(354108,351844,'Militia Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\r\n\r\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,460.0000,1,355468,0),(354122,351121,'Heavy Converse Shield Transporter','Once activated this module recharges the targeted vehicle s shields.',0,0.01,0,1,NULL,46320.0000,1,NULL,0),(354123,351121,'Heavy Clarity Ward Shield Transporter','Once activated this module recharges the targeted vehicle s shields.',0,0.01,0,1,NULL,67080.0000,1,NULL,0),(354124,351121,'Heavy C5-R Shield Transporter','Once activated this module recharges the targeted vehicle s shields.',0,0.01,0,1,NULL,97160.0000,1,NULL,0),(354125,351121,'Light Shield Transporter I','Once activated this module recharges the targeted vehicle s shields.',0,0.01,0,1,NULL,16000.0000,1,NULL,0),(354126,351121,'Light Converse Shield Transporter','Once activated this module recharges the targeted vehicle s shields.',0,0.01,0,1,NULL,23160.0000,1,NULL,0),(354127,351121,'Light C3-R Shield Transporter','Once activated this module recharges the targeted vehicle s shields.',0,0.01,0,1,NULL,48560.0000,1,NULL,0),(354128,351121,'Light Clarity Ward Shield Transporter','Once activated this module recharges the targeted vehicle s shields.',0,0.01,0,1,NULL,33560.0000,1,NULL,0),(354129,351121,'Enhanced Light Shield Booster','Once activated, this module instantly recharges a portion of the vehicle\'s shield HP.',0,0.01,0,1,NULL,14070.0000,1,363448,0),(354130,351121,'Complex Light Shield Booster','Once activated, this module instantly recharges a portion of the vehicle\'s shield HP.',0,0.01,0,1,NULL,23025.0000,1,363448,0),(354131,351121,'Light C3-L Shield Booster','Once activated this module provides an instant boost to the vehicle s shields.',0,0.01,0,1,NULL,48560.0000,1,NULL,0),(354132,351121,'Enhanced Heavy Shield Booster','Once activated, this module instantly recharges a portion of the vehicle\'s shield HP.',0,0.01,0,1,NULL,24105.0000,1,363449,0),(354133,351121,'Basic Heavy Shield Booster','Once activated, this module instantly recharges a portion of the vehicle\'s shield HP.',0,0.01,0,1,NULL,9000.0000,1,363449,0),(354134,351121,'Complex Heavy Shield Booster','Once activated, this module instantly recharges a portion of the vehicle\'s shield HP.',0,0.01,0,1,NULL,39465.0000,1,363449,0),(354135,351121,'Heavy C5-L Shield Booster','Once activated this module provides an instant boost to the vehicle s shields.',0,0.01,0,1,NULL,97160.0000,1,NULL,0),(354140,351121,'Energized Nanite Plating','Passively reduces damage done to the vehicle\'s armor. -11% damage taken to armor hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,8680.0000,1,NULL,0),(354141,351121,'Voltaic Energized Plating','Passively reduces damage done to the vehicle\'s armor.  -15% damage taken to armor hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,12560.0000,1,NULL,0),(354142,351121,'N-Type Energized Plating','Passively reduces damage done to the vehicle\'s armor. -14% damage taken to armor hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,18200.0000,1,NULL,0),(354147,351121,'Shield Resistance Amplifier I','Increases the damage resistance of the vehicle\'s shields. -10% damage taken to shield hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,6000.0000,1,NULL,0),(354148,351121,'Supplemental Shield Amplifier','Increases the damage resistance of the vehicle\'s shields. -11% damage taken to shield hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,8680.0000,1,NULL,0),(354149,351121,'Ward Shield Amplifier','Increases the damage resistance of the vehicle\'s shields. -15% damage taken to shield hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,12560.0000,1,NULL,0),(354150,351121,'F-S3 Shield Amplifier','Increases the damage resistance of the vehicle\'s shields. -14% damage taken to shield hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,18200.0000,1,NULL,0),(354151,351121,'Enhanced Heavy Shield Extender','Increases maximum strength of vehicle\'s shields but increases the shield depleted recharge delay.',0,0.01,0,1,NULL,24105.0000,1,363456,0),(354152,351121,'Complex Heavy Shield Extender','Increases maximum strength of vehicle\'s shields but increases the shield depleted recharge delay.',0,0.01,0,1,NULL,39465.0000,1,363456,0),(354153,351121,'Heavy F-S5 Regolith Shield Extender','Increases maximum strength of the vehicle\'s shields.',0,0.01,0,1,NULL,97160.0000,1,NULL,0),(354154,351121,'Enhanced Light Shield Extender','Increases maximum strength of vehicle\'s shields but increases the shield depleted recharge delay.',0,0.01,0,1,NULL,14070.0000,1,363457,0),(354155,351121,'Complex Light Shield Extender','Increases maximum strength of vehicle\'s shields but increases the shield depleted recharge delay.',0,0.01,0,1,NULL,23025.0000,1,363457,0),(354156,351121,'F-S3 Regolith Shield Extender','Increases maximum strength of the vehicle\'s shields.',0,0.01,0,1,NULL,48560.0000,1,NULL,0),(354158,351121,'Systemic Vortex Stabilizer','Increases the damage output of all vehicle mounted railgun and blaster turrets.  Grants 4% bonus to hybrid turret damage, and a 3% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,36240.0000,1,NULL,0),(354159,351121,'Systemic Field Stabilizer II','Increases the damage output of all vehicle mounted railgun and blaster turrets.  Grants 6% bonus to hybrid turret damage, and a 5% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,52480.0000,1,NULL,0),(354160,351121,'Systemic Stabilizer Array','Increases the damage output of all vehicle mounted railgun and blaster turrets.  Grants 6% bonus to hybrid turret damage, and a 5% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354169,351121,'Damage Control Unit I','When activated this module grants a moderate increase to damage resistance of vehicle\'s shields and armor.  Shield damage -5%, Armor damage -5%.\r\r\n\r\r\nNOTE: Only one damage control unit can be fitted at a time.  Bonuses are only applied when the module is active.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,14000.0000,1,NULL,0),(354170,351121,'Crisis Damage Control Unit','When activated this module grants a moderate increase to damage resistance of vehicle\'s shields and armor.  Shield damage -6%, Armor damage -6%.\r\r\n\r\r\nNOTE: Only one damage control unit can be fitted at a time.  Bonuses are only applied when the module is active.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,20280.0000,1,NULL,0),(354171,351121,'F45 Peripheral Damage Control Unit','When activated this module grants a moderate increase to damage resistance of vehicle\'s shields and armor.  Shield damage -9%, Armor damage -9%.\r\r\n\r\r\nNOTE: Only one damage control unit can be fitted at a time.  Bonuses are only applied when the module is active.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,29360.0000,1,NULL,0),(354172,351121,'Electron Damage Control Unit','When activated this module grants a moderate increase to damage resistance of vehicle\'s shields and armor.  Shield damage -8%, Armor damage -8%.\r\r\n\r\r\nNOTE: Only one damage control unit can be fitted at a time.  Bonuses are only applied when the module is active.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,42520.0000,1,NULL,0),(354173,351121,'Enhanced Scanner','Once activated, this module will reveal the location of enemy units within its active radius provided it\'s precise enough to detect the unit\'s scan profile.',0,0.01,0,1,NULL,16080.0000,1,356916,0),(354174,351121,'Complex Scanner','Once activated, this module will reveal the location of enemy units within its active radius provided it\'s precise enough to detect the unit\'s scan profile.',0,0.01,0,1,NULL,26310.0000,1,356916,0),(354175,351121,'Type-G Active Scanner','The active scanner reveals enemy units within its scan radius provided it\'s precise enough to pick up the enemies scan profile.',0,0.01,0,1,4,10575.0000,1,NULL,0),(354176,351121,'Enhanced 60mm Armor Plates','Increases maximum strength of vehicle\'s armor but the increased mass affects acceleration and top speed.',0,0.01,0,1,NULL,14070.0000,1,363306,0),(354177,351121,'Complex 60mm Armor Plates','Increases maximum strength of vehicle\'s armor but the increased mass affects acceleration and top speed.',0,0.01,0,1,NULL,23025.0000,1,363306,0),(354178,351121,'60mm Reinforced Type-A Plates','Increases maximum strength of vehicle\'s armor, but the increased mass reduces top speed.',0,0.01,0,1,NULL,48560.0000,1,NULL,0),(354179,351121,'Enhanced 120mm Armor Plates','Increases maximum strength of vehicle\'s armor but the increased mass affects acceleration and top speed.',0,0.01,0,1,NULL,24105.0000,1,363305,0),(354180,351121,'Complex 120mm Armor Plates','Increases maximum strength of vehicle\'s armor but the increased mass affects acceleration and top speed.',0,0.01,0,1,NULL,39465.0000,1,363305,0),(354181,351121,'120mm Reinforced Type-A Plates','Increases maximum strength of vehicle\'s armor, but the increased mass reduces top speed.',0,0.01,0,1,NULL,97160.0000,1,NULL,0),(354182,351121,'180mm Reinforced Steel Plates','Increases maximum strength of vehicle\'s armor, but the increased mass reduces top speed.',0,0.01,0,1,NULL,32000.0000,1,NULL,0),(354183,351121,'180mm Reinforced Nanofibre Plates','Increases maximum strength of vehicle\'s armor, but the increased mass reduces top speed.',0,0.01,0,1,NULL,46320.0000,1,NULL,0),(354184,351121,'180mm Reinforced Polycrystalline Plates','Increases maximum strength of vehicle\'s armor, but the increased mass reduces top speed. ',0,0.01,0,1,NULL,67080.0000,1,NULL,0),(354185,351121,'180mm Reinforced Type-A Plates','Increases maximum strength of vehicle\'s armor, but the increased mass reduces top speed. ',0,0.01,0,1,NULL,97160.0000,1,NULL,0),(354186,351121,'Modified P-Type Nanofiber','Increases vehicle speed at the cost of reduced armor strength. Top speed +13%, Armor HP -11%.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,8680.0000,1,NULL,0),(354187,351121,'Altered M-Type Nanofiber ','Increases vehicle speed at the cost of reduced armor strength.  Top speed +15%, Armor hp -16%\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,12560.0000,1,NULL,0),(354188,351121,'Type-G Nanofibre Internal Structure','Increases vehicle speed at the cost of reduced armor strength.  Top speed +14%, Armor HP -13%.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,18200.0000,1,NULL,0),(354192,351064,'\'Colossus\' Sentinel A-I','The Colossus was part of a hijacked shipment that has since found its way onto the open market. The Angel Cartel has made it known that it will hunt down those responsible and recover every last unit that was part of that shipment. Those brave enough to wear this suit do so knowing that it\'s only a matter of time...',0,0.01,0,1,NULL,3000.0000,1,354380,0),(354234,351064,'\'Solstice\' Scout G/1-Series','I do not question. I do not hesitate. I am an agent of change, as immutable as time itself. Fate is my shadow and will, my weapon. And on this day as you stare into my eyes and plead for mercy, you will know my name.\r\r\nThis is my promise.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(354235,351064,'\'Solstice\' Scout gk.0','I do not question. I do not hesitate. I am an agent of change, as immutable as time itself. Fate is my shadow and will, my weapon. And on this day as you stare into my eyes and plead for mercy, you will know my name.\r\r\nThis is my promise.',0,0.01,0,1,NULL,21540.0000,1,354390,0),(354237,351064,'\'Oblivion\' Logistics M-I','No-one understands the complexities of the battlefield better than those who choose to walk the line between healer and murderer. Mercy and death are often one and the same, and those who wear this suit understand that both can be granted with a bullet.',0,0.01,0,1,NULL,4905.0000,1,354384,0),(354251,351064,'\'Colossus\' Sentinel A/1-Series','The Colossus was part of a hijacked shipment that has since found its way onto the open market. The Angel Cartel has made it known that it will hunt down those responsible and recover every last unit that was part of that shipment. Those brave enough to wear this suit do so knowing that it\'s only a matter of time...',0,0.01,0,1,NULL,8040.0000,1,354381,0),(354252,351064,'\'Colossus\' Sentinel ak.0','The Colossus was part of a hijacked shipment that has since found its way onto the open market. The Angel Cartel has made it known that it will hunt down those responsible and recover every last unit that was part of that shipment. Those brave enough to wear this suit do so knowing that it\'s only a matter of time...',0,0.01,0,1,NULL,21540.0000,1,354382,0),(354264,351121,'Shield Regenerator I','Improves the recharge rate of the vehicle\'s shields. Increases shield regeneration rate by 15%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,6000.0000,1,NULL,0),(354265,351121,'Supplemental Shield Regenerator','Improves the recharge rate of the vehicle\'s shields. Increases shield regeneration rate by 14%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,8680.0000,1,NULL,0),(354266,351121,'Ward Shield Regenerator','Improves the recharge rate of the vehicle\'s shields. Increases shield regeneration rate by 19%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,12560.0000,1,NULL,0),(354267,351121,'M42 Shield Regenerator','Improves the recharge rate of the vehicle\'s shields. Increases shield regeneration rate by 18%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module affecting similar attributes after the first will be reduced. ',0,0.01,0,1,NULL,18200.0000,1,NULL,0),(354271,351064,'\'Anasoma\' Sentinel A-I','For anyone who grew up hearing the tales of the warrior Anasoma, this suit is the embodiment of their childhood nightmares. The story tells of how the fearless Anasoma was betrayed and captured. Before killing him, his torturers melted his famous battle armor to his flesh. It is said that he now roams the battlefields of New Eden searching for his betrayers.',0,0.01,0,1,NULL,3000.0000,1,354380,0),(354272,351064,'\'Anasoma\' Sentinel A/1-Series','For anyone who grew up hearing the tales of the warrior Anasoma, this suit is the embodiment of their childhood nightmares. The story tells of how the fearless Anasoma was betrayed and captured. Before killing him, his torturers melted his famous battle armor to his flesh. It is said that he now roams the battlefields of New Eden searching for his betrayers.',0,0.01,0,1,NULL,8040.0000,1,354381,0),(354273,351064,'\'Anasoma\' Sentinel ak.0','For anyone who grew up hearing the tales of the warrior Anasoma, this suit is the embodiment of their childhood nightmares. The story tells of how the fearless Anasoma was betrayed and captured. Before killing him, his torturers melted his famous battle armor to his flesh. It is said that he now roams the battlefields of New Eden searching for his betrayers.',0,0.01,0,1,NULL,21540.0000,1,354382,0),(354274,351064,'\'Oblivion\' Logistics M/1-Series','No-one understands the complexities of the battlefield better than those who choose to walk the line between healer and murderer. Mercy and death are often one and the same, and those who wear this suit understand that both can be granted with a bullet.',0,0.01,0,1,NULL,12160.0000,1,354385,0),(354275,351064,'\'Oblivion\' Logistics mk.0','No-one understands the complexities of the battlefield better than those who choose to walk the line between healer and murderer. Mercy and death are often one and the same, and those who wear this suit understand that both can be granted with a bullet.',0,0.01,0,1,NULL,53640.0000,1,354386,0),(354277,351064,'\'Hazard\' Logistics mk.0','Patterned after the uniform worn by Group-5, a regiment of first responders who lost their lives when the plasma wave struck Seyllin I and destroyed the planet, those who wear this suit pay tribute not just to them, but to all who lost their lives in one of the darkest moments in New Eden\'s history.',0,0.01,0,1,NULL,53640.0000,1,354386,0),(354317,351064,'\'Hazard\' Logistics M/1-Series','Patterned after the uniform worn by Group-5, a regiment of first responders who lost their lives when the plasma wave struck Seyllin I and destroyed the planet, those who wear this suit pay tribute not just to them, but to all who lost their lives in one of the darkest moments in New Eden\'s history.',0,0.01,0,1,NULL,12160.0000,1,354385,0),(354583,350858,'Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,1500.0000,1,354696,0),(354626,351844,'[TEST] Shield Gen 2','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,2800.0000,1,NULL,0),(354627,351844,'[TEST] Shield Gen 1','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,2800.0000,1,NULL,0),(354643,354641,'Active Booster (1-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(354644,354641,'Active Booster (7-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(354664,351844,'Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\n\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,600.0000,1,364492,0),(354667,351121,'Basic Profile Dampener','Decreases dropsuit\'s scan profile making it harder to detect by scanning systems.',0,0.01,0,1,NULL,780.0000,1,354671,0),(354669,351121,'Basic Precision Enhancer','Improves dropsuit\'s scan precision making it easier to detect nearby enemy signals.',0,0.01,0,1,NULL,825.0000,1,354671,0),(354685,350858,'Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,1500.0000,1,354690,0),(354714,351844,'Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\n\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,1500.0000,1,355187,0),(354741,351210,'Cestus','MCC needs a description',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354742,351210,'Charron','MCC needs a description',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354764,354753,'Command Node','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354765,354753,'Command Node ','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354767,354753,'Clone Reanimation Unit','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354770,354753,'Defense Relay','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354772,354753,'Supply Depot','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354773,354753,'[TEST] Drone Hive','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354789,354753,'Large Blaster Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354790,354753,'Small Blaster Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354791,354753,'Large CA Railgun Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354792,354753,'Small CA Railgun Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354793,354753,'Large GA Railgun Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354794,354753,'Small GA Railgun Installation ','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354796,354753,'Large Missile Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354797,354753,'Small Missile Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354824,354753,'Primary Console','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354826,354753,'Security Console','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354827,354753,'Anti-MCC Turret Console','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354850,354753,'Clone Reanimation Unit ','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354851,354753,'Defense Relay ','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354852,354753,'Supply Depot ','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354856,354753,'Small Missile Installation ','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354857,354753,'Small GA Railgun Installation ','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354858,354753,'Small CA Railgun Installation ','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354859,354753,'Small Blaster Installation ','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354867,351121,'Squad - Armor Bonus Test','Test Module, Give bonus to squads armor HP.',0,0.01,0,1,NULL,500.0000,1,NULL,0),(354869,351121,'Vehicle Shield Recharger','Test infantry module that boosts vehicle shield recharge rate',0,0.01,0,1,NULL,500.0000,1,NULL,0),(354870,351121,'Squad - Speed Test','Test module, Increases movement speed of squad',0,0.01,0,1,NULL,500.0000,1,NULL,0),(354884,351844,'Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,600.0000,1,355194,0),(354894,354753,'[TEST] Drone Hive 2','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354903,351121,'Basic Heavy Damage Modifier','Increases damage output of all heavy handheld weapons.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1275.0000,1,354434,0),(354904,351121,'Enhanced Heavy Damage Modifier','Increases damage output of all heavy handheld weapons.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,354434,0),(354905,351121,'Complex Heavy Damage Modifier','Increases damage output of all heavy handheld weapons.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5595.0000,1,354434,0),(354906,351121,'Basic Sidearm Damage Modifier','Increases damage output of all sidearm handheld weapons.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1275.0000,1,354434,0),(354907,351121,'Enhanced Sidearm Damage Modifier','Increases damage output of all sidearm handheld weapons.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,354434,0),(354908,351121,'Complex Sidearm Damage Modifier','Increases damage output of all sidearm handheld weapons.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5595.0000,1,354434,0),(354912,351121,'\'Stimulus\' Complex Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0.01,0,1,NULL,2610.0000,1,365248,0),(354913,351121,'\'Static\' Complex Shield Recharger','Improves the recharge rate of dropsuit\'s shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,3615.0000,1,365250,0),(354914,351121,'\'Iris\' Complex Kinetic Catalyzer','Increases sprinting speed of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,1815.0000,1,354427,0),(354915,351121,'\'Chord\' Basic Cardiac Stimulant','Increases maximum stamina of the user.\r\r\nThe Chord utilizes a simplified instruction set to reduce the skill level required to operate while still providing Enhanced-level performance.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,2600.0000,1,NULL,0),(354916,351121,'\'Macro\' Enhanced Cardiac Stimulant','Increases maximum stamina of the user.\r\r\nThe Macro utilizes a simplified instruction set to reduce the skill level required to operate while still providing Complex-level performance.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,3760.0000,1,NULL,0),(354917,351121,'\'Spiral\' Complex Cardiac Stimulant','Increases maximum stamina of the user.\r\r\nThe Spiral utilizes high-grade materials to reduce CPU and PG load while providing comparative Complex-level performance.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,5440.0000,1,NULL,0),(354918,351121,'\'Neuron\' Basic Cardiac Regulator','Increases max stamina and stamina recovery rate of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,720.0000,1,354425,0),(354919,351121,'\'Nucleus\' Enhanced Cardiac Regulator','Increases max stamina and stamina recovery rate of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1935.0000,1,354425,0),(354921,351121,'\'Membrane\' Complex Cardiac Regulator','Increases max stamina and stamina recovery rate of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1935.0000,1,354425,0),(354922,351121,'\'Sheath\' Basic Myofibril Stimulant','Increases damage done by melee attacks.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,780.0000,1,354429,0),(354923,351121,'\'Sanction\' Enhanced Myofibril Stimulant','Increases damage done by melee attacks.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,2085.0000,1,354429,0),(354924,351121,'\'Vigil\' Complex Myofibril Stimulant','Increases damage done by melee attacks.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,2085.0000,1,354429,0),(354926,351121,'Basic Fuel Injector','Once activated, this module provides a temporary speed boost to ground vehicles.\r\r\n\r\r\nNOTE: Only one active fuel injector can be fitted at a time.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,4500.0000,1,354461,0),(354927,351210,'[TEST] Onikuma Boost','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,27600.0000,1,NULL,0),(354928,350858,'GB-9 Breach Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,4,10770.0000,1,354332,0),(354929,350858,'GLU-5 Tactical Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,4,10770.0000,1,354332,0),(354930,350858,'Duvolle Tactical Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class.\r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,4,47220.0000,1,354333,0),(354934,351064,'Sniper - CA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer. \r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,4680.0000,1,NULL,0),(354935,351064,'Armor AV - CA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer. \r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,4680.0000,1,NULL,0),(354937,350858,'Militia Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\n\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,610.0000,1,355463,0),(354941,351064,'Militia Caldari Medium Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,585.0000,1,355469,0),(354949,354753,'Drone Hive - Lvl.2','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354956,350858,'CRG-3 Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,6585.0000,1,354697,0),(354957,350858,'CreoDron Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,28845.0000,1,354698,0),(354958,354753,'[DEMO] Drone Hive','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(354959,350858,'ELM-7 Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,10770.0000,1,354691,0),(354960,350858,'Viziam Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,47220.0000,1,354692,0),(354961,350858,'MH-82 Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,10770.0000,1,354566,0),(354962,350858,'Boundless Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,47220.0000,1,354567,0),(354963,350858,'EXO-5 Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,6585.0000,1,354619,0),(354964,350858,'Freedom Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,47220.0000,1,354620,0),(355010,350858,'PRO Drone Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.\r\r\n',0,0.01,0,1,NULL,1200.0000,1,NULL,0),(355013,350858,'ADV Drone Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.\r\r\n',0,0.01,0,1,NULL,1200.0000,1,NULL,0),(355015,350858,'Drone Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.\r\r\n',0,0.01,0,1,NULL,1200.0000,1,NULL,0),(355019,350858,'PRO Drone Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it. \r\r\nPowered by a Gemini microcapacitor, the Forge Gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,27980.0000,1,NULL,0),(355027,350858,'ADV Drone Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it. \r\r\nPowered by a Gemini microcapacitor, the Forge Gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,7850.0000,1,NULL,0),(355032,350858,'Drone Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it. \r\r\nPowered by a Gemini microcapacitor, the Forge Gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,2200.0000,1,NULL,0),(355038,350858,'Drone Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,1000.0000,1,NULL,0),(355043,350858,'PRO Drone Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,13990.0000,1,NULL,0),(355050,350858,'ADV Drone Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,3920.0000,1,NULL,0),(355067,350858,'PRO Drone Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,19080.0000,1,NULL,0),(355069,350858,'ADV Drone Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,7350.0000,1,NULL,0),(355071,350858,'Drone Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,1500.0000,1,NULL,0),(355081,350858,'Drone Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,1000.0000,1,NULL,0),(355087,350858,'PRO Drone Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,12720.0000,1,NULL,0),(355098,350858,'ADV Drone Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,3570.0000,1,NULL,0),(355104,350858,'PRO Drone Laser Rifle','The laser rifle is a continuous wave, medium range weapon equally effective against infantry and vehicles. Targets are  painted\' with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output initially, but as the weapon warms up to mean operating temperature, the wavelength stabilizes and the damage output increases significantly.\r\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,19080.0000,1,NULL,0),(355107,350858,'ADV Drone Laser Rifle','The laser rifle is a continuous wave, medium range weapon equally effective against infantry and vehicles. Targets are  painted\' with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output initially, but as the weapon warms up to mean operating temperature, the wavelength stabilizes and the damage output increases significantly.\r\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,7350.0000,1,NULL,0),(355109,350858,'Drone Laser Rifle','The laser rifle is a continuous wave, medium range weapon equally effective against infantry and vehicles. Targets are  painted\' with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output initially, but as the weapon warms up to mean operating temperature, the wavelength stabilizes and the damage output increases significantly.\r\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,1500.0000,1,NULL,0),(355139,350858,'PRO Drone Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,16540.0000,1,NULL,0),(355145,350858,'ADV Drone Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,4640.0000,1,NULL,0),(355151,350858,'Drone Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,1300.0000,1,NULL,0),(355157,350858,'PRO Drone HMG','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,27980.0000,1,NULL,0),(355159,350858,'ADV Drone HMG','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,10780.0000,1,NULL,0),(355161,350858,'Drone HMG','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,2200.0000,1,NULL,0),(355198,354753,'Drone Hive - Lvl.1','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355199,354753,'Drone Hive - Lvl.3','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355201,354753,'Drone Hive - Lvl.4','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355210,354641,'Passive Booster (15-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0.01,0,1,NULL,0.0000,1,354542,0),(355212,351648,'Shotgun Operation','Skill at handling shotguns.\r\n\r\n3% reduction to shotgun spread per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(355213,351648,'Shotgun Proficiency','Skill at handling shotguns.\r\r\n\r\r\n+3% shotgun damage against shields per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(355217,354641,'Active Booster (3-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(355218,354641,'Passive Booster (3-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0.01,0,1,NULL,0.0000,1,354542,0),(355219,354641,'Passive Booster (7-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0.01,0,1,NULL,0.0000,1,354542,0),(355249,351210,'Cestus ','MCC needs a description',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355250,351210,'Charron ','MCC needs a description',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355254,350858,'Boundless Breach Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,34770.0000,1,354354,0),(355256,350858,'Kaalakiota Tactical Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,47220.0000,1,354350,0),(355257,350858,'KLO-1 Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,2955.0000,1,354344,0),(355258,350858,'Carthum Assault Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,21240.0000,1,354345,0),(355259,350858,'Assault Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,1110.0000,1,354343,0),(355260,350858,'\'Cerberus\' CRG-3 Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,10770.0000,1,354697,0),(355261,350858,'\'Hydra\' CreoDron Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,28845.0000,1,354698,0),(355262,350858,'\'Broadside\' MH-82 Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,10770.0000,1,354566,0),(355263,350858,'\'Steelmine\' Boundless Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,28845.0000,1,354567,0),(355264,350858,'\'Cyclone\' EXO-5 Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,10770.0000,1,354619,0),(355265,350858,'\'Avalanche\' Freedom Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,28845.0000,1,354620,0),(355266,351844,'\'Maelstrom\' R11-4 Flux Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,3945.0000,1,354411,0),(355267,351844,'\'Void\' Viziam Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,10575.0000,1,354405,0),(355268,351844,'KIN-012 Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,2625.0000,1,355195,0),(355269,351844,'Wiyrkomi Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,7050.0000,1,355196,0),(355270,351844,'\'Necromancer\' KIN-012 Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,4305.0000,1,355195,0),(355271,351844,'\'Talisman\' Wiyrkomi Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,7050.0000,1,355196,0),(355280,351648,'Nanocircuitry','Skill and knowledge of nanocircuitry and its use in the operation of advanced technology.\r\r\n\r\r\nUnlocks access to standard nanohives and nanite injectors at lvl.1; advanced at lvl.3; prototype at lvl.5. \r\r\n',0,0.01,0,1,NULL,149000.0000,1,353708,0),(355294,351121,'Squad - Shield Resistance','A generic description for all infantry modules',0,0.01,0,1,NULL,500.0000,1,NULL,0),(355297,351121,'Squad - Signature Dampener','A generic description for all infantry modules',0,0.01,0,1,NULL,500.0000,1,NULL,0),(355299,351121,'[DEV] Remote Shield Recharger','A generic description for all infantry modules',0,0.01,0,1,NULL,500.0000,0,NULL,0),(355308,351121,'Squad - Shield Energizer','A generic description for all infantry modules',0,0.01,0,1,NULL,500.0000,1,NULL,0),(355325,354753,'QA Drone Hive 1','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355326,354753,'QA Drone Hive 2','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355327,354753,'QA Drone Hive 3','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355329,351121,'[DEV] Anti-Shield Recharger','Cancels shield recharge of enemy units within 15m radius. Can only be equipped by the Crusader dropsuit.',0,0.01,0,1,NULL,500.0000,0,NULL,0),(355331,351121,'[DEV] Anti-ROF','Reduces the ROF of enemy weapons in AoE',0,0.01,0,1,NULL,500.0000,0,NULL,0),(355332,351121,'[DEV] Movement Nullifier','A generic description for all infantry modules',0,0.01,0,1,NULL,500.0000,0,NULL,0),(355374,351210,'Sica','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,59565.0000,1,355464,0),(355375,351121,'Militia Light Armor Repairer','Passively repairs damage done to the vehicle\'s armor.',0,0.01,0,1,NULL,3210.0000,1,355467,0),(355402,351121,'Militia Heavy Armor Repairer','Passively repairs damage done to the vehicle\'s armor.',0,0.01,0,1,NULL,5505.0000,1,355467,0),(355403,351121,'Militia Light Shield Booster','Once activated, this module instantly recharges a portion of the vehicle\'s shield HP.',0,0.01,0,1,NULL,3210.0000,1,355467,0),(355404,351121,'Militia Heavy Shield Booster','Once activated, this module instantly recharges a portion of the vehicle\'s shield HP.',0,0.01,0,1,NULL,5505.0000,1,355467,0),(355405,351121,'Militia 60mm Armor Plates','Increases maximum strength of vehicle\'s armor but the increased mass affects acceleration and top speed.',0,0.01,0,1,NULL,3210.0000,1,355467,0),(355406,351121,'Militia 120mm Armor Plates','Increases maximum strength of vehicle\'s armor but the increased mass affects acceleration and top speed.',0,0.01,0,1,NULL,5505.0000,1,355467,0),(355407,351121,'Militia 180mm Reinforced Steel Plates','Increases maximum strength of vehicle\'s armor, but the increased mass reduces top speed',0,0.01,0,1,NULL,22080.0000,1,NULL,0),(355408,351121,'Militia Energized Plating','Passively reduces damage done to the vehicle\'s armor. -10% damage taken to armor hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(355409,351121,'Militia CPU Upgrade Unit','Increases a vehicle\'s maximum CPU output in order to support more CPU intensive modules.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1830.0000,1,355467,0),(355411,351121,'Militia Powergrid Upgrade','Increases a vehicles\'s maximum powergrid output in order to support more PG intensive modules. \r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1830.0000,1,355467,0),(355412,351121,'Militia Power Diagnostic System','Increases the overall efficiency of a vehicle\'s engineering subsystems, thereby increasing its powergrid, shields and shield recharge by 3%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters shield recharge rate or powergrid will be reduced.',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(355413,351121,'Militia Light Shield Extender ','Increases maximum strength of vehicle\'s shields but increases the shield depleted recharge delay.',0,0.01,0,1,NULL,3210.0000,1,355467,0),(355414,351121,'Militia Heavy Shield Extender','Increases maximum strength of vehicle\'s shields but increases the shield depleted recharge delay.',0,0.01,0,1,NULL,5505.0000,1,355467,0),(355415,351121,'Militia Shield Regenerator','Improves the recharge rate of the vehicle\'s shields. Increases shield regeneration rate by 10%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(355416,351121,'Militia Shield Resistance Amplifier','Increases damage resistance of the vehicle\'s shields. -10% damage taken to shield hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(355421,351121,'Militia Sidearm Damage Modifier','Increases damage output of all sidearm handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,520.0000,1,355466,0),(355422,351121,'Militia Heavy Damage Modifier','Increases damage output of all heavy handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,520.0000,1,355466,0),(355423,351210,'Onikuma - Impact','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,10000.0000,1,NULL,0),(355424,351210,'Baloch - Impact','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,10000.0000,1,NULL,0),(355425,351064,'Dire Sentinel','The Heavy dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,795.0000,1,NULL,0),(355426,351064,'Arbiter','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,5240.0000,1,NULL,0),(355427,351064,'Artificer','The Logistics-class dropsuit is a force multiplier, able to provide medical and mechanical support to units on the battlefield, greatly improving their effectiveness in battle. The Militia variant has limited module expandability.',0,0.01,0,1,NULL,5800.0000,1,NULL,0),(355428,351844,'Militia Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,240.0000,1,355468,0),(355430,351064,'\'Dragonfly\' Scout [nSv]','Engineered using technology plundered from archeological sites during the UBX-CC conflict in YC113, the Dragonfly is a GATE suit designed to adapt and conform to an individual s usage patterns, learning and eventually predicting actions before they occur, substantially increasing response times and maneuverability.',0,0.01,0,1,NULL,3000.0000,1,354388,0),(355432,350858,'\'Toxin\' ICD-9 Submachine Gun','A modified version of the Republic s seminal light weapon, the Toxin is a semi-automatic pistol adapted to fire doped slugs. \r\r\nA questionable design that many would agree offers little benefit beyond increasing a victim s discomfort as contaminants spread through the system, liquefying internal organs and disrupting nanite helixes in the bloodstream, causing the subunits to go haywire and attack the body they re designed to sustain.',0,0.01,0,1,NULL,675.0000,1,354352,0),(355434,350858,'HK4M Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,4020.0000,1,354697,0),(355435,351844,'Hacked Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,1470.0000,1,354403,0),(355438,354753,'Drone Hive','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355439,354753,'Drone Hive','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355442,351121,'1.5dn Myofibril Stimulant','Increases damage done by melee attacks.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,2085.0000,1,354429,0),(355443,350858,'Fused Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,450.0000,1,363464,0),(355445,351064,'QA God Suit','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient equipment hard points for mission-specific customizations.\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier\'s strength, balance, and resistance to impact forces. The suit\'s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. Furthermore, every armor plate on the suit is energized to absorb the force of incoming plasma-based projectiles, neutralizing their ionization and reducing thermal damage.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment\'s notice. Its ability to carry anything from small arms and explosives to heavy anti-vehicle munitions and deployable support gear makes it the most adaptable suit on the battlefield.',0,0.01,0,1,NULL,9400.0000,1,NULL,0),(355470,351210,'Soma','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,59565.0000,1,355464,0),(355471,351210,'Gorgon - Hatch','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,151840.0000,1,NULL,0),(355472,351210,'Viper','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,27495.0000,1,355464,0),(355473,351210,'Gorgon','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,27495.0000,1,355464,0),(355474,351210,'Viper - Hatch','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,151840.0000,1,NULL,0),(355475,351210,'Sica - Tension','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,138040.0000,1,NULL,0),(355476,350858,'Passenger Position','This is used for passenger positions. Please do not unpublish or delete this.',0,0.01,0,1,NULL,1500.0000,1,NULL,0),(355478,350858,'Passenger Position','This is used for passenger positions. Please do not unpublish or delete this.',0,0.01,0,1,NULL,1500.0000,1,NULL,0),(355479,351210,'Soma - Tension','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,138040.0000,1,NULL,0),(355483,350858,'AntiMCC Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,6000.0000,1,NULL,0),(355488,350858,'Passenger Position','This is used for passenger positions. Please do not unpublish or delete this.',0,0.01,0,1,NULL,1500.0000,1,NULL,0),(355495,350858,'Breach Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,2460.0000,1,354696,0),(355497,350858,'\'Chimera\' Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,4020.0000,1,354696,0),(355498,350858,'\'Golem\' Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,4,4020.0000,1,354565,0),(355499,350858,'\'Tsunami\' Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,4020.0000,1,354618,0),(355508,351844,'Cortex','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,4800.0000,1,NULL,0),(355514,350858,'KR-17 Breach Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,10770.0000,1,354697,0),(355515,350858,'Allotek Breach Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,47220.0000,1,354698,0),(355516,351064,'Logistics Type-II','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,4905.0000,0,NULL,0),(355517,351121,'Enhanced Profile Dampener','Decreases dropsuit\'s scan profile making it harder to detect by scanning systems.',0,0.01,0,1,NULL,2085.0000,1,354671,0),(355518,351121,'Complex Profile Dampener','Decreases dropsuit\'s scan profile making it harder to detect by scanning systems.',0,0.01,0,1,NULL,3420.0000,1,354671,0),(355519,351121,'\'Cataract\' Basic Profile Dampener','Decreases dropsuit\'s scan profile making it harder to detect by scanning systems.',0,0.01,0,1,NULL,780.0000,1,354671,0),(355520,351121,'\'Nyctalus\' Enhanced Profile Damper','Decreases dropsuit\'s scan profile making it harder to detect by scanning systems.',0,0.01,0,1,NULL,2085.0000,1,354671,0),(355521,351121,'\'Miosis\' Complex Profile Damper','Decreases dropsuit\'s scan profile making it harder to detect by scanning systems.',0,0.01,0,1,NULL,2085.0000,1,354671,0),(355523,351121,'Militia Profile Dampener','Decreases dropsuit\'s scan profile making it harder to detect by scanning systems.',0,0.01,0,1,NULL,320.0000,1,355466,0),(355526,351121,'\'Echo\' Basic Light Damage Modifier','Increases damage output of all light handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1275.0000,1,354434,0),(355527,351121,'\'Ricochet\' Enhanced Light Damage Modifier','Increases damage output of all light handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,354434,0),(355528,351121,'\'Cascade\' Complex Light Damage Modifier','Increases damage output of all light handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,3420.0000,1,354434,0),(355532,351121,'\'Debris\' Basic Sidearm Damage Modifier','Increases damage output of all sidearm handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1275.0000,1,354434,0),(355533,351121,'\'Fragment\' Enhanced Sidearm Damage Modifier','Increases damage output of all sidearm handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,3420.0000,1,354434,0),(355534,351121,'\'Sliver\' Complex Sidearm Damage Modifier','Increases damage output of all sidearm handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,354434,0),(355535,351121,'\'Tremor\' Basic Heavy Damage Modifier','Increases damage output of all heavy handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1275.0000,1,354434,0),(355536,351121,'\'Impact\' Enhanced Heavy Damage Modifier','Increases damage output of all heavy handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,354434,0),(355537,351121,'\'Seismic\' Complex Heavy Damage Modifier','Increases damage output of all heavy handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,354434,0),(355558,354641,'Passive Booster (30-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0.01,0,1,NULL,0.0000,1,354542,0),(355561,354641,'Active Booster (30-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(355566,351121,'Enhanced Codebreaker','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,2610.0000,1,355572,0),(355567,351121,'Complex Codebreaker','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,4275.0000,1,355572,0),(355568,351121,'Basic Codebreaker','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,975.0000,1,355572,0),(355569,351121,'\'Pandemic\' Complex Codebreaker','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,2610.0000,1,355572,0),(355570,351121,'\'Pathogen\' Basic Codebreaker','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,975.0000,1,355572,0),(355571,351121,'\'Contagion\' Enhanced Codebreaker','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,2610.0000,1,355572,0),(355577,351844,'Proximity Explosive','A proximity variant of the F/41 series of remote explosives designed to detonate automatically when an unidentified vehicle signature is detected. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units caught in the blast. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,1500.0000,1,355187,0),(355582,351121,'\'Origin\' Enhanced Shield Regulator','Reduces the length of the delay before shield recharge begins.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1815.0000,1,365249,0),(355583,351121,'\'Shaft\' Basic Shield Regulator','Reduces the length of the delay before shield recharge begins.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,675.0000,1,365249,0),(355584,351121,'\'Tether\' Complex Shield Regulator','Reduces the length of the delay before shield recharge begins.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1815.0000,1,365249,0),(355585,351121,'Basic Shield Regulator','Reduces the length of the delay before shield recharge begins.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,675.0000,1,365249,0),(355586,351121,'Complex Shield Regulator','Reduces the length of the delay before shield recharge begins.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,2955.0000,1,365249,0),(355587,351121,'Enhanced Shield Regulator','Reduces the length of the delay before shield recharge begins.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1815.0000,1,365249,0),(355591,351121,'Militia Shield Regulator','Reduces the length of the delay before shield recharge begins.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,270.0000,1,355466,0),(355594,350858,'C-7 Flux Grenade','The Flux grenade is a hand-thrown wave shaper designed to destroy low-level electronic equipment and disrupt shielding.',0,0.01,0,1,NULL,1605.0000,1,363471,0),(355595,350858,'Allotek Flux Grenade','The Flux grenade is a hand-thrown wave shaper designed to destroy low-level electronic equipment and disrupt shielding.',0,0.01,0,1,NULL,7050.0000,1,363472,0),(355596,350858,'\'Siren\' Flux Grenade','The Flux grenade is a hand-thrown wave shaper designed to destroy low-level electronic equipment and disrupt shielding.',0,0.01,0,1,NULL,1605.0000,1,363470,0),(355597,350858,'\'Klaxon\' Allotek Flux Grenade','The Flux grenade is a hand-thrown wave shaper designed to destroy low-level electronic equipment and disrupt shielding.',0,0.01,0,1,NULL,4305.0000,1,363472,0),(355598,350858,'\'Banshee\' C-7 Flux Grenade','The Flux grenade is a hand-thrown wave shaper designed to destroy low-level electronic equipment and disrupt shielding.',0,0.01,0,1,NULL,4305.0000,1,363471,0),(355599,350858,'\'Haze\' Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,1200.0000,1,363464,0),(355600,350858,'\'Husk\' AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,2010.0000,1,363467,0),(355603,350858,'Breach Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,1110.0000,1,354343,0),(355604,350858,'TY-5 Breach Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,4845.0000,1,354344,0),(355605,350858,'Imperial Breach Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,21240.0000,1,354345,0),(355607,351121,'Magnetic Field Stabilizer','Increases firing rate of hybrid turrets.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5000.0000,1,NULL,0),(355610,351121,'Fire Control System','Reduces spool up duration of railgun turrets by 10%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,12000.0000,1,NULL,0),(355611,351121,'Conscript Heat Sink','Reduces turret heat build-up of blaster and railgun turrets, thereby increasing effective firing time before overheating.  Reduces heat cost per shot by 10%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,12000.0000,1,NULL,0),(355613,351121,'Propulsion Test Plates','Increases maximum strength of vehicle\'s armor, but the increased mass reduces top speed. ',0,0.01,0,1,NULL,45360.0000,1,NULL,0),(355614,351121,'Inertia Test Plates','Increases maximum strength of vehicle\'s armor, but the increased mass reduces top speed.',0,0.01,0,1,NULL,45360.0000,1,NULL,0),(355615,350858,'Synch AV Grenade','The AV grenade is a high-explosive anti-vehicle grenade.',0,0.01,0,1,NULL,1230.0000,1,NULL,0),(355616,350858,'EX-3 Sleek AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,3285.0000,1,363468,0),(355617,350858,'Lai Dai Packed AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,23610.0000,1,363469,0),(355679,350858,'Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,1500.0000,1,364052,0),(355685,350858,'Viziam Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,47220.0000,1,364054,0),(355697,350858,'CRW-04 Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,10770.0000,1,364053,0),(355720,351064,'\'Skinweave\' Militia Caldari Medium Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(355721,354753,'Large Blaster Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355722,354753,'Large CA Railgun Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355723,354753,'Large GA Railgun Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355724,354753,'Large Missile Installation','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355740,350858,'Wiyrkomi Breach Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,47220.0000,1,354337,0),(355741,350858,'\'Grimoire\' 20GJ Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,24105.0000,1,356968,0),(355742,350858,'\'Calisto\' 20GJ Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,64605.0000,1,356969,0),(355743,350858,'\'Phantasm\' 20GJ Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,105735.0000,1,356970,0),(355744,350858,'\'Wraith\' 80GJ Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,64305.0000,1,356971,0),(355746,350858,'\'Oracle\' 80GJ Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,172260.0000,1,356972,0),(355747,350858,'\'Sodom\' 80GJ Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,281955.0000,1,356973,0),(355748,350858,'\'Lycan\' 20GJ Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,24105.0000,1,356979,0),(355749,350858,'\'Spartan\' 20GJ Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,64605.0000,1,356980,0),(355750,350858,'\'Martyr\' 20GJ Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,105735.0000,1,356981,0),(355751,350858,'\'Pariah\' 80GJ Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,64305.0000,1,356976,0),(355752,350858,'\'Mortis\' 80GJ Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,172260.0000,1,356977,0),(355753,350858,'\'Gomorrah\' 80GJ Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,281955.0000,1,356978,0),(355761,350858,'\'Brimstone\' ST-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,24105.0000,1,356963,0),(355762,350858,'\'Arson\' AT-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,64605.0000,1,356964,0),(355763,350858,'\'Cinder\' XT-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,105735.0000,1,356965,0),(355764,350858,'\'Harbinger\' ST-201 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,64305.0000,1,356960,0),(355765,350858,'\'Omen\' AT-201 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,172260.0000,1,356961,0),(355766,350858,'\'Prodigy\' XT-201 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,281955.0000,1,356962,0),(355767,351064,'\'Skinweave\' Militia Gallente Light Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(355768,351064,'\'Skinweave\' Militia Minmatar Medium Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(355771,351064,'\'Skinweave\' Militia Amarr Heavy Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(355772,351210,'Guristas Saga','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,353664,0),(355779,350858,'Breach Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,2460.0000,1,354618,0),(355781,350858,'Assault Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,2460.0000,0,NULL,0),(355785,351121,'Insulated Magnetic Field Stabilizer','Increases firing rate of hybrid turrets.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5000.0000,1,NULL,0),(355786,351121,'Nonlinear Flux Stabilizer','Increases firing rate of hybrid turrets.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5000.0000,1,NULL,0),(355787,351121,'\'Utopia\' Magnetic Field Stabilizer','Increases firing rate of hybrid turrets.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,2205.0000,1,NULL,0),(355788,351121,'Asynchronous Fire Control','Reduces spool up duration of railgun turrets by 14%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(355789,351121,'Fire Control System II','Reduces spool up duration of railgun turrets by 19%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355790,351121,'\'Trojan\' Fire Control System','Reduces spool up duration of railgun turrets by 18%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355791,351121,'Modified Extruded Heat Sink','Reduces turret heat build-up of blaster and railgun turrets, thereby increasing effective firing time before overheating. Reduces heat cost per shot by 14%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(355792,351121,'Vented Heat Sink','Reduces turret heat build-up of blaster and railgun turrets, thereby increasing effective firing time before overheating.  Reduces heat cost per shot by 19%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355793,351121,'\'Helios\' Heat Sink','Reduces turret heat build-up of blaster and railgun turrets, thereby increasing effective firing time before overheating.  Reduces heat cost per shot by 18%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355798,351121,'Basic Railgun Damage Amplifer','Once activated, this module temporarily increases the damage output of all railgun turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3750.0000,1,356581,0),(355799,351121,'Enhanced Railgun Damage Amplifer','Once activated, this module temporarily increases the damage output of all railgun turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,10050.0000,1,356581,0),(355800,351121,'Complex Railgun Damage Amplifer','Once activated, this module temporarily increases the damage output of all railgun turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,16440.0000,1,356581,0),(355801,351121,'LT Insulated Stabilizer Array','Increases the damage output of vehicle mounted small railgun and blaster turrets.  Grants 10% bonus to hybrid turret damage, and a 5% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355802,351121,'Basic Blaster Damage Amplifier','Once activated, this module temporarily increases the damage output of all blaster turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3750.0000,1,356579,0),(355803,351121,'Enhanced Blaster Damage Amplifier','Once activated, this module temporarily increases the damage output of all blaster turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,10050.0000,1,356579,0),(355804,351121,'Complex Blaster Damage Amplifier','Once activated, this module temporarily increases the damage output of all blaster turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,16440.0000,1,356579,0),(355805,351121,'HT Insulated Stabilizer Array','Increases the damage output of vehicle mounted large railgun and blaster turrets.  Grants 10% bonus to hybrid turret damage, and a 5% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355807,351121,'Calibration Subsystem','Increases turret\'s maximum effective range.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5000.0000,1,NULL,0),(355808,351121,'Routine Calibration Subsystem','Increases turret\'s maximum effective range.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5000.0000,1,NULL,0),(355809,351121,'Tolerant Calibration Subsystem','Increases turret\'s maximum effective range.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5000.0000,1,NULL,0),(355810,351121,'\'Cirrus\' Calibration Subsystem','Increases turret\'s maximum effective range.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5000.0000,1,NULL,0),(355811,351121,'Militia Blaster Damage Amplifier','Once activated, this module temporarily increases the damage output of all blaster turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,4575.0000,1,355467,0),(355812,350858,'EK-A2 Breach Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,10770.0000,1,354619,0),(355813,350858,'EC-3 Assault Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,10770.0000,1,354619,0),(355814,350858,'Core Breach Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,4,47220.0000,1,354620,0),(355815,350858,'Boundless Assault Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,4,47220.0000,1,354620,0),(355820,350858,'Burst Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,2460.0000,0,NULL,0),(355821,350858,'Assault Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,2460.0000,1,354565,0),(355822,350858,'80GJ Stabilized Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,69520.0000,1,NULL,0),(355823,350858,'80GJ Compressed Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,69520.0000,1,NULL,0),(355824,350858,'80GJ Stabilized Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,640600.0000,1,NULL,0),(355825,350858,'80GJ Compressed Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,640600.0000,1,NULL,0),(355826,350858,'80GJ Stabilized Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,211000.0000,1,NULL,0),(355827,350858,'80GJ Compressed Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,211000.0000,1,NULL,0),(355828,350858,'20GJ Stabilized Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,52760.0000,1,NULL,0),(355829,350858,'20GJ Compressed Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,52760.0000,1,NULL,0),(355830,350858,'20GJ Stabilized Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,160160.0000,1,NULL,0),(355831,350858,'20GJ Compressed Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,160160.0000,1,NULL,0),(355832,350858,'20GJ Stabilized Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(355833,350858,'20GJ Compressed Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(355834,350858,'80GJ Stabilized Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,211000.0000,1,NULL,0),(355835,350858,'80GJ Compressed Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,305520.0000,1,NULL,0),(355836,350858,'80GJ Stabilized Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,640600.0000,1,NULL,0),(355837,350858,'80GJ Compressed Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,927560.0000,1,NULL,0),(355839,350858,'80GJ Stabilized Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,69520.0000,1,NULL,0),(355840,350858,'80GJ Compressed Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,100640.0000,1,NULL,0),(355841,350858,'20GJ Stabilized Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,52760.0000,1,NULL,0),(355842,350858,'20GJ Compressed Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,76400.0000,1,NULL,0),(355843,350858,'20GJ Stabilized Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,160160.0000,1,NULL,0),(355844,350858,'20GJ Compressed Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,231880.0000,1,NULL,0),(355845,350858,'20GJ Stabilized Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(355846,350858,'20GJ Compressed Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355847,350858,'AT-201 Accelerated Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,305520.0000,1,NULL,0),(355848,350858,'AT-201 Fragmented Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,211000.0000,1,NULL,0),(355849,350858,'XT-201 Accelerated Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,927560.0000,1,NULL,0),(355850,350858,'XT-201 Fragmented Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,640600.0000,1,NULL,0),(355851,350858,'ST-201 Accelerated Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,100640.0000,1,NULL,0),(355852,350858,'ST-201 Fragmented Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,69520.0000,1,NULL,0),(355853,350858,'AT-1 Accelerated Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,76400.0000,1,NULL,0),(355854,350858,'AT-1 Fragmented Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,52760.0000,1,NULL,0),(355855,350858,'XT-1 Accelerated Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,231880.0000,1,NULL,0),(355856,350858,'XT-1 Fragmented Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,160160.0000,1,NULL,0),(355857,350858,'ST-1 Accelerated Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355858,350858,'ST-1 Fragmented Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(355859,350858,'Six Kin Burst Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,4,47220.0000,1,354567,0),(355860,350858,'Freedom Assault Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,4,47220.0000,1,354567,0),(355861,350858,'MLR-A Burst Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,4,10770.0000,1,354566,0),(355862,350858,'MO-4 Assault Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,4,10770.0000,1,354566,0),(355863,350858,'Specialist Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,1500.0000,0,NULL,0),(355864,350858,'K5 Specialist Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,10770.0000,1,354697,0),(355865,350858,'Duvolle Specialist Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,47220.0000,1,354698,0),(355866,350858,'80GJ Scattered Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,305520.0000,1,NULL,0),(355867,350858,'80GJ Scattered Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,927560.0000,1,NULL,0),(355868,350858,'80GJ Scattered Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,100640.0000,1,NULL,0),(355869,350858,'20GJ Scattered Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,76400.0000,1,NULL,0),(355870,350858,'20GJ Scattered Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,231880.0000,1,NULL,0),(355871,350858,'20GJ Scattered Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355872,350858,'80GJ Regulated Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,211000.0000,1,NULL,0),(355873,350858,'80GJ Regulated Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,640600.0000,1,NULL,0),(355874,350858,'80GJ Regulated Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,69520.0000,1,NULL,0),(355875,350858,'20GJ Regulated Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,52760.0000,1,NULL,0),(355876,350858,'20GJ Regulated Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,160160.0000,1,NULL,0),(355877,350858,'20GJ Regulated Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(355878,350858,'AT-201 Cycled Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,211000.0000,1,NULL,0),(355879,350858,'XT-201 Cycled Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,640600.0000,1,NULL,0),(355880,350858,'ST-201 Cycled Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,69520.0000,1,NULL,0),(355881,350858,'AT-1 Cycled Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,52760.0000,1,NULL,0),(355882,350858,'XT-1 Cycled Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,160160.0000,1,NULL,0),(355883,350858,'ST-1 Cycled Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(355894,351121,'Heavy Payload Control System I','Increases the damage output of vehicle mounted large missile turrets.  Grants 7% bonus to missile damage, and a 2% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,12000.0000,1,NULL,0),(355895,351121,'HP Multiphasic Bolt Array I','Increases the damage output of vehicle mounted large missile turrets.  Grants 8% bonus to missile damage, and a 3% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(355896,351121,'Heavy Payload Control System II','Increases the damage output of vehicle mounted large missile turrets.  Grants 10% bonus to missile damage, and a 5% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355897,351121,'HP Muon Coil Bolt Array I','Increases the damage output of vehicle mounted large missile turrets.  Grants 10% bonus to missile damage, and a 5% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355898,351121,'Basic Missile Damage Amplifier','Once activated, this module temporarily increases the damage output of all missile launcher turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3750.0000,1,356584,0),(355903,351121,'Enhanced Missile Damage Amplifier','Once activated, this module temporarily increases the damage output of all missile launcher turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,10050.0000,1,356584,0),(355904,351121,'Complex Missile Damage Amplifier','Once activated, this module temporarily increases the damage output of all missile launcher turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,16440.0000,1,356584,0),(355905,351121,'LP Muon Coil Bolt Array I','Increases the damage output of vehicle mounted small missile turrets.  Grants 10% bonus to missile damage, and a 5% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355906,351121,'Systemic Ballistic Control System I','Increases the damage output of all vehicle mounted missile turrets. Grants 3% bonus to missile damage, and a 2% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,12000.0000,1,NULL,0),(355908,351121,'Systemic Bolt Array I','Increases the damage output of all vehicle mounted missile turrets. Grants 4% bonus to missile damage, and a 3% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355909,351121,'Systemic Ballistic Control System II','Increases the damage output of all vehicle mounted missile turrets. Grants 6% bonus to missile damage, and a 5% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,36240.0000,1,NULL,0),(355910,351121,'Systemic \'Pandemonium\' Ballistic Enhancement','Increases the damage output of all vehicle mounted missile turrets. Grants 6% bonus to missile damage, and a 5% increase to rate of fire.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(355927,351121,'Militia Missile Damage Amplifier','Once activated, this module temporarily increases the damage output of all missile launcher turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,4575.0000,1,355467,0),(355928,351121,'Basic Heat Sink','Reduces heat cost per shot, enabling weapons to fire for a longer duration before overheating.',0,0.01,0,1,4,7000.0000,1,368919,0),(355929,351121,'Enhanced Heat Sink','Reduces heat cost per shot, enabling weapons to fire for a longer duration before overheating.',0,0.01,0,1,4,18760.0000,1,368919,0),(355930,351121,'Complex Heat Sink','Reduces heat cost per shot, enabling weapons to fire for a longer duration before overheating.',0,0.01,0,1,4,30700.0000,1,368919,0),(355931,351121,'Gadolinium Array','This coolant system actively flushes a weapon\'s housing, enabling it to fire for a longer duration before overheating.  Reduces heat cost per shot by 51%.\r\r\n\r\r\nNOTE: Only one Active Heatsink can be fitted at a time.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,33560.0000,1,NULL,0),(355932,351648,'Systems Hacking','Basic understanding of hacking.\r\r\n\r\r\nUnlocks ability to use codebreaker modules.\r\r\n\r\r\n+5% bonus to hacking speed per level.',0,0.01,0,1,NULL,567000.0000,1,353708,0),(355949,350858,'Handheld weapon needs a name','Handheld weapon needs a description',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355962,350858,'Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,1500.0000,1,NULL,0),(355964,350858,'Missile Installation','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,16560.0000,1,NULL,0),(355976,354641,'Universal Voice Transmitter (1-Day)','Universal Voice Transmitters are biomechanical implants that provide personal access to subspace routers, allowing users to communicate instantly with one another wherever they may be. The implants degrade over time and cease to function when fully absorbed by the user.',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355977,354641,'Universal Voice Transmitter (3-Day)','Universal Voice Transmitters are biomechanical implants that provide personal access to subspace routers, allowing users to communicate instantly with one another wherever they may be. The implants degrade over time and cease to function when fully absorbed by the user.',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355978,354641,'Universal Voice Transmitter (7-Day)','Universal Voice Transmitters are biomechanical implants that provide personal access to subspace routers, allowing users to communicate instantly with one another wherever they may be. The implants degrade over time and cease to function when fully absorbed by the user.',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355979,354641,'Universal Voice Transmitter (30-Day)','Universal Voice Transmitters are biomechanical implants that provide personal access to subspace routers, allowing users to communicate instantly with one another wherever they may be. The implants degrade over time and cease to function when fully absorbed by the user.',0,0.01,0,1,NULL,0.0000,1,NULL,0),(355994,350858,'Balac\'s GAR-21 Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,126495.0000,1,354333,0),(356012,354753,'Null Cannon','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356015,351064,'\'Primordial\' Militia Caldari Medium Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,369213,0),(356020,351064,'\'Thale\' Militia Gallente Light Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(356022,351064,'\'Fossil\' Militia Minmatar Medium Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,369213,0),(356023,351064,'\'Eon\' Militia Amarr Heavy Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,369213,0),(356024,351064,'\'Venom\' Militia Amarr Heavy Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,369213,0),(356031,351064,'\'Raven\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n \r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356032,351064,'\'Primordial\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,4905.0000,1,369213,0),(356034,351064,'\'Eon\' Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356035,351064,'\'Venom\' Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356037,351064,'\'Sever\' Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,4905.0000,1,369213,0),(356038,351064,'\'Fossil\' Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,4905.0000,1,369213,0),(356040,351064,'\'Valor\' Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356041,351064,'\'Thale\' Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,354388,0),(356042,350858,'Krin\'s SIN-11 Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class.\r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,126495.0000,1,354333,0),(356044,350858,'Cala\'s MK-33 Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,56925.0000,1,354354,0),(356046,350858,'Gastun\'s BRN-50 Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\n\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,126495.0000,1,354337,0),(356048,350858,'Thale\'s TAR-07 Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,126495.0000,1,354350,0),(356050,350858,'Wolfman\'s PCP-30 Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,56925.0000,1,354345,0),(356052,350858,'Gastun\'s MIN-7 HMG','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,47220.0000,1,354567,0),(356053,351064,'\'Quafe\' Assault C-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356056,351064,'\'Quafe\' Assault C/1-Series','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,14280.0000,1,354377,0),(356058,351064,'\'Quafe\' Assault ck.0','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,21540.0000,1,354378,0),(356059,351064,'\'Quafe\' Scout G-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356065,351064,'\'Quafe\' Scout gk.0','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,21540.0000,1,354390,0),(356068,351210,'\'AG-01\' Grimsnes','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,45000.0000,1,353671,0),(356069,351210,'\'CD-41\' Myron','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,45000.0000,1,353671,0),(356072,351210,'\'AI-102\' Madrugar','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,97500.0000,1,353657,0),(356073,351210,'\'HC-130\' Gunnlogi','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,200000.0000,1,353657,0),(356075,351210,'\'LC-217\' Saga','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,353664,0),(356077,351210,'\'LG-88\' Methana','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,353664,0),(356106,351064,'\'Valor\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356107,351064,'\'Sever\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356108,351064,'\'Valor\' Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356109,351064,'\'Raven\' Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356110,351064,'\'Sever\' Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356111,351064,'\'Valor\' Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,4905.0000,1,369213,0),(356112,351064,'\'Raven\' Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,4905.0000,1,369213,0),(356113,351064,'\'Raven\' Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356114,351064,'\'Sever\' Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(356115,350858,'\'Daemon\' Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,10080.0000,1,354696,0),(356116,350858,'\'Carnifax\' Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,450.0000,1,363464,0),(356207,351210,'Chakram','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies.\r\r\nDesigned for clandestine operations, the Black Ops HAV comes factory equipped with a robust suite of scanning and electronic warfare systems. A low scan profile and a built-in CRU make the Black Ops ideally suited for troop insertion behind enemy lines, and its hull formidable enough to keep them alive once they re there.',0,0.01,0,1,NULL,2682480.0000,1,NULL,0),(356211,351210,'Kubera','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies.\r\r\nDesigned for clandestine operations, the Black Ops HAV comes factory equipped with a robust suite of scanning and electronic warfare systems. A low scan profile and a built-in CRU make the Black Ops ideally suited for troop insertion behind enemy lines, and its hull formidable enough to keep them alive once they re there.',0,0.01,0,1,NULL,2682480.0000,1,NULL,0),(356214,350858,'Anti-MCC Turret','A Turret',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356300,350858,'Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\n\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0.01,0,1,NULL,675.0000,1,363791,0),(356305,351844,'K-CR Triage Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,6465.0000,0,NULL,0),(356306,351844,'Wiyrkomi Triage Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,28335.0000,1,354412,0),(356322,354753,'Null Cannon','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356331,350858,'Anti-MCC Turret','A Turret',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356332,350858,'Anti-MCC Turret','A Turret',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356333,350858,'Anti-MCC Turret','A Turret',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356334,350858,'Anti-MCC Turret','A Turret',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356335,354753,'Null Cannon','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356336,354753,'Null Cannon','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356337,354753,'Null Cannon','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356393,350858,'Seeker Flaylock','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0.01,0,1,NULL,1110.0000,0,NULL,0),(356401,351064,'Commando A-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,3000.0000,1,365279,0),(356416,351121,'[DEV] Remote Armor Repairer','A generic description for all infantry modules',0,0.01,0,1,NULL,500.0000,0,NULL,0),(356426,350858,'Nova Knives','A close-quarters melee weapon, the nova knife is as deadly a weapon as anything on the battlefield. Its name derives from the heated plasma edge of the blade   formed by a thermic igniter and linear gravity condenser   that, in skilled hands, can be used to carve through even the thickest dropsuit armor.',0,0.01,0,1,NULL,675.0000,1,356434,0),(356471,351121,'Conscript Tracking Enhancer I','Tracking Enhancers increase the rotation speed of all turrets equipped on a vehicle.  Tracking speed increased by 28%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,12000.0000,1,NULL,0),(356473,351121,'Conscript Tracking Computer I','Tracking computers actively increase the rotation speed of all turrets equipped on a vehicle.  Tracking increased by 42%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,16000.0000,1,NULL,0),(356495,351121,'G-11 Nonlinear Tracking Processor','Tracking computers actively increase the rotation speed of all turrets equipped on a vehicle.  Tracking increased by 41%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,36240.0000,1,NULL,0),(356496,351121,'Conscript Tracking Computer II','Tracking computers actively increase the rotation speed of all turrets equipped on a vehicle.  Tracking increased by 49%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,33560.0000,1,NULL,0),(356497,351121,'\'Delphi\' Tracking CPU','Tracking computers actively increase the rotation speed of all turrets equipped on a vehicle.  Tracking increased by 46%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,33560.0000,1,NULL,0),(356498,351121,'Delta-Nought Tracking Mode','Tracking Enhancers increase the rotation speed of all turrets equipped on a vehicle.  Tracking speed increased by 27%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(356499,351121,'Conscript Tracking Enhancer II','Tracking Enhancers increase the rotation speed of all turrets equipped on a vehicle.  Tracking speed increased by 34%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,17360.0000,1,NULL,0),(356500,351121,'Zeta-Nought Tracking Mode','Tracking Enhancers increase the rotation speed of all turrets equipped on a vehicle.  Tracking speed increased by 32%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,25160.0000,1,NULL,0),(356514,350858,'Handheld weapon needs a name','Handheld weapon needs a description',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356515,350858,'Handheld weapon needs a name','Handheld weapon needs a description',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356516,350858,'Handheld weapon needs a name','Handheld weapon needs a description',0,0.01,0,1,NULL,0.0000,1,NULL,0),(356526,351121,'Basic Range Amplifier','Increases dropsuit\'s scan radius allowing it to detect enemy units at greater range.',0,0.01,0,1,NULL,825.0000,1,354671,0),(356559,351064,'Medic - CA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer. \r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,4680.0000,1,NULL,0),(356562,351121,'Advanced Precision Enhancer','Improves dropsuit\'s scan precision making it easier to detect nearby enemy signals.',0,0.01,0,1,NULL,2205.0000,1,354671,0),(356563,351121,'Complex Precision Enhancer','Improves dropsuit\'s scan precision making it easier to detect nearby enemy signals.',0,0.01,0,1,NULL,5925.0000,1,354671,0),(356564,351121,'\'Visio\' Basic Precision Enhancer','Improves dropsuit\'s scan precision making it easier to detect nearby enemy signals.',0,0.01,0,1,NULL,825.0000,1,354671,0),(356565,351121,'\'Diaemus\' Enhanced Precision Enhancer','Improves dropsuit\'s scan precision making it easier to detect nearby enemy signals.',0,0.01,0,1,NULL,2205.0000,1,354671,0),(356566,351121,'\'Auga\' Complex Precision Enhancer','Improves dropsuit\'s scan precision making it easier to detect nearby enemy signals.',0,0.01,0,1,NULL,2205.0000,1,354671,0),(356567,351121,'Enhanced Range Amplifier','Increases dropsuit\'s scan radius allowing it to detect enemy units at greater range.',0,0.01,0,1,NULL,2205.0000,1,354671,0),(356569,351064,'Heavy B-Series','The Heavy dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,21540.0000,0,NULL,0),(356570,351064,'Heavy vk.1','The Heavy dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,94425.0000,0,NULL,0),(356571,351064,'Logistics B-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,13155.0000,0,NULL,0),(356572,351064,'Logistics vk.1','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,94425.0000,0,NULL,0),(356590,351121,'Enhanced Fuel Injector','Once activated, this module provides a temporary speed boost to ground vehicles.\r\r\n\r\r\nNOTE: Only one active fuel injector can be fitted at a time.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,12060.0000,1,354461,0),(356591,351121,'Complex Fuel Injector','Once activated, this module provides a temporary speed boost to ground vehicles.\r\r\n\r\r\nNOTE: Only one active fuel injector can be fitted at a time.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,19740.0000,1,354461,0),(356593,351121,'Enhanced Shield Hardener','Once activated, this module temporarily reduces the damage done to shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,16080.0000,1,363452,0),(356594,351121,'Complex Shield Hardener','Once activated, this module temporarily reduces the damage done to shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,26310.0000,1,363452,0),(356617,351064,'\'Neo\' Assault C/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(356618,351064,'\'Neo\' Assault ck.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,35250.0000,1,354378,0),(356619,351064,'\'Neo\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,4905.0000,1,354376,0),(356620,351064,'\'Neo\' Scout G/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(356621,351064,'\'Neo\' Scout gk.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,35250.0000,1,354390,0),(356622,351064,'\'Neo\' Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,4905.0000,1,354388,0),(356623,351064,'\'Neo\' Sentinel A/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,13155.0000,1,354381,0),(356624,351064,'\'Neo\' Sentinel ak.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,35250.0000,1,354382,0),(356625,351064,'\'Neo\' Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,4905.0000,1,354380,0),(356626,351064,'\'Neo\' Logistics M/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(356627,351064,'\'Neo\' Logistics mk.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,35250.0000,1,354386,0),(356628,351064,'\'Neo\' Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,4905.0000,1,354384,0),(356629,351121,'Militia Codebreaker','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,400.0000,1,355466,0),(356630,350858,'ZN-28 Nova Knives','A close-quarters melee weapon, the nova knife is as deadly a weapon as anything on the battlefield. Its name derives from the heated plasma edge of the blade   formed by a thermic igniter and linear gravity condenser   that, in skilled hands, can be used to carve through even the thickest dropsuit armor.',0,0.01,0,1,NULL,2955.0000,1,356435,0),(356632,350858,'Ishukone Nova Knives','A close-quarters melee weapon, the nova knife is as deadly a weapon as anything on the battlefield. Its name derives from the heated plasma edge of the blade   formed by a thermic igniter and linear gravity condenser   that, in skilled hands, can be used to carve through even the thickest dropsuit armor.',0,0.01,0,1,NULL,12975.0000,1,356436,0),(356658,351648,'Nova Knife Operation','Skill at handling nova knives.\r\r\n\r\r\n5% reduction to nova knife charge time per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(356701,351648,'Nova Knife Proficiency','Skill at handling nova knives. \r\n\r\n+3% nova knife damage per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(356703,351121,'\'Oculus\' Basic Range Amplifier','Increases dropsuit\'s scan radius allowing it to detect enemy units at greater range.',0,0.01,0,1,NULL,825.0000,1,354671,0),(356704,351121,'\'Ultrasonic\' Enhanced Range Amplifier','Increases dropsuit\'s scan radius allowing it to detect enemy units at greater range.',0,0.01,0,1,NULL,3615.0000,1,354671,0),(356705,351121,'\'Sjon\' Complex Range Amplifer','Increases dropsuit\'s scan radius allowing it to detect enemy units at greater range.',0,0.01,0,1,NULL,2205.0000,1,354671,0),(356707,351121,'Complex Range Amplifier','Increases dropsuit\'s scan radius allowing it to detect enemy units at greater range.',0,0.01,0,1,NULL,3615.0000,1,354671,0),(356708,351121,'Militia Precision Enhancer','Improves dropsuit\'s scan precision making it easier to detect nearby enemy signals.',0,0.01,0,1,NULL,340.0000,1,355466,0),(356709,351844,'A-86 Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\n\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,2625.0000,1,364493,0),(356710,351844,'CreoDron Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\n\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,11535.0000,1,364494,0),(356711,351121,'Militia Range Amplifier','Increases dropsuit\'s scan radius allowing it to detect enemy units at greater range.',0,0.01,0,1,NULL,340.0000,1,355466,0),(356724,351648,'Profile Dampening','Basic understanding of scan profiles.\r\r\n \r\r\nUnlocks the ability to use profile dampener modules.\r\r\n\r\r\n2% reduction to dropsuit scan profile per level.',0,0.01,0,1,NULL,149000.0000,1,353708,0),(356725,351648,'Sensor Upgrades','Basic understanding of scanning and sensors. \r\r\n\r\r\n5% reduction to CPU usage of scanning and sensor modules per level.',0,0.01,0,1,NULL,66000.0000,1,NULL,0),(356788,351121,'Militia Armor Plates Blueprint','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.',0,0.01,0,1,NULL,370.0000,1,355466,0),(356789,351121,'Militia Armor Repairer Blueprint','Passively repairs damage done to dropsuit\'s armor.',0,0.01,0,1,NULL,520.0000,1,355466,0),(356790,351121,'Militia Cardiac Stimulant Blueprint','Increases maximum stamina of the user.\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced.',0,0.01,0,1,NULL,450.0000,1,354425,0),(356791,351121,'Militia Kinetic Catalyzer Blueprint','Increases sprinting speed of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,270.0000,1,355466,0),(356792,351121,'Militia Cardiac Regulator Blueprint','Increases max stamina and stamina recovery rate of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,290.0000,1,355466,0),(356793,351121,'Militia Codebreaker Blueprint','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,400.0000,1,355466,0),(356794,351121,'Militia CPU Upgrade Blueprint','Increases dropsuit\'s maximum CPU output.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,490.0000,1,355466,0),(356795,351121,'Militia Precision Enhancer Blueprint','Improves dropsuit\'s scan precision making it easier to detect nearby enemy signals.',0,0.01,0,1,NULL,340.0000,1,355466,0),(356796,351121,'Militia Profile Dampener Blueprint','Decreases dropsuit\'s scan profile making it harder to detect by scanning systems.',0,0.01,0,1,NULL,320.0000,1,355466,0),(356797,351121,'Militia Range Amplifier Blueprint','Increases dropsuit\'s scan radius allowing it to detect enemy units at greater range.',0,0.01,0,1,NULL,340.0000,1,355466,0),(356798,351121,'Militia PG Upgrade Blueprint','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,490.0000,1,355466,0),(356799,351121,'Militia Shield Extender Blueprint','Increases maximum strength of dropsuit\'s shields.',0,0.01,0,1,NULL,400.0000,1,355466,0),(356800,351121,'Militia Shield Recharger Blueprint','Improves the recharge rate of dropsuit\'s shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,550.0000,1,355466,0),(356801,351121,'Militia Shield Regulator Blueprint','Reduces the length of the delay before shield recharge begins.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,270.0000,1,355466,0),(356802,351121,'Militia Heavy Damage Modifier Blueprint','Increases damage output of all heavy handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,520.0000,1,355466,0),(356803,351121,'Militia Light Damage Modifier Blueprint','Increases damage output of all light handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,520.0000,1,355466,0),(356804,351121,'Militia Sidearm Damage Modifier Blueprint','Increases damage output of all sidearm handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,520.0000,1,355466,0),(356805,351121,'Militia Myofibril Stimulant Blueprint','Increases damage done by melee attacks.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,320.0000,1,355466,0),(356819,351844,'K-2 Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,3945.0000,1,354411,0),(356827,351064,'\'Dren\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,610.0000,1,354376,0),(356828,351064,'\'Dren\' Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,8040.0000,1,354380,0),(356829,351064,'\'Dren\' Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,610.0000,1,354384,0),(356830,351064,'\'Dren\' Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\n \r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,354388,0),(356831,350858,'\'Dren\' Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,10080.0000,1,354696,0),(356833,350858,'\'Dren\' Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,610.0000,1,354364,0),(356835,350858,'\'Dren\' Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,270.0000,1,354343,0),(356837,350858,'\'Dren\' Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,1500.0000,1,354331,0),(356839,350858,'\'Covenant\' Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,610.0000,1,354347,0),(356840,351064,'\'Covenant\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,610.0000,1,354376,0),(356841,351210,'Ishukone Watch Saga','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,353664,0),(356842,351210,'Blood Raiders Saga','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,353664,0),(356843,351844,'Militia Drop Uplink Blueprint','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,370.0000,1,355468,0),(356844,351844,'Militia Nanohive Blueprint','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\n\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,370.0000,1,355468,0),(356845,351844,'Militia Repair Tool Blueprint','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\r\n\r\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,460.0000,1,355468,0),(356846,351844,'Militia Nanite Injector Blueprint','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,240.0000,1,355468,0),(356847,350858,'Militia Locus Grenade Blueprint','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor. The Militia variant is standard-issue for all new recruits.',0,0.01,0,1,NULL,180.0000,1,355463,0),(356848,350858,'Militia Assault Rifle Blueprint','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class.\r\r\n\r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,270.0000,1,355463,0),(356849,350858,'Militia Submachine Gun Blueprint','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets. \r\r\n\r\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,480.0000,1,355463,0),(356850,350858,'Militia Sniper Rifle Blueprint','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,610.0000,1,355463,0),(356851,350858,'Militia Swarm Launcher Blueprint','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,610.0000,1,355463,0),(356852,350858,'Militia Scrambler Pistol Blueprint','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\r\n\r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,270.0000,1,355463,0),(356853,350858,'Militia Shotgun Blueprint','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\n\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,610.0000,1,355463,0),(356854,351121,'Militia Light Armor Repairer Blueprint','Passively repairs damage done to the vehicle\'s armor.',0,0.01,0,1,NULL,11040.0000,1,355467,0),(356855,351121,'Militia Heavy Armor Repairer Blueprint','Passively repairs damage done to the vehicle\'s armor.',0,0.01,0,1,NULL,22080.0000,1,355467,0),(356857,351121,'Militia 120mm Armor Plates Blueprint','Increases maximum strength of vehicle\'s armor but the increased mass affects acceleration and top speed.',0,0.01,0,1,NULL,22080.0000,1,355467,0),(356858,351121,'Militia 180mm Reinforced Steel Plates Blueprint','Increases maximum strength of vehicle\'s armor, but the increased mass reduces top speed',0,0.01,0,1,NULL,22080.0000,1,NULL,0),(356859,351121,'Militia 60mm Armor Plates Blueprint','Increases maximum strength of vehicle\'s armor but the increased mass affects acceleration and top speed.',0,0.01,0,1,NULL,11040.0000,1,355467,0),(356860,351121,'Militia Light Shield Booster Blueprint','Once activated, this module instantly recharges a portion of the vehicle\'s shield HP.',0,0.01,0,1,NULL,17240.0000,1,355467,0),(356861,351121,'Militia Heavy Shield Booster Blueprint','Once activated, this module instantly recharges a portion of the vehicle\'s shield HP.',0,0.01,0,1,NULL,37280.0000,1,355467,0),(356862,351121,'Militia Light Shield Extender Blueprint','Increases maximum strength of vehicle\'s shields but increases the shield depleted recharge delay.',0,0.01,0,1,NULL,11040.0000,1,355467,0),(356863,351121,'Militia Heavy Shield Extender Blueprint','Increases maximum strength of vehicle\'s shields but increases the shield depleted recharge delay.',0,0.01,0,1,NULL,22080.0000,1,355467,0),(356864,351121,'Militia Shield Regenerator Blueprint','Improves the recharge rate of the vehicle\'s shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(356865,351121,'Militia Shield Resistance Amplifier','Increases damage resistance of the vehicle\'s shields. -10% damage taken to shield hp.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(356866,351121,'Militia Blaster Damage Amplifier Blueprint','Once activated, this module temporarily increases the damage output of all blaster turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,15000.0000,1,NULL,0),(356867,351121,'Militia Missile Damage Amplifier Blueprint','Once activated, this module temporarily increases the damage output of all missile launcher turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,15000.0000,1,NULL,0),(356868,351121,'Militia CPU Upgrade Unit Blueprint','Increases a vehicle\'s maximum CPU output in order to support more CPU intensive modules.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,4160.0000,1,355467,0),(356869,351121,'Militia Power Diagnostic System Blueprint','Increases the overall efficiency of a vehicle\'s engineering subsystems, thereby increasing its powergrid, shields and shield recharge by 3%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters shield recharge rate or powergrid will be reduced.',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(356870,351121,'Militia Powergrid Upgrade Blueprint','Increases a vehicles\'s maximum powergrid output in order to support more PG intensive modules.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,4160.0000,1,355467,0),(356871,351210,'Viper Blueprint','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,27495.0000,1,355464,0),(356872,351210,'Gorgon Blueprint','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,27495.0000,1,355464,0),(356873,351210,'Sica Blueprint','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,59565.0000,1,355464,0),(356874,351210,'Soma Blueprint','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,59565.0000,1,355464,0),(356875,351210,'Onikuma Blueprint','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,18330.0000,1,355464,0),(356876,351210,'Baloch Blueprint','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,18330.0000,1,355464,0),(356877,351844,'F/45 Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\n\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,6585.0000,1,355188,0),(356878,351844,'Boundless Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\n\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,28845.0000,1,355189,0),(356882,351844,'F/49 Proximity Explosive','A proximity variant of the F/41 series of remote explosives designed to detonate automatically when an unidentified vehicle signature is detected. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units caught in the blast. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,6585.0000,1,355188,0),(356883,351844,'Boundless Proximity Explosive','A proximity variant of the F/41 series of remote explosives designed to detonate automatically when an unidentified vehicle signature is detected. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units caught in the blast. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,28845.0000,1,355189,0),(356900,351844,'\'Acolyth\' A-86 Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,4305.0000,1,364493,0),(356901,351844,'\'Cirrus\' CreoDron Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,7050.0000,1,364494,0),(356909,351210,'HAV','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,200000.0000,1,NULL,0),(356913,350858,'\'Exile\' Assault Rifle','While functionally identical to the majority of mass-produced rifles available today, the choice of construction materials and unique cyclotron design has led many to speculate that the weapon is the work of Karisim Vynneve, the once prolific weapons designer thought killed in a test-fire exercise more than a decade ago. Whether a warning, a statement of intent or simply an elaborate ruse, it does not change the fact that it s a beautifully crafted weapon.',0,0.01,0,1,NULL,1500.0000,1,354331,0),(356914,350858,'\'Syndicate\' Submachine Gun','Due to its simple construction and readily available parts, the SMG has undergone a host of re-designs since it was introduced to the market. This particular modification was first popularized years ago by criminal organizations in the Curse region but ultimately fell out of favor, replaced by newer, more sophisticated weaponry.  Cheap, reliable and as lethal as ever, it has regained popularity, this time in the hands of cloned soldiers on battlefields throughout New Eden.',0,0.01,0,1,NULL,675.0000,1,354352,0),(356918,351844,'\'Eclipse\' Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,1605.0000,1,364492,0),(356925,350858,'Sniper Rifle [Experimental]','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,760.0000,1,NULL,0),(357007,354753,'[TEST] Drone Hive 2','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(357009,354753,'[TEST] Drone Hive 2','Installation component needs a description!',0,0.01,0,1,NULL,0.0000,1,NULL,0),(357011,351844,'Compact Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,900.0000,1,354410,0),(357018,351844,'Flux Proximity Explosive','A proximity variant of the F/41 series of remote explosives designed to detonate automatically when an unidentified vehicle signature is detected. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units caught in the blast. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,2460.0000,1,355187,0),(363069,350858,'Thukker Contact Locus Grenade','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor.',0,0.01,0,1,NULL,23190.0000,1,363466,0),(363096,351121,'Militia Mobile CRU Blueprint','This module provides a clone reanimation unit inside a manned vehicle for mobile spawning.',0,0.01,0,1,NULL,11600.0000,1,355467,0),(363105,350858,'ACOG Test Tactical Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,77720.0000,1,NULL,0),(363106,350858,'Ironsight Test Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,53640.0000,1,NULL,0),(363107,350858,'Red Dot Test Burst Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,77720.0000,1,NULL,0),(363309,350858,'Militia Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\r\n\r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,610.0000,1,355463,0),(363310,351064,'Enforcer','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer. \r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,4680.0000,1,NULL,0),(363349,351064,'Balac\'s Modified Assault ck.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,94425.0000,1,354378,0),(363350,350858,'Balac\'s MRN-30 Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,56925.0000,1,354354,0),(363351,350858,'Balac\'s N-17 Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,126495.0000,1,354350,0),(363354,351210,'Angel Cartel Saga','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,353664,0),(363355,350858,'KLA-90 Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,10770.0000,1,364057,0),(363356,350858,'Allotek Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,47220.0000,1,364058,0),(363357,350858,'\'Charstone\' Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,4020.0000,1,364056,0),(363358,350858,'\'Ripshade\' KLA-90 Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,10770.0000,1,364057,0),(363359,350858,'\'Deadflood\' Allotek Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,28845.0000,1,364058,0),(363360,351648,'Plasma Cannon Operation','Skill at handling plasma cannons.\r\n\r\n5% reduction to plasma cannon charge time per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(363362,351648,'Plasma Cannon Proficiency','Skill at handling plasma cannons.\r\r\n\r\r\n+3% plasma cannon damage against shields per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(363388,351121,'Enhanced Armor Hardener','Once activated, this module temporarily reduces the damage done to armor.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,16080.0000,1,357120,0),(363389,351121,'Complex Armor Hardener','Once activated, this module temporarily reduces the damage done to armor.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,26310.0000,1,357120,0),(363390,351121,'R-Type Vehicular Hardener','Armor Hardeners sink damage done to armor hitpoints.  They need to be activated to take effect. -25% damage to armor.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,5000.0000,1,NULL,0),(363394,350858,'\'Burnstalk\' Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,4020.0000,1,354690,0),(363395,350858,'\'Deathchorus\' ELM-7 Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,10770.0000,1,354691,0),(363396,350858,'\'Rawspark\' Viziam Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,28845.0000,1,354692,0),(363397,351064,'\'Dragonfly\' Assault [nSv]','Engineered using technology plundered from archeological sites during the UBX-CC conflict in YC113, the Dragonfly is a GATE suit designed to adapt and conform to an individual s usage patterns, learning and eventually predicting actions before they occur, substantially increasing response times and maneuverability.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(363398,350858,'\'Toxin\' Assault Rifle','A modified version of the widely adopted Federation weapon, the Toxin is a fully-automatic rifle adapted to fire doped plasma slugs. \r\r\nA questionable design that many would agree offers little benefit beyond increasing a victim s discomfort as contaminants spread through the system, liquefying internal organs and disrupting nanite helixes in the bloodstream, causing the subunits to go haywire and attack the body they re designed to sustain.',0,0.01,0,1,NULL,1500.0000,1,354331,0),(363400,351844,'Hacked Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,900.0000,1,354410,0),(363405,351121,'CN-V Light Damage Modifier','Increases damage output of all light handheld weapons.\r\n\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,354434,0),(363406,350858,'HK-2 Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,2955.0000,1,354344,0),(363408,350858,'Hacked EX-0 AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range.',0,0.01,0,1,NULL,2010.0000,1,363468,0),(363409,351844,'\'Torrent\' Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,2415.0000,1,354410,0),(363410,351844,'\'Whisper\' Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,3015.0000,1,354414,0),(363411,351844,'\'Cannibal\' Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,1605.0000,1,355194,0),(363412,351844,'\'Terminus\' Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,4,825.0000,1,354403,0),(363491,350858,'Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,1500.0000,1,365766,0),(363551,350858,'Magsec SMG','The magsec is a semi-automatic firearm capable of sustained, accurate fire at ranges beyond what conventional sidearms can offer. A high-speed slider feeds current to a magazine of hyper velocity projectiles that are discharged with minimal separation, maximizing energy efficiency and reducing flux shear to produce a weapon with lethal kinetic potential. \r\r\n\r\r\nHaving overcome early reliability issues, manufacturers  have since taken advantage of the weapon s modular design; the magsec has been made available in multiple combat configurations   including optical sights and silenced operation   and is in widespread service throughout the cluster.',0,0.01,0,1,NULL,675.0000,1,366575,0),(363570,350858,'Assault Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets. \r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,4,2460.0000,1,364052,0),(363578,350858,'Ion Pistol','A ruthlessly efficient close-quarters weapon, the ion pistol fires charged plasma munitions that rupture shields and scorch armor. Each discharge is enveloped in an electrostatic sheath that reduces field distortion and increases stability. The improved dispersion and stopping power is not without drawbacks though, as the higher density of each slug generates excessive heat, enough to seize the weapon if the rate of fire is not carefully controlled.\r\r\n\r\r\nBy overriding internal temperature controls, the weapon can be overcharged to produce a focused, bulk discharge of sufficient lethality to instantly neutralize most soft targets. Caution is advised however, as each overcharged shot will shut down internal systems until the excess heat can be flushed from the weapon s core.',0,0.01,0,1,NULL,675.0000,1,366742,0),(363592,350858,'Bolt Pistol','The result of years of R&D, the bolt pistol is a high-impact handgun capable of firing kinetic projectiles with pinpoint accuracy. Building upon its copious experience with microscale rail weaponry, Kaalakiota has further refined the technology to produce what is commonly regarded as the most powerful handgun on the market.\r\r\n\r\r\nCentral to its success is a smart sensor that bleeds off a minute amount of dropsuit energy at the moment of discharge, dissipating the sharp recoil impulse through the suit s internal membrane and greatly reducing the peak force of each shot. This seemingly minor innovation is what makes accurate fire of the weapon possible without the need for an external mounting.',0,0.01,0,1,NULL,675.0000,1,366571,0),(363604,350858,'Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,1500.0000,1,365770,0),(363770,350858,'Assault Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,1,2460.0000,1,365770,0),(363774,350858,'Core Seeker Flaylock','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,34770.0000,0,NULL,0),(363775,350858,'VN-30 Seeker Flaylock','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,7935.0000,0,NULL,0),(363780,350858,'Core Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\n\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,21240.0000,1,363793,0),(363781,350858,'GN-13 Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\n\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,4845.0000,1,363792,0),(363782,350858,'\'Darkvein\' Seeker Flaylock','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,1815.0000,1,NULL,0),(363783,350858,'\'Maimharvest\' VN-30 Seeker Flaylock','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,4845.0000,1,NULL,0),(363784,350858,'\'Skinbore\' Core Seeker Flaylock','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,12975.0000,1,NULL,0),(363785,350858,'\'Splashbone\' Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,1815.0000,1,363791,0),(363786,350858,'\'Rustmorgue\' GN-13 Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,4845.0000,1,363792,0),(363787,350858,'\'Howlcage\' Core Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,12975.0000,1,363793,0),(363788,351648,'Flaylock Pistol Operation','Skill at handling flaylock pistols.\r\n\r\n+5% flaylock pistol blast radius per level.',0,0,0,1,NULL,149000.0000,1,353684,0),(363789,351648,'Flaylock Pistol Proficiency','Skill at handling flaylock pistols.\r\r\n\r\r\n+3% flaylock pistol damage against armor per level.',0,0,0,1,NULL,567000.0000,1,353684,0),(363794,350858,'Burst Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,5520.0000,0,NULL,0),(363796,350858,'GN-20 Specialist Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\n\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,7935.0000,1,363792,0),(363797,350858,'VN-35 Tactical Seeker Flaylock','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,7935.0000,0,NULL,0),(363798,350858,'Breach Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\n\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,1110.0000,1,363791,0),(363800,350858,'Core Specialist Seeker Flaylock','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,56925.0000,0,NULL,0),(363801,350858,'Core Tactical Seeker Flaylock','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0,0,1,NULL,34770.0000,0,NULL,0),(363848,350858,'\'Ashborne\' Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,4020.0000,1,364052,0),(363849,350858,'\'Shrinesong\' CRW-04 Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,10770.0000,1,364053,0),(363850,350858,'\'Bloodgrail\' Viziam Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,28845.0000,1,364054,0),(363851,350858,'CRD-9 Assault Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,4,10770.0000,1,364053,0),(363852,350858,'Carthum Assault Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,4,47220.0000,1,364054,0),(363857,350858,'\'Sinwarden\' CRD-9 Assault Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,10770.0000,1,364053,0),(363858,350858,'\'Stormvein\' Carthum Assault Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,28845.0000,1,364054,0),(363861,351648,'Scrambler Rifle Operation','Skill at handling scrambler rifles.\r\r\n\r\r\n5% bonus to scrambler rifle cooldown speed per level.',0,0,0,1,NULL,149000.0000,1,353684,0),(363862,351648,'Scrambler Rifle Proficiency','Skill at handling scrambler rifles.\r\r\n\r\r\n+3% scrambler rifle damage against shields per level.',0,0,0,1,NULL,567000.0000,1,353684,0),(363934,351064,'Assault A-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(363935,351064,'Assault G-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(363936,351064,'Assault M-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(363955,351064,'Scout C-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,354388,0),(363956,351064,'Scout A-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,354388,0),(363957,351064,'Scout M-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\n\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat. \r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,354388,0),(363982,351064,'Logistics C-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,3000.0000,1,354384,0),(363983,351064,'Logistics G-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,3000.0000,1,354384,0),(363984,351064,'Logistics A-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,3000.0000,1,354384,0),(364009,351064,'Sentinel C-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,3000.0000,1,354380,0),(364010,351064,'Sentinel G-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0,0,1,NULL,3000.0000,1,354380,0),(364011,351064,'Sentinel M-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,3000.0000,1,354380,0),(364018,351064,'Assault M/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(364019,351064,'Assault G/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(364020,351064,'Assault A/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(364021,351064,'Assault mk.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,57690.0000,1,354378,0),(364022,351064,'Assault ak.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,57690.0000,1,354378,0),(364023,351064,'Assault gk.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,57690.0000,1,354378,0),(364024,351064,'Scout C/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(364025,351064,'Scout A/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(364026,351064,'Scout M/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\n\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(364027,351064,'Scout ck.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,57690.0000,1,354390,0),(364028,351064,'Scout mk.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\n\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,57690.0000,1,354390,0),(364029,351064,'Scout ak.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,57690.0000,1,354390,0),(364030,351064,'Logistics C/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(364031,351064,'Logistics G/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(364032,351064,'Logistics A/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(364033,351064,'Logistics ck.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,57690.0000,1,354386,0),(364034,351064,'Logistics gk.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,57690.0000,1,354386,0),(364035,351064,'Logistics ak.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,57690.0000,1,354386,0),(364036,351064,'Sentinel M/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,8040.0000,1,354381,0),(364037,351064,'Sentinel C/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0,0,1,NULL,8040.0000,1,354381,0),(364038,351064,'Sentinel G/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,8040.0000,1,354381,0),(364039,351064,'Sentinel mk.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,57690.0000,1,354382,0),(364040,351064,'Sentinel ck.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0,0,1,NULL,57690.0000,1,354382,0),(364041,351064,'Sentinel gk.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,57690.0000,1,354382,0),(364094,354641,'Active Omega-Booster (7-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool. The Omega-Booster features superior performance over standard models.',0,0.01,0,1,NULL,0.0000,1,354543,0),(364095,351064,'\'Raider\' Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,610.0000,1,368018,0),(364096,351064,'\'CQC\' Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,610.0000,1,368018,0),(364097,351064,'\'Hunter\' Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,610.0000,1,368018,0),(364098,351064,'Shock Assault','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient equipment hard points for mission-specific customizations.\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier\'s strength, balance, and resistance to impact forces. The suit\'s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. Furthermore, every armor plate on the suit is energized to absorb the force of incoming plasma-based projectiles, neutralizing their ionization and reducing thermal damage.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment\'s notice. Its ability to carry anything from small arms and explosives to heavy anti-vehicle munitions and deployable support gear makes it the most adaptable suit on the battlefield.',0,0.01,0,1,NULL,0.0000,1,368019,0),(364099,351064,'\'Mauler\' Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,3000.0000,1,368020,0),(364101,354641,'Active Recruit-Booster (7-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(364102,350858,'Recruit Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class.\r\r\n\r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,610.0000,1,355463,0),(364103,350858,'Recruit Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\r\n\r\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,270.0000,1,355463,0),(364105,351064,'Recruit Militia Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(364121,351210,'CreoDron Methana','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,0.0000,1,353664,0),(364171,351210,'Kaalakiota Tactical HAV','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. \r\r\n\r\r\nSpecial Kaalakiota limited edition release.',0,0,0,1,NULL,97500.0000,1,353657,0),(364172,351210,'CreoDron Breach HAV','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. \r\r\n\r\r\nSpecial CreoDron limited edition release.',0,0,0,1,NULL,97500.0000,1,353657,0),(364173,351121,'Militia Spool Reduction Unit','Reduces spool up duration of railgun turrets by 5%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0,0,1,NULL,8280.0000,1,NULL,0),(364174,351121,'Militia Heat Sink','Reduces turret heat build-up of blaster and railgun turrets, thereby increasing effective firing time before overheating.  Reduces heat cost per shot by 5%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0,0,1,NULL,8280.0000,1,NULL,0),(364175,351121,'Militia Tracking Enhancement','Tracking Enhancers increase the rotation speed of all turrets equipped on a vehicle. Tracking speed increased by 22%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0,0,1,NULL,8280.0000,1,NULL,0),(364176,351121,'Militia Active Heat Sink','This coolant system actively flushes a weapon\'s housing, enabling it to fire for a longer duration before overheating.  Reduces heat cost per shot by 12%.\r\r\n\r\r\nNOTE: Only one Active Heatsink can be fitted at a time.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0,0,1,NULL,11040.0000,1,NULL,0),(364177,351121,'Militia Tracking CPU','Tracking computers actively increase the rotation speed of all turrets equipped on a vehicle. Tracking increased by 35%.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0,0,1,NULL,11040.0000,1,NULL,0),(364178,351064,'\'Black Eagle\' Scout G/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. This variant of the A-Series Scout dropsuit was specifically requested by the Federal Intelligence Office s Special Department of Internal Investigations and was tailored to their needs for front line military operations and peacekeeping duty within the Gallente Federation.\r\n\r\nThe entire suit is wrapped in un-polished matte black crystalline carbonide armor plates, in homage to the  Black Eagles  nickname that the Special Department of Internal Investigation has become known by. Every armor plate attached to the suit is wrapped in an energized adaptive nano membrane designed to deflect small arms fire and absorb the force of incoming plasma based projectiles, neutralizing their ionization and reducing their ability to cause thermal damage.\r\n\r\nBuilding on the original design, the standard fusion core is replaced with a wafer thin seventh generation Duvolle Laboratories T-3405 fusion reactor situated between the user s shoulder blades to power the entire suit. Given requests from the Federal Intelligence Office for a suit that could outperform anything else in its class when worn by a well-trained user, Poteque Pharmaceuticals were drafted in to create custom kinetic monitoring equipment and a servo assisted movement system specifically tailored to this suit. Finally, to meet the operational demands of the Special Department of Internal Investigation the suit has undergone heavy modifications to allow mounting of two light weapon systems at the expense of support module capacity.\r\n',0,0.01,0,1,NULL,8040.0000,1,354389,0),(364200,350858,'\'Black Eagle\' Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,10080.0000,1,354696,0),(364201,350858,'\'Black Eagle\' Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0,0.01,1,NULL,1500.0000,1,354331,0),(364205,364204,'Cargo Hub','The Cargo Hub district can be hard to navigate, with its buildings tightly bound in a spiderweb of thick wires and tubes. Though most of wiring either lies underground or is stretched overhead, there is enough of it at body height to elicit very careful passage by pedestrians. Inside the buildings, rows upon rows of clone vats stand there in calm silence, hooked up to various types of monitoring and maintenance equipment.\r\r\n\r\r\nIncreases the district\'s maximum number of clones by 150.\r\r\n\r\r\n10% per district owned to a maximum of 4 districts, or 40%, decrease in manufacturing time at a starbases. This applies to all corporation and alliance starbases anchored at moons around the planet with the owned districts.',110000000,4000,0,1,4,25000000.0000,1,NULL,0),(364206,364204,'Surface Research Lab','The Surface Research Lab district has a permanently humid and chilly atmosphere, irrespective of its planetary coordinates, and is staffed only by the hardiest of workers. They wear protective gear at all times, not only to stave off the cold, but to keep absolutely safe the delicate electronics and experimental chemical stored in the various buildings of the district. These materials don\'t last long when put into use, but for the inert clones they\'re employed on, it\'s long enough.\r\r\n\r\r\nDecreases the attrition rate of moving clones between districts.\r\r\n\r\r\n5% per district owned to a maximum of 4 districts, or 20%, reduction in starbase fuel usage. This applies to all corporation and alliance starbases anchored at moons around the planet with the owned districts.',110000000,4000,0,1,4,25000000.0000,1,NULL,0),(364207,364204,'Production Facility','The Production Facility district is always hungry for materials, particularly biomass. The land around it tends to be empty of flora and fauna, though whether this is due to the faint smell in the air or something more sinister has never been established. Those visitors who\'ve been given the full tour (including the usually-restricted sections), and who\'ve later been capable of describing the experience, have said it\'s like going through a series of slaughterhouses in reverse.\r\r\n\r\r\nIncreases the district\'s clone generation rate by 20 clones per cycle.',110000000,4000,0,1,4,25000000.0000,1,NULL,0),(364242,351064,'Federal Defense Union Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,354388,0),(364243,351064,'State Protectorate Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(364245,351121,'Militia Overdrive','This propulsion upgrade increases a vehicle powerplant\'s power output for increased speed and torque.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,4160.0000,1,NULL,0),(364246,351210,'CreoDron Transport Dropship','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,45000.0000,1,355464,0),(364247,351210,'Kaalakiota Recon Dropship','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,45000.0000,1,355464,0),(364248,351121,'Militia Scanner','Once activated, this module will reveal the location of enemy units within its active radius provided it\'s precise enough to detect the unit\'s scan profile.',0,0.01,0,1,NULL,3660.0000,1,355467,0),(364249,351121,'Militia Damage Control Unit','Offers a slight increase to damage resistance of vehicle\'s shields and armor. Shield damage -2%, Armor damage -2%.\r\r\n\r\r\nNOTE: Only one damage control unit can be fitted at a time.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0,0,1,NULL,9680.0000,1,NULL,0),(364250,351121,'Militia Afterburner','Once activated, this module provides a temporary speed boost to aerial vehicles.\r\r\n\r\r\nNOTE: Only one afterburner can be fitted at a time.\r\r\nStacking penalties apply to this module and other modules of this type; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,2745.0000,1,355467,0),(364269,351648,' ',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(364317,351064,'Staff Recruiter Militia Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(364319,351064,'Senior Recruiter Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(364322,351064,'Master Recruiter Assault C-II','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,4905.0000,1,354376,0),(364331,350858,'Staff Recruiter Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,610.0000,1,354331,0),(364332,350858,'Staff Recruiter Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,1500.0000,1,354347,0),(364333,350858,'Staff Recruiter Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,675.0000,1,354343,0),(364334,350858,'Staff Recruiter Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,1500.0000,1,354690,0),(364344,351210,'Falchion','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies.\r\r\n\r\r\nThe Enforcer class possesses the greatest damage output and offensive reach of all HAVs, but the necessary hull modifications needed to achieve this result in weakened armor and shield output and greatly compromised speed.\r\r\n',0,0,0,1,NULL,1277600.0000,1,NULL,0),(364348,351210,'Vayu','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies.\r\r\n\r\r\nThe Enforcer class possesses the greatest damage output and offensive reach of all HAVs, but the necessary hull modifications needed to achieve this result in weakened armor and shield output and greatly compromised speed.\r\r\n',0,0,0,1,NULL,1227600.0000,1,NULL,0),(364355,351210,'Callisto','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden s modern battlefield.\r\r\n\r\r\nThe Scout class LAV is a high speed, highly maneuverable vehicle optimized for guerilla warfare; attacking vulnerable targets and withdrawing immediately or using its mobility to outmaneuver slower targets.  These LAVs are relatively fragile but occupants enjoy the benefit of increased acceleration and faster weapon tracking.\r\r\n',0,0,0,1,NULL,84000.0000,1,NULL,0),(364369,351210,'Abron','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden s modern battlefield.\r\r\n\r\r\nThe Scout class LAV is a high speed, highly maneuverable vehicle optimized for guerilla warfare; attacking vulnerable targets and withdrawing immediately or using its mobility to outmaneuver slower targets.  These LAVs are relatively fragile but occupants enjoy the benefit of increased acceleration and faster weapon tracking.\r\r\n',0,0,0,1,NULL,84000.0000,1,NULL,0),(364378,351210,'Crotalus','The Dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm s way.\r\r\n\r\r\nThe Bomber class is a tactical unit designed to eradicate heavy ground units and installations. While the increased bulk of the payload and augmented hull affect maneuverability and limit its ability to engage aerial targets, with accurate bombing it remains a singularly devastating means of engaging ground targets.\r\r\n',0,0,0,1,NULL,0.0000,1,NULL,0),(364380,351210,'Amarok','The Dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm s way.\r\r\n\r\r\nThe Bomber class is a tactical unit designed to eradicate heavy ground units and installations. While the increased bulk of the payload and augmented hull affect maneuverability and limit its ability to engage aerial targets, with accurate bombing it remains a singularly devastating means of engaging ground targets.\r\r\n\r\r\n\r\r\n',0,0,0,1,NULL,0.0000,1,NULL,0),(364408,351844,'Flux Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\n\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,975.0000,1,364492,0),(364409,351844,'A-45 Quantum Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\n\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,4305.0000,1,364493,0),(364410,351844,'A-19 Stable Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\n\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,4305.0000,1,364493,0),(364411,351844,'Duvolle Quantum Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\n\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,18885.0000,1,364494,0),(364412,351844,'CreoDron Flux Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\n\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,18885.0000,1,364494,0),(364413,351844,'CreoDron Proximity Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\n\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,18885.0000,1,364494,0),(364414,351844,'Duvolle Focused Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\n\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,30915.0000,1,364494,0),(364430,351648,' ',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(364471,354641,'Staff Recruiter Active Booster (1-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(364472,354641,'Staff Recruiter Active Booster (3-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(364477,354641,'Staff Recruiter Active Booster (7-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(364478,354641,'Staff Recruiter Active Booster (15-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(364479,354641,'Staff Recruiter Active Booster (30-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(364490,351210,'Senior Recruiter Light Assault Vehicle','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,353664,0),(364506,351121,'Tracking Enhancer (Scout LAV)','Tracking Enhancer (Scout LAV)',0,0,0,1,NULL,10.0000,1,NULL,0),(364519,351648,'Dropsuit Upgrades','Skill at altering dropsuit systems.\r\r\n\r\r\nUnlocks access to equipment and dropsuit modules.',0,0,0,1,NULL,48000.0000,1,353708,0),(364520,351648,'Dropsuit Core Upgrades','Basic understanding of dropsuit core systems.\r\r\n\r\r\n+1% to dropsuit maximum PG and CPU per level.',0,0,0,1,NULL,66000.0000,1,353708,0),(364521,351648,'Dropsuit Biotic Upgrades','Basic understanding of dropsuit biotic augmentations.\r\n\r\nUnlocks the ability to use biotic modules.\r\n\r\n+1% to sprint speed, maximum stamina and stamina recovery per level.',0,0,0,1,NULL,66000.0000,1,353708,0),(364531,351648,'Explosives','Basic knowledge of explosives.\r\n\r\n3% reduction to CPU usage per level.',0,0,0,1,NULL,66000.0000,1,353684,0),(364532,351648,'Heavy Weapon Operation','Basic understanding of heavy weapon operation.\r\n\r\n3% reduction to CPU usage per level.',0,0,0,1,NULL,66000.0000,1,353684,0),(364533,351648,'Light Weapon Operation','Basic understanding of light weapon operation.\r\n\r\n3% reduction to CPU usage per level.',0,0,0,1,NULL,66000.0000,1,353684,0),(364534,351648,'Sidearm Operation','Basic understanding of sidearm operation.\r\n\r\n3% reduction to CPU usage per level.',0,0,0,1,NULL,66000.0000,1,353684,0),(364555,351648,'Shield Extension','Advanced understanding of dropsuit shield enhancement.\r\r\n\r\r\nUnlocks access to shield extender dropsuit modules.\r\r\n\r\r\n+2% to shield extender module efficacy per level.',0,0,0,1,NULL,149000.0000,1,353708,0),(364556,351648,'Shield Regulation','Advanced understanding of dropsuit shield regulation.\r\r\n\r\r\nUnlocks access to shield regulator dropsuit modules.\r\r\n\r\r\n+2% to shield regulator module efficacy per level.',0,0,0,1,NULL,149000.0000,1,353708,0),(364559,350858,'\'Templar\' Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules.',0,0.01,0,1,NULL,270.0000,1,354343,0),(364561,350858,'\'Templar\' Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,4020.0000,1,364052,0),(364563,350858,'\'Templar\' Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,4020.0000,1,354690,0),(364564,351844,'\'Templar\' Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,1470.0000,1,354403,0),(364565,351064,'\'Templar\' Assault A-I','Few have heard of the Thirteen, but this suit is proof of the Templars  existence. First-generation tech that, while crude, remains as brutally effective as anything available on the battlefield today. The suit s original form is considered immaculate, the perfect amalgam of science and religion, embellished only slightly as befitting of the first Templars  status. Inscribed within each suit, unseen but felt, are passages from the Scriptures, The Word that guides the hand of all True Amarr.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(364566,351064,'\'Templar\' Logistics A-I','Few have heard of the Thirteen, but this suit is proof of the Templars  existence. First-generation tech that, while crude, remains as brutally effective as anything available on the battlefield today. The suit s original form is considered immaculate, the perfect amalgam of science and religion, embellished only slightly as befitting of the first Templars  status. Inscribed within each suit, unseen but felt, are passages from the Scriptures, The Word that guides the hand of all True Amarr.',0,0.01,0,1,NULL,3000.0000,1,354384,0),(364567,351064,'\'Templar\' Sentinel A-I','Few have heard of the Thirteen, but this suit is proof of the Templars  existence. First-generation tech that, while crude, remains as brutally effective as anything available on the battlefield today. The suit s original form is considered immaculate, the perfect amalgam of science and religion, embellished only slightly as befitting of the first Templars  status. Inscribed within each suit, unseen but felt, are passages from the Scriptures, The Word that guides the hand of all True Amarr.',0,0.01,0,1,NULL,610.0000,1,354380,0),(364570,351648,'Amarr Light Dropsuits','Skill at operating Amarr Light dropsuits. \r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,229000.0000,1,353707,0),(364571,351648,'Amarr Medium Dropsuits','Skill at operating Amarr Medium dropsuits.\r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0,0,1,NULL,229000.0000,1,353707,0),(364573,351648,'Caldari Light Dropsuits','Skill at operating Caldari Light dropsuits. \r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,229000.0000,1,353707,0),(364575,351648,'Caldari Heavy Dropsuits','Skill at operating Caldari Heavy dropsuits.\r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0,0,1,NULL,229000.0000,1,353707,0),(364576,351648,'Minmatar Light Dropsuits','Skill at operating Minmatar Light dropsuits. \r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0,0,1,NULL,229000.0000,1,353707,0),(364578,351648,'Minmatar Heavy Dropsuits','Skill at operating Minmatar Heavy dropsuits.\r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0,0,1,NULL,229000.0000,1,353707,0),(364579,351648,'Duplicate skill?','This looks like a duplicate?',0,0,0,1,NULL,0.0000,0,NULL,0),(364580,351648,'Gallente Medium Dropsuits','Skill at operating Gallente Medium dropsuits.\r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0,0,1,NULL,229000.0000,1,353707,0),(364581,351648,'Gallente Heavy Dropsuits','Skill at operating Gallente Heavy dropsuits.\r\r\n\r\r\nUnlocks access to standard dropsuits at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0,0,1,NULL,229000.0000,1,353707,0),(364594,351648,'Amarr Scout Dropsuits','Skill at operating Amarr Scout dropsuits.\r\n\r\nUnlocks access to Amarr Scout dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nScout Suit Bonus: +15% bonus to PG/CPU cost of cloak field per level.\r\nAmarr Scout Bonus: +5% bonus to scan precision, stamina regen and max.stamina per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364595,351648,'Amarr Pilot Dropsuits',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(364596,351648,'Caldari Pilot Dropsuits',' ',0,0,0,1,NULL,0.0000,0,NULL,0),(364597,351648,'Caldari Scout Dropsuits','Skill at operating Caldari Scout dropsuits.\r\n\r\nUnlocks access to Caldari Scout dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nScout Suit Bonus: +15% bonus to PG/CPU cost of cloak field per level.\r\nCaldari Scout Bonus: +10% bonus to dropsuit scan radius, 3% to scan profile per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364598,351648,'Gallente Pilot Dropsuits','Skill at operating Gallente Pilot dropsuits.\r\r\n\r\r\nUnlocks access to Gallente Pilot dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nPilot Suit Bonus: +10% to active vehicle module cooldown time per level.\r\r\nGallente Pilot Bonus: +2% to efficacy of vehicle shield and armor modules per level.',0,0,0,1,NULL,0.0000,0,NULL,0),(364599,351648,'Minmatar Scout Dropsuits','Skill at operating Minmatar Scout dropsuits.\r\r\n\r\r\nUnlocks access to Minmatar Scout dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nScout Suit Bonus: +15% bonus to PG/CPU cost of cloak field per level.\r\r\nMinmatar Scout Bonus: +5% bonus to hacking speed and nova knife damage per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364600,351648,'Minmatar Pilot Dropsuits','Skill at operating Minmatar Pilot dropsuits.\r\r\n\r\r\nUnlocks access to Minmatar Pilot dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nPilot Suit Bonus: +10% to active vehicle module cooldown time per level.\r\r\nMinmatar Pilot Bonus: +5% to efficacy of vehicle weapon upgrade modules per level.\r\r\n',0,0,0,1,NULL,0.0000,0,NULL,0),(364601,351648,'Amarr Sentinel Dropsuits','Skill at operating Amarr Sentinel dropsuits.\r\n\r\nUnlocks access to Amarr Sentinel dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nSentinel Suit Bonus: 5% resistance to splash damage per level. 5% reduction to PG/CPU cost of heavy weapons per level.\r\nAmarr Sentinel Bonus: \r\n3% armor resistance to projectile weapons.\r\n2% shield resistance to hybrid - railgun weapons.',0,0,0,1,NULL,787000.0000,1,353707,0),(364602,351648,'Amarr Commando Dropsuits','Skill at operating Amarr Commando dropsuits.\r\r\n\r\r\nUnlocks access to Amarr Commando dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nCommando Suit Bonus: 5% reduction to reload speed of light weapons per level.\r\r\nAmarr Commando Bonus: +2% damage to laser light weapons per level.',0,0.01,0,1,NULL,787000.0000,1,353707,0),(364603,351648,'Caldari Commando Dropsuits','Skill at operating Caldari Commando dropsuits.\r\r\n\r\r\nUnlocks access to Caldari Commando dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nCommando Suit Bonus: 5% reduction to reload speed of light weapons per level.\r\r\nCaldari Commando Bonus: +2% damage to hybrid - railgun light weapons per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364604,351648,'Caldari Sentinel Dropsuits','Skill at operating Caldari Sentinel dropsuits.\r\n\r\nUnlocks access to Caldari Sentinel dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nSentinel Suit Bonus: 5% resistance to splash damage per level. 5% reduction to PG/CPU cost of heavy weapons per level.\r\nCaldari Sentinel Bonus: \r\n3% shield resistance to hybrid - blaster weapons.\r\n2% shield resistance to laser weapons.',0,0,0,1,NULL,787000.0000,1,353707,0),(364605,351648,'Gallente Sentinel Dropsuits','Skill at operating Gallente Sentinel dropsuits.\r\n\r\nUnlocks access to Gallente Sentinel dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nSentinel Suit Bonus: 5% resistance to splash damage per level. 5% reduction to PG/CPU cost of heavy weapons per level.\r\nGallente Sentinel Bonus: \r\n3% armor resistance to hybrid - railgun weapons.\r\n2% armor resistance to projectile weapons.',0,0,0,1,NULL,787000.0000,1,353707,0),(364606,351648,'Gallente Commando Dropsuits','Skill at operating Gallente Commando dropsuits.\r\r\n\r\r\nUnlocks access to Gallente Commando dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nCommando Suit Bonus: 5% reduction to reload speed of light weapons per level.\r\r\nGallente Commando Bonus: +2% damage to hybrid - blaster light weapons per level.',0,0.01,0,1,NULL,787000.0000,1,353707,0),(364607,351648,'Minmatar Sentinel Dropsuits','Skill at operating Minmatar Sentinel dropsuits.\r\n\r\nUnlocks access to Minmatar Sentinel dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nSentinel Suit Bonus: 5% resistance to splash damage per level. 5% reduction to PG/CPU cost of heavy weapons per level.\r\nMinmatar Sentinel Bonus: \r\n3% shield resistance to laser weapons.\r\n2% armor resistance to hybrid - blaster weapons.',0,0,0,1,NULL,787000.0000,1,353707,0),(364608,351648,'Minmatar Commando Dropsuits','Skill at operating Minmatar Commando dropsuits.\r\r\n\r\r\nUnlocks access to Minmatar Commando dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nCommando Suit Bonus: 5% reduction to reload speed of light weapons per level.\r\r\nMinmatar Commando Bonus: +2% damage to projectile and explosive light weapons per level.',0,0.01,0,1,NULL,787000.0000,1,353707,0),(364609,351648,'Amarr Assault Dropsuits','Skill at operating Amarr Assault dropsuits.\r\n\r\nUnlocks access to Amarr Assault dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nAssault Suit Bonus: 5% reduction to PG/CPU cost of light/sidearm weapons and grenades per level.\r\nAmarr Assault Bonus: 5% reduction to laser weaponry heat build-up per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364610,351648,'Amarr Logistics Dropsuits','Skill at operating Amarr Logistics dropsuits.\r\r\n\r\r\nUnlocks access to Amarr Logistics dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nLogistics Suit Bonus: 5% reduction to PG/CPU cost of equipment  per level.\r\r\nAmarr Logistics Bonus: 10% reduction to drop uplink spawn time and +2 to max. spawn count per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364611,351648,'Caldari Assault Dropsuits','Skill at operating Caldari Assault dropsuits.\r\n\r\nUnlocks access to Caldari Assault dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nAssault Suit Bonus: 5% reduction to PG/CPU cost of light/sidearm weapons and grenades per level.\r\nCaldari Assault Bonus: +5% to reload speed of hybrid - railgun light/sidearm weapons per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364612,351648,'Caldari Logistics Dropsuits','Skill at operating Caldari Logistics dropsuits.\r\r\n\r\r\nUnlocks access to Caldari Logistics dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nLogistics Suit Bonus: 5% reduction to PG/CPU cost of equipment  per level.\r\r\nCaldari Logistics Bonus: +10% to nanohive max. nanites and +5% to supply rate and repair amount per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364613,351648,'Gallente Assault Dropsuits','Skill at operating Gallente Assault dropsuits.\r\n\r\nUnlocks access to Gallente Assault dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nAssault Suit Bonus: 5% reduction to PG/CPU cost of light/sidearm weapons and grenades per level.\r\nGallente Assault Bonus: 5% reduction to hybrid - blaster light/sidearm hip-fire dispersion and kick per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364614,351648,'Gallente Logistics Dropsuit','Skill at operating Gallente Logistics dropsuits.\r\r\n\r\r\nUnlocks access to Gallente Logistics dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nLogistics Suit Bonus: 5% reduction to PG/CPU cost of equipment  per level.\r\r\nGallente Logistics Bonus: +10% to active scanner visibility duration and +5% to active scanner precision per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364615,351648,'Minmatar Assault Dropsuits','Skill at operating Minmatar Assault dropsuits.\r\n\r\nUnlocks access to Minmatar Assault dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nAssault Suit Bonus: 5% reduction to PG/CPU cost of light/sidearm weapons and grenades per level.\r\nMinmatar Assault Bonus: +5% to clip size of projectile light/sidearm weapons per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364616,351648,'Minmatar Logistics Dropsuit','Skill at operating Minmatar Logistics dropsuits.\r\r\n\r\r\nUnlocks access to Minmatar Logistics dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\r\n\r\r\nLogistics Suit Bonus: 5% reduction to PG/CPU cost of equipment  per level.\r\r\nMinmatar Logistics Bonus: +10% to repair tool range and +5% to repair amount per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364617,351648,'Gallente Scout Dropsuits','Skill at operating Gallente Scout dropsuits.\r\n\r\nUnlocks access to Gallente Scout dropsuits. Standard at lvl.1; advanced at lvl.3; prototype at lvl.5.\r\n\r\nScout Suit Bonus: +15% bonus to PG/CPU cost of cloak field per level.\r\nGallente Scout Bonus: +2% bonus to dropsuit scan precision, 3% to scan profile per level.',0,0,0,1,NULL,787000.0000,1,353707,0),(364618,351648,'Handheld Weapon Upgrades','Basic understanding of weapon upgrades. \r\r\n\r\r\nUnlocks ability to use weapon upgrades such as damage modifiers.\r\r\n\r\r\n3% reduction to weapon upgrade CPU usage per level.',0,0,0,1,NULL,99000.0000,1,353684,0),(364633,351648,'Vehicle Upgrades','Skill at altering vehicle systems.\r\r\n\r\r\nUnlocks the ability to use vehicle modules.',0,0,0,1,NULL,48000.0000,1,365001,0),(364639,351648,'Vehicle Armor Upgrades','Basic understanding of vehicle armor augmentation.\r\r\n\r\r\nUnlocks the ability to use vehicle armor modules. Basic variants at lvl.1; enhanced at lvl.3; complex at lvl.5.',0,0,0,1,NULL,66000.0000,1,365001,0),(364640,351648,'Vehicle Core Upgrades','Basic understanding of vehicle core systems.\r\r\n\r\r\nUnlocks the ability to use modules that affect a vehicle\'s powergrid (PG), CPU and propulsion. Basic variants at lvl.1; enhanced at lvl.3; complex at lvl.5.',0,0,0,1,NULL,66000.0000,1,365001,0),(364641,351648,'Vehicle Shield Upgrades','Basic understanding of vehicle shield augmentation.\r\r\n\r\r\nUnlocks the ability to use vehicle shield modules. Basic variants at lvl.1; enhanced at lvl.3; complex at lvl.5.',0,0.01,0,1,NULL,66000.0000,1,365001,0),(364656,351648,'Assault Rifle Ammo Capacity','Skill at ammunition management.\r\n\r\n+5% maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364658,351648,'Assault Rifle Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364659,351648,'Assault Rifle Sharpshooter','Skill at weapon marksmanship.\r\n\r\n5% reduction to assault rifle dispersion per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364661,351648,'Assault Rifle Fitting Optimization','Advanced skill at weapon resource management.\r\n\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364662,351648,'Laser Rifle Fitting Optimization','Advanced skill at weapon resource management.\r\n\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364663,351648,'Laser Rifle Ammo Capacity','Skill at ammunition management.\r\n\r\n+5% maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364664,351648,'Laser Rifle Sharpshooter','Skill at weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0,0,1,NULL,203000.0000,0,NULL,0),(364665,351648,'Laser Rifle Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364666,351648,'Mass Driver Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+1 maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364667,351648,'Mass Driver Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364668,351648,'Mass Driver Fitting Optimization','Advanced skill at weapon resource management.\r\n\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364669,351648,'Mass Driver Sharpshooter','Skill at weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0,0,1,NULL,203000.0000,0,NULL,0),(364670,351648,'Plasma Cannon Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+1 maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364671,351648,'Plasma Cannon Fitting Optimization','Advanced skill at weapon resource management.\r\n\r\n+5% reduction to CPU usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364672,351648,'Plasma Cannon Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364673,351648,'Plasma Cannon Sharpshooter','Skill at weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0,0,1,NULL,203000.0000,0,NULL,0),(364674,351648,'Scrambler Rifle Ammo Capacity','Skill at ammunition management.\r\n\r\n+5% maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364675,351648,'Scrambler Rifle Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364676,351648,'Scrambler Rifle Sharpshooter','Skill at weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0,0,1,NULL,203000.0000,1,NULL,0),(364677,351648,'Scrambler Rifle Fitting Optimization','Advanced skill at weapon resource management.\r\n\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364678,351648,'Shotgun Ammo Capacity','Skill at ammunition management.\r\n\r\n+5% maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364679,351648,'Shotgun Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364680,351648,'Shotgun Fitting Optimization','Advanced skill at weapon resource management.\r\n\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364681,351648,'Shotgun Sharpshooter','Skill at weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0,0,1,NULL,203000.0000,0,NULL,0),(364682,351648,'Sniper Rifle Ammo Capacity','Skill at ammunition management.\r\n\r\n+5% maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364683,351648,'Sniper Rifle Fitting Optimization','Advanced skill at weapon resource management.\r\n\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364684,351648,'Sniper Rifle Sharpshooter','Skill at weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0,0,1,NULL,203000.0000,1,NULL,0),(364685,351648,'Sniper Rifle Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364686,351648,'Swarm Launcher Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+1 maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364687,351648,'Swarm Launcher Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364688,351648,'Swarm Launcher Fitting Optimization','Advanced skill at weapon resource management.\r\r\n\r\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364689,351648,'Swarm Launcher Sharpshooter','Skill at weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0,0,1,NULL,567000.0000,0,NULL,0),(364690,351648,'Flaylock Pistol Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+1 missile capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364691,351648,'Flaylock Pistol Fitting Optimization','Advanced skill at weapon resource management.\r\r\n\r\r\n5% reduction to CPU usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364692,351648,'Flaylock Pistol Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364693,351648,'Flaylock Pistol Sharpshooter','Skill at weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0,0,1,NULL,149000.0000,0,NULL,0),(364694,351648,'Scrambler Pistol Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+5% maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364695,351648,'Scrambler Pistol Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364696,351648,'Scrambler Pistol Fitting Optimization','Advanced skill at weapon resource management.\r\r\n\r\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364697,351648,'Scrambler Pistol Sharpshooter','Skill at weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0,0,1,NULL,149000.0000,1,NULL,0),(364698,351648,'Submachine Gun Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+5% maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364699,351648,'Submachine Gun Fitting Optimization','Advanced skill at weapon resource management.\r\r\n\r\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364700,351648,'Submachine Gun Sharpshooter','Skill at weapon marksmanship.\r\r\n\r\r\n5% reduction to submachine gun dispersion per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364701,351648,'Submachine Gun Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364702,351648,'Forge Gun Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+1 maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364703,351648,'Forge Gun Fitting Optimization','Advanced skill at weapon resource management.\r\n\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364704,351648,'Forge Gun Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+5% reload speed per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364705,351648,'Forge Gun Sharpshooter','Skill at weapon marksmanship.\r\r\n+5% maximum effective range per level.',0,0,0,1,NULL,203000.0000,0,NULL,0),(364706,351648,'Heavy Machine Gun Ammo Capacity','Skill at ammunition management.\r\n\r\n+5% maximum ammunition capacity per level.',0,0,0,1,NULL,203000.0000,1,353684,0),(364707,351648,'Heavy Machine Gun Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+5% reload speed per level.\r\r\n',0,0,0,1,NULL,203000.0000,1,353684,0),(364708,351648,'Heavy Machine Gun Sharpshooter','Skill at weapon marksmanship. \r\r\n+5% maximum effective range per level.\r\r\n',0,0,0,1,NULL,203000.0000,1,NULL,0),(364709,351648,'Heavy Machine Gun Fitting Optimization','Advanced skill at weapon resource management.\r\n\r\n5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(364726,351064,'Armor AV - AM','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364732,351064,'Armor AV - GA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364736,351064,'Armor AV - MN','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364738,351064,'Medic - AM','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364739,351064,'Sniper - AM','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364740,351064,'Frontline - AM','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364741,351064,'Medic - GA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364742,351064,'Sniper - GA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364743,351064,'Frontline - GA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364744,351064,'Medic - MN','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364745,351064,'Frontline - MN','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364746,351064,'Sniper - MN','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(364747,351648,'Gallente Marauder','Skill at operating vehicles specialized in Marauder roles. \r\r\n\r\r\n+4% bonus to turret damage per level.',0,0,0,1,NULL,4919000.0000,0,NULL,0),(364748,351648,'Caldari Logistics LAV','Skill at operating Caldari Logistics LAVs.\r\r\n\r\r\nUnlocks the ability to use Caldari Logistics LAVs.  +2% shield damage resistance per level.',0,0.01,0,1,NULL,638000.0000,0,NULL,0),(364749,351648,'Gallente Logistics LAV','Skill at operating Gallente Logistics LAVs.\r\r\n\r\r\nUnlocks the ability to use Gallente Logistics LAVs.  +2% armor damage resistance per level.',0,0.01,0,1,NULL,638000.0000,0,NULL,0),(364750,351648,'Gallente Logistics Dropship','Skill at piloting Gallente Logistics Dropships.\r\r\n\r\r\nUnlocks the ability to use Gallente Logistics Dropships. -2% CPU consumption to all armor modules per level.',0,0.01,0,1,NULL,1772000.0000,0,NULL,0),(364751,351648,'Caldari Logistics Dropship','Skill at piloting Caldari Logistics Dropships.\r\r\n\r\r\nUnlocks the ability to use Caldari Logistics Dropships. -2% CPU consumption to all shield modules per level.',0,0.01,0,1,NULL,1772000.0000,0,NULL,0),(364761,351648,'Vehicle Armor Repair Systems','Basic understanding of vehicle armor repairing.\r\r\n\r\r\n+5% to repair rate of vehicle armor repair modules per level.',0,0,0,1,NULL,99000.0000,1,365001,0),(364763,351648,'Vehicle Active Hardening','Basic understanding of active hardeners.\r\r\nUnlocks active hardeners.\r\r\n3% reduction in active hardener CPU usage per level.',0,0,0,1,NULL,203000.0000,1,NULL,0),(364769,351648,'Vehicle Armor Composition','Basic understanding of vehicle armor composition.\r\r\n\r\r\n10% reduction to speed penalty of armor plates per level.',0,0.01,0,1,NULL,99000.0000,1,365001,0),(364773,351648,'Engine Core Calibration','Basic understanding of active module management.\r\r\n\r\r\n+5% to active duration of all active modules per level.',0,0.01,0,1,NULL,567000.0000,1,365001,0),(364775,351648,'Chassis Modification','Skill at chassis modification.\r\r\n\r\r\nUnlocks weight reduction modules.\r\r\n\r\r\n+1% ground vehicle top speed per level.',0,0,0,1,NULL,149000.0000,1,NULL,0),(364776,351648,'Shield Fitting Optimization','Basic understanding of module resource management.\r\r\n\r\r\n5% reduction to CPU usage of vehicle shield modules per level.',0,0.01,0,1,NULL,567000.0000,1,365001,0),(364777,351648,'Vehicle Shield Regeneration','Basic understanding of vehicle shield regeneration.\r\r\n\r\r\n5% reduction to depleted shield recharge delay per level.',0,0.01,0,1,NULL,99000.0000,1,365001,0),(364781,351844,'Ishukone Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,17310.0000,1,354412,0),(364782,351844,'BDR-8 Triage Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,8070.0000,1,354415,0),(364783,351844,'Core Focused Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,35415.0000,1,354416,0),(364784,351844,'Viziam Flux Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death.',0,0.01,0,1,NULL,10575.0000,1,354405,0),(364785,351844,'Viziam Quantum Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,10575.0000,1,354405,0),(364786,350858,'\'Scorchtalon\' Nova Knives','A close-quarters melee weapon, the nova knife is as deadly a weapon as anything on the battlefield. Its name derives from the heated plasma edge of the blade   formed by a thermic igniter and linear gravity condenser   that, in skilled hands, can be used to carve through even the thickest dropsuit armor.',0,0.01,0,1,NULL,1815.0000,1,356434,0),(364787,350858,'\'Blackprey\' ZN-28 Nova Knives','A close-quarters melee weapon, the nova knife is as deadly a weapon as anything on the battlefield. Its name derives from the heated plasma edge of the blade   formed by a thermic igniter and linear gravity condenser   that, in skilled hands, can be used to carve through even the thickest dropsuit armor.',0,0.01,0,1,NULL,4845.0000,1,356435,0),(364788,350858,'\'Fleshriver\' Ishukone Nova Knives','A close-quarters melee weapon, the nova knife is as deadly a weapon as anything on the battlefield. Its name derives from the heated plasma edge of the blade   formed by a thermic igniter and linear gravity condenser   that, in skilled hands, can be used to carve through even the thickest dropsuit armor.',0,0.01,0,1,NULL,12975.0000,1,356436,0),(364789,351844,'\'Hateshard\' Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\n\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,4020.0000,1,355187,0),(364790,351844,'\'Scrapflake\' F/45 Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\n\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,10770.0000,1,355188,0),(364791,351844,'\'Skinjuice\' Boundless Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\n\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,28845.0000,1,355189,0),(364810,351064,'Amarr Light Frame A-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,3000.0000,1,364886,0),(364811,351064,'Caldari Light Frame C-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,3000.0000,1,364886,0),(364812,351064,'Gallente Light Frame G-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,3000.0000,1,364886,0),(364813,351064,'Minmatar Light Frame M-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.\r\r\n',0,0.01,0,1,NULL,3000.0000,1,364886,0),(364814,351064,'Amarr Medium Frame A-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,3000.0000,1,364890,0),(364815,351064,'Caldari Medium Frame C-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,3000.0000,1,364890,0),(364816,351064,'Gallente Medium Frame G-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,3000.0000,1,364890,0),(364817,351064,'Minmatar Medium Frame M-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,3000.0000,1,364890,0),(364818,351064,'Amarr Heavy Frame A-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,3000.0000,1,364894,0),(364819,351064,'Caldari Heavy Frame C-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0,0,1,NULL,3000.0000,1,364894,0),(364820,351064,'Gallente Heavy Frame G-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,3000.0000,1,364894,0),(364821,351064,'Minmatar Heavy Frame M-I','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,3000.0000,1,364894,0),(364863,351064,'Minmatar Light Frame M/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364887,0),(364872,351064,'Minmatar Light Frame mk.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364888,0),(364873,351064,'Gallente Light Frame G/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364887,0),(364874,351064,'Gallente Light Frame gk.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364888,0),(364875,351064,'Minmatar Medium Frame M/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364891,0),(364876,351064,'Minmatar Medium Frame mk.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364892,0),(364877,351064,'Gallente Medium Frame G/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364891,0),(364878,351064,'Gallente Medium Frame gk.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364892,0),(364879,351064,'Caldari Medium Frame C/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364891,0),(364880,351064,'Caldari Medium Frame ck.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364892,0),(364881,351064,'Amarr Medium Frame A/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364891,0),(364882,351064,'Amarr Medium Frame ak.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364892,0),(364883,351064,'Amarr Heavy Frame A/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364895,0),(364884,351064,'Amarr Heavy Frame ak.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364896,0),(364916,351648,'Range Amplification','Skill at altering dropsuit electronic scanning systems.\r\r\n\r\r\nUnlocks the ability to use range amplifier modules to improve dropsuit scan range.\r\r\n\r\r\n+10% to dropsuit scan range per level.',0,0,0,1,NULL,149000.0000,1,353708,0),(364918,351648,'Precision Enhancement','Skill at altering dropsuit electronic scanning systems.\r\r\n\r\r\nUnlocks the ability to use precision enhancer modules to improve dropsuit scan precision.\r\r\n\r\r\n2% bonus to dropsuit scan precision per level.',0,0,0,1,NULL,149000.0000,1,353708,0),(364919,351648,'Repair Tool Operation','Skill at using repair tools.\r\r\n\r\r\nUnlocks access to standard repair tools at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0,0,1,NULL,149000.0000,1,353708,0),(364920,351648,'Active Scanner Operation','Skill at using active scanners.\r\r\n\r\r\nUnlocks access to standard active scanners at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0,0,1,NULL,149000.0000,1,353708,0),(364921,351648,'Caldari Enforcer HAV','Skill at operating Caldari Enforcer HAVs.\r\r\n\r\r\nUnlocks the ability to use Caldari Enforcer HAVs.  +3% to missile damage and range per level.  +2% to maximum zoom per level.',0,0,0,1,NULL,3279000.0000,0,NULL,0),(364922,351648,'Gallente Enforcer HAV','Skill at operating Gallente Enforcer HAVs.\r\r\n\r\r\nUnlocks the ability to use Gallente Enforcer HAVs.  +3% to blaster damage and range per level.  +2% to maximum zoom per level.',0,0,0,1,NULL,3279000.0000,0,NULL,0),(364933,351648,'Caldari Scout LAV','Skill at operating Caldari Scout LAVs.\r\r\n\r\r\nUnlocks the ability to use Caldari Scout LAVs.  +2% to acceleration and turret rotation speed per level.',0,0,0,1,NULL,638000.0000,0,NULL,0),(364935,351648,'Gallente Scout LAV','Skill at operating Gallente Scout LAVs.\r\r\n\r\r\nUnlocks the ability to use Gallente Scout LAVs.  +2% to acceleration and turret rotation speed per level.',0,0,0,1,NULL,638000.0000,0,NULL,0),(364943,351648,'Caldari Assault Dropship','Skill at operating Caldari Assault Dropships.\r\n\r\nGrants +3% to missile turret ROF and +5% to missile turret maximum ammunition per level to Caldari Assault Dropships.',0,0,0,1,NULL,1772000.0000,1,353711,0),(364945,351648,'Gallente Assault Dropship','Skill at operating Gallente Assault Dropships.\r\n\r\nGrants +3% to hybrid turret ROF and +5% to hybrid turret maximum ammunition per level to Gallente Assault Dropships.',0,0,0,1,NULL,1772000.0000,1,353711,0),(364952,351064,'Militia Minmatar Light Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,655.0000,1,355469,0),(364955,351064,'Militia Amarr Medium Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,585.0000,1,355469,0),(364956,351064,'Militia Gallente Medium Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,585.0000,1,355469,0),(365200,351121,'HEP Metabolic Enhancer','Initially developed during the Human Endurance Program, Inherent Implants have improved and adapted their  formula to suit the new generation of cloned soldiers.\r\r\n\r\r\nBuilding on the initial success of a targeted intravenous infusion of nanite laced adrenaline into the bloodstream, this package contains two doses of stimulant that are pushed directly to the muscles and respiratory system for optimal uptake. The two compounds, consisting of DA-640 Synthetic Adrenaline and GF-07 Filtered Testosterone, are intravenously administered through the user s dropsuit support systems. The result of using such highly intelligent nanite based compounds is an immediate boost in respiratory and muscle function, allowing the user to sprint faster and inflict greater melee damage.',0.01,0,0,1,4,3420.0000,1,354429,0),(365229,351121,'Basic Ferroscale Plates','Ultra-light alloy that increases the maximum strength of dropsuit armor without affecting movement speed.',0,0.01,0,1,NULL,900.0000,1,365245,0),(365230,351121,'Enhanced Ferroscale Plates','Ultra-light alloy that increases the maximum strength of dropsuit armor without affecting movement speed.',0,0.01,0,1,NULL,2415.0000,1,365245,0),(365231,351121,'Complex Ferroscale Plates','Ultra-light alloy that increases the maximum strength of dropsuit armor without affecting movement speed.',0,0.01,0,1,NULL,3945.0000,1,365245,0),(365233,351121,'Basic Reactive Plates','Self-repairing armor plates that provide a marginal increase to dropsuit armor strength.',0,0.01,0,1,NULL,900.0000,1,365246,0),(365234,351121,'Enhanced Reactive Plates','Self-repairing armor plates that provide a marginal increase to dropsuit armor strength.',0,0.01,0,1,NULL,2415.0000,1,365246,0),(365235,351121,'Complex Reactive Plates','Self-repairing armor plates that provide a marginal increase to dropsuit armor strength.',0,0.01,0,1,NULL,3945.0000,1,365246,0),(365237,351121,'Basic Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0.01,0,1,NULL,1350.0000,1,365251,0),(365238,351121,'Enhanced Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0.01,0,1,NULL,3615.0000,1,365251,0),(365239,351121,'Complex Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0.01,0,1,NULL,5925.0000,1,365251,0),(365240,351121,'\'Bastion\' Enhanced Ferroscale Plates','Ultra-light alloy that increases the maximum strength of dropsuit armor without affecting movement speed.',0,0.01,0,1,NULL,2415.0000,1,365245,0),(365241,351121,'\'Castra\' Complex Ferroscale Plates','Ultra-light alloy that increases the maximum strength of dropsuit armor without affecting movement speed.',0,0.01,0,1,NULL,3945.0000,1,365245,0),(365242,351121,'\'Brille\' Enhanced Reactive Plates','Self-repairing armor plates that provide a marginal increase to dropsuit armor strength.',0,0.01,0,1,NULL,2415.0000,1,365246,0),(365243,351121,'\'Cuticle\' Complex Reactive Plates','Self-repairing armor plates that provide a marginal increase to dropsuit armor strength.',0,0.01,0,1,NULL,2415.0000,1,365246,0),(365252,351121,'\'Bond\' Enhanced Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0.01,0,1,NULL,3615.0000,1,365251,0),(365253,351121,'\'Graft\' Complex Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0.01,0,1,NULL,3615.0000,1,365251,0),(365254,351121,'\'Weld\' Basic Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0.01,0,1,NULL,1350.0000,1,365251,0),(365255,351121,'\'Abatis\' Basic Ferroscale Plates','Ultra-light alloy that increases the maximum strength of dropsuit armor without affecting movement speed.',0,0.01,0,1,NULL,900.0000,1,365245,0),(365256,351121,'\'Nacre\' Basic Reactive Plates','Self-repairing armor plates that provide a marginal increase to dropsuit armor strength.',0,0.01,0,1,NULL,900.0000,1,365246,0),(365262,351064,'Commando A/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,8040.0000,1,365280,0),(365263,351064,'Commando ak.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,57690.0000,1,365282,0),(365289,351064,'Pilot G/1-Series','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Gallente suit instead incorporates a host of structural monitoring nodes, smart I/O channels and energy management controllers into a wearable interface that enhances the performance of the vehicle s shield and armor subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,8040.0000,1,NULL,0),(365290,351064,'Pilot gk.0','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Gallente suit instead incorporates a host of structural monitoring nodes, smart I/O channels and energy management controllers into a wearable interface that enhances the performance of the vehicle s shield and armor subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,57690.0000,1,NULL,0),(365291,351064,'Pilot M-I','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Minmatar suit instead incorporates a host of predictive tracking solutions, smart I/O channels and fire management controllers into a wearable interface that enhances the performance of the vehicle s weapon subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,3000.0000,1,NULL,0),(365292,351064,'Pilot M/1-Series','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Minmatar suit instead incorporates a host of predictive tracking solutions, smart I/O channels and fire management controllers into a wearable interface that enhances the performance of the vehicle s weapon subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,8040.0000,1,NULL,0),(365293,351064,'Pilot mk.0','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Minmatar suit instead incorporates a host of predictive tracking solutions, smart I/O channels and fire management controllers into a wearable interface that enhances the performance of the vehicle s weapon subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,57690.0000,1,NULL,0),(365294,351121,'\'Terminal\' Basic Power Diagnostics Unit','Provides a marginal boost to power grid output and reduces the delay before shield recharge begins.',0,0.01,0,1,NULL,750.0000,1,NULL,0),(365295,351121,'\'Node\' Enhanced Power Diagnostics Unit','Provides a marginal boost to power grid output and reduces the delay before shield recharge begins.',0,0.01,0,1,NULL,2010.0000,1,NULL,0),(365296,351121,'\'Grid\' Complex Power Diagnostics Unit','Provides a marginal boost to power grid output and reduces the delay before shield recharge begins.',0,0.01,0,1,NULL,2010.0000,1,NULL,0),(365297,351064,'\'Neo\' Commando A-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,3000.0000,1,365279,0),(365298,351064,'\'Neo\' Commando A/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,13155.0000,1,365280,0),(365299,351064,'\'Neo\' Commando ak.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,35250.0000,1,365282,0),(365300,351064,'\'Neo\' Pilot G-I','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Gallente suit instead incorporates a host of structural monitoring nodes, smart I/O channels and energy management controllers into a wearable interface that enhances the performance of the vehicle s shield and armor subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,3000.0000,1,NULL,0),(365301,351064,'\'Neo\' Pilot G/1-Series','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Gallente suit instead incorporates a host of structural monitoring nodes, smart I/O channels and energy management controllers into a wearable interface that enhances the performance of the vehicle s shield and armor subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,8040.0000,1,NULL,0),(365302,351064,'\'Neo\' Pilot gk.0','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Gallente suit instead incorporates a host of structural monitoring nodes, smart I/O channels and energy management controllers into a wearable interface that enhances the performance of the vehicle s shield and armor subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,21540.0000,1,NULL,0),(365303,351064,'\'Neo\' Pilot M-I','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Minmatar suit instead incorporates a host of predictive tracking solutions, smart I/O channels and fire management controllers into a wearable interface that enhances the performance of the vehicle s weapon subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,3000.0000,1,NULL,0),(365304,351064,'\'Neo\' Pilot M/1-Series','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Minmatar suit instead incorporates a host of predictive tracking solutions, smart I/O channels and fire management controllers into a wearable interface that enhances the performance of the vehicle s weapon subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,8040.0000,1,NULL,0),(365305,351064,'\'Neo\' Pilot mk.0','The Pilot dropsuit enhances vehicle operability. Using an adaptive synth-nerve network, the suit seamlessly integrates with on-board systems, establishing a cognitive link between the user and the host vehicle. This provides unprecedented control over every aspect of a vehicle s weapon, navigation, propulsion, and electronic subsystems.\r\r\n\r\r\nIll-suited to frontline combat, the Minmatar suit instead incorporates a host of predictive tracking solutions, smart I/O channels and fire management controllers into a wearable interface that enhances the performance of the vehicle s weapon subsystems.\r\r\n\r\r\nIn much the same way the capsule revolutionized space flight, the Pilot suit has vastly improved the man-machine interface for planetside vehicles.',0,0.01,0,1,NULL,21540.0000,1,NULL,0),(365306,351064,'\'Neo\' Logistics A-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,3000.0000,1,354384,0),(365307,351064,'\'Neo\' Logistics A/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(365308,351064,'\'Neo\' Logistics ak.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,21540.0000,1,354386,0),(365309,351064,'\'Neo\' Logistics G-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,3000.0000,1,354384,0),(365310,351064,'\'Neo\' Logistics G/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(365311,351064,'\'Neo\' Logistics gk.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,21540.0000,1,354386,0),(365312,351064,'\'Neo\' Logistics C-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,3000.0000,1,354384,0),(365313,351064,'\'Neo\' Logistics C/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(365314,351064,'\'Neo\' Logistics ck.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,21540.0000,1,354386,0),(365315,351064,'\'Neo\' Assault A-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(365316,351064,'\'Neo\' Assault A/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(365317,351064,'\'Neo\' Assault ak.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,21540.0000,1,354378,0),(365318,351064,'\'Neo\' Assault G-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(365319,351064,'\'Neo\' Assault G/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(365320,351064,'\'Neo\' Assault gk.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,21540.0000,1,354378,0),(365321,351064,'\'Neo\' Assault M-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,354376,0),(365322,351064,'\'Neo\' Assault M/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(365323,351064,'\'Neo\' Assault mk.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,21540.0000,1,354378,0),(365324,351064,'\'Neo\' Scout M-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,354388,0),(365325,351064,'\'Neo\' Scout M/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(365326,351064,'\'Neo\' Scout mk.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,21540.0000,1,354390,0),(365351,351121,'Surge Carapace I','Surge modules create a brief, incredibly strong protective shell around a vehicle by instantly diverting a massive amount of charge from the vehicle\'s on-board capacitor to the vehicle\'s hull.\r\r\n\r\r\nThese modules are exceedingly effective at countering lock-on weaponry when activation is timed correctly.\r\r\n\r\r\nNote: Only one module of this type can be equipped at one time.',0,0,0,1,NULL,0.0000,1,NULL,0),(365352,351121,'Surge Carapace II','Surge modules create a brief, incredibly strong protective shell around a vehicle by instantly diverting a massive amount of charge from the vehicle\'s on-board capacitor to the vehicle\'s hull.\r\r\n\r\r\nThese modules are exceedingly effective at countering lock-on weaponry when activation is timed correctly.\r\r\n\r\r\nNote: Only one module of this type can be equipped at one time.',0,0,0,1,NULL,0.0000,1,NULL,0),(365353,351121,'XM-1 Capacitive Shell','Surge modules create a brief, incredibly strong protective shell around a vehicle by instantly diverting a massive amount of charge from the vehicle\'s on-board capacitor to the vehicle\'s hull.\r\r\n\r\r\nThese modules are exceedingly effective at countering lock-on weaponry when activation is timed correctly.\r\r\n\r\r\nNote: Only one module of this type can be equipped at one time.',0,0,0,1,NULL,0.0000,1,NULL,0),(365360,351121,'Basic Countermeasure','Countermeasures are employed to explicitly throw off munitions that are already locked-on and in pursuit of a target.',0,0,0,1,NULL,0.0000,1,NULL,0),(365361,351121,'Advanced Countermeasure','Countermeasures are employed to explicitly throw off munitions that are already locked-on and in pursuit of a target.',0,0,0,1,NULL,0.0000,1,NULL,0),(365362,351121,'\'Mercury\' Defensive Countermeasure','Countermeasures are employed to explicitly throw off munitions that are already locked-on and in pursuit of a target.',0,0,0,1,NULL,0.0000,1,NULL,0),(365364,351210,'Estoc','Conceived as the  ultimate urban pacifier , in practice the Medium Attack Vehicle is that and more   having inherited the strengths of its forebears, and few of their weaknesses. Its anti-personnel weaponry make it the perfect tool for flushing out insurgents, while the ample armor it carries means that it can withstand multiple direct hits and still keep coming. Though somewhat less effective on an open battlefield, its success rate in urban environments has earned the MAV almost legendary status among the troops it serves.',0,0,0,1,NULL,0.0000,1,NULL,0),(365386,351648,'Rail Rifle Operation','Skill at handling rail rifles.\r\r\n\r\r\n5% reduction to rail rifle kick per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(365388,351648,'Rail Rifle Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+5% maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(365389,351648,'Rail Rifle Proficiency','Skill at handling rail rifles.\r\r\n\r\r\n+3% rail rifle damage against armor per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(365391,351648,'Rail Rifle Fitting Optimization','Advanced skill at weapon resource management.\r\r\n\r\r\n5% reduction to PG usage per level.',0,0.01,0,1,NULL,774000.0000,1,353684,0),(365392,351648,'Rail Rifle Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(365393,351648,'Combat Rifle Operation','Skill at handling combat rifles.\r\r\n\r\r\n5% reduction to combat rifle kick per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(365395,351648,'Combat Rifle Sharpshooter','Skill at weapon marksmanship.\r\r\n\r\r\n5% reduction to combat rifle dispersion per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(365396,351648,'Combat Rifle Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+5% maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(365397,351648,'Combat Rifle Proficiency','Skill at handling combat rifles.\r\r\n\r\r\n+3% combat rifle damage against armor per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(365399,351648,'Combat Rifle Fitting Optimization','Advanced skill at weapon resource management.\r\r\n\r\r\n5% reduction to PG usage per level.',0,0.01,0,1,NULL,774000.0000,1,353684,0),(365400,351648,'Combat Rifle Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(365401,351648,'Magsec SMG Operation','Skill at handling submachine guns.\r\r\n\r\r\n5% reduction to magsec SMG kick per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(365404,351648,'Magsec SMG Sharpshooter','Skill at weapon marksmanship.\r\r\n\r\r\n5% reduction to magsec SMG dispersion per level.',0,0.01,0,1,NULL,203000.0000,0,NULL,0),(365405,351648,'Magsec SMG Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+5% maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(365406,351648,'Magsec SMG Proficiency','Skill at handling submachine guns.\r\r\n\r\r\n+3% magsec SMG damage against armor per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(365407,351648,'Magsec SMG Fitting Optimization','Advanced skill at weapon resource management.\r\r\n\r\r\n5% reduction to PG usage per level.',0,0.01,0,1,NULL,774000.0000,1,353684,0),(365408,351648,'Magsec SMG Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(365409,350858,'Assault Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,2,2460.0000,1,365766,0),(365420,351210,'\'LC-225\' Saga-II','Augmented with ultra-efficient active shielding, the  LC-225  Saga-II can temporarily withstand a barrage of enemy fire as it streaks through the frontline to deliver mercenaries into the heart of the battle.',0,0.01,0,1,NULL,49110.0000,1,353664,0),(365421,351064,'\'Harbinger\' Amarr Medium Frame A-I','The Harbinger does not judge. It is not his place to condemn or absolve. He is but a torch-bearer, a vessel for the holy light, chosen to shine the glory of Amarr upon all who stand mired in the darkness of doubt and faithlessness. And in its fire, be reborn.',0,0.01,0,1,NULL,3000.0000,1,364890,0),(365422,351121,' ',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(365424,351121,'Reactive Deflection Field I','Once activated, this module temporarily reduces the damage done to shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,12000.0000,1,363452,0),(365428,351210,'Saga-II','Augmented with ultra-efficient active shielding, the Saga-II can temporarily withstand a barrage of enemy fire as it streaks through the frontline to deliver mercenaries into the heart of the battle.',0,0.01,0,1,NULL,49110.0000,1,353664,0),(365433,354641,'Passive Omega-Booster (30-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nPassive Boosters increase the rate of passive skill point accrual while they are active. Omega-Boosters feature superior performance over standard models.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)\r\r\n\r\r\n',0,0.01,0,1,NULL,0.0000,1,354542,0),(365434,354641,'Passive Omega-Booster (60-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nPassive Boosters increase the rate of passive skill point accrual while they are active. Omega-Boosters feature superior performance over standard models.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)\r\r\n',0,0.01,0,1,NULL,0.0000,1,354542,0),(365435,354641,'Passive Omega-Booster (90-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nPassive Boosters increase the rate of passive skill point accrual while they are active. Omega-Boosters feature superior performance over standard models.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)\r\r\n',0,0.01,0,1,NULL,0.0000,1,354542,0),(365441,350858,'RS-90 Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,10770.0000,1,365767,0),(365442,350858,'Boundless Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,47220.0000,1,365768,0),(365443,350858,'BK-42 Assault Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,4,10770.0000,1,365767,0),(365444,350858,'Six Kin Assault Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,4,47220.0000,1,365768,0),(365446,354641,'Passive Booster (15-minute) [QA]','This is a test booster for the QA department. Not intended for public consumption.',0,0.01,0,1,NULL,0.0000,0,354542,0),(365447,350858,'SB-39 Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,10770.0000,1,365771,0),(365448,350858,'Kaalakiota Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,47220.0000,1,365772,0),(365449,350858,'Ishukone Assault Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,4,47220.0000,1,365772,0),(365450,350858,'SL-4 Assault Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,4,10770.0000,1,365771,0),(365451,350858,'\'Woundriot\' Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,4020.0000,1,365766,0),(365452,350858,'\'Leadgrave\' RS-90 Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,10770.0000,1,365767,0),(365453,350858,'\'Doomcradle\' BK-42 Assault Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,10770.0000,1,365767,0),(365454,350858,'\'Fearcrop\' Boundless Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,28845.0000,1,365768,0),(365455,350858,'\'Blisterrain\' Six Kin Assault Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,28845.0000,1,365768,0),(365456,350858,'\'Angerstar\' Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,4020.0000,1,365770,0),(365457,350858,'\'Grimcell\' SB-39 Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,10770.0000,1,365771,0),(365458,350858,'\'Bleakanchor\' SL-4 Assault Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,10770.0000,1,365771,0),(365459,350858,'\'Zerofrost\' Kaalakiota Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,28845.0000,1,365772,0),(365460,350858,'\'Crawtide\' Ishukone Assault Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,28845.0000,1,365772,0),(365566,350858,'N7-A Magsec SMG','The magsec is a semi-automatic firearm capable of sustained, accurate fire at ranges beyond what conventional sidearms can offer. A high-speed slider feeds current to a magazine of hyper velocity projectiles that are discharged with minimal separation, maximizing energy efficiency and reducing flux shear to produce a weapon with lethal kinetic potential. \r\r\n\r\r\nHaving overcome early reliability issues, manufacturers  have since taken advantage of the weapon s modular design; the magsec has been made available in multiple combat configurations   including optical sights and silenced operation   and is in widespread service throughout the cluster.',0,0.01,0,1,NULL,4845.0000,1,366576,0),(365567,350858,'Kaalakiota Magsec SMG','The magsec is a semi-automatic firearm capable of sustained, accurate fire at ranges beyond what conventional sidearms can offer. A high-speed slider feeds current to a magazine of hyper velocity projectiles that are discharged with minimal separation, maximizing energy efficiency and reducing flux shear to produce a weapon with lethal kinetic potential. \r\r\n\r\r\nHaving overcome early reliability issues, manufacturers  have since taken advantage of the weapon s modular design; the magsec has been made available in multiple combat configurations   including optical sights and silenced operation   and is in widespread service throughout the cluster.',0,0.01,0,1,NULL,21240.0000,1,366577,0),(365568,350858,'\'Gravepin\' N7-A Magsec SMG','The magsec is a semi-automatic firearm capable of sustained, accurate fire at ranges beyond what conventional sidearms can offer. A high-speed slider feeds current to a magazine of hyper velocity projectiles that are discharged with minimal separation, maximizing energy efficiency and reducing flux shear to produce a weapon with lethal kinetic potential. \r\r\n\r\r\nHaving overcome early reliability issues, manufacturers  have since taken advantage of the weapon s modular design; the magsec has been made available in multiple combat configurations   including optical sights and silenced operation   and is in widespread service throughout the cluster.',0,0.01,0,1,NULL,4845.0000,1,366576,0),(365569,350858,'\'Chokegrin\' Kaalakiota Magsec SMG','The magsec is a semi-automatic firearm capable of sustained, accurate fire at ranges beyond what conventional sidearms can offer. A high-speed slider feeds current to a magazine of hyper velocity projectiles that are discharged with minimal separation, maximizing energy efficiency and reducing flux shear to produce a weapon with lethal kinetic potential. \r\r\n\r\r\nHaving overcome early reliability issues, manufacturers  have since taken advantage of the weapon s modular design; the magsec has been made available in multiple combat configurations   including optical sights and silenced operation   and is in widespread service throughout the cluster.',0,0.01,0,1,NULL,12975.0000,1,366577,0),(365570,350858,'\'Skyglitch\' Magsec SMG','The magsec is a semi-automatic firearm capable of sustained, accurate fire at ranges beyond what conventional sidearms can offer. A high-speed slider feeds current to a magazine of hyper velocity projectiles that are discharged with minimal separation, maximizing energy efficiency and reducing flux shear to produce a weapon with lethal kinetic potential. \r\r\n\r\r\nHaving overcome early reliability issues, manufacturers  have since taken advantage of the weapon s modular design; the magsec has been made available in multiple combat configurations   including optical sights and silenced operation   and is in widespread service throughout the cluster.',0,0.01,0,1,NULL,1815.0000,1,366575,0),(365572,350858,'T-12 Ion Pistol','A ruthlessly efficient close-quarters weapon, the ion pistol fires charged plasma munitions that rupture shields and scorch armor. Each discharge is enveloped in an electrostatic sheath that reduces field distortion and increases stability. The improved dispersion and stopping power is not without drawbacks though, as the higher density of each slug generates excessive heat, enough to seize the weapon if the rate of fire is not carefully controlled.\r\r\n\r\r\nBy overriding internal temperature controls, the weapon can be overcharged to produce a focused, bulk discharge of sufficient lethality to instantly neutralize most soft targets. Caution is advised however, as each overcharged shot will shut down internal systems until the excess heat can be flushed from the weapon s core.',0,0.01,0,1,NULL,4845.0000,1,366743,0);
INSERT INTO `invTypes` VALUES (365573,350858,'CreoDron Ion Pistol','A ruthlessly efficient close-quarters weapon, the ion pistol fires charged plasma munitions that rupture shields and scorch armor. Each discharge is enveloped in an electrostatic sheath that reduces field distortion and increases stability. The improved dispersion and stopping power is not without drawbacks though, as the higher density of each slug generates excessive heat, enough to seize the weapon if the rate of fire is not carefully controlled.\r\r\n\r\r\nBy overriding internal temperature controls, the weapon can be overcharged to produce a focused, bulk discharge of sufficient lethality to instantly neutralize most soft targets. Caution is advised however, as each overcharged shot will shut down internal systems until the excess heat can be flushed from the weapon s core.',0,0.01,0,1,NULL,21240.0000,1,366744,0),(365574,350858,'\'Wildlight\' Ion Pistol','A ruthlessly efficient close-quarters weapon, the ion pistol fires charged plasma munitions that rupture shields and scorch armor. Each discharge is enveloped in an electrostatic sheath that reduces field distortion and increases stability. The improved dispersion and stopping power is not without drawbacks though, as the higher density of each slug generates excessive heat, enough to seize the weapon if the rate of fire is not carefully controlled.\r\r\n\r\r\nBy overriding internal temperature controls, the weapon can be overcharged to produce a focused, bulk discharge of sufficient lethality to instantly neutralize most soft targets. Caution is advised however, as each overcharged shot will shut down internal systems until the excess heat can be flushed from the weapon s core.',0,0.01,0,1,NULL,1815.0000,1,366742,0),(365575,350858,'\'Scattershin\' T-12 Ion Pistol','A ruthlessly efficient close-quarters weapon, the ion pistol fires charged plasma munitions that rupture shields and scorch armor. Each discharge is enveloped in an electrostatic sheath that reduces field distortion and increases stability. The improved dispersion and stopping power is not without drawbacks though, as the higher density of each slug generates excessive heat, enough to seize the weapon if the rate of fire is not carefully controlled.\r\r\n\r\r\nBy overriding internal temperature controls, the weapon can be overcharged to produce a focused, bulk discharge of sufficient lethality to instantly neutralize most soft targets. Caution is advised however, as each overcharged shot will shut down internal systems until the excess heat can be flushed from the weapon s core.',0,0.01,0,1,NULL,4845.0000,1,366743,0),(365576,350858,'\'Vaporlaw\' CreoDron Ion Pistol','A ruthlessly efficient close-quarters weapon, the ion pistol fires charged plasma munitions that rupture shields and scorch armor. Each discharge is enveloped in an electrostatic sheath that reduces field distortion and increases stability. The improved dispersion and stopping power is not without drawbacks though, as the higher density of each slug generates excessive heat, enough to seize the weapon if the rate of fire is not carefully controlled.\r\r\n\r\r\nBy overriding internal temperature controls, the weapon can be overcharged to produce a focused, bulk discharge of sufficient lethality to instantly neutralize most soft targets. Caution is advised however, as each overcharged shot will shut down internal systems until the excess heat can be flushed from the weapon s core.',0,0.01,0,1,NULL,12975.0000,1,366744,0),(365577,350858,'SR-25 Bolt Pistol','The result of years of R&D, the bolt pistol is a high-impact handgun capable of firing kinetic projectiles with pinpoint accuracy. Building upon its copious experience with microscale rail weaponry, Kaalakiota has further refined the technology to produce what is commonly regarded as the most powerful handgun on the market.\r\r\n\r\r\nCentral to its success is a smart sensor that bleeds off a minute amount of dropsuit energy at the moment of discharge, dissipating the sharp recoil impulse through the suit s internal membrane and greatly reducing the peak force of each shot. This seemingly minor innovation is what makes accurate fire of the weapon possible without the need for an external mounting.',0,0.01,0,1,NULL,4845.0000,1,366572,0),(365578,350858,'Kaalakiota Bolt Pistol','The result of years of R&D, the bolt pistol is a high-impact handgun capable of firing kinetic projectiles with pinpoint accuracy. Building upon its copious experience with microscale rail weaponry, Kaalakiota has further refined the technology to produce what is commonly regarded as the most powerful handgun on the market.\r\r\n\r\r\nCentral to its success is a smart sensor that bleeds off a minute amount of dropsuit energy at the moment of discharge, dissipating the sharp recoil impulse through the suit s internal membrane and greatly reducing the peak force of each shot. This seemingly minor innovation is what makes accurate fire of the weapon possible without the need for an external mounting.',0,0.01,0,1,NULL,21240.0000,1,366573,0),(365579,350858,'\'Guardwire\' Bolt Pistol','The result of years of R&D, the bolt pistol is a high-impact handgun capable of firing kinetic projectiles with pinpoint accuracy. Building upon its copious experience with microscale rail weaponry, Kaalakiota has further refined the technology to produce what is commonly regarded as the most powerful handgun on the market.\r\r\n\r\r\nCentral to its success is a smart sensor that bleeds off a minute amount of dropsuit energy at the moment of discharge, dissipating the sharp recoil impulse through the suit s internal membrane and greatly reducing the peak force of each shot. This seemingly minor innovation is what makes accurate fire of the weapon possible without the need for an external mounting.',0,0.01,0,1,NULL,1815.0000,1,366571,0),(365580,350858,'\'Shiftrisk\' SR-25 Bolt Pistol','The result of years of R&D, the bolt pistol is a high-impact handgun capable of firing kinetic projectiles with pinpoint accuracy. Building upon its copious experience with microscale rail weaponry, Kaalakiota has further refined the technology to produce what is commonly regarded as the most powerful handgun on the market.\r\r\n\r\r\nCentral to its success is a smart sensor that bleeds off a minute amount of dropsuit energy at the moment of discharge, dissipating the sharp recoil impulse through the suit s internal membrane and greatly reducing the peak force of each shot. This seemingly minor innovation is what makes accurate fire of the weapon possible without the need for an external mounting.',0,0.01,0,1,NULL,4845.0000,1,366572,0),(365581,350858,'\'Nodeasylum\' Kaalakiota Bolt Pistol','The result of years of R&D, the bolt pistol is a high-impact handgun capable of firing kinetic projectiles with pinpoint accuracy. Building upon its copious experience with microscale rail weaponry, Kaalakiota has further refined the technology to produce what is commonly regarded as the most powerful handgun on the market.\r\r\n\r\r\nCentral to its success is a smart sensor that bleeds off a minute amount of dropsuit energy at the moment of discharge, dissipating the sharp recoil impulse through the suit s internal membrane and greatly reducing the peak force of each shot. This seemingly minor innovation is what makes accurate fire of the weapon possible without the need for an external mounting.',0,0.01,0,1,NULL,12975.0000,1,366573,0),(365623,350858,'\'Construct\' Duvolle Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\n\r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,28845.0000,1,354333,0),(365624,350858,'\'Construct\' Six Kin Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\r\n\r\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,12975.0000,1,354354,0),(365625,350858,'\'Construct\' Kaalakiota Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\r\n\r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,0.0000,1,354337,0),(365626,350858,'\'Construct\' Ishukone Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,28845.0000,1,354350,0),(365627,350858,'\'Construct\' Wiyrkomi Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets.\r\r\n\r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,28845.0000,1,354367,0),(365628,350858,'\'Construct\' Viziam Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\r\n\r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,12975.0000,1,354345,0),(365629,350858,'\'Construct\' CreoDron Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\n\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,28845.0000,1,354698,0),(365630,350858,'\'Construct\' Viziam Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\r\n\r\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,28845.0000,1,354692,0),(365631,350858,'\'Construct\' Boundless Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\n\r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,28845.0000,1,354567,0),(365632,350858,'\'Construct\' Freedom Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,28845.0000,1,354620,0),(365633,350858,'\'Construct\' Imperial Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,28845.0000,1,364054,0),(365634,350858,'\'Construct\' Core Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\n\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0.01,0,1,NULL,12975.0000,1,363793,0),(365635,350858,'\'Construct\' Allotek Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,28845.0000,1,364058,0),(365636,350858,'\'Construct\' Ishukone Nova Knives','A close-quarters melee weapon, the nova knife is as deadly a weapon as anything on the battlefield. Its name derives from the heated plasma edge of the blade   formed by a thermic igniter and linear gravity condenser   that, in skilled hands, can be used to carve through even the thickest dropsuit armor.',0,0.01,0,1,NULL,12975.0000,1,356436,0),(365650,350858,'\'Pyrus\' Assault Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4020.0000,1,354331,0),(365651,350858,'\'Pyrus\' ATK-21 Assault Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,10770.0000,1,354332,0),(365652,350858,'\'Pyrus\' Allotek Assault Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,28845.0000,1,354333,0),(365654,350858,'\'Pyrus\' Submachine Gun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,1815.0000,1,354352,0),(365655,350858,'\'Pyrus\' ATK-05 Submachine Gun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4845.0000,1,354353,0),(365656,350858,'\'Pyrus\' Allotek Submachine Gun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,12975.0000,1,354354,0),(365657,350858,'\'Pyrus\' Forge Gun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4020.0000,1,354335,0),(365658,350858,'\'Pyrus\' ATK-90 Forge Gun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,10770.0000,1,354336,0),(365659,350858,'\'Pyrus\' Allotek Forge Gun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,28845.0000,1,354337,0),(365660,350858,'\'Pyrus\' Sniper Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4020.0000,1,354347,0),(365661,350858,'\'Pyrus\' ATK-58 Sniper Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,10770.0000,1,354348,0),(365662,350858,'\'Pyrus\' Allotek Sniper Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,28845.0000,1,354350,0),(365663,350858,'\'Pyrus\' Swarm Launcher','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4020.0000,1,354364,0),(365664,350858,'\'Pyrus\' ATK-32 Swarm Launcher','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,10770.0000,1,354366,0),(365665,350858,'\'Pyrus\' Allotek Swarm Launcher','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,28845.0000,1,354367,0),(365666,350858,'\'Pyrus\' Scrambler Pistol','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,1815.0000,1,354343,0),(365667,350858,'\'Pyrus\' ATK-17 Scrambler Pistol','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,2955.0000,1,354344,0),(365668,350858,'\'Pyrus\' Allotek Scrambler Pistol','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,12975.0000,1,354345,0),(365669,350858,'\'Pyrus\' Shotgun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4020.0000,1,354696,0),(365670,350858,'\'Pyrus\' ATK-44 Shotgun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,10770.0000,1,354697,0),(365671,350858,'\'Pyrus\' Allotek Shotgun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,28845.0000,1,354698,0),(365673,350858,'\'Pyrus\' Laser Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4020.0000,1,354690,0),(365674,350858,'\'Pyrus\' ATK-50 Laser Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,10770.0000,1,354691,0),(365675,350858,'\'Pyrus\' Allotek Laser Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,28845.0000,1,354692,0),(365676,350858,'\'Pyrus\' Heavy Machine Gun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4020.0000,1,354565,0),(365677,350858,'\'Pyrus\' ATK-108 Heavy Machine Gun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,10770.0000,1,354566,0),(365678,350858,'\'Pyrus\' Allotek Heavy Machine Gun','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,28845.0000,1,354567,0),(365679,350858,'\'Pyrus\' Mass Driver','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4020.0000,1,354618,0),(365680,350858,'\'Pyrus\' ATK-43 Mass Driver','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,10770.0000,1,354619,0),(365681,350858,'\'Pyrus\' Allotek Mass Driver','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,28845.0000,1,354620,0),(365682,350858,'\'Pyrus\' Scrambler Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4020.0000,1,364052,0),(365683,350858,'\'Pyrus\' ATK-30 Scrambler Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,10770.0000,1,364053,0),(365684,350858,'\'Pyrus\' Allotek Scrambler Rifle','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,28845.0000,1,364054,0),(365685,350858,'\'Pyrus\' Flaylock Pistol','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,1815.0000,1,363791,0),(365686,350858,'\'Pyrus\' ATK-9 Flaylock Pistol','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4845.0000,1,363792,0),(365687,350858,'\'Pyrus\' Allotek Flaylock Pistol','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,12975.0000,1,363793,0),(365688,350858,'\'Pyrus\' Plasma Cannon','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4020.0000,1,364056,0),(365689,350858,'\'Pyrus\' ATK-73 Plasma Cannon','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,10770.0000,1,364057,0),(365690,350858,'\'Pyrus\' Allotek Plasma Cannon','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,28845.0000,1,364058,0),(365691,350858,'\'Pyrus\' Nova Knives','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,1815.0000,1,356434,0),(365692,350858,'\'Pyrus\' ATK-11 Nova Knives','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4845.0000,1,356435,0),(365693,350858,'\'Pyrus\' Allotek Nova Knives','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,12975.0000,1,356436,0),(365694,351064,'\'Pyrus\' Scout G-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354388,0),(365695,351064,'\'Pyrus\' Scout G/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(365696,351064,'\'Pyrus\' Scout gk.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354390,0),(365697,351064,'\'Pyrus\' Scout M-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354388,0),(365698,351064,'\'Pyrus\' Scout M/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(365699,351064,'\'Pyrus\' Scout mk.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354390,0),(365700,351064,'\'Pyrus\' Assault A-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354376,0),(365701,351064,'\'Pyrus\' Assault A/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(365702,351064,'\'Pyrus\' Assault ak.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354378,0),(365703,351064,'\'Pyrus\' Assault C-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354376,0),(365704,351064,'\'Pyrus\' Assault C/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(365705,351064,'\'Pyrus\' Assault ck.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354378,0),(365706,351064,'\'Pyrus\' Assault G-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354376,0),(365707,351064,'\'Pyrus\' Assault G/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(365708,351064,'\'Pyrus\' Assault gk.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354378,0),(365709,351064,'\'Pyrus\' Assault M-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354376,0),(365710,351064,'\'Pyrus\' Assault M/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(365711,351064,'\'Pyrus\' Assault mk.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354378,0),(365712,351064,'\'Pyrus\' Logistics A-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354384,0),(365713,351064,'\'Pyrus\' Logistics A/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(365714,351064,'\'Pyrus\' Logistics ak.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354386,0),(365715,351064,'\'Pyrus\' Logistics C-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354384,0),(365716,351064,'\'Pyrus\' Logistics C/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(365717,351064,'\'Pyrus\' Logistics ck.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354386,0),(365718,351064,'\'Pyrus\' Logistics G-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354384,0),(365719,351064,'\'Pyrus\' Logistics G/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(365720,351064,'\'Pyrus\' Logistics gk.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354386,0),(365721,351064,'\'Pyrus\' Logistics M-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354384,0),(365722,351064,'\'Pyrus\' Logistics M/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,8040.0000,1,354385,0),(365723,351064,'\'Pyrus\' Logistics mk.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354386,0),(365724,351064,'\'Pyrus\' Sentinel A-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,4905.0000,1,354380,0),(365725,351064,'\'Pyrus\' Sentinel A/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,13155.0000,1,354381,0),(365726,351064,'\'Pyrus\' Sentinel ak.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,354382,0),(365727,351064,'\'Pyrus\' Commando A-I','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,3000.0000,1,365279,0),(365728,351064,'\'Pyrus\' Commando A/1-Series','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,13155.0000,1,365280,0),(365729,351064,'\'Pyrus\' Commando ak.0','Utilizing sub-licensed technology sourced from all across the cluster, Allotek Industries  Pyrus product line offers a wide range of dropsuit and weapon variants developed and manufactured in accordance with the corporation s stringent guidelines to ensure that all products are worthy of carrying the Allotek quality guarantee.',0,0.01,0,1,NULL,35250.0000,1,365282,0),(365777,351121,'Basic Blaster Ammo Expansion Unit','Increases maximum ammunition capacity of all blaster turrets fitted on a vehicle.',0,0.01,0,1,NULL,3000.0000,1,365899,0),(365778,351121,'Enhanced Blaster Ammo Expansion Unit','Increases maximum ammunition capacity of all blaster turrets fitted on a vehicle.',0,0.01,0,1,NULL,8040.0000,1,365899,0),(365779,351121,'Complex Blaster Ammo Expansion Unit','Increases maximum ammunition capacity of all blaster turrets fitted on a vehicle.',0,0.01,0,1,NULL,13155.0000,1,365899,0),(365783,351121,'Basic Missile Ammo Expansion Unit','Increases maximum ammunition capacity of all missile launcher turrets fitted on a vehicle.',0,0.01,0,1,NULL,3000.0000,1,365900,0),(365784,351121,'Enhanced Missile Ammo Expansion Unit','Increases maximum ammunition capacity of all missile launcher turrets fitted on a vehicle.',0,0.01,0,1,NULL,8040.0000,1,365900,0),(365785,351121,'Complex Missile Ammo Expansion Unit','Increases maximum ammunition capacity of all missile launcher turrets fitted on a vehicle.',0,0.01,0,1,NULL,13155.0000,1,365900,0),(365786,351121,'Basic Railgun Ammo Expansion Unit','Increases maximum ammunition capacity of all railgun turrets fitted on a vehicle.',0,0.01,0,1,NULL,3000.0000,1,365901,0),(365787,351121,'Enhanced Railgun Ammo Expansion Unit','Increases maximum ammunition capacity of all railgun turrets fitted on a vehicle.',0,0.01,0,1,NULL,8040.0000,1,365901,0),(365788,351121,'Complex Railgun Ammo Expansion Unit','Increases maximum ammunition capacity of all railgun turrets fitted on a vehicle.',0,0.01,0,1,NULL,13155.0000,1,365901,0),(365832,351648,'Armor Fitting Optimization','Basic understanding of module resource management.\r\r\n\r\r\n5% reduction to PG usage of vehicle armor modules per level.',0,0.01,0,1,NULL,567000.0000,1,365001,0),(365844,351648,'Large Railgun Operation','Skill at operating large railgun turrets.\r\r\n\r\r\nUnlocks access to standard large railguns at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,149000.0000,1,353715,0),(365845,351648,'Small Railgun Operation','Skill at operating small railgun turrets.\r\r\n\r\r\nUnlocks access to standard small railguns at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,149000.0000,1,353715,0),(365848,351648,'Small Blaster Fitting Optimization','Advanced skill at turret resource management.\r\r\n\r\r\n3% reduction to PG/CPU usage of small blasters per level.',0,0.01,0,1,NULL,774000.0000,1,353715,0),(365850,351648,'Small Blaster Ammo Capacity','Skill at turret ammunition management.\r\r\n\r\r\n+5% to small blaster maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365851,351648,'Small Blaster Reload Systems','Skill at monitoring turret reload systems.\r\r\n\r\r\n+5% to small blaster reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365853,351648,'Small Missile Launcher Fitting Optimization','Advanced skill at turret resource management.\r\r\n\r\r\n3% reduction to PG/CPU usage of small missile launchers per level.',0,0.01,0,1,NULL,774000.0000,1,353715,0),(365854,351648,'Small Missile Launcher Reload Systems','Skill at monitoring turret reload systems.\r\r\n\r\r\n+5% to small missile launcher reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365855,351648,'Small Missile Launcher Ammo Capacity','Skill at turret ammunition management.\r\r\n\r\r\n+5% to small missile launcher maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365857,351648,'Small Railgun Fitting Optimization','Advanced skill at turret resource management.\r\r\n\r\r\n3% reduction to PG/CPU usage of small railguns per level.',0,0.01,0,1,NULL,774000.0000,1,353715,0),(365859,351648,'Small Railgun Ammo Capacity','Skill at turret ammunition management.\r\r\n\r\r\n+5% to small railgun maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365860,351648,'Small Railgun Reload Systems','Skill at monitoring turret reload systems.\r\r\n\r\r\n+5% to small railgun reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365861,351648,'Small Railgun Proficiency','Advanced skill at operating small railgun turrets.\r\r\n\r\r\n+10% to small railgun rotation speed per level.',0,0.01,0,1,NULL,567000.0000,1,353715,0),(365864,351648,'Large Railgun Ammo Capacity','Skill at turret ammunition management.\r\r\n\r\r\n+5% to large railgun maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365865,351648,'Large Railgun Reload Systems','Skill at monitoring turret reload systems.\r\r\n\r\r\n+5% to large railgun reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365866,351648,'Large Railgun Fitting Optimization','Advanced skill at turret resource management.\r\r\n\r\r\n3% reduction to PG/CPU usage of large railguns per level.',0,0.01,0,1,NULL,774000.0000,1,353715,0),(365868,351648,'Large Railgun Proficiency','Advanced skill at operating large railgun turrets.\r\r\n\r\r\n+10% to large railgun rotation speed per level.',0,0.01,0,1,NULL,567000.0000,1,353715,0),(365870,351648,'Large Blaster Fitting Optimization','Advanced skill at turret resource management.\r\r\n\r\r\n3% reduction to PG/CPU usage of large blasters per level.',0,0.01,0,1,NULL,774000.0000,1,353715,0),(365872,351648,'Large Blaster Reload Systems','Skill at monitoring turret reload systems.\r\r\n\r\r\n+5% to large blaster reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365873,351648,'Large Blaster Ammo Capacity','Skill at turret ammunition management.\r\r\n\r\r\n+5% to large blaster maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365875,351648,'Large Missile Launcher Fitting Optimization','Advanced skill at turret resource management.\r\r\n\r\r\n3% reduction to PG/CPU usage of large missile launchers per level.',0,0.01,0,1,NULL,774000.0000,1,353715,0),(365876,351648,'Large Missile Launcher Ammo Capacity','Skill at turret ammunition management.\r\r\n\r\r\n+5% to large missile launcher maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365877,351648,'Large Missile Launcher Reload Systems','Skill at monitoring turret reload systems.\r\r\n\r\r\n+5% to large missile launcher reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353715,0),(365878,351648,'Large Turret Operation','Basic understanding of large turret operation.\r\r\n\r\r\nUnlocks the ability to use large blaster, railgun and missile launcher turrets. 2% reduction to PG/CPU usage of large turrets per level.',0,0.01,0,1,NULL,72000.0000,1,353715,0),(365879,351648,'Small Turret Operation','Basic understanding of small turret operation.\r\r\n\r\r\nUnlocks the ability to use small blaster, railgun and missile launcher turrets. 2% reduction to PG/CPU usage of small turrets per level.',0,0.01,0,1,NULL,72000.0000,1,353715,0),(365893,351648,'Damage Amplifier Fitting Optimization','Basic understanding of module resource management.\r\r\n\r\r\n3% reduction to PG/CPU usage of vehicle damage amplifier modules per level.',0,0.01,0,1,NULL,774000.0000,1,353716,0),(365902,351121,'Militia Armor Hardener','Once activated, this module temporarily reduces the damage done to armor.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3660.0000,1,355467,0),(365903,351121,'Militia Shield Hardener','Once activated, this module temporarily reduces the damage done to shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3660.0000,1,355467,0),(365904,351121,'Militia Railgun Damage Amplifier','Once activated, this module temporarily increases the damage output of all railgun turrets fitted to a vehicle.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,4575.0000,1,355467,0),(365905,351121,'Militia Blaster Ammo Expansion Unit','Increases maximum ammunition capacity of all blaster turrets fitted on a vehicle.',0,0.01,0,1,NULL,1830.0000,1,355467,0),(365906,351121,'Militia Railgun Ammo Expansion Unit','Increases maximum ammunition capacity of all railgun turrets fitted on a vehicle.',0,0.01,0,1,NULL,1830.0000,1,355467,0),(365907,351121,'Militia Missile Ammo Expansion Unit','Increases maximum ammunition capacity of all missile launcher turrets fitted on a vehicle.',0,0.01,0,1,NULL,1830.0000,1,355467,0),(365908,351121,'Militia Mobile CRU','This module provides a clone reanimation unit inside a manned vehicle for mobile spawning.',0,0.01,0,1,NULL,4125.0000,1,355467,0),(365909,354641,'Passive Omega-Booster (7-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nPassive Boosters increase the rate of passive skill point accrual while they are active. Omega-Boosters feature superior performance over standard models.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0.01,0,1,NULL,0.0000,1,354542,0),(365912,354641,'Passive Omega-Booster (15-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nPassive Boosters increase the rate of passive skill point accrual while they are active. Omega-Boosters feature superior performance over standard models.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0.01,0,1,NULL,0.0000,1,354542,0),(365913,354641,'Passive Omega-Booster (1-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nPassive Boosters increase the rate of passive skill point accrual while they are active. Omega-Boosters feature superior performance over standard models.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0.01,0,1,NULL,0.0000,1,354542,0),(365914,354641,'Passive Omega-Booster (3-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nPassive Boosters increase the rate of passive skill point accrual while they are active. Omega-Boosters feature superior performance over standard models.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0.01,0,1,NULL,0.0000,1,354542,0),(365915,354641,'Active Omega-Booster (1-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(365916,354641,'Active Omega-Booster (3-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(365917,354641,'Active Omega-Booster (15-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool. The Omega-Booster features superior performance over standard models.',0,0.01,0,1,NULL,0.0000,1,354543,0),(365918,354641,'Active Omega-Booster (30-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(365919,354641,'Active Omega-Booster (60-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(365920,354641,'Active Omega-Booster (90-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(365921,354641,'Active Booster (15-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0,0,1,NULL,0.0000,1,354543,0),(365922,354641,'Active Booster (60-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(365923,354641,'Active Booster (90-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nActive Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool.',0,0.01,0,1,NULL,0.0000,1,354543,0),(365924,354641,'Passive Booster (1-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0.01,0,1,NULL,0.0000,1,354542,0),(365925,354641,'Passive Booster (60-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0,0,1,NULL,0.0000,1,354542,0),(365926,354641,'Passive Booster (90-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function.\r\r\n\r\r\nNOTE: Passive boosters will continue to function on non-primary clones as a factor of the base skillpoint accrual rate. (Non-primary clones without a passive skill booster do not accrue skill points at all.)',0,0.01,0,1,NULL,0.0000,1,354542,0),(365928,351064,'\'Flying Scotsman\' Assault ck.0','NOTE: In addition to pre-requisite skills, this pre-fitted dropsuit requires PG/CPU optimization skills to be trained in order to be used.\r\r\n\r\r\nThe Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,57690.0000,1,368019,0),(365930,351064,'\'Hellmar\' Sentinel ak.0','NOTE: In addition to pre-requisite skills, this pre-fitted dropsuit requires PG/CPU optimization skills to be trained in order to be used.\r\r\n\r\r\nThe Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0,0,1,NULL,57690.0000,1,368020,0),(365932,351064,'\'Remnant IX\' Logistics mk.0','NOTE: In addition to pre-requisite skills, this pre-fitted dropsuit requires PG/CPU optimization skills to be trained in order to be used.\r\r\n\r\r\nThe Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0,0,1,NULL,57690.0000,1,368021,0),(365934,351064,'\'Wolfman\' Assault A/1-Series','NOTE: In addition to pre-requisite skills, this pre-fitted dropsuit requires PG/CPU optimization skills to be trained in order to be used.\r\r\n\r\r\nThe Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,368019,0),(365936,351064,'\'Rattati\' Assault G/1-Series','NOTE: In addition to pre-requisite skills, this pre-fitted dropsuit requires PG/CPU optimization skills to be trained in order to be used.\r\r\n\r\r\nThe Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,368019,0),(365938,351064,'\'Logicloop\' Scout M-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,368018,0),(365940,351064,'\'Foxfour\' Assault G-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,368019,0),(365942,351064,'\'Tigris\' Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,3000.0000,1,368020,0),(365943,351210,'\'Praetorian VII\' Madrugar','NOTE: In addition to pre-requisite skills, this pre-fitted vehicle requires PG/CPU optimization skills to be trained in order to be used.\r\r\n\r\r\nThe Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,200000.0000,1,365951,0),(365944,351210,'\'Nullarbor\' Myron','NOTE: In addition to pre-requisite skills, this pre-fitted vehicle requires PG/CPU optimization skills to be trained in order to be used.\r\r\n\r\r\nThe dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,112500.0000,1,365949,0),(365945,351210,'\'Greyscale\' Saga','NOTE: In addition to pre-requisite skills, this pre-fitted vehicle requires PG/CPU optimization skills to be trained in order to be used.\r\r\n\r\r\nThe Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,40000.0000,1,365950,0),(365952,351121,'Complex Afterburner','Once activated, this module provides a temporary speed boost to aerial vehicles.\r\r\n\r\r\nNOTE: Only one afterburner can be fitted at a time.\r\r\nStacking penalties apply to this module and other modules of this type; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,19740.0000,1,354460,0),(365956,351121,'Militia Fuel Injector','Once activated, this module provides a temporary speed boost to ground vehicles.\r\r\n\r\r\nNOTE: Only one active fuel injector can be fitted at a time.\r\r\nStacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,2745.0000,1,355467,0),(365971,351064,'\'Neo\' Scout A-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,4905.0000,1,354388,0),(365972,351064,'\'Neo\' Scout A/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(365973,351064,'\'Neo\' Scout ak.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,35250.0000,1,354390,0),(365974,351064,'\'Neo\' Scout C-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,4905.0000,1,354388,0),(365975,351064,'\'Neo\' Scout C/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,8040.0000,1,354389,0),(365976,351064,'\'Neo\' Scout ck.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,35250.0000,1,354390,0),(365993,351064,'\'Origin\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,4905.0000,1,354376,0),(365994,351064,'\'Origin\' Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,4905.0000,1,354384,0),(366004,351844,'Cloak Field','The cloak field absorbs electromagnetic emissions and manipulates light to render the dropsuit practically invisible. When active, the field alters the magnetic permeability of the suit s surface area to generate a negative refractive index. \r\r\n\r\r\nWhile cloaked, the suit s susceptibility to magnetometric waves is moderately reduced, allowing it to evade all but the most sensitive scanning systems. However, cascading distortion introduced by weapon or equipment activation will desychronize the suit s sensors and short-circuit the cloak.',0,0.01,0,1,NULL,2085.0000,1,366753,0),(366009,350858,'Contact Grenade','The Contact grenade is a delayed-detonation explosive that can adhere to any metallic surface.',0,0.01,0,1,NULL,675.0000,1,NULL,0),(366014,350858,'D-9 Contact Grenade','The Contact grenade is a delayed-detonation explosive that can adhere to any metallic surface.',0,0.01,0,1,NULL,1815.0000,1,NULL,0),(366015,350858,'Viziam Contact Grenade','The Contact grenade is a delayed-detonation explosive that can adhere to any metallic surface.',0,0.01,0,1,NULL,7935.0000,1,NULL,0),(366022,354641,'Faction Booster Amarr (1-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366021,0),(366023,354641,'Faction Booster Caldari (1-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366350,0),(366024,354641,'Faction Booster Gallente (1-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366351,0),(366025,354641,'Faction Booster Minmatar (1-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366352,0),(366094,350858,'Federation Duvolle Specialist Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class.\r\r\n\r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,4,47220.0000,1,366224,0),(366095,350858,'Republic Boundless Specialist Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,4,47220.0000,1,366274,0),(366096,350858,'Imperial Viziam Specialist Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\r\n\r\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,4,47220.0000,1,366259,0),(366097,350858,'Republic Freedom Specialist Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,4,47220.0000,1,366274,0),(366098,350858,'Federation Allotek Specialist Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,4,47220.0000,1,366224,0),(366099,350858,'State Kaalakiota Specialist Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,4,47220.0000,1,366221,0),(366100,350858,'Imperial Viziam Specialist Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,4,47220.0000,1,366259,0),(366101,350858,'Federation CreoDron Specialist Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\n\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,4,47220.0000,1,366224,0),(366102,350858,'State Ishukone Specialist Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,4,47220.0000,1,366221,0),(366103,350858,'State Wiyrkomi Specialist Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets.\r\r\n \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,4,47220.0000,1,366221,0),(366104,351844,'Imperial Viziam Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,28335.0000,1,366267,0),(366105,351844,'State Ishukone Quantum Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\n\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,28335.0000,1,366285,0),(366106,351844,'Federation Duvolle Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\r\n\r\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,18885.0000,1,366263,0),(366107,351844,'State Kaalakiota Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,18885.0000,1,366285,0),(366108,351844,'Republic Boundless Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\r\n\r\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,21630.0000,1,366278,0),(366131,351210,' ',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(366228,351648,'Assault Dropships','Skill at operating Assault Dropships.\r\r\n\r\r\nUnlocks Assault Dropships of all races. +2% to small turret damage per level.',0,0.01,0,1,NULL,567000.0000,1,353711,0),(366229,354641,'Faction Booster Amarr (3-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366021,0),(366230,354641,'Faction Booster Amarr (7-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366021,0),(366231,354641,'Faction Booster Amarr (15-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366021,0),(366232,354641,'Faction Booster Amarr (30-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366021,0),(366233,354641,'Faction Booster Amarr (60-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366021,0),(366234,354641,'Faction Booster Amarr (90-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366021,0),(366235,354641,'Faction Booster Caldari (3-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366350,0),(366236,354641,'Faction Booster Caldari (7-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366350,0),(366237,354641,'Faction Booster Caldari (15-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366350,0),(366238,354641,'Faction Booster Caldari (30-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366350,0),(366239,354641,'Faction Booster Caldari (60-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366350,0),(366240,354641,'Faction Booster Caldari (90-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366350,0),(366241,354641,'Faction Booster Gallente (3-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366351,0),(366242,354641,'Faction Booster Gallente (7-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366351,0),(366243,354641,'Faction Booster Gallente (15-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366351,0),(366244,354641,'Faction Booster Gallente (30-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366351,0),(366245,354641,'Faction Booster Gallente (60-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366351,0),(366246,354641,'Faction Booster Gallente (90-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366351,0),(366247,354641,'Faction Booster Minmatar (3-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366352,0),(366248,354641,'Faction Booster Minmatar (7-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366352,0),(366249,354641,'Faction Booster Minmatar (15-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366352,0),(366250,354641,'Faction Booster Minmatar (30-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366352,0),(366251,354641,'Faction Booster Minmatar (60-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366352,0),(366252,354641,'Faction Booster Minmatar (90-Day)','Faction boosters are biometric identification chips issued by major factions throughout New Eden. Once activated they uniquely identify the user as a supporter of the issuing faction. Corporations operating on behalf of the faction will then be authorized to increase rewards to that individual.',0,0,0,1,NULL,0.0000,1,366352,0),(366289,351121,'Imperial Basic Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.',0,0,0,1,NULL,0.0000,1,366268,0),(366290,351121,'Imperial Enhanced Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.',0,0,0,1,NULL,0.0000,1,366269,0),(366291,351121,'Imperial Complex Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.',0,0,0,1,NULL,0.0000,1,366271,0),(366292,351121,'Imperial Basic Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0,0,1,NULL,0.0000,1,366268,0),(366293,351121,'Imperial Enhanced Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0,0,1,NULL,0.0000,1,366269,0),(366294,351121,'Imperial Complex Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0,0,1,NULL,0.0000,1,366271,0),(366295,351121,'Imperial Basic CPU Upgrade','Increases dropsuit\'s maximum CPU output. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366268,0),(366296,351121,'Imperial Enhanced CPU Upgrade','Increases dropsuit\'s maximum CPU output. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366269,0),(366297,351121,'Imperial Complex CPU Upgrade','Increases dropsuit\'s maximum CPU output. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366271,0),(366298,351121,'Imperial Basic PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0,0,1,NULL,0.0000,1,366268,0),(366299,351121,'Imperial Enhanced PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0,0,1,NULL,0.0000,1,366269,0),(366300,351121,'Imperial Complex PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0,0,1,NULL,0.0000,1,366271,0),(366301,351121,'State Basic PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0,0,1,NULL,0.0000,1,366286,0),(366302,351121,'State Enhanced PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0,0,1,NULL,0.0000,1,366287,0),(366303,351121,'State Complex PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0,0,1,NULL,0.0000,1,366288,0),(366304,351121,'State Basic CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0,0,1,NULL,0.0000,1,366286,0),(366305,351121,'State Enhanced CPU Upgrade','Increases dropsuit\'s maximum CPU output. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366287,0),(366306,351121,'State Complex CPU Upgrade','Increases dropsuit\'s maximum CPU output. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366288,0),(366307,351121,'State Basic Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0,0,1,NULL,0.0000,1,366286,0),(366308,351121,'State Enhanced Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0,0,1,NULL,0.0000,1,366287,0),(366309,351121,'State Complex Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0,0,1,NULL,0.0000,1,366288,0),(366310,351121,'State Basic Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0,0,1,NULL,0.0000,1,366286,0),(366311,351121,'State Enhanced Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0,0,1,NULL,0.0000,1,366287,0),(366312,351121,'State Complex Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0,0,1,NULL,0.0000,1,366288,0),(366313,351121,'State Basic Shield Recharger','Improves the recharge rate of dropsuit\'s shields. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366286,0),(366314,351121,'State Enhanced Shield Recharger','Improves the recharge rate of dropsuit\'s shields. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366287,0),(366315,351121,'State Complex Shield Recharger','Improves the recharge rate of dropsuit\'s shields. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366288,0),(366316,351121,'State Basic Shield Regulator','Reduces the length of the delay before shield recharge begins. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366286,0),(366317,351121,'State Enhanced Shield Regulator','Reduces the length of the delay before shield recharge begins. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366287,0),(366318,351121,'State Complex Shield Regulator','Reduces the length of the delay before shield recharge begins. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366288,0),(366319,351121,'Republic Basic PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0,0,1,NULL,0.0000,1,366279,0),(366320,351121,'Republic Enhanced PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0,0,1,NULL,0.0000,1,366280,0),(366321,351121,'Republic Complex PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0,0,1,NULL,0.0000,1,366281,0),(366322,351121,'Republic Basic CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0,0,1,NULL,0.0000,1,366279,0),(366323,351121,'Republic Enhanced CPU Upgrade','Increases dropsuit\'s maximum CPU output. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366280,0),(366324,351121,'Republic Complex CPU Upgrade','Increases dropsuit\'s maximum CPU output. NOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0,0,1,NULL,0.0000,1,366281,0),(366336,351064,'\'State Peacekeeper\' Assault C/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(366337,351064,'\'State Peacekeeper\' Assault ck.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,35250.0000,1,354378,0),(366338,351064,'\'Republic Command\' Assault M/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(366339,351064,'\'Republic Command\' Assault mk.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,35250.0000,1,354378,0),(366340,351064,'\'Imperial Guard\' Assault A/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(366341,351064,'\'Imperial Guard\' Assault ak.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,35250.0000,1,354378,0),(366342,351064,'\'Federal Marine\' Assault G/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,354377,0),(366343,351064,'\'Federal Marine\' Assault gk.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,35250.0000,1,354378,0),(366344,350858,'\'Imperial Guard\'  VZN-20 Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\r\n\r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,10770.0000,1,354336,0),(366345,350858,'\'Imperial Guard\' Viziam Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\r\n\r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,28845.0000,1,354337,0),(366346,351064,'\'Stahl\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,4905.0000,1,354376,0),(366363,351064,'Federation Assault G-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,366200,0),(366364,351064,'Federation Assault G/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,366201,0),(366365,351064,'Federation Assault gk.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,21540.0000,1,366202,0),(366366,351064,'Federation Logistics G-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,3000.0000,1,366200,0),(366367,351064,'Federation Logistics G/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,366201,0),(366368,351064,'Federation Logistics gk.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,21540.0000,1,366202,0),(366369,351064,'Federation Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,4905.0000,1,366200,0),(366370,351064,'Federation Scout G/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,8040.0000,1,366201,0),(366371,351064,'Federation Scout gk.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\n\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\n\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,35250.0000,1,366202,0),(366372,350858,'Federation Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,4020.0000,1,366222,0),(366373,350858,'Federation GK-13 Burst Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,10770.0000,1,366223,0),(366374,350858,'Federation GEK-38 Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,10770.0000,1,366223,0),(366375,350858,'Federation Duvolle Tactical Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\n\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,28845.0000,1,366224,0),(366376,350858,'Federation Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,4020.0000,1,366222,0),(366377,350858,'Federation KLA-90 Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,10770.0000,1,366223,0),(366378,350858,'Federation Allotek Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,28845.0000,1,366224,0),(366379,350858,'Federation Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,4020.0000,1,366222,0),(366380,350858,'Federation CRG-3 Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,10770.0000,1,366223,0),(366381,350858,'Federation CreoDron Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\n\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,28845.0000,1,366224,0),(366382,351210,'Federation Grimsnes','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,45000.0000,1,366209,0),(366383,351210,'Federation Madrugar','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,97500.0000,1,366209,0),(366384,351210,'Federation Methana','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,366209,0),(366385,350858,'Federation 20GJ Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,24105.0000,1,366210,0),(366386,350858,'Federation 20GJ Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,64605.0000,1,366211,0),(366387,350858,'Federation 20GJ Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,105735.0000,1,366212,0),(366388,350858,'Federation 80GJ Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,64305.0000,1,366210,0),(366389,350858,'Federation 80GJ Neutron Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,172260.0000,1,366211,0),(366390,350858,'Federation 80GJ Ion Cannon','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,NULL,281955.0000,1,366212,0),(366391,351121,'Federation Basic PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,1200.0000,1,366253,0),(366392,351121,'Federation Enhanced PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,3210.0000,1,366254,0),(366393,351121,'Federation Complex PG Upgrade','Increases dropsuit\'s maximum powergrid output.',0,0.01,0,1,NULL,3210.0000,1,366255,0),(366394,351121,'Federation Basic Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.\r\r\n',0,0.01,0,1,NULL,900.0000,1,366253,0),(366395,351121,'Federation Enhanced Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.\r\r\n',0,0.01,0,1,NULL,2415.0000,1,366254,0),(366396,351121,'Federation Complex Armor Plates','Increases maximum strength of dropsuit\'s armor, but the increased mass reduces movement speed.',0,0.01,0,1,NULL,2415.0000,1,366255,0),(366397,351121,'Federation Basic Kinetic Catalyzer','Increases sprinting speed of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,675.0000,1,366253,0),(366398,351121,'Federation Enhanced Kinetic Catalyzer','Increases sprinting speed of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,1815.0000,1,366254,0),(366399,351121,'Federation Complex Kinetic Catalyzer','Increases sprinting speed of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module after the first will be reduced. ',0,0.01,0,1,NULL,1815.0000,1,366255,0),(366400,351121,'Federation Basic Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0.01,0,1,NULL,1275.0000,1,366253,0),(366401,351121,'Federation Enhanced Armor Repairer','Passively repairs damage done to dropsuit\'s armor.\r\r\n',0,0.01,0,1,NULL,3420.0000,1,366254,0),(366402,351121,'Federation Complex Armor Repairer','Passively repairs damage done to dropsuit\'s armor.',0,0.01,0,1,NULL,3420.0000,1,366255,0),(366403,351121,'Federation Basic Codebreaker','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,975.0000,1,366253,0),(366404,351121,'Federation Enhanced Codebreaker','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,2610.0000,1,366254,0),(366405,351121,'Federation Complex Codebreaker','Increases hacking speed, making it easier to seize control of enemy vehicles and installations.',0,0.01,0,1,NULL,2610.0000,1,366255,0),(366406,351121,'Federation Basic CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1200.0000,1,366253,0),(366407,351121,'Federation Enhanced CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3210.0000,1,366254,0),(366408,351121,'Federation Complex CPU Upgrade','Increases dropsuit\'s maximum CPU output.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3210.0000,1,366255,0),(366409,351844,'Federation Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,1605.0000,1,366261,0),(366410,351844,'Federation A-86 Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,4305.0000,1,366262,0),(366411,351844,'Federation CreoDron Active Scanner','Sending out a triggered pulse of high-frequency magnetometric waves and interpreting the results with an uplinked onboard computer, the Active Scanner gives ground units a snapshot of enemy positions. Projection nodes set at specific angles on the hand-held device, generate a vectored impulse capable of extracting objects from high-noise environments. Feedback from the pulse is filtered to reduce ambient clutter and pinpoint targets lacking IFF signals.\r\r\nThough the amount of energy required to produce the blast is much greater than its on-board power source can readily generate, the Active Scanner makes use of redundant J-24 micro-capacitors to circulate and build the charge up to the required output. The resulting delay between activations is a small price to pay for the enormous tactical advantage the device provides its user.',0,0.01,0,1,NULL,7050.0000,1,366263,0),(366412,351064,'Imperial Assault A-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,366197,0),(366413,351064,'Imperial Assault A/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,366198,0),(366414,351064,'Imperial Assault ak.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,21540.0000,1,366199,0),(366415,351064,'Imperial Commando A-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,3000.0000,1,366197,0),(366416,351064,'Imperial Commando A/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,13155.0000,1,366198,0),(366417,351064,'Imperial Commando ak.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,35250.0000,1,366199,0),(366418,351064,'Imperial Logistics A-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,3000.0000,1,366197,0),(366419,351064,'Imperial Logistics A/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,366198,0),(366420,351064,'Imperial Logistics ak.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,21540.0000,1,366199,0),(366421,351064,'Imperial Sentinel A-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,4905.0000,1,366197,0),(366422,351064,'Imperial Sentinel A/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,13155.0000,1,366198,0),(366423,351064,'Imperial Sentinel ak.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,35250.0000,1,366199,0),(366424,350858,'Imperial Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,4020.0000,1,366257,0),(366425,350858,'Imperial CRW-04 Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,10770.0000,1,366258,0),(366426,350858,'Imperial CRD-9 Assault Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,10770.0000,1,366258,0),(366427,350858,'Imperial Viziam Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,28845.0000,1,366259,0),(366428,350858,'Imperial Carthum Assault Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,28845.0000,1,366259,0),(366429,350858,'Imperial Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,4020.0000,1,366257,0),(366430,350858,'Imperial ELM-7 Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,10770.0000,1,366258,0),(366431,350858,'Imperial Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,1815.0000,1,366257,0),(366432,350858,'Imperial Viziam Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\n\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,28845.0000,1,366259,0),(366433,350858,'Imperial CAR-9 Burst Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target.\r\n\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,4845.0000,1,366258,0),(366434,350858,'Imperial Viziam Scrambler Pistol','The Scrambler is a semi-automatic pistol originally designed and manufactured by Carthum Conglomerate. A small-scale directed energy weapon, it produces a laser-induced plasma channel capable of dealing short-range pin-point damage to a target. \r\r\nPower consumption is excessive, but is addressed via a rear-loaded fuel cell, allowing cells to be exchanged quickly and easily once exhausted. Moreover, advances in the polymers used in the weapon\'s construction have greatly reduced heat build-up and improved heat dissipation, resulting in improved reliability over earlier modules. ',0,0.01,0,1,NULL,12975.0000,1,366259,0),(366435,351121,'Imperial Basic Cardiac Regulator','Increases max stamina and stamina recovery rate of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,720.0000,1,366268,0),(366436,351121,'Imperial Enhanced Cardiac Regulator','Increases max stamina and stamina recovery rate of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1935.0000,1,366269,0),(366437,351121,'Imperial Complex Cardiac Regulator','Increases max stamina and stamina recovery rate of the user.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1935.0000,1,366271,0),(366438,351121,'Imperial Basic Heavy Damage Modifier','Increases damage output of all heavy handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1275.0000,1,366268,0),(366439,351121,'Imperial Enhanced Heavy Damage Modifier','Increases damage output of all heavy handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,366269,0),(366440,351121,'Imperial Complex Heavy Damage Modifier','Increases damage output of all heavy handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,366271,0),(366441,351844,'Imperial R-9 Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,3945.0000,1,366266,0),(366442,351844,'Imperial Viziam Drop Uplink','The drop uplink is a slave transponder, a short-range tether that produces the precise spatial coordinates necessary to generate a localized wormhole, traversal of which allows the user to travel short distances instantly. Highly experimental, the process is excruciatingly painful and exposes organic tissue to excessive radiation, resulting in accelerated cellular decay and, ultimately, death. ',0,0.01,0,1,NULL,10575.0000,1,366267,0),(366443,351064,'Republic Assault M-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,3000.0000,1,366203,0),(366444,351064,'Republic Assault M/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,366204,0),(366445,351064,'Republic Assault mk.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,21540.0000,1,366205,0),(366446,351064,'Republic Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,4905.0000,1,366203,0),(366447,351064,'Republic Logistics M/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,366204,0),(366448,351064,'Republic Logistics mk.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,35250.0000,1,366205,0),(366449,351064,'Republic Scout M-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,3000.0000,1,366203,0),(366450,351064,'Republic Scout M/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,8040.0000,1,366204,0),(366451,351064,'Republic Scout mk.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,NULL,21540.0000,1,366205,0),(366452,350858,'Republic Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,4,4020.0000,1,366272,0),(366453,350858,'Republic MH-82 Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\n\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,10770.0000,1,366273,0),(366454,350858,'Republic Boundless Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,28845.0000,1,366274,0),(366455,350858,'Republic Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,1815.0000,1,366272,0),(366456,350858,'Republic M512-A Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,4845.0000,1,366273,0),(366457,350858,'Republic Six Kin Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,12975.0000,1,366274,0),(366458,350858,'Republic Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0.01,0,1,NULL,1815.0000,1,366272,0),(366459,350858,'Republic GN-13 Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0.01,0,1,NULL,4845.0000,1,366273,0),(366460,350858,'Republic Core Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0.01,0,1,NULL,12975.0000,1,366274,0),(366461,350858,'Republic Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,4020.0000,1,366272,0),(366462,350858,'Republic EXO-5 Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,10770.0000,1,366273,0),(366463,350858,'Republic Freedom Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,28845.0000,1,366274,0),(366464,350858,'Republic SK9M Breach Submachine Gun','Favoring function over form, the SMG is a lightweight, semi-automatic weapon designed for close-quarters combat. What it lacks in stopping power and accuracy it grossly overcompensates for with quantity. Designed to injure and impede, the hailstorm of bullets the SMG produces is most effective in tight spaces against multiple targets.\r\n\r\nThis original design is a paradigm of Minmatar construction. An inelegant, but reliable weapon solution that is simple to produce, easily repaired using almost any available materials, and provides comparable pound-for-pound performance with similar sub-automatic weapons. Although an unabashedly low-tech weapon, it excels at what it was designed for: killing anything right in front of you.',0,0.01,0,1,NULL,4845.0000,1,366273,0),(366465,351121,'Republic Basic Sidearm Damage Modifier','Increases damage output of all sidearm handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1275.0000,1,366279,0),(366466,351121,'Republic Enhanced Sidearm Damage Modifier','Increases damage output of all sidearm handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,3420.0000,1,366280,0),(366467,351121,'Republic Complex Sidearm Damage Modifier','Increases damage output of all sidearm handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,366281,0),(366468,351121,'Republic Basic Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0.01,0,1,NULL,975.0000,1,366279,0),(366469,351121,'Republic Enhanced Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0.01,0,1,NULL,2610.0000,1,366280,0),(366470,351121,'Republic Complex Shield Extender','Increases the maximum strength of dropsuit shields, but lengthens the recharge delay once shields are fully depleted.',0,0.01,0,1,NULL,2610.0000,1,366281,0),(366471,351121,'Republic Basic Shield Regulator','Reduces the length of the delay before shield recharge begins.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,675.0000,1,366279,0),(366472,351121,'Republic Enhanced Shield Regulator','Reduces the length of the delay before shield recharge begins.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1815.0000,1,366280,0),(366473,351121,'Republic Complex Shield Regulator','Reduces the length of the delay before shield recharge begins.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1815.0000,1,366281,0),(366474,351121,'Republic Basic Shield Recharger','Improves the recharge rate of dropsuit\'s shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,1350.0000,1,366279,0),(366475,351121,'Republic Enhanced Shield Recharger','Improves the recharge rate of dropsuit\'s shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3615.0000,1,366280,0),(366476,351121,'Republic Complex Shield Recharger','Improves the recharge rate of dropsuit\'s shields.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,3615.0000,1,366281,0),(366477,351121,'Republic Basic Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0.01,0,1,NULL,1350.0000,1,366279,0),(366478,351121,'Republic Enhanced Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0.01,0,1,NULL,3615.0000,1,366280,0),(366479,351121,'Republic Complex Shield Energizer','Greatly improves the recharge rate of dropsuit s shields at the cost of shield strength.',0,0.01,0,1,NULL,3615.0000,1,366281,0),(366480,351121,'Republic Basic Myofibril Stimulant','Increases damage done by melee attacks.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,780.0000,1,366279,0),(366481,351121,'Republic Enhanced Myofibril Stimulant','Increases damage done by melee attacks.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,2085.0000,1,366280,0),(366482,351121,'Republic Complex Myofibril Stimulant','Increases damage done by melee attacks.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,2085.0000,1,366281,0),(366483,351844,'Republic Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\n\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,4020.0000,1,366276,0),(366484,351844,'Republic F/45 Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\n\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,10770.0000,1,366277,0),(366485,351844,'Republic Boundless Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\n\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,NULL,28845.0000,1,366278,0),(366486,351844,'Republic Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,3015.0000,1,366276,0),(366487,351844,'Republic A/7 Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,8070.0000,1,366277,0),(366488,351844,'Republic Core Repair Tool','By projecting a focused harmonic beam into damaged materials, the repair tool channels construction nanites to return the targeted matter to its original state. Its on-board processor interfaces with a forward-facing sensor suite, instantly recognizing vehicles, devices, and personal armor based on microscopic manufacturer\'s tags. The beam, a bi-channel  hollow laser , simultaneously acts as both a containment field and transport medium for the nanite swarm, which works to sift unwanted particles from the structure, undo ionization, and reconstruct the atomic patterns of the material.\r\n\r\nThe repair tool has several design innovations, the most surprising probably being the incorporation of Amarr focusing crystal technology. Beyond that, the device also makes use of an advanced K7 nano static co-processor on par with Caldari planet side missile tracking systems and a 55x5 reverse current power cell configuration rarely used beyond self-sustaining Gallente drone units. The result is an elegant tool combining the best technology from several very different design philosophies.',0,0.01,0,1,NULL,8070.0000,1,366278,0),(366489,351064,'State Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,4905.0000,1,366206,0),(366490,351064,'State Logistics C-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,3000.0000,1,366206,0),(366491,351064,'State Assault C/1-Series','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,8040.0000,1,366207,0),(366492,351064,'State Logistics C/1-Series','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,8040.0000,1,366207,0),(366493,351064,'State Assault ck.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,35250.0000,1,366208,0),(366494,351064,'State Logistics ck.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,NULL,21540.0000,1,366208,0),(366495,350858,'State Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,4020.0000,1,366219,0),(366496,350858,'State Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,4020.0000,1,366219,0),(366497,350858,'State Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,4020.0000,1,366219,0),(366498,350858,'State SL-4 Assault Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,10770.0000,1,366220,0),(366499,350858,'State CBR7 Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,10770.0000,1,366220,0),(366500,350858,'State C15-A Tactical Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,10770.0000,1,366220,0),(366501,350858,'State NT-511 Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,10770.0000,1,366220,0),(366502,350858,'State SB-39 Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,10770.0000,1,366220,0),(366503,350858,'State Ishukone Assault Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,28845.0000,1,366221,0),(366504,350858,'State Wiyrkomi Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,28845.0000,1,366221,0),(366505,350858,'State Kaalakiota Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,28845.0000,1,366221,0),(366506,350858,'State Kaalakiota Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,28845.0000,1,366221,0),(366507,351210,'State Myron','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,NULL,45000.0000,1,366216,0),(366508,351210,'State Gunnlogi','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,NULL,97500.0000,1,366216,0),(366509,351210,'State Saga','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,NULL,30000.0000,1,366216,0),(366510,350858,'State ST-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,24105.0000,1,366213,0),(366511,350858,'State ST-201 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,64305.0000,1,366213,0),(366512,350858,'State 20GJ Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,24105.0000,1,366213,0),(366513,350858,'State 80GJ Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,64305.0000,1,366213,0),(366514,350858,'State AT-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,64605.0000,1,366214,0),(366515,350858,'State 80GJ Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,172260.0000,1,366214,0),(366516,350858,'State AT-201 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,172260.0000,1,366214,0),(366517,350858,'State 20GJ Particle Accelerator','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,64605.0000,1,366214,0),(366518,350858,'State XT-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,105735.0000,1,366215,0),(366519,350858,'State 80GJ Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,281955.0000,1,366215,0),(366520,350858,'State 20GJ Particle Cannon','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,NULL,105735.0000,1,366215,0),(366521,350858,'State XT-201 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,NULL,281955.0000,1,366215,0),(366522,351121,'State Basic Light Damage Modifier','Increases damage output of all light handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,1275.0000,1,366286,0),(366523,351121,'State Enhanced Light Damage Modifier','Increases damage output of all light handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced. ',0,0.01,0,1,NULL,3420.0000,1,366287,0),(366524,351121,'State Complex Light Damage Modifier','Increases damage output of all light handheld weapons.\r\r\n\r\r\nNOTE: Stacking penalties apply to this module; the effectiveness of each additional module (after the first) that alters the same attributes will be reduced.',0,0.01,0,1,NULL,3420.0000,1,366288,0),(366525,351844,'State Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,1605.0000,1,366283,0),(366526,351844,'State Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,2415.0000,1,366283,0),(366527,351844,'State K-17D Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,3945.0000,1,366284,0),(366528,351844,'State KIN-012 Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,4305.0000,1,366284,0),(366529,351844,'State Ishukone Nanohive','The nanohive is one of the most advanced pieces of battlefield technology to date, able to convert formatted matter from its limited internal stores and reorganize it into any kind of ammunition. When a soldier approaches, the nanohive receives an automated request from the Cortex Holographic Interface instructing swarms of self-replicating construction nanites to begin producing whatever type of ammunition that soldier requires.\r\n\r\nThe device itself is composed of three major parts: a composite carbon polymer shell, heavily shielded to prevent potentially disruptive ambient electronic interference; a low-level replicator assembly housing the initial seed swarm; and a C11 power core capable of producing class-one containment fields, confining the nanite swarm as it replicates to its maximum sustainable mass. There is, however, no central computer; each nanite is born with a complete set of instructions on how to create every known variety of ammunition round.',0,0.01,0,1,NULL,10575.0000,1,366285,0),(366530,351844,'State Wiyrkomi Nanite Injector','The nanite injector delivers an active helix directly into the bloodstream of the downed victim, whereupon individual subunits work to suppress the pain response, repair tissue and organ damage and reestablish regular cardiac rhythm. If administered in time, first-phase resuscitation (defined as  minimum-essential combat functionality\') is typically achievable, though some psychological trauma is to be expected.',0,0.01,0,1,NULL,7050.0000,1,366285,0),(366532,351844,'ARN-18 Cloak Field','The cloak field absorbs electromagnetic emissions and manipulates light to render the dropsuit practically invisible. When active, the field alters the magnetic permeability of the suit s surface area to generate a negative refractive index. \r\r\n\r\r\nWhile cloaked, the suit s susceptibility to magnetometric waves is moderately reduced, allowing it to evade all but the most sensitive scanning systems. However, cascading distortion introduced by weapon or equipment activation will desychronize the suit s sensors and short-circuit the cloak.',0,0.01,0,1,NULL,3420.0000,1,366754,0),(366534,351844,'Ishukone Cloak Field','The cloak field absorbs electromagnetic emissions and manipulates light to render the dropsuit practically invisible. When active, the field alters the magnetic permeability of the suit s surface area to generate a negative refractive index. \r\r\n\r\r\nWhile cloaked, the suit s susceptibility to magnetometric waves is moderately reduced, allowing it to evade all but the most sensitive scanning systems. However, cascading distortion introduced by weapon or equipment activation will desychronize the suit s sensors and short-circuit the cloak.',0,0.01,0,1,NULL,9150.0000,1,366755,0),(366587,351648,'Bolt Pistol Fitting Optimization','Advanced skill at weapon resource management.\r\r\n\r\r\n5% reduction to PG usage per level.',0,0.01,0,1,NULL,774000.0000,1,353684,0),(366589,351648,'Bolt Pistol Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+5% maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(366590,351648,'Bolt Pistol Proficiency','Skill at handling bolt pistols.\r\r\n\r\r\n+3% bolt pistol damage against armor per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(366591,351648,'Bolt Pistol Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(366592,351648,'Bolt Pistol Operation','Skill at handling bolt pistols.\r\r\n\r\r\n5% reduction to bolt pistol kick per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(366595,351648,'Ion Pistol Fitting Optimization','Advanced skill at weapon resource management.\r\r\n\r\r\n5% reduction to CPU usage per level.',0,0.01,0,1,NULL,774000.0000,1,353684,0),(366596,351648,'Ion Pistol Sharpshooter','Skill at weapon marksmanship.\r\r\n\r\r\n5% reduction to ion pistol dispersion per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(366597,351648,'Ion Pistol Ammo Capacity','Skill at ammunition management.\r\r\n\r\r\n+5% maximum ammunition capacity per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(366598,351648,'Ion Pistol Proficiency','Skill at handling ion pistols.\r\r\n\r\r\n+3% ion pistol damage against shields per level.',0,0.01,0,1,NULL,567000.0000,1,353684,0),(366599,351648,'Ion Pistol Rapid Reload','Advanced skill at rapidly reloading weapons.\r\r\n\r\r\n+3% reload speed per level.',0,0.01,0,1,NULL,203000.0000,1,353684,0),(366600,351648,'Ion Pistol Operation','Skill at handling ion pistols.\r\r\n\r\r\n5% reduction to ion pistol charge time per level.',0,0.01,0,1,NULL,149000.0000,1,353684,0),(366677,351064,'\'Neo\' Sentinel M-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,4905.0000,1,354380,0),(366678,351064,'\'Neo\' Sentinel M/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,13155.0000,1,354381,0),(366679,351064,'\'Neo\' Sentinel mk.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,35250.0000,1,354382,0),(366680,351064,'\'Neo\' Sentinel G-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,4905.0000,1,354380,0),(366681,351064,'\'Neo\' Sentinel G/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0,0,1,NULL,13155.0000,1,354381,0),(366682,351064,'\'Neo\' Sentinel gk.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,35250.0000,1,354382,0),(366683,351064,'\'Neo\' Sentinel C-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,4905.0000,1,354380,0),(366684,351064,'\'Neo\' Sentinel C/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0,0,1,NULL,13155.0000,1,354381,0),(366685,351064,'\'Neo\' Sentinel ck.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,35250.0000,1,354382,0),(366686,351064,'Gallente Heavy Frame G/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364895,0),(366687,351064,'Gallente Heavy Frame gk.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364896,0),(366688,351064,'Minmatar Heavy Frame M/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364895,0),(366689,351064,'Minmatar Heavy Frame mk.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364896,0),(366690,351064,'Caldari Heavy Frame C/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364895,0),(366691,351064,'Caldari Heavy Frame ck.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364896,0),(366695,351064,'Militia Caldari Heavy Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(366696,351064,'Militia Gallente Heavy Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(366697,351064,'Militia Minmatar Heavy Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(366698,351064,'Commando C-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,3000.0000,1,365279,0),(366699,351064,'Commando G-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,3000.0000,1,365279,0),(366700,351064,'Commando M-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,3000.0000,1,365279,0),(366710,351064,'Commando C/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,8040.0000,1,365280,0),(366711,351064,'Commando ck.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,57690.0000,1,365282,0),(366712,351064,'Commando G/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,8040.0000,1,365280,0),(366713,351064,'Commando gk.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,57690.0000,1,365282,0),(366714,351064,'Commando M/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,8040.0000,1,365280,0),(366715,351064,'Commando mk.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,57690.0000,1,365282,0),(366716,351064,'\'Neo\' Commando C-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,3000.0000,1,365279,0),(366717,351064,'\'Neo\' Commando C/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,13155.0000,1,365280,0),(366718,351064,'\'Neo\' Commando ck.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,35250.0000,1,365282,0),(366719,351064,'\'Neo\' Commando G-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,3000.0000,1,365279,0),(366720,351064,'\'Neo\' Commando G/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,13155.0000,1,365280,0),(366721,351064,'\'Neo\' Commando gk.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,35250.0000,1,365282,0),(366722,351064,'\'Neo\' Commando M-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,3000.0000,1,365279,0),(366723,351064,'\'Neo\' Commando M/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0,0,1,NULL,13155.0000,1,365280,0),(366724,351064,'\'Neo\' Commando mk.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,NULL,35250.0000,1,365282,0),(366732,351064,'Amarr Light Frame A/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364887,0),(366733,351064,'Amarr Light Frame ak.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364888,0),(366734,351064,'Caldari Light Frame C/1-Series','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,8040.0000,1,364887,0),(366735,351064,'Caldari Light Frame ck.0','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,4,34614.0000,1,364888,0),(366736,351064,'Militia Caldari Light Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(366737,351064,'Militia Amarr Light Frame','A basic dropsuit frame hardwired with all minimum designation combat suites and protocols but without any role-specific customizations.\r\r\n\r\r\nNOTE: This basic frame does not receive any role-specific bonuses.',0,0.01,0,1,NULL,610.0000,1,355469,0),(366749,351844,'\'Apparition\' Cloak Field','The cloak field absorbs electromagnetic emissions and manipulates light to render the dropsuit practically invisible. When active, the field alters the magnetic permeability of the suit s surface area to generate a negative refractive index. \r\r\n\r\r\nWhile cloaked, the suit s susceptibility to magnetometric waves is moderately reduced, allowing it to evade all but the most sensitive scanning systems. However, cascading distortion introduced by weapon or equipment activation will desychronize the suit s sensors and short-circuit the cloak.',0,0.01,0,1,NULL,3420.0000,1,366753,0),(366750,351844,'\'Phantasm\' ARN-18 Cloak Field','The cloak field absorbs electromagnetic emissions and manipulates light to render the dropsuit practically invisible. When active, the field alters the magnetic permeability of the suit s surface area to generate a negative refractive index. \r\r\n\r\r\nWhile cloaked, the suit s susceptibility to magnetometric waves is moderately reduced, allowing it to evade all but the most sensitive scanning systems. However, cascading distortion introduced by weapon or equipment activation will desychronize the suit s sensors and short-circuit the cloak.',0,0.01,0,1,NULL,5595.0000,1,366754,0),(366751,351844,'\'Poltergeist\' Ishukone Cloak Field','The cloak field absorbs electromagnetic emissions and manipulates light to render the dropsuit practically invisible. When active, the field alters the magnetic permeability of the suit s surface area to generate a negative refractive index. \r\r\n\r\r\nWhile cloaked, the suit s susceptibility to magnetometric waves is moderately reduced, allowing it to evade all but the most sensitive scanning systems. However, cascading distortion introduced by weapon or equipment activation will desychronize the suit s sensors and short-circuit the cloak.',0,0.01,0,1,NULL,14985.0000,1,366755,0),(366760,351648,'Cloak Field  Operation','Skill at using cloak fields.\r\r\n\r\r\nUnlocks access to standard cloak fields at lvl.1; advanced at lvl.3; prototype at lvl.5.',0,0.01,0,1,NULL,149000.0000,1,353708,0),(366967,368656,'Mangled Coil Assembly','Semi-rare scrap metals salvaged from the battlefield.',0,0.01,0,1,4,30000.0000,1,368655,0),(366968,368656,'Crushed Magazine Housing','Semi-rare scrap metals salvaged from the battlefield.',0,0.01,0,1,4,50000.0000,1,368655,0),(366969,368656,'Broken Optronic Sight','Semi-rare scrap metals salvaged from the battlefield.',0,0.01,0,1,4,80000.0000,1,368655,0),(366970,368656,'Shattered Heat Shield','Semi-rare scrap metals salvaged from the battlefield.',0,0.01,0,1,4,100000.0000,1,368655,0),(366971,368656,'Melted Heat Sink','Semi-rare scrap metals salvaged from the battlefield.',0,0.01,0,1,4,150000.0000,1,368655,0),(367223,350858,'Militia Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367226,350858,'Militia Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry. However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons. The foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367227,350858,'Militia Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367228,350858,'Militia Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367229,350858,'Militia Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\r\n\r\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367230,350858,'Militia Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367380,351648,' ',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(367382,351648,'Nova Knife Fitting Optimization','Advanced skill at weapon resource management. 5% reduction to PG usage per level.',0,0,0,1,NULL,774000.0000,1,353684,0),(367436,350858,'Militia Ion Pistol','A ruthlessly efficient close-quarters weapon, the ion pistol fires charged plasma munitions that rupture shields and scorch armor. Each discharge is enveloped in an electrostatic sheath that reduces field distortion and increases stability. The improved dispersion and stopping power is not without drawbacks though, as the higher density of each slug generates excessive heat, enough to seize the weapon if the rate of fire is not carefully controlled.\r\r\n\r\r\nBy overriding internal temperature controls, the weapon can be overcharged to produce a focused, bulk discharge of sufficient lethality to instantly neutralize most soft targets. Caution is advised however, as each overcharged shot will shut down internal systems until the excess heat can be flushed from the weapon s core.',0,0.01,0,1,NULL,270.0000,1,355463,0),(367437,350858,'Militia Bolt Pistol','The result of years of R&D, the bolt pistol is a high-impact handgun capable of firing kinetic projectiles with pinpoint accuracy. Building upon its copious experience with microscale rail weaponry, Kaalakiota has further refined the technology to produce what is commonly regarded as the most powerful handgun on the market.\r\r\n\r\r\nCentral to its success is a smart sensor that bleeds off a minute amount of dropsuit energy at the moment of discharge, dissipating the sharp recoil impulse through the suit s internal membrane and greatly reducing the peak force of each shot. This seemingly minor innovation is what makes accurate fire of the weapon possible without the need for an external mounting.',0,0.01,0,1,NULL,270.0000,1,355463,0),(367439,350858,'Militia Magsec SMG','The magsec is a semi-automatic firearm capable of sustained, accurate fire at ranges beyond what conventional sidearms can offer. A high-speed slider feeds current to a magazine of hyper velocity projectiles that are discharged with minimal separation, maximizing energy efficiency and reducing flux shear to produce a weapon with lethal kinetic potential. \r\r\n\r\r\nHaving overcome early reliability issues, manufacturers  have since taken advantage of the weapon s modular design; the magsec has been made available in multiple combat configurations   including optical sights and silenced operation   and is in widespread service throughout the cluster.',0,0.01,0,1,NULL,270.0000,1,355463,0),(367440,350858,'Militia Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\n\r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367442,351064,'Frontline Special Issue Mk II-A','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,6800.0000,1,368019,0),(367443,351064,'Frontline Special Issue Mk II-C','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,6800.0000,1,368019,0),(367450,351064,'Frontline Special Issue Mk II-M','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,6800.0000,1,368019,0),(367451,351064,'Frontline Special Issue Mk II-G','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,NULL,6800.0000,1,368019,0),(367453,351064,'Defender Special Issue Mk II-A','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,6800.0000,1,368020,0),(367455,351064,'Defender Special Issue Mk II-C','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,6800.0000,1,368020,0),(367456,351064,'Defender Special Issue Mk II-M','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,6800.0000,1,368020,0),(367457,351064,'Defender Special Issue Mk II-G','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,NULL,6800.0000,1,368020,0),(367472,350858,'Militia Flaylock Pistol','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\n\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0.01,0,1,NULL,270.0000,1,355463,0),(367477,350858,'Kubo s GMK-16 Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,126495.0000,1,364058,0),(367489,350858,'Beacon s ELI-74 Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,NULL,126495.0000,1,354367,0),(367499,367487,'Skill Tree Reset and Refund','All of the mercenary s skills in the Skill Tree are completely reset and Skill Points refunded. Corporation Skills are not affected. Skillbooks are refunded at 80% of the Market Price.',0,0,0.1,1,NULL,0.0000,1,367486,0),(367500,350858,'Symb\'s FORK-5 Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,NULL,126495.0000,1,354350,0),(367502,350858,'Agimus\' Modified AGO-56 Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,126495.0000,1,354620,0),(367511,350858,'Luis\' Modified VC-107 Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,126495.0000,1,365768,0),(367517,350858,'Kalante\'s RXS-05 Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class.\r\r\n\r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,NULL,126495.0000,1,354333,0),(367519,350858,'Ghalag\'s Modified MRT-17 Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,126495.0000,1,365772,0),(367528,350858,'Darth\'s GIO-66 Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,126495.0000,1,364054,0),(367541,350858,'Viktor s NEG-1 Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\r\n\r\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,126495.0000,1,354692,0),(367548,350858,'Alex\'s Modified ZX-030 Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\n\r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,126495.0000,1,354567,0),(367549,350858,'Alldin\'s IMP-10 Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\r\n\r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,126495.0000,1,354337,0),(367552,350858,'Bons\' SIN-7 Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\n\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,NULL,126495.0000,1,354698,0),(367578,367580,'Jara Kumora - Contract','This agent provides a valuable service to Mercenaries by interfacing directly with the New Eden Market, instantly locating the best trading prices.',0,0,0,1,4,0.0000,1,367571,0),(367586,350858,'Militia Nova Knives','A close-quarters melee weapon, the nova knife is as deadly a weapon as anything on the battlefield. Its name derives from the heated plasma edge of the blade   formed by a thermic igniter and linear gravity condenser   that, in skilled hands, can be used to carve through even the thickest dropsuit armor.',0,0.01,0,1,NULL,270.0000,1,355463,0),(367587,350858,'Militia Flaylock Pistol Blueprint','The flaylock is a snub-nosed pistol designed to fire one-inch direct attack missiles. Typically, the weapon is armed with pack-loaded dumbfire or seeker missiles effective against infantry and armored targets, but is fully compatible with a broad range of missile types, making it one of the most versatile sidearm weapons on the battlefield.\r\r\n\r\r\nSeeker missiles utilize pre-launch lock-on and rudimentary self-guidance to track designated targets, though finite propellant limits the practical engagement zone to short ranges. Although less effective against shielded targets, the tandem warhead allows penetration of armor layers before detonation, amplifying the effectiveness of the narrow fragment stream and maximizing each projectile s lethality.',0,0.01,0,1,NULL,270.0000,1,355463,0),(367589,350858,'Militia Bolt Pistol Blueprint','The result of years of R&D, the bolt pistol is a high-impact handgun capable of firing kinetic projectiles with pinpoint accuracy. Building upon its copious experience with microscale rail weaponry, Kaalakiota has further refined the technology to produce what is commonly regarded as the most powerful handgun on the market.\r\r\n\r\r\nCentral to its success is a smart sensor that bleeds off a minute amount of dropsuit energy at the moment of discharge, dissipating the sharp recoil impulse through the suit s internal membrane and greatly reducing the peak force of each shot. This seemingly minor innovation is what makes accurate fire of the weapon possible without the need for an external mounting.',0,0.01,0,1,NULL,270.0000,1,355463,0),(367590,350858,'Militia Ion Pistol Blueprint','A ruthlessly efficient close-quarters weapon, the ion pistol fires charged plasma munitions that rupture shields and scorch armor. Each discharge is enveloped in an electrostatic sheath that reduces field distortion and increases stability. The improved dispersion and stopping power is not without drawbacks though, as the higher density of each slug generates excessive heat, enough to seize the weapon if the rate of fire is not carefully controlled.\r\r\n\r\r\nBy overriding internal temperature controls, the weapon can be overcharged to produce a focused, bulk discharge of sufficient lethality to instantly neutralize most soft targets. Caution is advised however, as each overcharged shot will shut down internal systems until the excess heat can be flushed from the weapon s core.',0,0.01,0,1,NULL,270.0000,1,355463,0),(367591,350858,'Militia Nova Knife Blueprint','A close-quarters melee weapon, the nova knife is as deadly a weapon as anything on the battlefield. Its name derives from the heated plasma edge of the blade   formed by a thermic igniter and linear gravity condenser   that, in skilled hands, can be used to carve through even the thickest dropsuit armor.',0,0.01,0,1,NULL,270.0000,1,355463,0),(367592,350858,'Militia Magsec SMG Blueprint','The magsec is a semi-automatic firearm capable of sustained, accurate fire at ranges beyond what conventional sidearms can offer. A high-speed slider feeds current to a magazine of hyper velocity projectiles that are discharged with minimal separation, maximizing energy efficiency and reducing flux shear to produce a weapon with lethal kinetic potential. \r\r\n\r\r\nHaving overcome early reliability issues, manufacturers  have since taken advantage of the weapon s modular design; the magsec has been made available in multiple combat configurations   including optical sights and silenced operation   and is in widespread service throughout the cluster.',0,0.01,0,1,NULL,270.0000,1,355463,0),(367596,367487,'Instant Booster 2X',' ',0,0,0,1,NULL,0.0000,1,NULL,0),(367597,367487,'Instant Booster 3X',' ',0,0,0,1,4,0.0000,1,NULL,0),(367598,367487,'Instant Booster 4X',' ',0,0,0,1,4,0.0000,1,NULL,0),(367600,367594,'APEX \'Dominus\' Sentinel','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEvery vital area of the wearer is protected by 25mm of composite ceramic shell or high tensile steel plates, layered with impact absorbing, compressed carbon latticework. A secondary thermal dispersion membrane channels excess heat away from the point of contact, distributing it over a larger surface area and thereby lessening the potential damage. Superconductive veins of hybrid silver coat the outer layers and connect every piece of the armor to a grounding heat sink, dampening the harmful effects of direct fire electromagnetic weaponry.\r\r\n\r\r\nHeavy frame dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,4,57690.0000,1,369217,0),(367621,350858,'Militia Scrambler Rifle Blueprint','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367622,350858,'Militia Laser Rifle Blueprint','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\r\n\r\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367623,350858,'Militia Rail Rifle Blueprint','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry. However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons. The foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367624,350858,'Militia Combat Rifle Blueprint','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367625,350858,'Militia Plasma Cannon Blueprint','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367627,350858,'Militia Heavy Machine Gun Blueprint','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\n\r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367628,350858,'Militia Forge Gun Blueprint','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\r\n\r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,NULL,610.0000,1,355463,0),(367629,350858,'Militia Mass Driver Blueprint','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,NULL,610.0000,1,355463,0),(367630,350858,'Militia Flux Grenade','The Flux grenade is a hand-thrown wave shaper designed to destroy low-level electronic equipment and disrupt shielding. The Militia variant is standard-issue for all new recruits.',0,0.01,0,1,NULL,180.0000,1,355463,0),(367631,350858,'Militia Flux Grenade Blueprint','The Locus is a timed-fuse fragmentation explosive that is highly effective against dropsuit armor. The Militia variant is standard-issue for all new recruits.',0,0.01,0,1,NULL,180.0000,1,355463,0),(367632,350858,'Militia AV Grenade','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range. The Militia variant is standard-issue for all new recruits.',0,0.01,0,1,NULL,180.0000,1,355463,0),(367633,350858,'Militia AV Grenade Blueprint','The AV grenade is a high-explosive homing charge that automatically targets any hostile vehicle within its seek range. The Militia variant is standard-issue for all new recruits.',0,0.01,0,1,NULL,180.0000,1,355463,0),(367634,351064,'\'Quafe\' Sentinel G-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(367650,351064,'\'Quafe\' Sentinel C-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(367651,351064,'\'Quafe\' Sentinel A-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(367652,351064,'\'Quafe\' Sentinel M-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(367653,351064,'\'Quafe\' Assault G-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(367654,351064,'\'Quafe\' Assault A-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(367655,351064,'\'Quafe\' Assault M-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(367656,351064,'\'Quafe\' Scout C-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(367657,351064,'\'Quafe\' Scout A-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(367658,351064,'\'Quafe\' Scout M-I','Regarded as one of the most outrageous promotional stunts in the company s history, the Quafesuit has been called both  genius  and  loathsome . Love it or hate it, none can deny its effectiveness as a marketing ploy, though many have questioned how the softdrink giant was able to procure a shipment of dropsuits in the first place.',0,0.01,0,1,NULL,3000.0000,1,369213,0),(367677,367594,'APEX \'Shogun\' Sentinel','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\n\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\n\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,1,57690.0000,1,369217,0),(367679,367594,'APEX \'Atlas\' Sentinel','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\n\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\n\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,8,57690.0000,1,369217,0),(367681,367594,'APEX \'Warlord\' Sentinel','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\n\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\n\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,2,57690.0000,1,369217,0),(367685,367594,'APEX \'Rasetsu\' Assault','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,1,57690.0000,1,369217,0),(367687,367594,'APEX \'Spartan\' Assault','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,8,57690.0000,1,369217,0),(367689,367594,'APEX \'Nomad\' Assault','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,2,57690.0000,1,369217,0),(367691,367594,'APEX \'Opus\' Assault','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,57690.0000,1,369217,0),(367693,367594,'APEX \'Kampo\' Logistics','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,1,57690.0000,1,369217,0),(367695,367594,'APEX \'Chiron\' Logistics','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,8,57690.0000,1,369217,0),(367697,367594,'APEX \'Shaman\' Logistics','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,2,57690.0000,1,369217,0),(367699,367594,'APEX \'Seraph\' Logistics','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,4,57690.0000,1,369217,0),(367701,367594,'APEX \'Hawk\' Scout','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,1,57690.0000,1,369217,0),(367703,367594,'APEX \'Serpent\' Scout','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\r\n\r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,8,57690.0000,1,369217,0),(367705,367594,'APEX \'Tiger\' Scout','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\r\n\r\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,2,57690.0000,1,369217,0),(367707,367594,'APEX \'Dragon\' Scout','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,4,57690.0000,1,369217,0),(367709,367594,'APEX \'Samurai\' Commando','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,1,57690.0000,1,369217,0),(367711,367594,'APEX \'Centurion\' Commando','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,8,57690.0000,1,369217,0),(367713,367594,'APEX \'Renegade\' Commando','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,2,57690.0000,1,369217,0),(367715,367594,'APEX \'Paladin\' Commando','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,4,57690.0000,1,369217,0),(367716,351064,'Archduke\'s Modified Sentinel mk.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\n\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\n\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,4,94425.0000,1,354382,0),(367738,351064,'Frame\'s Modified Assault ck.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,94425.0000,1,354378,0),(367742,351064,'Scotsman\'s Modified Scout gk.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. This high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system. When missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,4,94425.0000,1,354390,0),(367751,351064,'Logibro\'s Modified Logistics mk.0','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.\r\n\r\nThis particular suit is the result of personal development by a figure only known as \"Logibro\". Optimized for survivability, this dropsuit provides additional protection through both strengthened armor and shielding, and the addition of more powerful sensors.',0,0.01,0,1,4,94425.0000,1,354386,0),(367760,351064,'Rattati\'s Modified Assault gk.0','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,94425.0000,1,354378,0),(367765,367774,'Encrypted Strongbox','An encrypted strongbox is used to transport high security valuables, such as armaments and ISK, and can only be opened by the decryptor key used to lock it. Crafty individuals may find that there are other ways to pry it open.',0,0,0,1,4,0.0000,1,367772,0),(367768,367774,'Special Encrypted Strongbox',' ',0,0,0,1,4,0.0000,1,NULL,0),(367770,367776,'Hacked Decryptor Key','A decryptor key is commonly used to lock and gain access to encrypted strongboxes and systems, by their rightful owners. Hacked keys, however, can be used by anyone, and are highly sought after by unscrupulous mercenaries.',0,0,0,1,4,0.0000,1,367773,0),(367777,367776,'Basic Decryptor2',' ',0,0,0,1,4,0.0000,1,367773,0),(367778,367776,'Enhanced Decryptor1',' ',0,0,0,1,4,0.0000,1,367773,0),(367779,367776,'Complex Decryptor_test',' ',0,0,0,1,4,0.0000,1,367773,0),(367811,367594,'State \'Shogun\' Sentinel','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,1,57690.0000,1,366208,0),(367813,350858,'Republic Assault Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.',0,0.01,0,1,2,0.0000,1,366272,0),(367843,367487,'mission_reroll',' ',0,0,0,1,4,0.0000,1,NULL,0),(367845,367487,'instant_booster4',' ',0,0,0,1,4,0.0000,1,NULL,0),(367848,350858,'Federation Burst Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,4,2460.0000,1,366222,0),(367854,367594,'Imperial \'Opus\' Assault','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,57690.0000,1,366199,0),(367856,367594,'Republic \'Shaman\' Logistics','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,2,57690.0000,1,366205,0),(367863,367594,'Federation \'Serpent\' Scout','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\r\n\r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,8,57690.0000,1,366202,0),(367864,367594,'Federation \'Centurion\' Commando','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,8,57690.0000,1,366202,0),(367885,351064,'Storm Raider\'s Modified Commando ak.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\n\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\n\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,4,94425.0000,1,365282,0),(367895,351064,'Archduke\'s Modified Sentinel mk.0 (Master)','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\n\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\n\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,4,0.0000,1,354382,0),(367896,351064,'Logibro\'s Modified Logistics mk.0 (Master)','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\n\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\n\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.\r\n\r\nThis particular suit is the result of personal development by a figure only known as \"Logibro\". Optimized for survivability, this dropsuit provides additional protection through both strengthened armor and shielding, and the addition of more powerful sensors.',0,0.01,0,1,4,0.0000,1,354386,0),(367897,351064,'Rattati\'s Modified Assault gk.0 (Master)','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,0.0000,1,354378,0),(367898,351064,'Storm Raider\'s Modified Commando ak.0 (Master)','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\n\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\n\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,4,0.0000,1,365282,0),(367899,351064,'Frame\'s Modified Assault ck.0 (Master)','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\n\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\n\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,0.0000,1,354378,0),(367900,351064,'Scotsman\'s Modified Scout gk.0 (Master)','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. This high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system. When missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,4,0.0000,1,354390,0),(367948,367594,'Federation \'Atlas\' Sentinel','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,8,57690.0000,1,366202,0),(367955,367594,'State \'Rasetsu\' Assault','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,1,57690.0000,1,366208,0),(367959,367594,'Imperial \'Seraph\' Logistics','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,4,57690.0000,1,366199,0),(367960,367594,'Republic \'Tiger\' Scout','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature.\r\r\n\r\r\nBiotic augments make this suit ideal for a melee-focused role. Woven into the suit, a tremor membrane saturates muscles with nutrients amplifying the cross-sectional force of physical strikes. Combined with rigorous training, this temporarily enhanced strength and dexterity make the Minmatar Scout almost unmatched in hand-to-hand combat.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,2,57690.0000,1,366205,0),(367963,367594,'Republic \'Renegade\' Commando','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,2,57690.0000,1,366205,0),(367987,367594,'APEX \'Atlas\' Sentinel vX.1','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,8,57690.0000,1,369217,0),(367988,367594,'APEX \'Nomad\' Assault vX.1','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,2,57690.0000,1,369217,0),(367989,367594,'APEX \'Dragon\' Scout vX.1','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,4,57690.0000,1,369217,0),(367992,350858,'Militia Assault Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.',0,0.01,0,1,2,610.0000,1,355463,0),(367994,350858,'Militia Assault Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\n\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,4,610.0000,1,355463,0),(367996,350858,'Militia Assault Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,4,610.0000,1,355463,0),(367998,367594,'Republic \'Warlord\' Sentinel','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,4,57690.0000,1,366205,0),(367999,367594,'Federation \'Spartan\' Assault','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nGallente forces have access to some of the most advanced armor systems in the cluster. An ablative-variant solution is used to dissipate energy across available surface area with only minimal degradation of the material at the impact point resulting in armor that is efficient and durable enough to maintain operational integrity for multiple short-term engagements. Augmented ferro-fibre musculature enhances the soldier s strength, balance, and reaction time, while quad-opsis sensors allow wide arc identification and prioritization of battlefield targets.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,8,57690.0000,1,366202,0),(368000,367594,'State \'Kampo\' Logistics','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,1,57690.0000,1,366208,0),(368001,367594,'Imperial \'Dragon\' Scout','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,4,57690.0000,1,366199,0),(368003,367594,'Imperial \'Paladin\' Commando','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,4,57690.0000,1,366199,0),(368014,350858,'Imperial Assault Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,4,4020.0000,1,366257,0),(368015,350858,'State Assault Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,1,4020.0000,1,366219,0),(368016,350858,'Federation Breach Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\n\r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0.01,0,1,8,4020.0000,1,366222,0),(368022,367594,'Imperial \'Dominus\' Sentinel','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,4,57690.0000,1,366199,0),(368023,367594,'Republic \'Nomad\' Assault','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nNative Minmatar tech favors straightforward solutions, a consequence of the fledgling Nation s indigent past. Stripped of the haptic bindings and sensor technology of the Logistics suit, the Assault variant is a lightweight, low-power solution that utilizes a combination of shielding and resistive plating to thwart enemy fire. Its slimline hydraulic assisted exoskeleton enhances movement speed and user strength, while hard shell reactive armor protects the wearer from a wide-range of small arms ballistics. A mimetic recycler stores and reroutes excess power as needed.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,2,57690.0000,1,366205,0),(368024,367594,'Federation \'Chiron\' Logistics','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,8,57690.0000,1,366202,0),(368025,367594,'State \'Hawk\' Scout','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,1,57690.0000,1,366208,0),(368026,367594,'State \'Samurai\' Commando','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,1,57690.0000,1,366208,0),(368061,351064,'Amarr Combat Standard Loadout','A Loadout using a standard Basic dropsuit frame fitted with standard gear and weapons.',0,0.01,0,1,4,10000.0000,1,368091,0),(368062,351064,'Amarr Combat Advanced Loadout','A Loadout using an advanced Basic dropsuit frame fitted with advanced gear and weapons.',0,0.01,0,1,4,36000.0000,1,368091,0),(368064,351064,'Gallente Combat Standard Loadout','A Loadout using a standard Basic dropsuit frame fitted with standard gear and weapons.',0,0.01,0,1,8,10000.0000,1,368091,0),(368065,351064,'Gallente Combat Advanced Loadout','A Loadout using an advanced Basic dropsuit frame fitted with advanced gear and weapons.',0,0.01,0,1,8,36000.0000,1,368091,0),(368066,351064,'Minmatar Combat Standard Loadout','A Loadout using a standard Basic dropsuit frame fitted with standard gear and weapons.',0,0.01,0,1,2,10000.0000,1,368091,0),(368067,351064,'Minmatar Combat Advanced Loadout','A Loadout using an advanced Basic dropsuit frame fitted with advanced gear and weapons.',0,0.01,0,1,2,36000.0000,1,368091,0),(368069,351064,'Caldari Combat Standard Loadout','A Loadout using a standard Basic dropsuit frame fitted with standard gear and weapons.',0,0.01,0,1,1,10000.0000,1,368091,0),(368071,351064,'Caldari Combat Advanced Loadout','A Loadout using an advanced Basic dropsuit frame fitted with advanced gear and weapons.',0,0.01,0,1,1,36000.0000,1,368091,0),(368242,351844,'Boundless Packed Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\r\n\r\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,4,28845.0000,1,355189,0),(368243,351844,'Packed Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\r\n\r\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,4,1500.0000,1,355187,0),(368244,351844,'F/45 Packed Remote Explosive','The F/41 series of remote explosives are among the most powerful manually triggered demolitions devices available in New Eden. Each unit is reliable and effective, using a mix of three volatile materials to produce a yield high enough to penetrate layered armor, shatter reinforced structures, and decimate infantry units.\r\r\n\r\r\nThese explosives are deployed by hand and detonated using a coded frequency generated by the Cortex Holographic Interface, which maintains a database of unique activation ciphers for every charge placed. The F/41 product line also boasts several other advanced features, such as EM hardened circuits, an encrypted multi-frequency receiver, and a lightweight hybrid ceramic frame.',0,0.01,0,1,4,6585.0000,1,355188,0),(368245,350858,'X-MS15 Snowball Launcher','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,4,47220.0000,1,354620,0),(368497,368666,'Warbarge Component','Warbarge manufacturing processes.',0,0.01,0,1,64,10.0000,1,368668,0),(368518,351210,'CreoDron Methana vX.1','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,4,0.0000,1,353664,0),(368519,350858,'X-MS Snowball Launcher','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,4,47220.0000,1,354620,0),(368524,351064,'Imperial Scout A-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,4,3000.0000,1,366197,0),(368531,351210,'\'Quafe\' Gunnlogi','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,1,97500.0000,1,353657,0),(368532,351210,'\'Quafe\' Madrugar','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,8,97500.0000,1,353657,0),(368533,351210,'\'Quafe\' Grimsnes','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,8,45000.0000,1,353671,0),(368534,351210,'\'Quafe\' Myron','The dropship is a two-engine VTOL craft that combines advances in shielded hardware, redundant software protocols, and networked aeronautics into a heavily armored tactical platform capable of insertion and extraction in even the most hostile situations. Its standard five-man carrying capacity, dual hardpoints, and reinforced plating allow it to operate independently in any situation, alternately tracking and engaging enemy targets and ferrying troops into and out of harm\'s way.',0,0.01,0,1,1,45000.0000,1,353671,0),(368537,351210,'\'Quafe\' Saga','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,1,30000.0000,1,353664,0),(368539,351210,'\'Quafe\' Methana','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,8,30000.0000,1,353664,0),(368540,350858,'\'Quafe\' ST-201 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,4,30000.0000,1,356960,0),(368541,350858,'\'Quafe\' ST-1 Missile Launcher','Missile launcher tech is comparatively unsophisticated. It\'s the missiles themselves and the supplementary tracking, targeting, and guidance systems comprising the delivery system that make missiles such deadly ordnance. ',0,0.01,0,1,4,30000.0000,1,356963,0),(368542,350858,'\'Quafe\' 80GJ Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,4,30000.0000,1,356971,0),(368543,350858,'\'Quafe\' 20GJ Blaster','Blaster technology harnesses magnetic containment fields to project superheated energy over short distances.',0,0.01,0,1,4,30000.0000,1,356968,0),(368544,350858,'\'Quafe\' 80GJ Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,4,30000.0000,1,356976,0),(368545,350858,'\'Quafe\' 20GJ Railgun','The railgun weaponizes velocity by using magnetic fields to accelerate projectiles to hypersonic speeds. ',0,0.01,0,1,4,30000.0000,1,356979,0),(368546,351210,'\'Quafe\' Saga Blueprint','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,1,30000.0000,1,353664,0),(368547,351210,'\'Quafe\' Methana Blueprint','The Light Attack Vehicle (LAV) represents a new generation of mobile support vehicle, an agile and effective unit, adept at assisting both infantry and other vehicles on the battlefield with its cadre of electronic warfare subsystems and all-terrain maneuverability modules. Whether employed as a scout vehicle or as an anti-infantry unit, the LAV is a ubiquitous part of New Eden\'s modern battlefield.',0,0.01,0,1,8,30000.0000,1,353664,0),(368548,351064,'\'Quafe\' Logistics A-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nThe Amarr variant is a durable, combat-focused suit that provides above-average protection, allowing logistic units to operate in the middle of a firefight, actively dispersing aid and support as needed while simultaneously engaging the enemy and inflicting trauma of its own.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,4,3000.0000,1,369213,0),(368549,351064,'\'Quafe\' Logistics C-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nOffering only the ruthless, bare-minimum functionality needed to ensure operator survivability, this is a triage suit unfettered by conventional rationale. Like most Caldari designs, utility is paramount and so all integrated tech is optimized for secondary support; resupplying and repairing units from distance, only engaging the enemy when absolutely necessary.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,1,3000.0000,1,369213,0),(368550,351064,'\'Quafe\' Logistics G-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nGallente military doctrine places a premium on human life, favoring technological solutions that augment or even entirely replace human combatants in a conflict. Unsurprisingly, the Gallente Logistics suit is designed to minimize loss of life on the battlefield. A resilient suit, it features an array of biomechanical sensors to monitor ongoing health, while the copious equipment slots allow it to carry everything needed to effectively render aid to victims.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,8,3000.0000,1,369213,0),(368551,351064,'\'Quafe\' Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,2,3000.0000,1,369213,0),(368552,351064,'\'Quafe\' Commando A-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nInterlaced with subframe wiring, the Amarr variant utilizes asymmetric power distribution to intelligently reroute power to the suit s various subsystems as needed. This improved throughput allows light-class laser weaponry to draw from the suit s power reserves to enhance the damage dealt.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,4,3000.0000,1,369213,0),(368553,351064,'\'Quafe\' Commando C-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,1,3000.0000,1,369213,0),(368554,351064,'\'Quafe\' Commando G-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,8,3000.0000,1,369213,0),(368555,351064,'\'Quafe\' Commando M-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,2,3000.0000,1,369213,0),(368556,350858,'\'Quafe\' Heavy Machine Gun','A multi-barrel, rotary drive machine gun, the HMG is a singularly devastating anti-infantry weapon. Eschewing the advantages of a lighter frame in favor of stopping power, the exponentially increased heat and vibration produced by this Boundless Creation developed weapon makes it almost unbearable to fire. Yet despite this fact, its above average hit ratio and extreme rate of fire has earned it the nickname  Death\'s Engine. \r\r\n\r\r\nUnlike earlier models, the weapon requires no spool up time; rounds are expelled the instant the trigger is pressed. This comes at the cost of initially reduced accuracy as the counter-rotating drives slowly align. Once fully aligned, however, the HMG produces a pinpoint stream of gunfire with unmatched killing potential.',0,0.01,0,1,4,1500.0000,1,354565,0),(368557,350858,'\'Quafe\' Forge Gun','Adapted from Deep Core Mining Inc.\'s proprietary technology, the DCMA S-1 subverts conventional expectations of what a man-portable anti-material weapons platform is capable of. Despite its excessive weight and extended recharge time, the  Forge Gun  as it has become known, is regarded as the most devastating infantry weapon on the battlefield, and an invaluable tool for those capable of wielding it.\r\r\n\r\r\nPowered by a Gemini microcapacitor, the forge gun utilizes a stored electric charge to fire kinetic slugs at speeds in excess of 7,000 m/s, enough to penetrate even augmented armor systems. During the pre-fire charge, the forward armature locks into position, stabilizing the magnetic field and helping to shield the user from backscatter and the excessive heat produced.  Power generation remains the single largest drawback of the current design, the onboard capacitor requiring a significant amount of time to reach full power after each discharge. ',0,0.01,0,1,4,1500.0000,1,354335,0),(368558,350858,'\'Quafe\' Nova Knives','A close-quarters melee weapon, the nova knife is as deadly a weapon as anything on the battlefield. Its name derives from the heated plasma edge of the blade   formed by a thermic igniter and linear gravity condenser   that, in skilled hands, can be used to carve through even the thickest dropsuit armor.',0,0.01,0,1,4,675.0000,1,356434,0),(368559,350858,'\'Quafe\' Mass Driver','The Mass Driver is a semi-automatic, multi-shot grenade launcher useful as both a breaching tool and area denial weapon. Firing smart HIND explosive rounds, the weapon is highly effective against all forms of dropsuit and light vehicle, while its lightweight frame and compact design make it easy to wield in both urban and open terrain engagements.',0,0.01,0,1,4,1500.0000,1,354618,0),(368560,350858,'\'Quafe\' Swarm Launcher','A mid-range anti-material weapon, the shoulder-mounted rocket launcher provides infantry squads with the means to effectively engage armored vehicles and installation gun emplacements. With pre-launch lock-on capabilities and intelligent swarm missiles, it is a man-portable system able to deliver devastating payloads against material targets. \r\r\nKey to its success is the swarm missile technology. Fired in salvos, each warhead is fitted with an onboard guidance controller, which introduces random deviations and unpredictable patterns into the swarm\'s flight path, allowing some, if not all, missiles in the salvo to defeat basic countermeasure systems.',0,0.01,0,1,4,1500.0000,1,354364,0),(368561,350858,'\'Quafe\' Assault Rifle','Conceived by Duvolle Laboratories, a corporation best known for its ceaseless R&D, the G75-VLB solves many of the problems inherent in mass-manufactured plasma weapons. The result is a weapon that offers improved accuracy and greater containment field stability (which equates to faster, longer bursts of fire) than anything in its class. \r\r\n\r\r\nIt is a magazine-fed, short-to-mid range weapon offering fully automatic fire. Charged plasma munitions are pumped into a cyclotron that converts the plasma into a highly lethal bolt before it is expelled from the chamber. Upon impact with the target, the magnetic field surrounding the bolt collapses, venting superheated plasma onto the contact point.',0,0,0,1,4,1500.0000,1,354331,0),(368562,350858,'\'Quafe\' Plasma Cannon','The plasma cannon is a single-shot, direct-fire weapon developed by Allotek Industries primarily for use in urban operations and confined space combat. The dense plasma discharge it generates is highly unstable, decaying rapidly and venting sufficient heat and energy to severely damage targets caught within its critical emission radius.\r\r\n\r\r\nDuring the short pre-fire charge, ultracold plasma is prepared and then heated inside a magneto-core trap. Just prior to discharge, a small precursor projectile is fired that produces (and is ultimately consumed by) a short-lived trail that helps guide and contain the volatile discharge as it travels towards its target.',0,0.01,0,1,4,1500.0000,1,364056,0),(368563,350858,'\'Quafe\' Shotgun','Designed for close-range combat, the shotgun is a spread weapon with tremendous stopping power. Unlike traditional cyclotron designs, a walled centrifugal well is used to simultaneously shunt dozens of plasma charges, generating a wide-pattern  kill spread\' that is lethal over short distances.\r\r\n\r\r\nThe excessive recoil produced by each discharge is absorbed by the pneumatic armature, allowing the weapon to be fired repeatedly without significant injury to the user. The operator controlled crank-action flushes coolant through the interior well before cycling additional rounds into the chamber.',0,0.01,0,1,4,1500.0000,1,354696,0),(368564,350858,'\'Quafe\' Rail Rifle','Part of Kaalakiota s Stahl line of weaponry, the rail rifle is a fast-firing precision weapon designed for field operations where penetrative power and range are paramount. Developed using the corporation s proprietary microscale technology, the rail rifle solves oversaturation issues endemic to sustained fire electromagnetic weaponry.  However, its greater range and power are offset by a smaller magazine capacity and lower rate of fire than similarly classified weapons.\r\r\n\r\r\nThe foregrip design aids stabilization and remains cool to the touch even during prolonged discharge where the barrel can exceed mean operating temperatures. Featuring a reinforced subassembly and compact, heavy-barrel design, the rail rifle is the premier fully automatic microscale weapon available today.',0,0.01,0,1,4,1500.0000,1,365770,0),(368565,350858,'\'Quafe\' Sniper Rifle','Using microscale railgun technology, the sniper rifle effectively weaponizes velocity, putting an inert round downrange in excess of 2,500m/s. The standard round is a 2-inch  beehive\' flechette, loaded automatically from a center-mount pack. The pack design eliminates user intervention and minimizes reload time while simultaneously allowing for future upgradeability; different ammunition configurations require nothing more than switching out the rifle\'s pack.',0,0.01,0,1,4,1500.0000,1,354347,0),(368566,350858,'\'Quafe\' Laser Rifle','The laser rifle is a continuous wave, medium range weapon. Targets are  painted  with a high intensity beam that deals sustained, focused damage in a concentrated area to maximize damage potential.  At the core of the weapon is the thermal cavity, within which an optic spacer converges and blends three individually pumped beams into a single coherent output. The additional distortion introduced by each beam results in weakened output at close range, but as the weapon warms up to mean operating temperature the wavelength stabilizes and the damage output increases significantly, producing a weapon of unmatched precision and lethality in mid-range combat.\r\r\n\r\r\nHeat build-up is typically managed by a self-regulating failsafe, a device used to forcibly shut the weapon off at regular intervals, flushing heat from its internal workings and preventing lethal feedback to the user, but most laser rifles in the field have been altered to bypass the built-in safety protocols.',0,0.01,0,1,4,1500.0000,1,354690,0),(368567,350858,'\'Quafe\' Scrambler Rifle','The scrambler rifle is a selective-fire weapon capable of semi-automatic and charged fire. Each shot produces a pulse of sinuous energy capable of penetrating shield and metal. By keeping pressure on the trigger, the operator can control the power of each discharge, scaling it to produce an intense pulse of energy fatal to soft targets.\r\r\n\r\r\nThe added power output does come with downsides, most notably increased heat build-up; left unmanaged, thermal stresses age the focusing crystal prematurely, resulting in splintering and potentially lethal feedback. Despite this and several other issues   increased heft, poor reliability, and high manufacturing cost   the scrambler rifle is widely available and in service on battlefields clusterwide.',0,0.01,0,1,4,1500.0000,1,364052,0),(368568,350858,'\'Quafe\' Combat Rifle','A gas-operated, short-barreled weapon, the combat rifle is a semi-automatic weapon well-suited to both short and medium range combat. Classified as a light support weapon, it is typically employed in target-rich environments where the high volume of fire produced enables operators to engage multiple targets in rapid succession, whilst the weapon s extended range keeps the operator just beyond the threat threshold of most standard assault rifles.\r\r\n\r\r\nIts advanced bullpup configuration reduces weapon weight and improves maneuverability making it the ideal cross-over weapon for urban and field combat. The modular design has more practical advantages as well in that it s cheap to maintain and easily replaced if damaged, making it one of the most reliable weapons in service today.',0,0.01,0,1,4,1500.0000,1,365766,0),(368574,351064,'Imperial Scout A/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,4,8040.0000,1,366198,0),(368576,351064,'\'Brutor\' Logistics M-I','The Logistics dropsuit is outfitted with the latest in integrated diagnostic technology, most of which revolves around maintaining the condition and efficiency of squad mates and their equipment. As such, a soldier equipped with this class of dropsuit becomes a force multiplier, greatly improving the overall effectiveness of the unit.\r\r\n\r\r\nUtilizing a combination of high- and low-tech equipment, operators of the logistics suit are able to make effective repairs to installations, vehicles, and even other soldiers; every apparatus required for field triage is present and easily accessible from the utility pockets and satchels attached to the suit. Its hydraulic assisted exoskeleton allows the wearer to effortlessly hoist heavy equipment, while the helmet is packed with material scanners sensitive enough to spot microfractures in layered steel.\r\r\n\r\r\nWhen deployed, a soldier equipped with a Logistics suit fills a vital tactical role in small unit operations and full-scale warfare, providing both, medical and mechanical support.',0,0.01,0,1,2,3000.0000,1,369213,0),(368577,351064,'\'Tash Murkon\' Logistics A-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,4,3000.0000,1,369213,0),(368579,351064,'Imperial Scout ak.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nBuilding on recent advancements in biotic technology, this suit incorporates an array of cardiovascular augmentations that are automatically administered to the user in battle, improving overall stamina and reducing fatigue. \r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,4,35250.0000,1,366199,0),(368580,351064,'\'Tash Murkon\' Sentinel A-I','For anyone who grew up hearing the tales of the warrior Anasoma, this suit is the embodiment of their childhood nightmares. The story tells of how the fearless Anasoma was betrayed and captured. Before killing him, his torturers melted his famous battle armor to his flesh. It is said that he now roams the battlefields of New Eden searching for his betrayers.',0,0.01,0,1,4,3000.0000,1,369213,0),(368581,351064,'\'Brutor\' Commando M-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,2,3000.0000,1,369213,0),(368582,351064,'\'Kaalakiota\' Assault C-I','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\n\r\r\nA flat-coil e5000 fifth generation fusion core runs up the inside of the back plate, powering the entire suit. Its output and heat buildup are controlled by a L2  Gatekeeper  regulator conduit, which connects directly to the sensor system at the base of the neck. Every joint is reinforced with kinetic sensors and two-way, high torque servos to enhance the soldier s strength, balance, and resistance to impact forces. The suit s helmet has more integrated sensor, communication, targeting, and data processing systems than most civilian vehicles. As is common with Caldari designs, armor plating is limited to vital areas, relying instead on high-power shield systems to protect the wearer.\r\r\n\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,1,3000.0000,1,369213,0),(368583,351064,'\'Kaalakiota\' Scout C-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,1,3000.0000,1,369213,0),(368584,351064,'\'Roden\' Scout G-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nThis high-tech suit is coated in adaptive camouflage, a thin layer of bio-hermetic membranes interwoven with microscopic optical sensors that control millions of individual pigment ferro-crystals. An integrated AI-53  All Eyes  sensor system wraps around the inside of the helmet, which also includes a chemically scrubbed atmospheric filtration system.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,8,3000.0000,1,369213,0),(368585,351064,'\'Roden\' Commando G-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,8,3000.0000,1,369213,0),(368586,351064,'State Scout C-I','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,1,4905.0000,1,366206,0),(368587,350858,'Solar\'s PAR-8 Flaylock Pistol','A rare weapon salvaged from the battlefield',0,0.01,0,1,4,86000.0000,1,363793,0),(368588,350858,'Kubo\'s PE-165 Ion Pistol','A rare weapon salvaged from the battlefield',0,0.01,0,1,4,86000.0000,1,366744,0),(368589,350858,'Ghalag\'s OCT-91 Bolt Pistol','A rare weapon salvaged from the battlefield',0,0.01,0,1,4,86000.0000,1,366573,0),(368590,350858,'Nanaki\'s LORB-7 Magsec SMG','A rare weapon salvaged from the battlefield',0,0.01,0,1,4,86000.0000,1,366577,0),(368591,350858,'Kubo\'s PX-6 Scrambler Pistol','A rare weapon salvaged from the battlefield',0,0.01,0,1,4,86000.0000,1,354345,0),(368592,350858,'Nothi\'s NOS-47 Nova Knives','A rare weapon salvaged from the battlefield',0,0.01,0,1,4,86000.0000,1,356436,0),(368593,350858,'Alex\'s Modified VC-107 SMG','A rare weapon salvaged from the battlefield',0,0.01,0,1,4,86000.0000,1,354354,0),(368594,351064,'State Scout C/1-Series','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,1,8040.0000,1,366207,0),(368595,350858,'Experimental Heavy Machine Gun','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354567,0),(368596,350858,'Experimental Forge Gun','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354337,0),(368597,350858,'Experimental Mass Driver','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354620,0),(368598,350858,'Experimental Swarm Launcher','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354367,0),(368599,350858,'Experimental Assault Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354333,0),(368600,350858,'Experimental Plasma Cannon','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,364058,0),(368601,350858,'Experimental Shotgun','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354698,0),(368602,350858,'Experimental Rail Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,365772,0),(368603,350858,'Experimental Sniper Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354350,0),(368604,350858,'Experimental Laser Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354692,0),(368605,350858,'Experimental Scrambler Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,364054,0),(368606,350858,'Experimental Combat Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,365768,0),(368607,350858,'Experimental Assault Combat Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,365768,0),(368608,350858,'Experimental Assault Scrambler Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,364054,0),(368609,350858,'Experimental Assault Rail Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,365772,0),(368610,350858,'Experimental Tactical Assault Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354333,0),(368611,350858,'Experimental Breach Assault Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354333,0),(368612,350858,'Experimental Burst Assault Rifle','An experimental weapon synthesized in a laboratory',0,0.01,0,1,4,80000.0000,1,354333,0),(368614,351064,'State Scout ck.0','The Scout dropsuit is a lightweight suit optimized for enhanced mobility, multi-spectrum stealth, and heightened awareness. Augmented joint servo motors give every movement extra speed and flexibility, while integrated friction and impact dampening materials reduce the overall sound signature. \r\r\n\r\r\nDeveloped to support counterinsurgency operations, this Caldari suit is highly effective at asymmetric combat. An enhanced sensor package allows it to seek out and destroy dampened targets wherever they might be on the battlefield.\r\r\n\r\r\nWhen missions call for speed and stealth, situations in which heavily armored suits would be more of a burden than an advantage, a scout dropsuit is the best option. The enhanced mobility it provides makes up for its relatively low protection, and when combined with stealth technology modules, the scout suit is the obvious choice for infiltration, counter-espionage, and assassination.',0,0.01,0,1,1,35250.0000,1,366208,0),(368615,351064,'State Commando C-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,1,3000.0000,1,366206,0),(368616,351064,'State Commando C/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,1,13155.0000,1,366207,0),(368617,351064,'State Commando ck.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,1,57690.0000,1,366208,0),(368618,351064,'State Sentinel C-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,1,3000.0000,1,366206,0),(368619,351064,'State Sentinel C/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,1,8040.0000,1,366207,0),(368620,351064,'State Sentinel ck.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nDesigned for maximum energy absorption, the Caldari Sentinel s shielding system features an elevated saturation threshold, allowing it to dissipate a greater amount of energy in order to maintain overall shield integrity. Additionally, highly efficient refraction systems make subtle adjustments to the overlapping fields that comprise the shielding surface area, diverting minute amounts of incoming energy and dampening the effective damage of certain small arms fire.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,1,57690.0000,1,366208,0),(368631,351064,'Federation Commando G-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,8,3000.0000,1,366200,0),(368632,351064,'Federation Commando G/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nUtilizing technologies sourced from across the State, the Commando s subframe is hardwired with custom-built damage modifiers that enhance the output of all light-class railgun weaponry synched with the suit s core operating system. This is achieved, in part, by managing the weapon s charge efficiency in order to ensure maximum impact of every discharge.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,8,8040.0000,1,366201,0),(368633,351064,'Federation Commando gk.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nModified to better interface with light-class blaster weaponry, the Gallente Commando s subframe regulates the weapon s cyclotron output, improving plasma compression and enhancing the magnetic acceleration of the produced discharge with devastating results.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,8,57690.0000,1,366202,0),(368634,351064,'Federation Sentinel G-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,8,3000.0000,1,366200,0),(368635,351064,'Federation Sentinel G/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,8,8040.0000,1,366201,0),(368636,351064,'Federation Sentinel gk.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nEnhanced to withstand kinetic and fragmentary impacts with minimal deformation, Gallente Sentinel technology offers the best armor protection currently available in the cluster. Ablative surfacing helps deflect incoming fire and ultra-efficient armor composites and electrically charged active protection plates increase survivability in even the most dangerous combat situations.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,8,57690.0000,1,366202,0),(368638,351064,'Republic Commando M-I','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,2,3000.0000,1,366203,0),(368640,351064,'Republic Commando M/1-Series','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,2,8040.0000,1,366204,0),(368647,351064,'Republic Commando mk.0','The Commando dropsuit is a variable combat unit capable of reacting to battlefield threats as they emerge. Built using a repurposed heavy frame, the suit is designed for maximum offensive flexibility. The streamlined frame does away with extraneous armor layers, using the augmented power of the exoskeleton to instead shoulder the weight and bulk of two light-class weapons.\r\r\n\r\r\nStripped of all but the most necessary protection, the Minmatar Commando is the fastest, most agile heavy frame on the battlefield. Jury-rigged into the subframe are off-the-shelf damage modifiers able to improve the damage yield of all light-class projectile and explosive weaponry wielded by the user.\r\r\n\r\r\nThe Commando is the ultimate suppression fighter. What the suit sacrifices in tactical versatility, it more than makes up for with flexible weapon loadouts that can counter any of the myriad threats an ever-evolving battlefield may present.',0,0.01,0,1,2,57690.0000,1,366205,0),(368649,351064,'Republic Sentinel M-I','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,2,3000.0000,1,366203,0),(368650,351064,'Republic Sentinel M/1-Series','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,2,8040.0000,1,366204,0),(368651,351064,'Republic Sentinel mk.0','The Sentinel dropsuit is a second-generation solution designed to withstand concentrated small arms fire and protect the wearer from the concussive, thermal, and impact forces of low-grade explosives. Additionally, its power-assisted exoskeleton facilitates usage of the heaviest caliber personal weapons.\r\r\n\r\r\nBased upon a deep-core construction exoskeleton, the Minmatar Sentinel is capable of withstanding some of the harshest conditions in the galaxy. Hardened shield systems and armor modifications improve its combat durability, while the various op-assist mechanisms used to augment movement make it second only to the Minmatar s own Commando variant in terms of overall speed and mobility.\r\r\n\r\r\nHeavy dropsuits lack the mobility of lighter suits, but this trade-off results in a defensive system that defies standard infantry conventions. No other classification of personal armor can claim to be able to stand toe-to-toe with enemy vehicles and survive.',0,0.01,0,1,2,57690.0000,1,366205,0),(368725,368726,'Medium Caldari SKIN - Red','This SKIN only applies to Medium Caldari dropsuit frames!',0,0,0,1,4,0.0000,1,369215,0),(368755,368726,'Heavy Amarr SKIN - Yellow','This SKIN only applies to Heavy Amarr dropsuit frames!',0,0,0,1,4,0.0000,1,369215,0),(368756,368726,'Light Gallente SKIN - Green','This SKIN only applies to Light Gallente dropsuit frames!',0,0,0,1,8,0.0000,1,369215,0),(368776,368726,'Medium Minmatar SKIN - Quafe','This SKIN only works on Medium Minmatar Dropsuits',0,0,0,1,2,0.0000,1,369215,0),(368777,351121,'Krin s LEX -71 Damage Modifier','A special issue, rare module that increases the damage of all handheld weapons.',0,0.01,0,1,4,3000.0000,1,354434,0),(368880,351210,'Marduk G-I','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies.',0,0.01,0,1,8,97500.0000,1,353657,0),(368881,351210,'Madrugar G/1','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,8,195000.0000,1,368922,0),(368882,351210,'Madrugar Gv.0','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,8,682500.0000,1,368923,0),(368884,351210,'Marduk G/1','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,8,195000.0000,1,368922,0),(368885,351210,'Marduk Gv.0','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,8,682500.0000,1,368923,0),(368887,351210,'Gladius C-I','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies.',0,0.01,0,1,1,97500.0000,1,353657,0),(368888,351210,'Gunnlogi C/1','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,1,195000.0000,1,368922,0),(368889,351210,'Gunnlogi Cv.0','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,1,682500.0000,1,368923,0),(368890,351210,'Gladius C/1','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,1,195000.0000,1,368922,0),(368891,351210,'Gladius Cv.0','The Heavy Attack Vehicle (HAV) serves as an anchoring unit for many planetary engagements, fulfilling its role as a long-range and heavily armored unit. Equipped with thick and resilient armor plating and high-capacity shielding systems, it is a tenacious defensive vehicle, able to withstand persistent onslaughts from entrenched enemies. ',0,0.01,0,1,1,682500.0000,1,368923,0),(368893,351121,'Basic Shield Regulator','Reduces the length of the delay before the vehicle shield recharge begins.',0,0,0,1,1,7000.0000,1,368917,0),(368894,351121,'Enhanced Shield Regulator','Reduces the length of the delay before the vehicle shield recharge begins.',0,0,0,1,1,18760.0000,1,368917,0),(368895,351121,'Complex Shield Regulator','Reduces the length of the delay before the vehicle shield recharge begins.',0,0,0,1,1,30700.0000,1,368917,0),(368898,351121,'Basic Dispersion Stabilizer','Reduces the dispersion growth per shot of fully automatic fire, increasing accuracy.',0,0,0,1,4,3750.0000,1,368921,0),(368899,351121,'Enhanced Dispersion Stabilizer','Reduces the dispersion growth per shot of fully automatic fire, increasing accuracy.',0,0,0,1,4,10050.0000,1,368921,0),(368900,351121,'Complex Dispersion Stabilizer','Reduces the dispersion growth per shot of fully automatic fire, increasing accuracy.',0,0,0,1,4,16440.0000,1,368921,0),(368908,351064,'Shield AV - AM','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(368909,351064,'Recon - AM','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,4,6800.0000,1,NULL,0),(368910,351064,'Shield AV - CA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,1,6800.0000,1,NULL,0),(368911,351064,'Recon - CA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,1,6800.0000,1,NULL,0),(368912,351064,'Shield AV - GA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,8,6800.0000,1,NULL,0),(368913,351064,'Recon - GA','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,8,6800.0000,1,NULL,0),(368914,351064,'Shield AV - MN','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,2,0.0000,1,NULL,0),(368915,351064,'Recon - MN','The Assault dropsuit is a versatile frontline combat suit that combines excellent protection, good mobility, and sufficient hard points for mission-specific customizations.\r\r\nA hydra-membrane graft directly integrates the suit with the wearer s neurological system. While painful, this neuromorphic interface improves processing speed and reaction time while also allowing the suit to draw a limited, renewable supply of energy from the wearer s body, which in turn can be applied to reinforce shield systems or augment overall power output. Aesthetics are a vital aspect of the suit s design, because to the Amarr, aesthetics are function. Enshrined within the armor, the wearer becomes a vessel, the embodiment of God s will and an instrument of holy wrath, unmistakable, and feared, by all who look upon him. To the Amarr, the dropsuit itself is the weapon.\r\r\nAssault dropsuits are intended for standard combat operations or those in which the objectives are likely to change at a moment s notice. Its ability to carry anything from small arms and explosives to anti-vehicle munitions and deployable support gear makes it the most adaptable direct combat suit on the battlefield.',0,0.01,0,1,2,6800.0000,1,NULL,0),(368951,368726,'Medium Minmatar SKIN - Brutor','This SKIN only works on Medium Minmatar Dropsuits',0,0,0,1,2,0.0000,1,369215,0),(369091,368726,'State \'Marine Issue\' CA-M SKIN','This SKIN only applies to Medium Caldari dropsuit frames!',0,0.01,0,1,1,3000.0000,1,369225,0),(369092,368726,'Federation \'Marine Issue\' GA-M SKIN','This SKIN only applies to Medium Gallente dropsuit frames!',0,0.01,0,1,8,3000.0000,1,369227,0),(369093,368726,'Imperial \'Marine Issue\' AM-M SKIN','This SKIN only applies to Medium Amarr dropsuit frames!',0,0.01,0,1,4,3000.0000,1,369221,0),(369094,368726,'Republic \'Marine Issue\' MN-M SKIN','This SKIN only applies to Medium Minmatar dropsuit frames!',0,0.01,0,1,2,3000.0000,1,369223,0),(369102,368726,'Imperial \'Marine Issue\' AM-H SKIN','This SKIN only applies to Heavy Amarr dropsuit frames!',0,0.01,0,1,4,3000.0000,1,369221,0),(369103,368726,'State \'Marine Issue\' CA-H SKIN','This SKIN only applies to Heavy Caldari dropsuit frames!',0,0.01,0,1,1,3000.0000,1,369225,0),(369104,368726,'Federation \'Marine Issue\' GA-H SKIN','This SKIN only applies to Heavy Gallente dropsuit frames!',0,0.01,0,1,8,3000.0000,1,369227,0),(369105,368726,'Republic \'Marine Issue\' MN-H SKIN','This SKIN only applies to Heavy Minmatar dropsuit frames!',0,0.01,0,1,2,3000.0000,1,369223,0),(369106,368726,'State \'Marine Issue\' CA-L SKIN','This SKIN only applies to Light Caldari dropsuit frames!',0,0.01,0,1,1,3000.0000,1,369225,0),(369107,368726,'Federation \'Marine Issue\' GA-L SKIN','This SKIN only applies to Light Gallente dropsuit frames!',0,0.01,0,1,8,3000.0000,1,369227,0),(369108,368726,'Imperial \'Marine Issue\' AM-L SKIN','This SKIN only applies to Light Amarr dropsuit frames!',0,0.01,0,1,4,3000.0000,1,369221,0),(369109,368726,'Republic \'Marine Issue\' MN-L SKIN','This SKIN only applies to Light Minmatar dropsuit frames!',0,0.01,0,1,2,3000.0000,1,369223,0),(369115,368726,'\'Serpentis\' GA-M SKIN','This SKIN only applies to Medium Gallente dropsuit frames!',0,0.01,0,1,8,3000.0000,1,369215,0),(369158,368726,'\'Legacy\' MN-M SKIN','This SKIN only applies to Medium Minmatar dropsuit frames!',0,0.01,0,1,2,3000.0000,1,369215,0),(369159,368726,'\'Thukker\' MN-L SKIN','This SKIN only applies to Light Minmatar dropsuit frames!',0,0.01,0,1,2,3000.0000,1,369215,0),(369160,368726,'\'Angel Cartel\' MN-H SKIN','This SKIN only applies to Heavy Minmatar dropsuit frames!',0,0.01,0,1,2,3000.0000,1,369215,0),(369161,368726,'\'Duvolle\' GA-H SKIN','This SKIN only applies to Heavy Gallente dropsuit frames!',0,0.01,0,1,8,3000.0000,1,369215,0),(369162,368726,'\'Legacy\' GA-L SKIN','This SKIN only applies to Light Gallente dropsuit frames!',0,0.01,0,1,8,3000.0000,1,369215,0),(369163,368726,'\'Ishukone\' CA-M SKIN','This SKIN only applies to Medium Caldari dropsuit frames!',0,0.01,0,1,1,3000.0000,1,369215,0),(369164,368726,'\'Guristas\' CA-L SKIN','This SKIN only applies to Light Caldari dropsuit frames!',0,0.01,0,1,1,3000.0000,1,369215,0),(369165,368726,'\'Legacy\' CA-H SKIN','This SKIN only applies to Heavy Caldari dropsuit frames!',0,0.01,0,1,1,3000.0000,1,369215,0),(369166,368726,'\'Blood Raiders\' AM-H SKIN','This SKIN only applies to Heavy Amarr dropsuit frames!',0,0.01,0,1,4,3000.0000,1,369215,0),(369167,368726,'\'Kador\' AM-L SKIN','This SKIN only applies to Light Amarr dropsuit frames!',0,0.01,0,1,4,3000.0000,1,369215,0),(369168,368726,'\'Legacy\' AM-M SKIN','This SKIN only applies to Medium Amarr dropsuit frames!',0,0.01,0,1,4,3000.0000,1,369215,0),(369180,368726,'\'Leopard\' CA-M SKIN','This SKIN only applies to Medium Caldari dropsuit frames!',0,0.01,0,1,1,3000.0000,1,369215,0),(369200,368726,'\'Jungle Hunter\' CA-M SKIN','This SKIN only applies to Medium Caldari dropsuit frames!',0,0.01,0,1,1,3000.0000,1,369215,0),(369203,368726,'\'Tash Murkon\' AM-L SKIN','This SKIN only applies to Light Amarr dropsuit frames!',0,0.01,0,1,4,3000.0000,1,369215,0),(369204,368726,'\'Roden\' GA-M SKIN','This SKIN only applies to Medium Gallente dropsuit frames!',0,0.01,0,1,8,3000.0000,1,369215,0),(369205,368726,'\'Kaalakiota\' CA-H SKIN','This SKIN only applies to Heavy Caldari dropsuit frames!',0,0.01,0,1,1,3000.0000,1,369215,0),(369206,368726,'\'Brutor\' MN-L SKIN','This SKIN only applies to Light Minmatar dropsuit frames!',0,0.01,0,1,2,3000.0000,1,369215,0),(369211,351844,'\'APEX\' Cloak Field','APEX Specialized Cloak Field. No skill required.(NO SKILLS REQUIRED)',0,0.01,0,1,4,3000.0000,1,NULL,0),(369233,354641,'Active Omega-Booster NWS (7-Day)','Boosters are biomechanical grafts designed to stimulate nerve growth and neurotransmitter activity, temporarily increasing cognitive processes. The graft will degrade over time until it is completely absorbed by the body and ceases to function. Active Boosters add a percentage bonus to the number of skill points earned at the end of each battle. They do not increase the number of skill points remaining in the active skill point pool. The Omega-Booster features superior performance over standard models.',0,0,0,1,4,0.0000,1,354543,0),(369242,368726,'\'Kador\' AM-H SKIN','This SKIN only applies to Heavy Amarr dropsuit frames!',0,0.01,0,1,4,3000.0000,1,369215,0),(369243,368726,'\'Ishukone\' CA-L SKIN','This SKIN only applies to Light Caldari dropsuit frames!',0,0.01,0,1,1,3000.0000,1,369215,0),(369244,368726,'\'Duvolle\' GA-M SKIN','This SKIN only applies to Medium Gallente dropsuit frames!',0,0.01,0,1,8,3000.0000,1,369215,0),(369245,368726,'\'Thukker\' MN-H SKIN','This SKIN only applies to Heavy Minmatar dropsuit frames!',0,0.01,0,1,2,3000.0000,1,369215,0);
/*!40000 ALTER TABLE `invTypes` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2015-06-02 21:29:16
